from ..value_set import ValueSet

class AbnormalWeightLoss(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for abnormal weight loss

    **Data Element Scope:** This value set may use a model element related to Diagnosis

    **Inclusion Criteria:** Includes concepts representing abnormal weight loss

    **Exclusion Criteria:** N/A
    """

    VALUE_SET_NAME = "Abnormal Weight Loss"
    OID = "2.16.840.1.113762.1.4.1258.2"
    DEFINITION_VERSION = "20241012"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "R634",  # Abnormal weight loss
        "R64",  # Cachexia
        "Z681",  # Body mass index [BMI] 19.9 or less, adult
    }

class CoagulationDisorders(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for coagulation disorders.

    **Data Element Scope:** This value set may use a model element related to Diagnosis.

    **Inclusion Criteria:** Includes concepts for coagulation disorders.

    **Exclusion Criteria:** None
    """

    VALUE_SET_NAME = "Coagulation Disorders"
    OID = "2.16.840.1.113762.1.4.1248.23"
    DEFINITION_VERSION = "20250205"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "D473",  # Essential (hemorrhagic) thrombocythemia
        "D6102",  # Shwachman-Diamond syndrome
        "D6103",  # Fanconi anemia
        "D6109",  # Other constitutional aplastic anemia
        "D611",  # Drug-induced aplastic anemia
        "D612",  # Aplastic anemia due to other external agents
        "D613",  # Idiopathic aplastic anemia
        "D61810",  # Antineoplastic chemotherapy induced pancytopenia
        "D61811",  # Other drug-induced pancytopenia
        "D61818",  # Other pancytopenia
        "D6182",  # Myelophthisis
        "D6189",  # Other specified aplastic anemias and other bone marrow failure syndromes
        "D619",  # Aplastic anemia, unspecified
        "D65",  # Disseminated intravascular coagulation [defibrination syndrome]
        "D66",  # Hereditary factor VIII deficiency
        "D67",  # Hereditary factor IX deficiency
        "D6800",  # Von Willebrand disease, unspecified
        "D6801",  # Von Willebrand disease, type 1
        "D68020",  # Von Willebrand disease, type 2A
        "D68021",  # Von Willebrand disease, type 2B
        "D68022",  # Von Willebrand disease, type 2M
        "D68023",  # Von Willebrand disease, type 2N
        "D68029",  # Von Willebrand disease, type 2, unspecified
        "D6803",  # Von Willebrand disease, type 3
        "D6804",  # Acquired von Willebrand disease
        "D6809",  # Other von Willebrand disease
        "D681",  # Hereditary factor XI deficiency
        "D682",  # Hereditary deficiency of other clotting factors
        "D68311",  # Acquired hemophilia
        "D68312",  # Antiphospholipid antibody with hemorrhagic disorder
        "D68318",  # Other hemorrhagic disorder due to intrinsic circulating anticoagulants, antibodies, or inhibitors
        "D6832",  # Hemorrhagic disorder due to extrinsic circulating anticoagulants
        "D684",  # Acquired coagulation factor deficiency
        "D688",  # Other specified coagulation defects
        "D689",  # Coagulation defect, unspecified
        "D691",  # Qualitative platelet defects
        "D693",  # Immune thrombocytopenic purpura
        "D6941",  # Evans syndrome
        "D6942",  # Congenital and hereditary thrombocytopenia purpura
        "D6949",  # Other primary thrombocytopenia
        "D6951",  # Posttransfusion purpura
        "D6959",  # Other secondary thrombocytopenia
        "D696",  # Thrombocytopenia, unspecified
        "D698",  # Other specified hemorrhagic conditions
        "D699",  # Hemorrhagic condition, unspecified
    }

class DeliriumOrDementiaAndOtherPsychoses(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for delirium, dementia, and other psychoses

    **Data Element Scope:** This value set may use a model element related to Diagnosis

    **Inclusion Criteria:** Includes concepts that represent delirium, dementia, and other psychoses

    **Exclusion Criteria:** N/A
    """

    VALUE_SET_NAME = "Delirium or Dementia and Other Psychoses"
    OID = "2.16.840.1.113762.1.4.1248.168"
    DEFINITION_VERSION = "20221006"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "F0150",  # Vascular dementia, unspecified severity, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F0280",  # Dementia in other diseases classified elsewhere, unspecified severity, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F0390",  # Unspecified dementia, unspecified severity, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F05",  # Delirium due to known physiological condition
        "F060",  # Psychotic disorder with hallucinations due to known physiological condition
        "F062",  # Psychotic disorder with delusions due to known physiological condition
        "F10121",  # Alcohol abuse with intoxication delirium
        "F10131",  # Alcohol abuse with withdrawal delirium
        "F10150",  # Alcohol abuse with alcohol-induced psychotic disorder with delusions
        "F10151",  # Alcohol abuse with alcohol-induced psychotic disorder with hallucinations
        "F10159",  # Alcohol abuse with alcohol-induced psychotic disorder, unspecified
        "F10221",  # Alcohol dependence with intoxication delirium
        "F10231",  # Alcohol dependence with withdrawal delirium
        "F10250",  # Alcohol dependence with alcohol-induced psychotic disorder with delusions
        "F10251",  # Alcohol dependence with alcohol-induced psychotic disorder with hallucinations
        "F10259",  # Alcohol dependence with alcohol-induced psychotic disorder, unspecified
        "F1027",  # Alcohol dependence with alcohol-induced persisting dementia
        "F10921",  # Alcohol use, unspecified with intoxication delirium
        "F10931",  # Alcohol use, unspecified with withdrawal delirium
        "F10950",  # Alcohol use, unspecified with alcohol-induced psychotic disorder with delusions
        "F10951",  # Alcohol use, unspecified with alcohol-induced psychotic disorder with hallucinations
        "F10959",  # Alcohol use, unspecified with alcohol-induced psychotic disorder, unspecified
        "F1097",  # Alcohol use, unspecified with alcohol-induced persisting dementia
        "F11121",  # Opioid abuse with intoxication delirium
        "F11150",  # Opioid abuse with opioid-induced psychotic disorder with delusions
        "F11151",  # Opioid abuse with opioid-induced psychotic disorder with hallucinations
        "F11159",  # Opioid abuse with opioid-induced psychotic disorder, unspecified
        "F11221",  # Opioid dependence with intoxication delirium
        "F11250",  # Opioid dependence with opioid-induced psychotic disorder with delusions
        "F11251",  # Opioid dependence with opioid-induced psychotic disorder with hallucinations
        "F11259",  # Opioid dependence with opioid-induced psychotic disorder, unspecified
        "F11921",  # Opioid use, unspecified with intoxication delirium
        "F11950",  # Opioid use, unspecified with opioid-induced psychotic disorder with delusions
        "F11951",  # Opioid use, unspecified with opioid-induced psychotic disorder with hallucinations
        "F11959",  # Opioid use, unspecified with opioid-induced psychotic disorder, unspecified
        "F12121",  # Cannabis abuse with intoxication delirium
        "F12150",  # Cannabis abuse with psychotic disorder with delusions
        "F12151",  # Cannabis abuse with psychotic disorder with hallucinations
        "F12159",  # Cannabis abuse with psychotic disorder, unspecified
        "F12221",  # Cannabis dependence with intoxication delirium
        "F12250",  # Cannabis dependence with psychotic disorder with delusions
        "F12251",  # Cannabis dependence with psychotic disorder with hallucinations
        "F12259",  # Cannabis dependence with psychotic disorder, unspecified
        "F12921",  # Cannabis use, unspecified with intoxication delirium
        "F12950",  # Cannabis use, unspecified with psychotic disorder with delusions
        "F12951",  # Cannabis use, unspecified with psychotic disorder with hallucinations
        "F12959",  # Cannabis use, unspecified with psychotic disorder, unspecified
        "F13121",  # Sedative, hypnotic or anxiolytic abuse with intoxication delirium
        "F13131",  # Sedative, hypnotic or anxiolytic abuse with withdrawal delirium
        "F13150",  # Sedative, hypnotic or anxiolytic abuse with sedative, hypnotic or anxiolytic-induced psychotic disorder with delusions
        "F13151",  # Sedative, hypnotic or anxiolytic abuse with sedative, hypnotic or anxiolytic-induced psychotic disorder with hallucinations
        "F13159",  # Sedative, hypnotic or anxiolytic abuse with sedative, hypnotic or anxiolytic-induced psychotic disorder, unspecified
        "F13221",  # Sedative, hypnotic or anxiolytic dependence with intoxication delirium
        "F13231",  # Sedative, hypnotic or anxiolytic dependence with withdrawal delirium
        "F13250",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced psychotic disorder with delusions
        "F13251",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced psychotic disorder with hallucinations
        "F13259",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced psychotic disorder, unspecified
        "F1327",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced persisting dementia
        "F13921",  # Sedative, hypnotic or anxiolytic use, unspecified with intoxication delirium
        "F13931",  # Sedative, hypnotic or anxiolytic use, unspecified with withdrawal delirium
        "F13950",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced psychotic disorder with delusions
        "F13951",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced psychotic disorder with hallucinations
        "F13959",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced psychotic disorder, unspecified
        "F1397",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced persisting dementia
        "F14121",  # Cocaine abuse with intoxication with delirium
        "F14150",  # Cocaine abuse with cocaine-induced psychotic disorder with delusions
        "F14151",  # Cocaine abuse with cocaine-induced psychotic disorder with hallucinations
        "F14159",  # Cocaine abuse with cocaine-induced psychotic disorder, unspecified
        "F14221",  # Cocaine dependence with intoxication delirium
        "F14250",  # Cocaine dependence with cocaine-induced psychotic disorder with delusions
        "F14251",  # Cocaine dependence with cocaine-induced psychotic disorder with hallucinations
        "F14259",  # Cocaine dependence with cocaine-induced psychotic disorder, unspecified
        "F14921",  # Cocaine use, unspecified with intoxication delirium
        "F14950",  # Cocaine use, unspecified with cocaine-induced psychotic disorder with delusions
        "F14951",  # Cocaine use, unspecified with cocaine-induced psychotic disorder with hallucinations
        "F14959",  # Cocaine use, unspecified with cocaine-induced psychotic disorder, unspecified
        "F15121",  # Other stimulant abuse with intoxication delirium
        "F15150",  # Other stimulant abuse with stimulant-induced psychotic disorder with delusions
        "F15151",  # Other stimulant abuse with stimulant-induced psychotic disorder with hallucinations
        "F15159",  # Other stimulant abuse with stimulant-induced psychotic disorder, unspecified
        "F15221",  # Other stimulant dependence with intoxication delirium
        "F15250",  # Other stimulant dependence with stimulant-induced psychotic disorder with delusions
        "F15251",  # Other stimulant dependence with stimulant-induced psychotic disorder with hallucinations
        "F15259",  # Other stimulant dependence with stimulant-induced psychotic disorder, unspecified
        "F15921",  # Other stimulant use, unspecified with intoxication delirium
        "F15950",  # Other stimulant use, unspecified with stimulant-induced psychotic disorder with delusions
        "F15951",  # Other stimulant use, unspecified with stimulant-induced psychotic disorder with hallucinations
        "F15959",  # Other stimulant use, unspecified with stimulant-induced psychotic disorder, unspecified
        "F16121",  # Hallucinogen abuse with intoxication with delirium
        "F16150",  # Hallucinogen abuse with hallucinogen-induced psychotic disorder with delusions
        "F16151",  # Hallucinogen abuse with hallucinogen-induced psychotic disorder with hallucinations
        "F16159",  # Hallucinogen abuse with hallucinogen-induced psychotic disorder, unspecified
        "F16221",  # Hallucinogen dependence with intoxication with delirium
        "F16250",  # Hallucinogen dependence with hallucinogen-induced psychotic disorder with delusions
        "F16251",  # Hallucinogen dependence with hallucinogen-induced psychotic disorder with hallucinations
        "F16259",  # Hallucinogen dependence with hallucinogen-induced psychotic disorder, unspecified
        "F16921",  # Hallucinogen use, unspecified with intoxication with delirium
        "F16950",  # Hallucinogen use, unspecified with hallucinogen-induced psychotic disorder with delusions
        "F16951",  # Hallucinogen use, unspecified with hallucinogen-induced psychotic disorder with hallucinations
        "F16959",  # Hallucinogen use, unspecified with hallucinogen-induced psychotic disorder, unspecified
        "F18121",  # Inhalant abuse with intoxication delirium
        "F18150",  # Inhalant abuse with inhalant-induced psychotic disorder with delusions
        "F18151",  # Inhalant abuse with inhalant-induced psychotic disorder with hallucinations
        "F18159",  # Inhalant abuse with inhalant-induced psychotic disorder, unspecified
        "F1817",  # Inhalant abuse with inhalant-induced dementia
        "F18221",  # Inhalant dependence with intoxication delirium
        "F18250",  # Inhalant dependence with inhalant-induced psychotic disorder with delusions
        "F18251",  # Inhalant dependence with inhalant-induced psychotic disorder with hallucinations
        "F18259",  # Inhalant dependence with inhalant-induced psychotic disorder, unspecified
        "F1827",  # Inhalant dependence with inhalant-induced dementia
        "F18921",  # Inhalant use, unspecified with intoxication with delirium
        "F18950",  # Inhalant use, unspecified with inhalant-induced psychotic disorder with delusions
        "F18951",  # Inhalant use, unspecified with inhalant-induced psychotic disorder with hallucinations
        "F18959",  # Inhalant use, unspecified with inhalant-induced psychotic disorder, unspecified
        "F1897",  # Inhalant use, unspecified with inhalant-induced persisting dementia
        "F19121",  # Other psychoactive substance abuse with intoxication delirium
        "F19131",  # Other psychoactive substance abuse with withdrawal delirium
        "F19150",  # Other psychoactive substance abuse with psychoactive substance-induced psychotic disorder with delusions
        "F19151",  # Other psychoactive substance abuse with psychoactive substance-induced psychotic disorder with hallucinations
        "F19159",  # Other psychoactive substance abuse with psychoactive substance-induced psychotic disorder, unspecified
        "F1917",  # Other psychoactive substance abuse with psychoactive substance-induced persisting dementia
        "F19221",  # Other psychoactive substance dependence with intoxication delirium
        "F19231",  # Other psychoactive substance dependence with withdrawal delirium
        "F19250",  # Other psychoactive substance dependence with psychoactive substance-induced psychotic disorder with delusions
        "F19251",  # Other psychoactive substance dependence with psychoactive substance-induced psychotic disorder with hallucinations
        "F19259",  # Other psychoactive substance dependence with psychoactive substance-induced psychotic disorder, unspecified
        "F1927",  # Other psychoactive substance dependence with psychoactive substance-induced persisting dementia
        "F19921",  # Other psychoactive substance use, unspecified with intoxication with delirium
        "F19931",  # Other psychoactive substance use, unspecified with withdrawal delirium
        "F19950",  # Other psychoactive substance use, unspecified with psychoactive substance-induced psychotic disorder with delusions
        "F19951",  # Other psychoactive substance use, unspecified with psychoactive substance-induced psychotic disorder with hallucinations
        "F19959",  # Other psychoactive substance use, unspecified with psychoactive substance-induced psychotic disorder, unspecified
        "F1997",  # Other psychoactive substance use, unspecified with psychoactive substance-induced persisting dementia
        "F200",  # Paranoid schizophrenia
        "F201",  # Disorganized schizophrenia
        "F202",  # Catatonic schizophrenia
        "F203",  # Undifferentiated schizophrenia
        "F205",  # Residual schizophrenia
        "F2081",  # Schizophreniform disorder
        "F2089",  # Other schizophrenia
        "F209",  # Schizophrenia, unspecified
        "F21",  # Schizotypal disorder
        "F22",  # Delusional disorders
        "F23",  # Brief psychotic disorder
        "F24",  # Shared psychotic disorder
        "F250",  # Schizoaffective disorder, bipolar type
        "F251",  # Schizoaffective disorder, depressive type
        "F258",  # Other schizoaffective disorders
        "F259",  # Schizoaffective disorder, unspecified
        "F28",  # Other psychotic disorder not due to a substance or known physiological condition
        "F29",  # Unspecified psychosis not due to a substance or known physiological condition
        "F302",  # Manic episode, severe with psychotic symptoms
        "F312",  # Bipolar disorder, current episode manic severe with psychotic features
        "F315",  # Bipolar disorder, current episode depressed, severe, with psychotic features
        "F3164",  # Bipolar disorder, current episode mixed, severe, with psychotic features
        "F323",  # Major depressive disorder, single episode, severe with psychotic features
        "F333",  # Major depressive disorder, recurrent, severe with psychotic symptoms
        "F531",  # Puerperal psychosis
        "G300",  # Alzheimer's disease with early onset
        "G301",  # Alzheimer's disease with late onset
        "G308",  # Other Alzheimer's disease
        "G309",  # Alzheimer's disease, unspecified
        "G3101",  # Pick's disease
        "G3109",  # Other frontotemporal neurocognitive disorder
        "G3183",  # Neurocognitive disorder with Lewy bodies
        "R410",  # Disorientation, unspecified
    }

class Depression(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for depression

    **Data Element Scope:** This value set may use a model element related to Diagnosis

    **Inclusion Criteria:** Includes concepts that represent depression, including depressed episodes of bipolar disorder

    **Exclusion Criteria:** N/A
    """

    VALUE_SET_NAME = "Depression"
    OID = "2.16.840.1.113762.1.4.1248.169"
    DEFINITION_VERSION = "20221006"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "F3130",  # Bipolar disorder, current episode depressed, mild or moderate severity, unspecified
        "F3131",  # Bipolar disorder, current episode depressed, mild
        "F3132",  # Bipolar disorder, current episode depressed, moderate
        "F314",  # Bipolar disorder, current episode depressed, severe, without psychotic features
        "F320",  # Major depressive disorder, single episode, mild
        "F321",  # Major depressive disorder, single episode, moderate
        "F322",  # Major depressive disorder, single episode, severe without psychotic features
        "F324",  # Major depressive disorder, single episode, in partial remission
        "F325",  # Major depressive disorder, single episode, in full remission
        "F3281",  # Premenstrual dysphoric disorder
        "F3289",  # Other specified depressive episodes
        "F329",  # Major depressive disorder, single episode, unspecified
        "F32A",  # Depression, unspecified
        "F330",  # Major depressive disorder, recurrent, mild
        "F331",  # Major depressive disorder, recurrent, moderate
        "F332",  # Major depressive disorder, recurrent severe without psychotic features
        "F3340",  # Major depressive disorder, recurrent, in remission, unspecified
        "F3341",  # Major depressive disorder, recurrent, in partial remission
        "F3342",  # Major depressive disorder, recurrent, in full remission
        "F338",  # Other recurrent depressive disorders
        "F339",  # Major depressive disorder, recurrent, unspecified
        "F341",  # Dysthymic disorder
        "F530",  # Postpartum depression
    }

class Epilepsy(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for epilepsy

    **Data Element Scope:** This value set may use a model element related to Diagnosis

    **Inclusion Criteria:** Includes concepts that represent epilepsy

    **Exclusion Criteria:** N/A
    """

    VALUE_SET_NAME = "Epilepsy"
    OID = "2.16.840.1.113762.1.4.1248.171"
    DEFINITION_VERSION = "20250205"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "G40001",  # Localization-related (focal) (partial) idiopathic epilepsy and epileptic syndromes with seizures of localized onset, not intractable, with status epilepticus
        "G40009",  # Localization-related (focal) (partial) idiopathic epilepsy and epileptic syndromes with seizures of localized onset, not intractable, without status epilepticus
        "G40011",  # Localization-related (focal) (partial) idiopathic epilepsy and epileptic syndromes with seizures of localized onset, intractable, with status epilepticus
        "G40019",  # Localization-related (focal) (partial) idiopathic epilepsy and epileptic syndromes with seizures of localized onset, intractable, without status epilepticus
        "G40101",  # Localization-related (focal) (partial) symptomatic epilepsy and epileptic syndromes with simple partial seizures, not intractable, with status epilepticus
        "G40109",  # Localization-related (focal) (partial) symptomatic epilepsy and epileptic syndromes with simple partial seizures, not intractable, without status epilepticus
        "G40111",  # Localization-related (focal) (partial) symptomatic epilepsy and epileptic syndromes with simple partial seizures, intractable, with status epilepticus
        "G40119",  # Localization-related (focal) (partial) symptomatic epilepsy and epileptic syndromes with simple partial seizures, intractable, without status epilepticus
        "G40201",  # Localization-related (focal) (partial) symptomatic epilepsy and epileptic syndromes with complex partial seizures, not intractable, with status epilepticus
        "G40209",  # Localization-related (focal) (partial) symptomatic epilepsy and epileptic syndromes with complex partial seizures, not intractable, without status epilepticus
        "G40211",  # Localization-related (focal) (partial) symptomatic epilepsy and epileptic syndromes with complex partial seizures, intractable, with status epilepticus
        "G40219",  # Localization-related (focal) (partial) symptomatic epilepsy and epileptic syndromes with complex partial seizures, intractable, without status epilepticus
        "G40301",  # Generalized idiopathic epilepsy and epileptic syndromes, not intractable, with status epilepticus
        "G40309",  # Generalized idiopathic epilepsy and epileptic syndromes, not intractable, without status epilepticus
        "G40311",  # Generalized idiopathic epilepsy and epileptic syndromes, intractable, with status epilepticus
        "G40319",  # Generalized idiopathic epilepsy and epileptic syndromes, intractable, without status epilepticus
        "G40401",  # Other generalized epilepsy and epileptic syndromes, not intractable, with status epilepticus
        "G40409",  # Other generalized epilepsy and epileptic syndromes, not intractable, without status epilepticus
        "G40411",  # Other generalized epilepsy and epileptic syndromes, intractable, with status epilepticus
        "G40419",  # Other generalized epilepsy and epileptic syndromes, intractable, without status epilepticus
        "G4042",  # Cyclin-Dependent Kinase-Like 5 Deficiency Disorder
        "G40501",  # Epileptic seizures related to external causes, not intractable, with status epilepticus
        "G40509",  # Epileptic seizures related to external causes, not intractable, without status epilepticus
        "G40801",  # Other epilepsy, not intractable, with status epilepticus
        "G40802",  # Other epilepsy, not intractable, without status epilepticus
        "G40803",  # Other epilepsy, intractable, with status epilepticus
        "G40804",  # Other epilepsy, intractable, without status epilepticus
        "G40811",  # Lennox-Gastaut syndrome, not intractable, with status epilepticus
        "G40812",  # Lennox-Gastaut syndrome, not intractable, without status epilepticus
        "G40813",  # Lennox-Gastaut syndrome, intractable, with status epilepticus
        "G40814",  # Lennox-Gastaut syndrome, intractable, without status epilepticus
        "G40821",  # Epileptic spasms, not intractable, with status epilepticus
        "G40822",  # Epileptic spasms, not intractable, without status epilepticus
        "G40823",  # Epileptic spasms, intractable, with status epilepticus
        "G40824",  # Epileptic spasms, intractable, without status epilepticus
        "G40833",  # Dravet syndrome, intractable, with status epilepticus
        "G40834",  # Dravet syndrome, intractable, without status epilepticus
        "G40841",  # KCNQ2-related epilepsy, not intractable, with status epilepticus
        "G40842",  # KCNQ2-related epilepsy, not intractable, without status epilepticus
        "G40843",  # KCNQ2-related epilepsy, intractable, with status epilepticus
        "G40844",  # KCNQ2-related epilepsy, intractable, without status epilepticus
        "G4089",  # Other seizures
        "G40901",  # Epilepsy, unspecified, not intractable, with status epilepticus
        "G40909",  # Epilepsy, unspecified, not intractable, without status epilepticus
        "G40911",  # Epilepsy, unspecified, intractable, with status epilepticus
        "G40919",  # Epilepsy, unspecified, intractable, without status epilepticus
        "G40A01",  # Absence epileptic syndrome, not intractable, with status epilepticus
        "G40A09",  # Absence epileptic syndrome, not intractable, without status epilepticus
        "G40A11",  # Absence epileptic syndrome, intractable, with status epilepticus
        "G40A19",  # Absence epileptic syndrome, intractable, without status epilepticus
        "G40C01",  # Lafora progressive myoclonus epilepsy, not intractable, with status epilepticus
        "G40C09",  # Lafora progressive myoclonus epilepsy, not intractable, without status epilepticus
        "G40C11",  # Lafora progressive myoclonus epilepsy, intractable, with status epilepticus
        "G40C19",  # Lafora progressive myoclonus epilepsy, intractable, without status epilepticus
        "G9081",  # Serotonin syndrome
        "G9345",  # Developmental and epileptic encephalopathy
        "R561",  # Post traumatic seizures
        "R569",  # Unspecified convulsions
    }

class LeukemiaOrLymphoma(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for a diagnosis of leukemia or lymphoma

    **Data Element Scope:** This value set may use a model element related to Diagnosis

    **Inclusion Criteria:** Includes concepts that represent a diagnosis of leukemia or lymphoma in adults

    **Exclusion Criteria:** Excludes concepts that represent a diagnosis of juvenile leukemia or lymphoma
    """

    VALUE_SET_NAME = "Leukemia or Lymphoma"
    OID = "2.16.840.1.113762.1.4.1248.136"
    DEFINITION_VERSION = "20221006"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "C8100",  # Nodular lymphocyte predominant Hodgkin lymphoma, unspecified site
        "C8101",  # Nodular lymphocyte predominant Hodgkin lymphoma, lymph nodes of head, face, and neck
        "C8102",  # Nodular lymphocyte predominant Hodgkin lymphoma, intrathoracic lymph nodes
        "C8103",  # Nodular lymphocyte predominant Hodgkin lymphoma, intra-abdominal lymph nodes
        "C8104",  # Nodular lymphocyte predominant Hodgkin lymphoma, lymph nodes of axilla and upper limb
        "C8105",  # Nodular lymphocyte predominant Hodgkin lymphoma, lymph nodes of inguinal region and lower limb
        "C8106",  # Nodular lymphocyte predominant Hodgkin lymphoma, intrapelvic lymph nodes
        "C8107",  # Nodular lymphocyte predominant Hodgkin lymphoma, spleen
        "C8108",  # Nodular lymphocyte predominant Hodgkin lymphoma, lymph nodes of multiple sites
        "C8109",  # Nodular lymphocyte predominant Hodgkin lymphoma, extranodal and solid organ sites
        "C8110",  # Nodular sclerosis Hodgkin lymphoma, unspecified site
        "C8111",  # Nodular sclerosis Hodgkin lymphoma, lymph nodes of head, face, and neck
        "C8112",  # Nodular sclerosis Hodgkin lymphoma, intrathoracic lymph nodes
        "C8113",  # Nodular sclerosis Hodgkin lymphoma, intra-abdominal lymph nodes
        "C8114",  # Nodular sclerosis Hodgkin lymphoma, lymph nodes of axilla and upper limb
        "C8115",  # Nodular sclerosis Hodgkin lymphoma, lymph nodes of inguinal region and lower limb
        "C8116",  # Nodular sclerosis Hodgkin lymphoma, intrapelvic lymph nodes
        "C8117",  # Nodular sclerosis Hodgkin lymphoma, spleen
        "C8118",  # Nodular sclerosis Hodgkin lymphoma, lymph nodes of multiple sites
        "C8119",  # Nodular sclerosis Hodgkin lymphoma, extranodal and solid organ sites
        "C8120",  # Mixed cellularity Hodgkin lymphoma, unspecified site
        "C8121",  # Mixed cellularity Hodgkin lymphoma, lymph nodes of head, face, and neck
        "C8122",  # Mixed cellularity Hodgkin lymphoma, intrathoracic lymph nodes
        "C8123",  # Mixed cellularity Hodgkin lymphoma, intra-abdominal lymph nodes
        "C8124",  # Mixed cellularity Hodgkin lymphoma, lymph nodes of axilla and upper limb
        "C8125",  # Mixed cellularity Hodgkin lymphoma, lymph nodes of inguinal region and lower limb
        "C8126",  # Mixed cellularity Hodgkin lymphoma, intrapelvic lymph nodes
        "C8127",  # Mixed cellularity Hodgkin lymphoma, spleen
        "C8128",  # Mixed cellularity Hodgkin lymphoma, lymph nodes of multiple sites
        "C8129",  # Mixed cellularity Hodgkin lymphoma, extranodal and solid organ sites
        "C8130",  # Lymphocyte depleted Hodgkin lymphoma, unspecified site
        "C8131",  # Lymphocyte depleted Hodgkin lymphoma, lymph nodes of head, face, and neck
        "C8132",  # Lymphocyte depleted Hodgkin lymphoma, intrathoracic lymph nodes
        "C8133",  # Lymphocyte depleted Hodgkin lymphoma, intra-abdominal lymph nodes
        "C8134",  # Lymphocyte depleted Hodgkin lymphoma, lymph nodes of axilla and upper limb
        "C8135",  # Lymphocyte depleted Hodgkin lymphoma, lymph nodes of inguinal region and lower limb
        "C8136",  # Lymphocyte depleted Hodgkin lymphoma, intrapelvic lymph nodes
        "C8137",  # Lymphocyte depleted Hodgkin lymphoma, spleen
        "C8138",  # Lymphocyte depleted Hodgkin lymphoma, lymph nodes of multiple sites
        "C8139",  # Lymphocyte depleted Hodgkin lymphoma, extranodal and solid organ sites
        "C8140",  # Lymphocyte-rich Hodgkin lymphoma, unspecified site
        "C8141",  # Lymphocyte-rich Hodgkin lymphoma, lymph nodes of head, face, and neck
        "C8142",  # Lymphocyte-rich Hodgkin lymphoma, intrathoracic lymph nodes
        "C8143",  # Lymphocyte-rich Hodgkin lymphoma, intra-abdominal lymph nodes
        "C8144",  # Lymphocyte-rich Hodgkin lymphoma, lymph nodes of axilla and upper limb
        "C8145",  # Lymphocyte-rich Hodgkin lymphoma, lymph nodes of inguinal region and lower limb
        "C8146",  # Lymphocyte-rich Hodgkin lymphoma, intrapelvic lymph nodes
        "C8147",  # Lymphocyte-rich Hodgkin lymphoma, spleen
        "C8148",  # Lymphocyte-rich Hodgkin lymphoma, lymph nodes of multiple sites
        "C8149",  # Lymphocyte-rich Hodgkin lymphoma, extranodal and solid organ sites
        "C8170",  # Other Hodgkin lymphoma, unspecified site
        "C8171",  # Other Hodgkin lymphoma, lymph nodes of head, face, and neck
        "C8172",  # Other Hodgkin lymphoma, intrathoracic lymph nodes
        "C8173",  # Other Hodgkin lymphoma, intra-abdominal lymph nodes
        "C8174",  # Other Hodgkin lymphoma, lymph nodes of axilla and upper limb
        "C8175",  # Other Hodgkin lymphoma, lymph nodes of inguinal region and lower limb
        "C8176",  # Other Hodgkin lymphoma, intrapelvic lymph nodes
        "C8177",  # Other Hodgkin lymphoma, spleen
        "C8178",  # Other Hodgkin lymphoma, lymph nodes of multiple sites
        "C8179",  # Other Hodgkin lymphoma, extranodal and solid organ sites
        "C8190",  # Hodgkin lymphoma, unspecified, unspecified site
        "C8191",  # Hodgkin lymphoma, unspecified, lymph nodes of head, face, and neck
        "C8192",  # Hodgkin lymphoma, unspecified, intrathoracic lymph nodes
        "C8193",  # Hodgkin lymphoma, unspecified, intra-abdominal lymph nodes
        "C8194",  # Hodgkin lymphoma, unspecified, lymph nodes of axilla and upper limb
        "C8195",  # Hodgkin lymphoma, unspecified, lymph nodes of inguinal region and lower limb
        "C8196",  # Hodgkin lymphoma, unspecified, intrapelvic lymph nodes
        "C8197",  # Hodgkin lymphoma, unspecified, spleen
        "C8198",  # Hodgkin lymphoma, unspecified, lymph nodes of multiple sites
        "C8199",  # Hodgkin lymphoma, unspecified, extranodal and solid organ sites
        "C8200",  # Follicular lymphoma grade I, unspecified site
        "C8201",  # Follicular lymphoma grade I, lymph nodes of head, face, and neck
        "C8202",  # Follicular lymphoma grade I, intrathoracic lymph nodes
        "C8203",  # Follicular lymphoma grade I, intra-abdominal lymph nodes
        "C8204",  # Follicular lymphoma grade I, lymph nodes of axilla and upper limb
        "C8205",  # Follicular lymphoma grade I, lymph nodes of inguinal region and lower limb
        "C8206",  # Follicular lymphoma grade I, intrapelvic lymph nodes
        "C8207",  # Follicular lymphoma grade I, spleen
        "C8208",  # Follicular lymphoma grade I, lymph nodes of multiple sites
        "C8209",  # Follicular lymphoma grade I, extranodal and solid organ sites
        "C8210",  # Follicular lymphoma grade II, unspecified site
        "C8211",  # Follicular lymphoma grade II, lymph nodes of head, face, and neck
        "C8212",  # Follicular lymphoma grade II, intrathoracic lymph nodes
        "C8213",  # Follicular lymphoma grade II, intra-abdominal lymph nodes
        "C8214",  # Follicular lymphoma grade II, lymph nodes of axilla and upper limb
        "C8215",  # Follicular lymphoma grade II, lymph nodes of inguinal region and lower limb
        "C8216",  # Follicular lymphoma grade II, intrapelvic lymph nodes
        "C8217",  # Follicular lymphoma grade II, spleen
        "C8218",  # Follicular lymphoma grade II, lymph nodes of multiple sites
        "C8219",  # Follicular lymphoma grade II, extranodal and solid organ sites
        "C8220",  # Follicular lymphoma grade III, unspecified, unspecified site
        "C8221",  # Follicular lymphoma grade III, unspecified, lymph nodes of head, face, and neck
        "C8222",  # Follicular lymphoma grade III, unspecified, intrathoracic lymph nodes
        "C8223",  # Follicular lymphoma grade III, unspecified, intra-abdominal lymph nodes
        "C8224",  # Follicular lymphoma grade III, unspecified, lymph nodes of axilla and upper limb
        "C8225",  # Follicular lymphoma grade III, unspecified, lymph nodes of inguinal region and lower limb
        "C8226",  # Follicular lymphoma grade III, unspecified, intrapelvic lymph nodes
        "C8227",  # Follicular lymphoma grade III, unspecified, spleen
        "C8228",  # Follicular lymphoma grade III, unspecified, lymph nodes of multiple sites
        "C8229",  # Follicular lymphoma grade III, unspecified, extranodal and solid organ sites
        "C8230",  # Follicular lymphoma grade IIIa, unspecified site
        "C8231",  # Follicular lymphoma grade IIIa, lymph nodes of head, face, and neck
        "C8232",  # Follicular lymphoma grade IIIa, intrathoracic lymph nodes
        "C8233",  # Follicular lymphoma grade IIIa, intra-abdominal lymph nodes
        "C8234",  # Follicular lymphoma grade IIIa, lymph nodes of axilla and upper limb
        "C8235",  # Follicular lymphoma grade IIIa, lymph nodes of inguinal region and lower limb
        "C8236",  # Follicular lymphoma grade IIIa, intrapelvic lymph nodes
        "C8237",  # Follicular lymphoma grade IIIa, spleen
        "C8238",  # Follicular lymphoma grade IIIa, lymph nodes of multiple sites
        "C8239",  # Follicular lymphoma grade IIIa, extranodal and solid organ sites
        "C8240",  # Follicular lymphoma grade IIIb, unspecified site
        "C8241",  # Follicular lymphoma grade IIIb, lymph nodes of head, face, and neck
        "C8242",  # Follicular lymphoma grade IIIb, intrathoracic lymph nodes
        "C8243",  # Follicular lymphoma grade IIIb, intra-abdominal lymph nodes
        "C8244",  # Follicular lymphoma grade IIIb, lymph nodes of axilla and upper limb
        "C8245",  # Follicular lymphoma grade IIIb, lymph nodes of inguinal region and lower limb
        "C8246",  # Follicular lymphoma grade IIIb, intrapelvic lymph nodes
        "C8247",  # Follicular lymphoma grade IIIb, spleen
        "C8248",  # Follicular lymphoma grade IIIb, lymph nodes of multiple sites
        "C8249",  # Follicular lymphoma grade IIIb, extranodal and solid organ sites
        "C8250",  # Diffuse follicle center lymphoma, unspecified site
        "C8251",  # Diffuse follicle center lymphoma, lymph nodes of head, face, and neck
        "C8252",  # Diffuse follicle center lymphoma, intrathoracic lymph nodes
        "C8253",  # Diffuse follicle center lymphoma, intra-abdominal lymph nodes
        "C8254",  # Diffuse follicle center lymphoma, lymph nodes of axilla and upper limb
        "C8255",  # Diffuse follicle center lymphoma, lymph nodes of inguinal region and lower limb
        "C8256",  # Diffuse follicle center lymphoma, intrapelvic lymph nodes
        "C8257",  # Diffuse follicle center lymphoma, spleen
        "C8258",  # Diffuse follicle center lymphoma, lymph nodes of multiple sites
        "C8259",  # Diffuse follicle center lymphoma, extranodal and solid organ sites
        "C8260",  # Cutaneous follicle center lymphoma, unspecified site
        "C8261",  # Cutaneous follicle center lymphoma, lymph nodes of head, face, and neck
        "C8262",  # Cutaneous follicle center lymphoma, intrathoracic lymph nodes
        "C8263",  # Cutaneous follicle center lymphoma, intra-abdominal lymph nodes
        "C8264",  # Cutaneous follicle center lymphoma, lymph nodes of axilla and upper limb
        "C8265",  # Cutaneous follicle center lymphoma, lymph nodes of inguinal region and lower limb
        "C8266",  # Cutaneous follicle center lymphoma, intrapelvic lymph nodes
        "C8267",  # Cutaneous follicle center lymphoma, spleen
        "C8268",  # Cutaneous follicle center lymphoma, lymph nodes of multiple sites
        "C8269",  # Cutaneous follicle center lymphoma, extranodal and solid organ sites
        "C8280",  # Other types of follicular lymphoma, unspecified site
        "C8281",  # Other types of follicular lymphoma, lymph nodes of head, face, and neck
        "C8282",  # Other types of follicular lymphoma, intrathoracic lymph nodes
        "C8283",  # Other types of follicular lymphoma, intra-abdominal lymph nodes
        "C8284",  # Other types of follicular lymphoma, lymph nodes of axilla and upper limb
        "C8285",  # Other types of follicular lymphoma, lymph nodes of inguinal region and lower limb
        "C8286",  # Other types of follicular lymphoma, intrapelvic lymph nodes
        "C8287",  # Other types of follicular lymphoma, spleen
        "C8288",  # Other types of follicular lymphoma, lymph nodes of multiple sites
        "C8289",  # Other types of follicular lymphoma, extranodal and solid organ sites
        "C8290",  # Follicular lymphoma, unspecified, unspecified site
        "C8291",  # Follicular lymphoma, unspecified, lymph nodes of head, face, and neck
        "C8292",  # Follicular lymphoma, unspecified, intrathoracic lymph nodes
        "C8293",  # Follicular lymphoma, unspecified, intra-abdominal lymph nodes
        "C8294",  # Follicular lymphoma, unspecified, lymph nodes of axilla and upper limb
        "C8295",  # Follicular lymphoma, unspecified, lymph nodes of inguinal region and lower limb
        "C8296",  # Follicular lymphoma, unspecified, intrapelvic lymph nodes
        "C8297",  # Follicular lymphoma, unspecified, spleen
        "C8298",  # Follicular lymphoma, unspecified, lymph nodes of multiple sites
        "C8299",  # Follicular lymphoma, unspecified, extranodal and solid organ sites
        "C8300",  # Small cell B-cell lymphoma, unspecified site
        "C8301",  # Small cell B-cell lymphoma, lymph nodes of head, face, and neck
        "C8302",  # Small cell B-cell lymphoma, intrathoracic lymph nodes
        "C8303",  # Small cell B-cell lymphoma, intra-abdominal lymph nodes
        "C8304",  # Small cell B-cell lymphoma, lymph nodes of axilla and upper limb
        "C8305",  # Small cell B-cell lymphoma, lymph nodes of inguinal region and lower limb
        "C8306",  # Small cell B-cell lymphoma, intrapelvic lymph nodes
        "C8307",  # Small cell B-cell lymphoma, spleen
        "C8308",  # Small cell B-cell lymphoma, lymph nodes of multiple sites
        "C8309",  # Small cell B-cell lymphoma, extranodal and solid organ sites
        "C8310",  # Mantle cell lymphoma, unspecified site
        "C8311",  # Mantle cell lymphoma, lymph nodes of head, face, and neck
        "C8312",  # Mantle cell lymphoma, intrathoracic lymph nodes
        "C8313",  # Mantle cell lymphoma, intra-abdominal lymph nodes
        "C8314",  # Mantle cell lymphoma, lymph nodes of axilla and upper limb
        "C8315",  # Mantle cell lymphoma, lymph nodes of inguinal region and lower limb
        "C8316",  # Mantle cell lymphoma, intrapelvic lymph nodes
        "C8317",  # Mantle cell lymphoma, spleen
        "C8318",  # Mantle cell lymphoma, lymph nodes of multiple sites
        "C8319",  # Mantle cell lymphoma, extranodal and solid organ sites
        "C8330",  # Diffuse large B-cell lymphoma, unspecified site
        "C8331",  # Diffuse large B-cell lymphoma, lymph nodes of head, face, and neck
        "C8332",  # Diffuse large B-cell lymphoma, intrathoracic lymph nodes
        "C8333",  # Diffuse large B-cell lymphoma, intra-abdominal lymph nodes
        "C8334",  # Diffuse large B-cell lymphoma, lymph nodes of axilla and upper limb
        "C8335",  # Diffuse large B-cell lymphoma, lymph nodes of inguinal region and lower limb
        "C8336",  # Diffuse large B-cell lymphoma, intrapelvic lymph nodes
        "C8337",  # Diffuse large B-cell lymphoma, spleen
        "C8338",  # Diffuse large B-cell lymphoma, lymph nodes of multiple sites
        "C8339",  # Diffuse large B-cell lymphoma, extranodal and solid organ sites
        "C8350",  # Lymphoblastic (diffuse) lymphoma, unspecified site
        "C8351",  # Lymphoblastic (diffuse) lymphoma, lymph nodes of head, face, and neck
        "C8352",  # Lymphoblastic (diffuse) lymphoma, intrathoracic lymph nodes
        "C8353",  # Lymphoblastic (diffuse) lymphoma, intra-abdominal lymph nodes
        "C8354",  # Lymphoblastic (diffuse) lymphoma, lymph nodes of axilla and upper limb
        "C8355",  # Lymphoblastic (diffuse) lymphoma, lymph nodes of inguinal region and lower limb
        "C8356",  # Lymphoblastic (diffuse) lymphoma, intrapelvic lymph nodes
        "C8357",  # Lymphoblastic (diffuse) lymphoma, spleen
        "C8358",  # Lymphoblastic (diffuse) lymphoma, lymph nodes of multiple sites
        "C8359",  # Lymphoblastic (diffuse) lymphoma, extranodal and solid organ sites
        "C8370",  # Burkitt lymphoma, unspecified site
        "C8371",  # Burkitt lymphoma, lymph nodes of head, face, and neck
        "C8372",  # Burkitt lymphoma, intrathoracic lymph nodes
        "C8373",  # Burkitt lymphoma, intra-abdominal lymph nodes
        "C8374",  # Burkitt lymphoma, lymph nodes of axilla and upper limb
        "C8375",  # Burkitt lymphoma, lymph nodes of inguinal region and lower limb
        "C8376",  # Burkitt lymphoma, intrapelvic lymph nodes
        "C8377",  # Burkitt lymphoma, spleen
        "C8378",  # Burkitt lymphoma, lymph nodes of multiple sites
        "C8379",  # Burkitt lymphoma, extranodal and solid organ sites
        "C8380",  # Other non-follicular lymphoma, unspecified site
        "C8381",  # Other non-follicular lymphoma, lymph nodes of head, face, and neck
        "C8382",  # Other non-follicular lymphoma, intrathoracic lymph nodes
        "C8383",  # Other non-follicular lymphoma, intra-abdominal lymph nodes
        "C8384",  # Other non-follicular lymphoma, lymph nodes of axilla and upper limb
        "C8385",  # Other non-follicular lymphoma, lymph nodes of inguinal region and lower limb
        "C8386",  # Other non-follicular lymphoma, intrapelvic lymph nodes
        "C8387",  # Other non-follicular lymphoma, spleen
        "C8388",  # Other non-follicular lymphoma, lymph nodes of multiple sites
        "C8389",  # Other non-follicular lymphoma, extranodal and solid organ sites
        "C8390",  # Non-follicular (diffuse) lymphoma, unspecified, unspecified site
        "C8391",  # Non-follicular (diffuse) lymphoma, unspecified, lymph nodes of head, face, and neck
        "C8392",  # Non-follicular (diffuse) lymphoma, unspecified, intrathoracic lymph nodes
        "C8393",  # Non-follicular (diffuse) lymphoma, unspecified, intra-abdominal lymph nodes
        "C8394",  # Non-follicular (diffuse) lymphoma, unspecified, lymph nodes of axilla and upper limb
        "C8395",  # Non-follicular (diffuse) lymphoma, unspecified, lymph nodes of inguinal region and lower limb
        "C8396",  # Non-follicular (diffuse) lymphoma, unspecified, intrapelvic lymph nodes
        "C8397",  # Non-follicular (diffuse) lymphoma, unspecified, spleen
        "C8398",  # Non-follicular (diffuse) lymphoma, unspecified, lymph nodes of multiple sites
        "C8399",  # Non-follicular (diffuse) lymphoma, unspecified, extranodal and solid organ sites
        "C8400",  # Mycosis fungoides, unspecified site
        "C8401",  # Mycosis fungoides, lymph nodes of head, face, and neck
        "C8402",  # Mycosis fungoides, intrathoracic lymph nodes
        "C8403",  # Mycosis fungoides, intra-abdominal lymph nodes
        "C8404",  # Mycosis fungoides, lymph nodes of axilla and upper limb
        "C8405",  # Mycosis fungoides, lymph nodes of inguinal region and lower limb
        "C8406",  # Mycosis fungoides, intrapelvic lymph nodes
        "C8407",  # Mycosis fungoides, spleen
        "C8408",  # Mycosis fungoides, lymph nodes of multiple sites
        "C8409",  # Mycosis fungoides, extranodal and solid organ sites
        "C8410",  # Sezary disease, unspecified site
        "C8411",  # Sezary disease, lymph nodes of head, face, and neck
        "C8412",  # Sezary disease, intrathoracic lymph nodes
        "C8413",  # Sezary disease, intra-abdominal lymph nodes
        "C8414",  # Sezary disease, lymph nodes of axilla and upper limb
        "C8415",  # Sezary disease, lymph nodes of inguinal region and lower limb
        "C8416",  # Sezary disease, intrapelvic lymph nodes
        "C8417",  # Sezary disease, spleen
        "C8418",  # Sezary disease, lymph nodes of multiple sites
        "C8419",  # Sezary disease, extranodal and solid organ sites
        "C8440",  # Peripheral T-cell lymphoma, not elsewhere classified, unspecified site
        "C8441",  # Peripheral T-cell lymphoma, not elsewhere classified, lymph nodes of head, face, and neck
        "C8442",  # Peripheral T-cell lymphoma, not elsewhere classified, intrathoracic lymph nodes
        "C8443",  # Peripheral T-cell lymphoma, not elsewhere classified, intra-abdominal lymph nodes
        "C8444",  # Peripheral T-cell lymphoma, not elsewhere classified, lymph nodes of axilla and upper limb
        "C8445",  # Peripheral T-cell lymphoma, not elsewhere classified, lymph nodes of inguinal region and lower limb
        "C8446",  # Peripheral T-cell lymphoma, not elsewhere classified, intrapelvic lymph nodes
        "C8447",  # Peripheral T-cell lymphoma, not elsewhere classified, spleen
        "C8448",  # Peripheral T-cell lymphoma, not elsewhere classified, lymph nodes of multiple sites
        "C8449",  # Peripheral T-cell lymphoma, not elsewhere classified, extranodal and solid organ sites
        "C8460",  # Anaplastic large cell lymphoma, ALK-positive, unspecified site
        "C8461",  # Anaplastic large cell lymphoma, ALK-positive, lymph nodes of head, face, and neck
        "C8462",  # Anaplastic large cell lymphoma, ALK-positive, intrathoracic lymph nodes
        "C8463",  # Anaplastic large cell lymphoma, ALK-positive, intra-abdominal lymph nodes
        "C8464",  # Anaplastic large cell lymphoma, ALK-positive, lymph nodes of axilla and upper limb
        "C8465",  # Anaplastic large cell lymphoma, ALK-positive, lymph nodes of inguinal region and lower limb
        "C8466",  # Anaplastic large cell lymphoma, ALK-positive, intrapelvic lymph nodes
        "C8467",  # Anaplastic large cell lymphoma, ALK-positive, spleen
        "C8468",  # Anaplastic large cell lymphoma, ALK-positive, lymph nodes of multiple sites
        "C8469",  # Anaplastic large cell lymphoma, ALK-positive, extranodal and solid organ sites
        "C8470",  # Anaplastic large cell lymphoma, ALK-negative, unspecified site
        "C8471",  # Anaplastic large cell lymphoma, ALK-negative, lymph nodes of head, face, and neck
        "C8472",  # Anaplastic large cell lymphoma, ALK-negative, intrathoracic lymph nodes
        "C8473",  # Anaplastic large cell lymphoma, ALK-negative, intra-abdominal lymph nodes
        "C8474",  # Anaplastic large cell lymphoma, ALK-negative, lymph nodes of axilla and upper limb
        "C8475",  # Anaplastic large cell lymphoma, ALK-negative, lymph nodes of inguinal region and lower limb
        "C8476",  # Anaplastic large cell lymphoma, ALK-negative, intrapelvic lymph nodes
        "C8477",  # Anaplastic large cell lymphoma, ALK-negative, spleen
        "C8478",  # Anaplastic large cell lymphoma, ALK-negative, lymph nodes of multiple sites
        "C8479",  # Anaplastic large cell lymphoma, ALK-negative, extranodal and solid organ sites
        "C847A",  # Anaplastic large cell lymphoma, ALK-negative, breast
        "C8490",  # Mature T/NK-cell lymphomas, unspecified, unspecified site
        "C8491",  # Mature T/NK-cell lymphomas, unspecified, lymph nodes of head, face, and neck
        "C8492",  # Mature T/NK-cell lymphomas, unspecified, intrathoracic lymph nodes
        "C8493",  # Mature T/NK-cell lymphomas, unspecified, intra-abdominal lymph nodes
        "C8494",  # Mature T/NK-cell lymphomas, unspecified, lymph nodes of axilla and upper limb
        "C8495",  # Mature T/NK-cell lymphomas, unspecified, lymph nodes of inguinal region and lower limb
        "C8496",  # Mature T/NK-cell lymphomas, unspecified, intrapelvic lymph nodes
        "C8497",  # Mature T/NK-cell lymphomas, unspecified, spleen
        "C8498",  # Mature T/NK-cell lymphomas, unspecified, lymph nodes of multiple sites
        "C8499",  # Mature T/NK-cell lymphomas, unspecified, extranodal and solid organ sites
        "C84A0",  # Cutaneous T-cell lymphoma, unspecified, unspecified site
        "C84A1",  # Cutaneous T-cell lymphoma, unspecified lymph nodes of head, face, and neck
        "C84A2",  # Cutaneous T-cell lymphoma, unspecified, intrathoracic lymph nodes
        "C84A3",  # Cutaneous T-cell lymphoma, unspecified, intra-abdominal lymph nodes
        "C84A4",  # Cutaneous T-cell lymphoma, unspecified, lymph nodes of axilla and upper limb
        "C84A5",  # Cutaneous T-cell lymphoma, unspecified, lymph nodes of inguinal region and lower limb
        "C84A6",  # Cutaneous T-cell lymphoma, unspecified, intrapelvic lymph nodes
        "C84A7",  # Cutaneous T-cell lymphoma, unspecified, spleen
        "C84A8",  # Cutaneous T-cell lymphoma, unspecified, lymph nodes of multiple sites
        "C84A9",  # Cutaneous T-cell lymphoma, unspecified, extranodal and solid organ sites
        "C84Z0",  # Other mature T/NK-cell lymphomas, unspecified site
        "C84Z1",  # Other mature T/NK-cell lymphomas, lymph nodes of head, face, and neck
        "C84Z2",  # Other mature T/NK-cell lymphomas, intrathoracic lymph nodes
        "C84Z3",  # Other mature T/NK-cell lymphomas, intra-abdominal lymph nodes
        "C84Z4",  # Other mature T/NK-cell lymphomas, lymph nodes of axilla and upper limb
        "C84Z5",  # Other mature T/NK-cell lymphomas, lymph nodes of inguinal region and lower limb
        "C84Z6",  # Other mature T/NK-cell lymphomas, intrapelvic lymph nodes
        "C84Z7",  # Other mature T/NK-cell lymphomas, spleen
        "C84Z8",  # Other mature T/NK-cell lymphomas, lymph nodes of multiple sites
        "C84Z9",  # Other mature T/NK-cell lymphomas, extranodal and solid organ sites
        "C8510",  # Unspecified B-cell lymphoma, unspecified site
        "C8511",  # Unspecified B-cell lymphoma, lymph nodes of head, face, and neck
        "C8512",  # Unspecified B-cell lymphoma, intrathoracic lymph nodes
        "C8513",  # Unspecified B-cell lymphoma, intra-abdominal lymph nodes
        "C8514",  # Unspecified B-cell lymphoma, lymph nodes of axilla and upper limb
        "C8515",  # Unspecified B-cell lymphoma, lymph nodes of inguinal region and lower limb
        "C8516",  # Unspecified B-cell lymphoma, intrapelvic lymph nodes
        "C8517",  # Unspecified B-cell lymphoma, spleen
        "C8518",  # Unspecified B-cell lymphoma, lymph nodes of multiple sites
        "C8519",  # Unspecified B-cell lymphoma, extranodal and solid organ sites
        "C8520",  # Mediastinal (thymic) large B-cell lymphoma, unspecified site
        "C8521",  # Mediastinal (thymic) large B-cell lymphoma, lymph nodes of head, face, and neck
        "C8522",  # Mediastinal (thymic) large B-cell lymphoma, intrathoracic lymph nodes
        "C8523",  # Mediastinal (thymic) large B-cell lymphoma, intra-abdominal lymph nodes
        "C8524",  # Mediastinal (thymic) large B-cell lymphoma, lymph nodes of axilla and upper limb
        "C8525",  # Mediastinal (thymic) large B-cell lymphoma, lymph nodes of inguinal region and lower limb
        "C8526",  # Mediastinal (thymic) large B-cell lymphoma, intrapelvic lymph nodes
        "C8527",  # Mediastinal (thymic) large B-cell lymphoma, spleen
        "C8528",  # Mediastinal (thymic) large B-cell lymphoma, lymph nodes of multiple sites
        "C8529",  # Mediastinal (thymic) large B-cell lymphoma, extranodal and solid organ sites
        "C8580",  # Other specified types of non-Hodgkin lymphoma, unspecified site
        "C8581",  # Other specified types of non-Hodgkin lymphoma, lymph nodes of head, face, and neck
        "C8582",  # Other specified types of non-Hodgkin lymphoma, intrathoracic lymph nodes
        "C8583",  # Other specified types of non-Hodgkin lymphoma, intra-abdominal lymph nodes
        "C8584",  # Other specified types of non-Hodgkin lymphoma, lymph nodes of axilla and upper limb
        "C8585",  # Other specified types of non-Hodgkin lymphoma, lymph nodes of inguinal region and lower limb
        "C8586",  # Other specified types of non-Hodgkin lymphoma, intrapelvic lymph nodes
        "C8587",  # Other specified types of non-Hodgkin lymphoma, spleen
        "C8588",  # Other specified types of non-Hodgkin lymphoma, lymph nodes of multiple sites
        "C8589",  # Other specified types of non-Hodgkin lymphoma, extranodal and solid organ sites
        "C8590",  # Non-Hodgkin lymphoma, unspecified, unspecified site
        "C8591",  # Non-Hodgkin lymphoma, unspecified, lymph nodes of head, face, and neck
        "C8592",  # Non-Hodgkin lymphoma, unspecified, intrathoracic lymph nodes
        "C8593",  # Non-Hodgkin lymphoma, unspecified, intra-abdominal lymph nodes
        "C8594",  # Non-Hodgkin lymphoma, unspecified, lymph nodes of axilla and upper limb
        "C8595",  # Non-Hodgkin lymphoma, unspecified, lymph nodes of inguinal region and lower limb
        "C8596",  # Non-Hodgkin lymphoma, unspecified, intrapelvic lymph nodes
        "C8597",  # Non-Hodgkin lymphoma, unspecified, spleen
        "C8598",  # Non-Hodgkin lymphoma, unspecified, lymph nodes of multiple sites
        "C8599",  # Non-Hodgkin lymphoma, unspecified, extranodal and solid organ sites
        "C860",  # Extranodal NK/T-cell lymphoma, nasal type
        "C861",  # Hepatosplenic T-cell lymphoma
        "C862",  # Enteropathy-type (intestinal) T-cell lymphoma
        "C863",  # Subcutaneous panniculitis-like T-cell lymphoma
        "C864",  # Blastic NK-cell lymphoma
        "C865",  # Angioimmunoblastic T-cell lymphoma
        "C866",  # Primary cutaneous CD30-positive T-cell proliferations
        "C880",  # Waldenstrom macroglobulinemia
        "C882",  # Heavy chain disease
        "C883",  # Immunoproliferative small intestinal disease
        "C884",  # Extranodal marginal zone B-cell lymphoma of mucosa-associated lymphoid tissue [MALT-lymphoma]
        "C888",  # Other malignant immunoproliferative diseases
        "C889",  # Malignant immunoproliferative disease, unspecified
        "C9000",  # Multiple myeloma not having achieved remission
        "C9001",  # Multiple myeloma in remission
        "C9002",  # Multiple myeloma in relapse
        "C9010",  # Plasma cell leukemia not having achieved remission
        "C9011",  # Plasma cell leukemia in remission
        "C9012",  # Plasma cell leukemia in relapse
        "C9020",  # Extramedullary plasmacytoma not having achieved remission
        "C9021",  # Extramedullary plasmacytoma in remission
        "C9022",  # Extramedullary plasmacytoma in relapse
        "C9030",  # Solitary plasmacytoma not having achieved remission
        "C9031",  # Solitary plasmacytoma in remission
        "C9032",  # Solitary plasmacytoma in relapse
        "C9100",  # Acute lymphoblastic leukemia not having achieved remission
        "C9101",  # Acute lymphoblastic leukemia, in remission
        "C9102",  # Acute lymphoblastic leukemia, in relapse
        "C9110",  # Chronic lymphocytic leukemia of B-cell type not having achieved remission
        "C9111",  # Chronic lymphocytic leukemia of B-cell type in remission
        "C9112",  # Chronic lymphocytic leukemia of B-cell type in relapse
        "C9130",  # Prolymphocytic leukemia of B-cell type not having achieved remission
        "C9131",  # Prolymphocytic leukemia of B-cell type, in remission
        "C9132",  # Prolymphocytic leukemia of B-cell type, in relapse
        "C9140",  # Hairy cell leukemia not having achieved remission
        "C9141",  # Hairy cell leukemia, in remission
        "C9142",  # Hairy cell leukemia, in relapse
        "C9150",  # Adult T-cell lymphoma/leukemia (HTLV-1-associated) not having achieved remission
        "C9151",  # Adult T-cell lymphoma/leukemia (HTLV-1-associated), in remission
        "C9152",  # Adult T-cell lymphoma/leukemia (HTLV-1-associated), in relapse
        "C9160",  # Prolymphocytic leukemia of T-cell type not having achieved remission
        "C9161",  # Prolymphocytic leukemia of T-cell type, in remission
        "C9162",  # Prolymphocytic leukemia of T-cell type, in relapse
        "C9190",  # Lymphoid leukemia, unspecified not having achieved remission
        "C9191",  # Lymphoid leukemia, unspecified, in remission
        "C9192",  # Lymphoid leukemia, unspecified, in relapse
        "C91A0",  # Mature B-cell leukemia Burkitt-type not having achieved remission
        "C91A1",  # Mature B-cell leukemia Burkitt-type, in remission
        "C91A2",  # Mature B-cell leukemia Burkitt-type, in relapse
        "C91Z0",  # Other lymphoid leukemia not having achieved remission
        "C91Z1",  # Other lymphoid leukemia, in remission
        "C91Z2",  # Other lymphoid leukemia, in relapse
        "C9200",  # Acute myeloblastic leukemia, not having achieved remission
        "C9201",  # Acute myeloblastic leukemia, in remission
        "C9202",  # Acute myeloblastic leukemia, in relapse
        "C9210",  # Chronic myeloid leukemia, BCR/ABL-positive, not having achieved remission
        "C9211",  # Chronic myeloid leukemia, BCR/ABL-positive, in remission
        "C9212",  # Chronic myeloid leukemia, BCR/ABL-positive, in relapse
        "C9220",  # Atypical chronic myeloid leukemia, BCR/ABL-negative, not having achieved remission
        "C9221",  # Atypical chronic myeloid leukemia, BCR/ABL-negative, in remission
        "C9222",  # Atypical chronic myeloid leukemia, BCR/ABL-negative, in relapse
        "C9230",  # Myeloid sarcoma, not having achieved remission
        "C9231",  # Myeloid sarcoma, in remission
        "C9232",  # Myeloid sarcoma, in relapse
        "C9240",  # Acute promyelocytic leukemia, not having achieved remission
        "C9241",  # Acute promyelocytic leukemia, in remission
        "C9242",  # Acute promyelocytic leukemia, in relapse
        "C9250",  # Acute myelomonocytic leukemia, not having achieved remission
        "C9251",  # Acute myelomonocytic leukemia, in remission
        "C9252",  # Acute myelomonocytic leukemia, in relapse
        "C9260",  # Acute myeloid leukemia with 11q23-abnormality not having achieved remission
        "C9261",  # Acute myeloid leukemia with 11q23-abnormality in remission
        "C9262",  # Acute myeloid leukemia with 11q23-abnormality in relapse
        "C9290",  # Myeloid leukemia, unspecified, not having achieved remission
        "C9291",  # Myeloid leukemia, unspecified in remission
        "C9292",  # Myeloid leukemia, unspecified in relapse
        "C92A0",  # Acute myeloid leukemia with multilineage dysplasia, not having achieved remission
        "C92A1",  # Acute myeloid leukemia with multilineage dysplasia, in remission
        "C92A2",  # Acute myeloid leukemia with multilineage dysplasia, in relapse
        "C92Z0",  # Other myeloid leukemia not having achieved remission
        "C92Z1",  # Other myeloid leukemia, in remission
        "C92Z2",  # Other myeloid leukemia, in relapse
        "C9300",  # Acute monoblastic/monocytic leukemia, not having achieved remission
        "C9301",  # Acute monoblastic/monocytic leukemia, in remission
        "C9302",  # Acute monoblastic/monocytic leukemia, in relapse
        "C9310",  # Chronic myelomonocytic leukemia not having achieved remission
        "C9311",  # Chronic myelomonocytic leukemia, in remission
        "C9312",  # Chronic myelomonocytic leukemia, in relapse
        "C9390",  # Monocytic leukemia, unspecified, not having achieved remission
        "C9391",  # Monocytic leukemia, unspecified in remission
        "C9392",  # Monocytic leukemia, unspecified in relapse
        "C93Z0",  # Other monocytic leukemia, not having achieved remission
        "C93Z1",  # Other monocytic leukemia, in remission
        "C93Z2",  # Other monocytic leukemia, in relapse
        "C9400",  # Acute erythroid leukemia, not having achieved remission
        "C9401",  # Acute erythroid leukemia, in remission
        "C9402",  # Acute erythroid leukemia, in relapse
        "C9420",  # Acute megakaryoblastic leukemia not having achieved remission
        "C9421",  # Acute megakaryoblastic leukemia, in remission
        "C9422",  # Acute megakaryoblastic leukemia, in relapse
        "C9430",  # Mast cell leukemia not having achieved remission
        "C9431",  # Mast cell leukemia, in remission
        "C9432",  # Mast cell leukemia, in relapse
        "C9440",  # Acute panmyelosis with myelofibrosis not having achieved remission
        "C9441",  # Acute panmyelosis with myelofibrosis, in remission
        "C9442",  # Acute panmyelosis with myelofibrosis, in relapse
        "C946",  # Myelodysplastic disease, not elsewhere classified
        "C9480",  # Other specified leukemias not having achieved remission
        "C9481",  # Other specified leukemias, in remission
        "C9482",  # Other specified leukemias, in relapse
        "C9500",  # Acute leukemia of unspecified cell type not having achieved remission
        "C9501",  # Acute leukemia of unspecified cell type, in remission
        "C9502",  # Acute leukemia of unspecified cell type, in relapse
        "C9510",  # Chronic leukemia of unspecified cell type not having achieved remission
        "C9511",  # Chronic leukemia of unspecified cell type, in remission
        "C9512",  # Chronic leukemia of unspecified cell type, in relapse
        "C9590",  # Leukemia, unspecified not having achieved remission
        "C9591",  # Leukemia, unspecified, in remission
        "C9592",  # Leukemia, unspecified, in relapse
        "C960",  # Multifocal and multisystemic (disseminated) Langerhans-cell histiocytosis
        "C9620",  # Malignant mast cell neoplasm, unspecified
        "C9621",  # Aggressive systemic mastocytosis
        "C9622",  # Mast cell sarcoma
        "C9629",  # Other malignant mast cell neoplasm
        "C964",  # Sarcoma of dendritic cells (accessory cells)
        "C969",  # Malignant neoplasm of lymphoid, hematopoietic and related tissue, unspecified
        "C96A",  # Histiocytic sarcoma
        "C96Z",  # Other specified malignant neoplasms of lymphoid, hematopoietic and related tissue
        "D47Z9",  # Other specified neoplasms of uncertain behavior of lymphoid, hematopoietic and related tissue
    }

class LiverDiseaseModerateToSevere(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for a diagnosis of moderate to severe liver disease

    **Data Element Scope:** This value set may use a model element related to Diagnosis

    **Inclusion Criteria:** Includes concepts that represent a diagnosis of moderate to severe liver disease such as viral hepatitis with hepatic coma, esophageal and gastric varices, hepatic failure, and portal hypertension

    **Exclusion Criteria:** Excludes concepts that represent a diagnosis of liver disease such as liver inflammation, simple hepatitis, and liver cancer
    """

    VALUE_SET_NAME = "Liver Disease Moderate to Severe"
    OID = "2.16.840.1.113762.1.4.1248.137"
    DEFINITION_VERSION = "20221006"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "B190",  # Unspecified viral hepatitis with hepatic coma
        "B1911",  # Unspecified viral hepatitis B with hepatic coma
        "B1921",  # Unspecified viral hepatitis C with hepatic coma
        "I8500",  # Esophageal varices without bleeding
        "I8501",  # Esophageal varices with bleeding
        "I8510",  # Secondary esophageal varices without bleeding
        "I8511",  # Secondary esophageal varices with bleeding
        "I864",  # Gastric varices
        "K7040",  # Alcoholic hepatic failure without coma
        "K7041",  # Alcoholic hepatic failure with coma
        "K7210",  # Chronic hepatic failure without coma
        "K7211",  # Chronic hepatic failure with coma
        "K7290",  # Hepatic failure, unspecified without coma
        "K7291",  # Hepatic failure, unspecified with coma
        "K765",  # Hepatic veno-occlusive disease
        "K766",  # Portal hypertension
        "K767",  # Hepatorenal syndrome
        "K9182",  # Postprocedural hepatic failure
    }

class MajorInjuries(ValueSet):
    """
    **Clinical Focus:** The purpose of this ICD-10-CM value set is to identify major injuries or death that could occur as a result of a fall within a hospital setting.

    **Data Element Scope:** This value set may use a model element related to Diagnosis.

    **Inclusion Criteria:** Includes ICD-10-CM concepts that represent major injuries that could occur as a result of a fall within a hospital setting, such as large bone fractures, closed head injuries, and internal bleeding

    **Exclusion Criteria:** Excludes moderate injuries (such as lacerations, open wounds, dislocations, sprains, and muscle strains.) Excludes minor injuries (such as abrasions, small bone fractures.) Excludes injuries as a result of a fall that could not occur within a hospital setting
    """

    VALUE_SET_NAME = "Major Injuries"
    OID = "2.16.840.1.113762.1.4.1147.120"
    DEFINITION_VERSION = "20240112"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "M8000XA",  # Age-related osteoporosis with current pathological fracture, unspecified site, initial encounter for fracture
        "M80011A",  # Age-related osteoporosis with current pathological fracture, right shoulder, initial encounter for fracture
        "M80012A",  # Age-related osteoporosis with current pathological fracture, left shoulder, initial encounter for fracture
        "M80019A",  # Age-related osteoporosis with current pathological fracture, unspecified shoulder, initial encounter for fracture
        "M80021A",  # Age-related osteoporosis with current pathological fracture, right humerus, initial encounter for fracture
        "M80022A",  # Age-related osteoporosis with current pathological fracture, left humerus, initial encounter for fracture
        "M80029A",  # Age-related osteoporosis with current pathological fracture, unspecified humerus, initial encounter for fracture
        "M80031A",  # Age-related osteoporosis with current pathological fracture, right forearm, initial encounter for fracture
        "M80032A",  # Age-related osteoporosis with current pathological fracture, left forearm, initial encounter for fracture
        "M80039A",  # Age-related osteoporosis with current pathological fracture, unspecified forearm, initial encounter for fracture
        "M80041A",  # Age-related osteoporosis with current pathological fracture, right hand, initial encounter for fracture
        "M80042A",  # Age-related osteoporosis with current pathological fracture, left hand, initial encounter for fracture
        "M80049A",  # Age-related osteoporosis with current pathological fracture, unspecified hand, initial encounter for fracture
        "M80051A",  # Age-related osteoporosis with current pathological fracture, right femur, initial encounter for fracture
        "M80052A",  # Age-related osteoporosis with current pathological fracture, left femur, initial encounter for fracture
        "M80059A",  # Age-related osteoporosis with current pathological fracture, unspecified femur, initial encounter for fracture
        "M80061A",  # Age-related osteoporosis with current pathological fracture, right lower leg, initial encounter for fracture
        "M80062A",  # Age-related osteoporosis with current pathological fracture, left lower leg, initial encounter for fracture
        "M80069A",  # Age-related osteoporosis with current pathological fracture, unspecified lower leg, initial encounter for fracture
        "M80071A",  # Age-related osteoporosis with current pathological fracture, right ankle and foot, initial encounter for fracture
        "M80072A",  # Age-related osteoporosis with current pathological fracture, left ankle and foot, initial encounter for fracture
        "M80079A",  # Age-related osteoporosis with current pathological fracture, unspecified ankle and foot, initial encounter for fracture
        "M8008XA",  # Age-related osteoporosis with current pathological fracture, vertebra(e), initial encounter for fracture
        "M800AXA",  # Age-related osteoporosis with current pathological fracture, other site, initial encounter for fracture
        "M800B1A",  # Age-related osteoporosis with current pathological fracture, right pelvis, initial encounter for fracture
        "M800B2A",  # Age-related osteoporosis with current pathological fracture, left pelvis, initial encounter for fracture
        "M800B9A",  # Age-related osteoporosis with current pathological fracture, unspecified pelvis, initial encounter for fracture
        "M8080XA",  # Other osteoporosis with current pathological fracture, unspecified site, initial encounter for fracture
        "M80811A",  # Other osteoporosis with current pathological fracture, right shoulder, initial encounter for fracture
        "M80812A",  # Other osteoporosis with current pathological fracture, left shoulder, initial encounter for fracture
        "M80819A",  # Other osteoporosis with current pathological fracture, unspecified shoulder, initial encounter for fracture
        "M80821A",  # Other osteoporosis with current pathological fracture, right humerus, initial encounter for fracture
        "M80822A",  # Other osteoporosis with current pathological fracture, left humerus, initial encounter for fracture
        "M80829A",  # Other osteoporosis with current pathological fracture, unspecified humerus, initial encounter for fracture
        "M80831A",  # Other osteoporosis with current pathological fracture, right forearm, initial encounter for fracture
        "M80832A",  # Other osteoporosis with current pathological fracture, left forearm, initial encounter for fracture
        "M80839A",  # Other osteoporosis with current pathological fracture, unspecified forearm, initial encounter for fracture
        "M80841A",  # Other osteoporosis with current pathological fracture, right hand, initial encounter for fracture
        "M80842A",  # Other osteoporosis with current pathological fracture, left hand, initial encounter for fracture
        "M80849A",  # Other osteoporosis with current pathological fracture, unspecified hand, initial encounter for fracture
        "M80851A",  # Other osteoporosis with current pathological fracture, right femur, initial encounter for fracture
        "M80852A",  # Other osteoporosis with current pathological fracture, left femur, initial encounter for fracture
        "M80859A",  # Other osteoporosis with current pathological fracture, unspecified femur, initial encounter for fracture
        "M80861A",  # Other osteoporosis with current pathological fracture, right lower leg, initial encounter for fracture
        "M80862A",  # Other osteoporosis with current pathological fracture, left lower leg, initial encounter for fracture
        "M80869A",  # Other osteoporosis with current pathological fracture, unspecified lower leg, initial encounter for fracture
        "M80871A",  # Other osteoporosis with current pathological fracture, right ankle and foot, initial encounter for fracture
        "M80872A",  # Other osteoporosis with current pathological fracture, left ankle and foot, initial encounter for fracture
        "M80879A",  # Other osteoporosis with current pathological fracture, unspecified ankle and foot, initial encounter for fracture
        "M8088XA",  # Other osteoporosis with current pathological fracture, vertebra(e), initial encounter for fracture
        "M808AXA",  # Other osteoporosis with current pathological fracture, other site, initial encounter for fracture
        "M808B1A",  # Other osteoporosis with current pathological fracture, right pelvis, initial encounter for fracture
        "M808B2A",  # Other osteoporosis with current pathological fracture, left pelvis, initial encounter for fracture
        "M808B9A",  # Other osteoporosis with current pathological fracture, unspecified pelvis, initial encounter for fracture
        "S020XXA",  # Fracture of vault of skull, initial encounter for closed fracture
        "S020XXB",  # Fracture of vault of skull, initial encounter for open fracture
        "S02101A",  # Fracture of base of skull, right side, initial encounter for closed fracture
        "S02101B",  # Fracture of base of skull, right side, initial encounter for open fracture
        "S02102A",  # Fracture of base of skull, left side, initial encounter for closed fracture
        "S02102B",  # Fracture of base of skull, left side, initial encounter for open fracture
        "S02109A",  # Fracture of base of skull, unspecified side, initial encounter for closed fracture
        "S02109B",  # Fracture of base of skull, unspecified side, initial encounter for open fracture
        "S02110A",  # Type I occipital condyle fracture, unspecified side, initial encounter for closed fracture
        "S02110B",  # Type I occipital condyle fracture, unspecified side, initial encounter for open fracture
        "S02111A",  # Type II occipital condyle fracture, unspecified side, initial encounter for closed fracture
        "S02111B",  # Type II occipital condyle fracture, unspecified side, initial encounter for open fracture
        "S02112A",  # Type III occipital condyle fracture, unspecified side, initial encounter for closed fracture
        "S02112B",  # Type III occipital condyle fracture, unspecified side, initial encounter for open fracture
        "S02113A",  # Unspecified occipital condyle fracture, initial encounter for closed fracture
        "S02113B",  # Unspecified occipital condyle fracture, initial encounter for open fracture
        "S02118A",  # Other fracture of occiput, unspecified side, initial encounter for closed fracture
        "S02118B",  # Other fracture of occiput, unspecified side, initial encounter for open fracture
        "S02119A",  # Unspecified fracture of occiput, initial encounter for closed fracture
        "S02119B",  # Unspecified fracture of occiput, initial encounter for open fracture
        "S0211AA",  # Type I occipital condyle fracture, right side, initial encounter for closed fracture
        "S0211AB",  # Type I occipital condyle fracture, right side, initial encounter for open fracture
        "S0211BA",  # Type I occipital condyle fracture, left side, initial encounter for closed fracture
        "S0211BB",  # Type I occipital condyle fracture, left side, initial encounter for open fracture
        "S0211CA",  # Type II occipital condyle fracture, right side, initial encounter for closed fracture
        "S0211CB",  # Type II occipital condyle fracture, right side, initial encounter for open fracture
        "S0211DA",  # Type II occipital condyle fracture, left side, initial encounter for closed fracture
        "S0211DB",  # Type II occipital condyle fracture, left side, initial encounter for open fracture
        "S0211EA",  # Type III occipital condyle fracture, right side, initial encounter for closed fracture
        "S0211EB",  # Type III occipital condyle fracture, right side, initial encounter for open fracture
        "S0211FA",  # Type III occipital condyle fracture, left side, initial encounter for closed fracture
        "S0211FB",  # Type III occipital condyle fracture, left side, initial encounter for open fracture
        "S0211GA",  # Other fracture of occiput, right side, initial encounter for closed fracture
        "S0211GB",  # Other fracture of occiput, right side, initial encounter for open fracture
        "S0211HA",  # Other fracture of occiput, left side, initial encounter for closed fracture
        "S0211HB",  # Other fracture of occiput, left side, initial encounter for open fracture
        "S02121A",  # Fracture of orbital roof, right side, initial encounter for closed fracture
        "S02121B",  # Fracture of orbital roof, right side, initial encounter for open fracture
        "S02122A",  # Fracture of orbital roof, left side, initial encounter for closed fracture
        "S02122B",  # Fracture of orbital roof, left side, initial encounter for open fracture
        "S02129A",  # Fracture of orbital roof, unspecified side, initial encounter for closed fracture
        "S02129B",  # Fracture of orbital roof, unspecified side, initial encounter for open fracture
        "S0219XA",  # Other fracture of base of skull, initial encounter for closed fracture
        "S0219XB",  # Other fracture of base of skull, initial encounter for open fracture
        "S022XXA",  # Fracture of nasal bones, initial encounter for closed fracture
        "S022XXB",  # Fracture of nasal bones, initial encounter for open fracture
        "S0230XA",  # Fracture of orbital floor, unspecified side, initial encounter for closed fracture
        "S0230XB",  # Fracture of orbital floor, unspecified side, initial encounter for open fracture
        "S0231XA",  # Fracture of orbital floor, right side, initial encounter for closed fracture
        "S0231XB",  # Fracture of orbital floor, right side, initial encounter for open fracture
        "S0232XA",  # Fracture of orbital floor, left side, initial encounter for closed fracture
        "S0232XB",  # Fracture of orbital floor, left side, initial encounter for open fracture
        "S02400A",  # Malar fracture, unspecified side, initial encounter for closed fracture
        "S02400B",  # Malar fracture, unspecified side, initial encounter for open fracture
        "S02401A",  # Maxillary fracture, unspecified side, initial encounter for closed fracture
        "S02401B",  # Maxillary fracture, unspecified side, initial encounter for open fracture
        "S02402A",  # Zygomatic fracture, unspecified side, initial encounter for closed fracture
        "S02402B",  # Zygomatic fracture, unspecified side, initial encounter for open fracture
        "S0240AA",  # Malar fracture, right side, initial encounter for closed fracture
        "S0240AB",  # Malar fracture, right side, initial encounter for open fracture
        "S0240BA",  # Malar fracture, left side, initial encounter for closed fracture
        "S0240BB",  # Malar fracture, left side, initial encounter for open fracture
        "S0240CA",  # Maxillary fracture, right side, initial encounter for closed fracture
        "S0240CB",  # Maxillary fracture, right side, initial encounter for open fracture
        "S0240DA",  # Maxillary fracture, left side, initial encounter for closed fracture
        "S0240DB",  # Maxillary fracture, left side, initial encounter for open fracture
        "S0240EA",  # Zygomatic fracture, right side, initial encounter for closed fracture
        "S0240EB",  # Zygomatic fracture, right side, initial encounter for open fracture
        "S0240FA",  # Zygomatic fracture, left side, initial encounter for closed fracture
        "S0240FB",  # Zygomatic fracture, left side, initial encounter for open fracture
        "S02411A",  # LeFort I fracture, initial encounter for closed fracture
        "S02411B",  # LeFort I fracture, initial encounter for open fracture
        "S02412A",  # LeFort II fracture, initial encounter for closed fracture
        "S02412B",  # LeFort II fracture, initial encounter for open fracture
        "S02413A",  # LeFort III fracture, initial encounter for closed fracture
        "S02413B",  # LeFort III fracture, initial encounter for open fracture
        "S0242XA",  # Fracture of alveolus of maxilla, initial encounter for closed fracture
        "S0242XB",  # Fracture of alveolus of maxilla, initial encounter for open fracture
        "S02600A",  # Fracture of unspecified part of body of mandible, unspecified side, initial encounter for closed fracture
        "S02600B",  # Fracture of unspecified part of body of mandible, unspecified side, initial encounter for open fracture
        "S02601A",  # Fracture of unspecified part of body of right mandible, initial encounter for closed fracture
        "S02601B",  # Fracture of unspecified part of body of right mandible, initial encounter for open fracture
        "S02602A",  # Fracture of unspecified part of body of left mandible, initial encounter for closed fracture
        "S02602B",  # Fracture of unspecified part of body of left mandible, initial encounter for open fracture
        "S02609A",  # Fracture of mandible, unspecified, initial encounter for closed fracture
        "S02609B",  # Fracture of mandible, unspecified, initial encounter for open fracture
        "S02610A",  # Fracture of condylar process of mandible, unspecified side, initial encounter for closed fracture
        "S02610B",  # Fracture of condylar process of mandible, unspecified side, initial encounter for open fracture
        "S02611A",  # Fracture of condylar process of right mandible, initial encounter for closed fracture
        "S02611B",  # Fracture of condylar process of right mandible, initial encounter for open fracture
        "S02612A",  # Fracture of condylar process of left mandible, initial encounter for closed fracture
        "S02612B",  # Fracture of condylar process of left mandible, initial encounter for open fracture
        "S02620A",  # Fracture of subcondylar process of mandible, unspecified side, initial encounter for closed fracture
        "S02620B",  # Fracture of subcondylar process of mandible, unspecified side, initial encounter for open fracture
        "S02621A",  # Fracture of subcondylar process of right mandible, initial encounter for closed fracture
        "S02621B",  # Fracture of subcondylar process of right mandible, initial encounter for open fracture
        "S02622A",  # Fracture of subcondylar process of left mandible, initial encounter for closed fracture
        "S02622B",  # Fracture of subcondylar process of left mandible, initial encounter for open fracture
        "S02630A",  # Fracture of coronoid process of mandible, unspecified side, initial encounter for closed fracture
        "S02630B",  # Fracture of coronoid process of mandible, unspecified side, initial encounter for open fracture
        "S02631A",  # Fracture of coronoid process of right mandible, initial encounter for closed fracture
        "S02631B",  # Fracture of coronoid process of right mandible, initial encounter for open fracture
        "S02632A",  # Fracture of coronoid process of left mandible, initial encounter for closed fracture
        "S02632B",  # Fracture of coronoid process of left mandible, initial encounter for open fracture
        "S02640A",  # Fracture of ramus of mandible, unspecified side, initial encounter for closed fracture
        "S02640B",  # Fracture of ramus of mandible, unspecified side, initial encounter for open fracture
        "S02641A",  # Fracture of ramus of right mandible, initial encounter for closed fracture
        "S02641B",  # Fracture of ramus of right mandible, initial encounter for open fracture
        "S02642A",  # Fracture of ramus of left mandible, initial encounter for closed fracture
        "S02642B",  # Fracture of ramus of left mandible, initial encounter for open fracture
        "S02650A",  # Fracture of angle of mandible, unspecified side, initial encounter for closed fracture
        "S02650B",  # Fracture of angle of mandible, unspecified side, initial encounter for open fracture
        "S02651A",  # Fracture of angle of right mandible, initial encounter for closed fracture
        "S02651B",  # Fracture of angle of right mandible, initial encounter for open fracture
        "S02652A",  # Fracture of angle of left mandible, initial encounter for closed fracture
        "S02652B",  # Fracture of angle of left mandible, initial encounter for open fracture
        "S0266XA",  # Fracture of symphysis of mandible, initial encounter for closed fracture
        "S0266XB",  # Fracture of symphysis of mandible, initial encounter for open fracture
        "S02670A",  # Fracture of alveolus of mandible, unspecified side, initial encounter for closed fracture
        "S02670B",  # Fracture of alveolus of mandible, unspecified side, initial encounter for open fracture
        "S02671A",  # Fracture of alveolus of right mandible, initial encounter for closed fracture
        "S02671B",  # Fracture of alveolus of right mandible, initial encounter for open fracture
        "S02672A",  # Fracture of alveolus of left mandible, initial encounter for closed fracture
        "S02672B",  # Fracture of alveolus of left mandible, initial encounter for open fracture
        "S0269XA",  # Fracture of mandible of other specified site, initial encounter for closed fracture
        "S0269XB",  # Fracture of mandible of other specified site, initial encounter for open fracture
        "S0280XA",  # Fracture of other specified skull and facial bones, unspecified side, initial encounter for closed fracture
        "S0280XB",  # Fracture of other specified skull and facial bones, unspecified side, initial encounter for open fracture
        "S0281XA",  # Fracture of other specified skull and facial bones, right side, initial encounter for closed fracture
        "S0281XB",  # Fracture of other specified skull and facial bones, right side, initial encounter for open fracture
        "S0282XA",  # Fracture of other specified skull and facial bones, left side, initial encounter for closed fracture
        "S0282XB",  # Fracture of other specified skull and facial bones, left side, initial encounter for open fracture
        "S02831A",  # Fracture of medial orbital wall, right side, initial encounter for closed fracture
        "S02831B",  # Fracture of medial orbital wall, right side, initial encounter for open fracture
        "S02832A",  # Fracture of medial orbital wall, left side, initial encounter for closed fracture
        "S02832B",  # Fracture of medial orbital wall, left side, initial encounter for open fracture
        "S02839A",  # Fracture of medial orbital wall, unspecified side, initial encounter for closed fracture
        "S02839B",  # Fracture of medial orbital wall, unspecified side, initial encounter for open fracture
        "S02841A",  # Fracture of lateral orbital wall, right side, initial encounter for closed fracture
        "S02841B",  # Fracture of lateral orbital wall, right side, initial encounter for open fracture
        "S02842A",  # Fracture of lateral orbital wall, left side, initial encounter for closed fracture
        "S02842B",  # Fracture of lateral orbital wall, left side, initial encounter for open fracture
        "S02849A",  # Fracture of lateral orbital wall, unspecified side, initial encounter for closed fracture
        "S02849B",  # Fracture of lateral orbital wall, unspecified side, initial encounter for open fracture
        "S0285XA",  # Fracture of orbit, unspecified, initial encounter for closed fracture
        "S0285XB",  # Fracture of orbit, unspecified, initial encounter for open fracture
        "S0291XA",  # Unspecified fracture of skull, initial encounter for closed fracture
        "S0291XB",  # Unspecified fracture of skull, initial encounter for open fracture
        "S0292XA",  # Unspecified fracture of facial bones, initial encounter for closed fracture
        "S0292XB",  # Unspecified fracture of facial bones, initial encounter for open fracture
        "S0520XA",  # Ocular laceration and rupture with prolapse or loss of intraocular tissue, unspecified eye, initial encounter
        "S0521XA",  # Ocular laceration and rupture with prolapse or loss of intraocular tissue, right eye, initial encounter
        "S0522XA",  # Ocular laceration and rupture with prolapse or loss of intraocular tissue, left eye, initial encounter
        "S0530XA",  # Ocular laceration without prolapse or loss of intraocular tissue, unspecified eye, initial encounter
        "S0531XA",  # Ocular laceration without prolapse or loss of intraocular tissue, right eye, initial encounter
        "S0532XA",  # Ocular laceration without prolapse or loss of intraocular tissue, left eye, initial encounter
        "S0540XA",  # Penetrating wound of orbit with or without foreign body, unspecified eye, initial encounter
        "S0541XA",  # Penetrating wound of orbit with or without foreign body, right eye, initial encounter
        "S0542XA",  # Penetrating wound of orbit with or without foreign body, left eye, initial encounter
        "S0550XA",  # Penetrating wound with foreign body of unspecified eyeball, initial encounter
        "S0551XA",  # Penetrating wound with foreign body of right eyeball, initial encounter
        "S0552XA",  # Penetrating wound with foreign body of left eyeball, initial encounter
        "S0560XA",  # Penetrating wound without foreign body of unspecified eyeball, initial encounter
        "S0561XA",  # Penetrating wound without foreign body of right eyeball, initial encounter
        "S0562XA",  # Penetrating wound without foreign body of left eyeball, initial encounter
        "S0570XA",  # Avulsion of unspecified eye, initial encounter
        "S0571XA",  # Avulsion of right eye, initial encounter
        "S0572XA",  # Avulsion of left eye, initial encounter
        "S060X1A",  # Concussion with loss of consciousness of 30 minutes or less, initial encounter
        "S060X9A",  # Concussion with loss of consciousness of unspecified duration, initial encounter
        "S061X0A",  # Traumatic cerebral edema without loss of consciousness, initial encounter
        "S061X1A",  # Traumatic cerebral edema with loss of consciousness of 30 minutes or less, initial encounter
        "S061X2A",  # Traumatic cerebral edema with loss of consciousness of 31 minutes to 59 minutes, initial encounter
        "S061X3A",  # Traumatic cerebral edema with loss of consciousness of 1 hour to 5 hours 59 minutes, initial encounter
        "S061X4A",  # Traumatic cerebral edema with loss of consciousness of 6 hours to 24 hours, initial encounter
        "S061X5A",  # Traumatic cerebral edema with loss of consciousness greater than 24 hours with return to pre-existing conscious level, initial encounter
        "S061X6A",  # Traumatic cerebral edema with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, initial encounter
        "S061X7A",  # Traumatic cerebral edema with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, initial encounter
        "S061X8A",  # Traumatic cerebral edema with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, initial encounter
        "S061X9A",  # Traumatic cerebral edema with loss of consciousness of unspecified duration, initial encounter
        "S061XAA",  # Traumatic cerebral edema with loss of consciousness status unknown, initial encounter
        "S062X0A",  # Diffuse traumatic brain injury without loss of consciousness, initial encounter
        "S062X1A",  # Diffuse traumatic brain injury with loss of consciousness of 30 minutes or less, initial encounter
        "S062X2A",  # Diffuse traumatic brain injury with loss of consciousness of 31 minutes to 59 minutes, initial encounter
        "S062X3A",  # Diffuse traumatic brain injury with loss of consciousness of 1 hour to 5 hours 59 minutes, initial encounter
        "S062X4A",  # Diffuse traumatic brain injury with loss of consciousness of 6 hours to 24 hours, initial encounter
        "S062X5A",  # Diffuse traumatic brain injury with loss of consciousness greater than 24 hours with return to pre-existing conscious levels, initial encounter
        "S062X6A",  # Diffuse traumatic brain injury with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, initial encounter
        "S062X7A",  # Diffuse traumatic brain injury with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, initial encounter
        "S062X8A",  # Diffuse traumatic brain injury with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, initial encounter
        "S062X9A",  # Diffuse traumatic brain injury with loss of consciousness of unspecified duration, initial encounter
        "S062XAA",  # Diffuse traumatic brain injury with loss of consciousness status unknown, initial encounter
        "S06300A",  # Unspecified focal traumatic brain injury without loss of consciousness, initial encounter
        "S06301A",  # Unspecified focal traumatic brain injury with loss of consciousness of 30 minutes or less, initial encounter
        "S06302A",  # Unspecified focal traumatic brain injury with loss of consciousness of 31 minutes to 59 minutes, initial encounter
        "S06303A",  # Unspecified focal traumatic brain injury with loss of consciousness of 1 hour to 5 hours 59 minutes, initial encounter
        "S06304A",  # Unspecified focal traumatic brain injury with loss of consciousness of 6 hours to 24 hours, initial encounter
        "S06305A",  # Unspecified focal traumatic brain injury with loss of consciousness greater than 24 hours with return to pre-existing conscious level, initial encounter
        "S06306A",  # Unspecified focal traumatic brain injury with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, initial encounter
        "S06307A",  # Unspecified focal traumatic brain injury with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, initial encounter
        "S06308A",  # Unspecified focal traumatic brain injury with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, initial encounter
        "S06309A",  # Unspecified focal traumatic brain injury with loss of consciousness of unspecified duration, initial encounter
        "S0630AA",  # Unspecified focal traumatic brain injury with loss of consciousness status unknown, initial encounter
        "S06310A",  # Contusion and laceration of right cerebrum without loss of consciousness, initial encounter
        "S06311A",  # Contusion and laceration of right cerebrum with loss of consciousness of 30 minutes or less, initial encounter
        "S06312A",  # Contusion and laceration of right cerebrum with loss of consciousness of 31 minutes to 59 minutes, initial encounter
        "S06313A",  # Contusion and laceration of right cerebrum with loss of consciousness of 1 hour to 5 hours 59 minutes, initial encounter
        "S06314A",  # Contusion and laceration of right cerebrum with loss of consciousness of 6 hours to 24 hours, initial encounter
        "S06315A",  # Contusion and laceration of right cerebrum with loss of consciousness greater than 24 hours with return to pre-existing conscious level, initial encounter
        "S06316A",  # Contusion and laceration of right cerebrum with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, initial encounter
        "S06317A",  # Contusion and laceration of right cerebrum with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, initial encounter
        "S06318A",  # Contusion and laceration of right cerebrum with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, initial encounter
        "S06319A",  # Contusion and laceration of right cerebrum with loss of consciousness of unspecified duration, initial encounter
        "S0631AA",  # Contusion and laceration of right cerebrum with loss of consciousness status unknown, initial encounter
        "S06320A",  # Contusion and laceration of left cerebrum without loss of consciousness, initial encounter
        "S06321A",  # Contusion and laceration of left cerebrum with loss of consciousness of 30 minutes or less, initial encounter
        "S06322A",  # Contusion and laceration of left cerebrum with loss of consciousness of 31 minutes to 59 minutes, initial encounter
        "S06323A",  # Contusion and laceration of left cerebrum with loss of consciousness of 1 hour to 5 hours 59 minutes, initial encounter
        "S06324A",  # Contusion and laceration of left cerebrum with loss of consciousness of 6 hours to 24 hours, initial encounter
        "S06325A",  # Contusion and laceration of left cerebrum with loss of consciousness greater than 24 hours with return to pre-existing conscious level, initial encounter
        "S06326A",  # Contusion and laceration of left cerebrum with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, initial encounter
        "S06327A",  # Contusion and laceration of left cerebrum with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, initial encounter
        "S06328A",  # Contusion and laceration of left cerebrum with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, initial encounter
        "S06329A",  # Contusion and laceration of left cerebrum with loss of consciousness of unspecified duration, initial encounter
        "S0632AA",  # Contusion and laceration of left cerebrum with loss of consciousness status unknown, initial encounter
        "S06330A",  # Contusion and laceration of cerebrum, unspecified, without loss of consciousness, initial encounter
        "S06331A",  # Contusion and laceration of cerebrum, unspecified, with loss of consciousness of 30 minutes or less, initial encounter
        "S06332A",  # Contusion and laceration of cerebrum, unspecified, with loss of consciousness of 31 minutes to 59 minutes, initial encounter
        "S06333A",  # Contusion and laceration of cerebrum, unspecified, with loss of consciousness of 1 hour to 5 hours 59 minutes, initial encounter
        "S06334A",  # Contusion and laceration of cerebrum, unspecified, with loss of consciousness of 6 hours to 24 hours, initial encounter
        "S06335A",  # Contusion and laceration of cerebrum, unspecified, with loss of consciousness greater than 24 hours with return to pre-existing conscious level, initial encounter
        "S06336A",  # Contusion and laceration of cerebrum, unspecified, with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, initial encounter
        "S06337A",  # Contusion and laceration of cerebrum, unspecified, with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, initial encounter
        "S06338A",  # Contusion and laceration of cerebrum, unspecified, with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, initial encounter
        "S06339A",  # Contusion and laceration of cerebrum, unspecified, with loss of consciousness of unspecified duration, initial encounter
        "S0633AA",  # Contusion and laceration of cerebrum, unspecified, with loss of consciousness status unknown, initial encounter
        "S06340A",  # Traumatic hemorrhage of right cerebrum without loss of consciousness, initial encounter
        "S06341A",  # Traumatic hemorrhage of right cerebrum with loss of consciousness of 30 minutes or less, initial encounter
        "S06342A",  # Traumatic hemorrhage of right cerebrum with loss of consciousness of 31 minutes to 59 minutes, initial encounter
        "S06343A",  # Traumatic hemorrhage of right cerebrum with loss of consciousness of 1 hours to 5 hours 59 minutes, initial encounter
        "S06344A",  # Traumatic hemorrhage of right cerebrum with loss of consciousness of 6 hours to 24 hours, initial encounter
        "S06345A",  # Traumatic hemorrhage of right cerebrum with loss of consciousness greater than 24 hours with return to pre-existing conscious level, initial encounter
        "S06346A",  # Traumatic hemorrhage of right cerebrum with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, initial encounter
        "S06347A",  # Traumatic hemorrhage of right cerebrum with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, initial encounter
        "S06348A",  # Traumatic hemorrhage of right cerebrum with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, initial encounter
        "S06349A",  # Traumatic hemorrhage of right cerebrum with loss of consciousness of unspecified duration, initial encounter
        "S0634AA",  # Traumatic hemorrhage of right cerebrum with loss of consciousness status unknown, initial encounter
        "S06350A",  # Traumatic hemorrhage of left cerebrum without loss of consciousness, initial encounter
        "S06351A",  # Traumatic hemorrhage of left cerebrum with loss of consciousness of 30 minutes or less, initial encounter
        "S06352A",  # Traumatic hemorrhage of left cerebrum with loss of consciousness of 31 minutes to 59 minutes, initial encounter
        "S06353A",  # Traumatic hemorrhage of left cerebrum with loss of consciousness of 1 hours to 5 hours 59 minutes, initial encounter
        "S06354A",  # Traumatic hemorrhage of left cerebrum with loss of consciousness of 6 hours to 24 hours, initial encounter
        "S06355A",  # Traumatic hemorrhage of left cerebrum with loss of consciousness greater than 24 hours with return to pre-existing conscious level, initial encounter
        "S06356A",  # Traumatic hemorrhage of left cerebrum with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, initial encounter
        "S06357A",  # Traumatic hemorrhage of left cerebrum with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, initial encounter
        "S06358A",  # Traumatic hemorrhage of left cerebrum with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, initial encounter
        "S06359A",  # Traumatic hemorrhage of left cerebrum with loss of consciousness of unspecified duration, initial encounter
        "S0635AA",  # Traumatic hemorrhage of left cerebrum with loss of consciousness status unknown, initial encounter
        "S06360A",  # Traumatic hemorrhage of cerebrum, unspecified, without loss of consciousness, initial encounter
        "S06361A",  # Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness of 30 minutes or less, initial encounter
        "S06362A",  # Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness of 31 minutes to 59 minutes, initial encounter
        "S06363A",  # Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness of 1 hours to 5 hours 59 minutes, initial encounter
        "S06364A",  # Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness of 6 hours to 24 hours, initial encounter
        "S06365A",  # Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness greater than 24 hours with return to pre-existing conscious level, initial encounter
        "S06366A",  # Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, initial encounter
        "S06367A",  # Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, initial encounter
        "S06368A",  # Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, initial encounter
        "S06369A",  # Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness of unspecified duration, initial encounter
        "S0636AA",  # Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness status unknown, initial encounter
        "S06370A",  # Contusion, laceration, and hemorrhage of cerebellum without loss of consciousness, initial encounter
        "S06371A",  # Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness of 30 minutes or less, initial encounter
        "S06372A",  # Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness of 31 minutes to 59 minutes, initial encounter
        "S06373A",  # Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness of 1 hour to 5 hours 59 minutes, initial encounter
        "S06374A",  # Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness of 6 hours to 24 hours, initial encounter
        "S06375A",  # Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness greater than 24 hours with return to pre-existing conscious level, initial encounter
        "S06376A",  # Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, initial encounter
        "S06377A",  # Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, initial encounter
        "S06378A",  # Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, initial encounter
        "S06379A",  # Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness of unspecified duration, initial encounter
        "S0637AA",  # Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness status unknown, initial encounter
        "S06380A",  # Contusion, laceration, and hemorrhage of brainstem without loss of consciousness, initial encounter
        "S06381A",  # Contusion, laceration, and hemorrhage of brainstem with loss of consciousness of 30 minutes or less, initial encounter
        "S06382A",  # Contusion, laceration, and hemorrhage of brainstem with loss of consciousness of 31 minutes to 59 minutes, initial encounter
        "S06383A",  # Contusion, laceration, and hemorrhage of brainstem with loss of consciousness of 1 hour to 5 hours 59 minutes, initial encounter
        "S06384A",  # Contusion, laceration, and hemorrhage of brainstem with loss of consciousness of 6 hours to 24 hours, initial encounter
        "S06385A",  # Contusion, laceration, and hemorrhage of brainstem with loss of consciousness greater than 24 hours with return to pre-existing conscious level, initial encounter
        "S06386A",  # Contusion, laceration, and hemorrhage of brainstem with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, initial encounter
        "S06387A",  # Contusion, laceration, and hemorrhage of brainstem with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, initial encounter
        "S06388A",  # Contusion, laceration, and hemorrhage of brainstem with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, initial encounter
        "S06389A",  # Contusion, laceration, and hemorrhage of brainstem with loss of consciousness of unspecified duration, initial encounter
        "S0638AA",  # Contusion, laceration, and hemorrhage of brainstem with loss of consciousness status unknown, initial encounter
        "S064X0A",  # Epidural hemorrhage without loss of consciousness, initial encounter
        "S064X1A",  # Epidural hemorrhage with loss of consciousness of 30 minutes or less, initial encounter
        "S064X2A",  # Epidural hemorrhage with loss of consciousness of 31 minutes to 59 minutes, initial encounter
        "S064X3A",  # Epidural hemorrhage with loss of consciousness of 1 hour to 5 hours 59 minutes, initial encounter
        "S064X4A",  # Epidural hemorrhage with loss of consciousness of 6 hours to 24 hours, initial encounter
        "S064X5A",  # Epidural hemorrhage with loss of consciousness greater than 24 hours with return to pre-existing conscious level, initial encounter
        "S064X6A",  # Epidural hemorrhage with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, initial encounter
        "S064X7A",  # Epidural hemorrhage with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, initial encounter
        "S064X8A",  # Epidural hemorrhage with loss of consciousness of any duration with death due to other causes prior to regaining consciousness, initial encounter
        "S064X9A",  # Epidural hemorrhage with loss of consciousness of unspecified duration, initial encounter
        "S064XAA",  # Epidural hemorrhage with loss of consciousness status unknown, initial encounter
        "S065X0A",  # Traumatic subdural hemorrhage without loss of consciousness, initial encounter
        "S065X1A",  # Traumatic subdural hemorrhage with loss of consciousness of 30 minutes or less, initial encounter
        "S065X2A",  # Traumatic subdural hemorrhage with loss of consciousness of 31 minutes to 59 minutes, initial encounter
        "S065X3A",  # Traumatic subdural hemorrhage with loss of consciousness of 1 hour to 5 hours 59 minutes, initial encounter
        "S065X4A",  # Traumatic subdural hemorrhage with loss of consciousness of 6 hours to 24 hours, initial encounter
        "S065X5A",  # Traumatic subdural hemorrhage with loss of consciousness greater than 24 hours with return to pre-existing conscious level, initial encounter
        "S065X6A",  # Traumatic subdural hemorrhage with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, initial encounter
        "S065X7A",  # Traumatic subdural hemorrhage with loss of consciousness of any duration with death due to brain injury before regaining consciousness, initial encounter
        "S065X8A",  # Traumatic subdural hemorrhage with loss of consciousness of any duration with death due to other cause before regaining consciousness, initial encounter
        "S065X9A",  # Traumatic subdural hemorrhage with loss of consciousness of unspecified duration, initial encounter
        "S065XAA",  # Traumatic subdural hemorrhage with loss of consciousness status unknown, initial encounter
        "S066X0A",  # Traumatic subarachnoid hemorrhage without loss of consciousness, initial encounter
        "S066X1A",  # Traumatic subarachnoid hemorrhage with loss of consciousness of 30 minutes or less, initial encounter
        "S066X2A",  # Traumatic subarachnoid hemorrhage with loss of consciousness of 31 minutes to 59 minutes, initial encounter
        "S066X3A",  # Traumatic subarachnoid hemorrhage with loss of consciousness of 1 hour to 5 hours 59 minutes, initial encounter
        "S066X4A",  # Traumatic subarachnoid hemorrhage with loss of consciousness of 6 hours to 24 hours, initial encounter
        "S066X5A",  # Traumatic subarachnoid hemorrhage with loss of consciousness greater than 24 hours with return to pre-existing conscious level, initial encounter
        "S066X6A",  # Traumatic subarachnoid hemorrhage with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, initial encounter
        "S066X7A",  # Traumatic subarachnoid hemorrhage with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, initial encounter
        "S066X8A",  # Traumatic subarachnoid hemorrhage with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, initial encounter
        "S066X9A",  # Traumatic subarachnoid hemorrhage with loss of consciousness of unspecified duration, initial encounter
        "S066XAA",  # Traumatic subarachnoid hemorrhage with loss of consciousness status unknown, initial encounter
        "S06810A",  # Injury of right internal carotid artery, intracranial portion, not elsewhere classified without loss of consciousness, initial encounter
        "S06811A",  # Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of 30 minutes or less, initial encounter
        "S06812A",  # Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of 31 minutes to 59 minutes, initial encounter
        "S06813A",  # Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of 1 hour to 5 hours 59 minutes, initial encounter
        "S06814A",  # Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of 6 hours to 24 hours, initial encounter
        "S06815A",  # Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness greater than 24 hours with return to pre-existing conscious level, initial encounter
        "S06816A",  # Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, initial encounter
        "S06817A",  # Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, initial encounter
        "S06818A",  # Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, initial encounter
        "S06819A",  # Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of unspecified duration, initial encounter
        "S06820A",  # Injury of left internal carotid artery, intracranial portion, not elsewhere classified without loss of consciousness, initial encounter
        "S06821A",  # Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of 30 minutes or less, initial encounter
        "S06822A",  # Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of 31 minutes to 59 minutes, initial encounter
        "S06823A",  # Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of 1 hour to 5 hours 59 minutes, initial encounter
        "S06824A",  # Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of 6 hours to 24 hours, initial encounter
        "S06825A",  # Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness greater than 24 hours with return to pre-existing conscious level, initial encounter
        "S06826A",  # Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, initial encounter
        "S06827A",  # Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, initial encounter
        "S06828A",  # Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, initial encounter
        "S06829A",  # Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of unspecified duration, initial encounter
        "S06890A",  # Other specified intracranial injury without loss of consciousness, initial encounter
        "S06891A",  # Other specified intracranial injury with loss of consciousness of 30 minutes or less, initial encounter
        "S06892A",  # Other specified intracranial injury with loss of consciousness of 31 minutes to 59 minutes, initial encounter
        "S06893A",  # Other specified intracranial injury with loss of consciousness of 1 hour to 5 hours 59 minutes, initial encounter
        "S06894A",  # Other specified intracranial injury with loss of consciousness of 6 hours to 24 hours, initial encounter
        "S06895A",  # Other specified intracranial injury with loss of consciousness greater than 24 hours with return to pre-existing conscious level, initial encounter
        "S06896A",  # Other specified intracranial injury with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, initial encounter
        "S06897A",  # Other specified intracranial injury with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, initial encounter
        "S06898A",  # Other specified intracranial injury with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, initial encounter
        "S06899A",  # Other specified intracranial injury with loss of consciousness of unspecified duration, initial encounter
        "S069X0A",  # Unspecified intracranial injury without loss of consciousness, initial encounter
        "S069X1A",  # Unspecified intracranial injury with loss of consciousness of 30 minutes or less, initial encounter
        "S069X2A",  # Unspecified intracranial injury with loss of consciousness of 31 minutes to 59 minutes, initial encounter
        "S069X3A",  # Unspecified intracranial injury with loss of consciousness of 1 hour to 5 hours 59 minutes, initial encounter
        "S069X4A",  # Unspecified intracranial injury with loss of consciousness of 6 hours to 24 hours, initial encounter
        "S069X5A",  # Unspecified intracranial injury with loss of consciousness greater than 24 hours with return to pre-existing conscious level, initial encounter
        "S069X6A",  # Unspecified intracranial injury with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, initial encounter
        "S069X7A",  # Unspecified intracranial injury with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, initial encounter
        "S069X8A",  # Unspecified intracranial injury with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, initial encounter
        "S069X9A",  # Unspecified intracranial injury with loss of consciousness of unspecified duration, initial encounter
        "S12000A",  # Unspecified displaced fracture of first cervical vertebra, initial encounter for closed fracture
        "S12000B",  # Unspecified displaced fracture of first cervical vertebra, initial encounter for open fracture
        "S12001A",  # Unspecified nondisplaced fracture of first cervical vertebra, initial encounter for closed fracture
        "S12001B",  # Unspecified nondisplaced fracture of first cervical vertebra, initial encounter for open fracture
        "S1201XA",  # Stable burst fracture of first cervical vertebra, initial encounter for closed fracture
        "S1201XB",  # Stable burst fracture of first cervical vertebra, initial encounter for open fracture
        "S1202XA",  # Unstable burst fracture of first cervical vertebra, initial encounter for closed fracture
        "S1202XB",  # Unstable burst fracture of first cervical vertebra, initial encounter for open fracture
        "S12030A",  # Displaced posterior arch fracture of first cervical vertebra, initial encounter for closed fracture
        "S12030B",  # Displaced posterior arch fracture of first cervical vertebra, initial encounter for open fracture
        "S12031A",  # Nondisplaced posterior arch fracture of first cervical vertebra, initial encounter for closed fracture
        "S12031B",  # Nondisplaced posterior arch fracture of first cervical vertebra, initial encounter for open fracture
        "S12040A",  # Displaced lateral mass fracture of first cervical vertebra, initial encounter for closed fracture
        "S12040B",  # Displaced lateral mass fracture of first cervical vertebra, initial encounter for open fracture
        "S12041A",  # Nondisplaced lateral mass fracture of first cervical vertebra, initial encounter for closed fracture
        "S12041B",  # Nondisplaced lateral mass fracture of first cervical vertebra, initial encounter for open fracture
        "S12090A",  # Other displaced fracture of first cervical vertebra, initial encounter for closed fracture
        "S12090B",  # Other displaced fracture of first cervical vertebra, initial encounter for open fracture
        "S12091A",  # Other nondisplaced fracture of first cervical vertebra, initial encounter for closed fracture
        "S12091B",  # Other nondisplaced fracture of first cervical vertebra, initial encounter for open fracture
        "S12100A",  # Unspecified displaced fracture of second cervical vertebra, initial encounter for closed fracture
        "S12100B",  # Unspecified displaced fracture of second cervical vertebra, initial encounter for open fracture
        "S12101A",  # Unspecified nondisplaced fracture of second cervical vertebra, initial encounter for closed fracture
        "S12101B",  # Unspecified nondisplaced fracture of second cervical vertebra, initial encounter for open fracture
        "S12110A",  # Anterior displaced Type II dens fracture, initial encounter for closed fracture
        "S12110B",  # Anterior displaced Type II dens fracture, initial encounter for open fracture
        "S12111A",  # Posterior displaced Type II dens fracture, initial encounter for closed fracture
        "S12111B",  # Posterior displaced Type II dens fracture, initial encounter for open fracture
        "S12112A",  # Nondisplaced Type II dens fracture, initial encounter for closed fracture
        "S12112B",  # Nondisplaced Type II dens fracture, initial encounter for open fracture
        "S12120A",  # Other displaced dens fracture, initial encounter for closed fracture
        "S12120B",  # Other displaced dens fracture, initial encounter for open fracture
        "S12121A",  # Other nondisplaced dens fracture, initial encounter for closed fracture
        "S12121B",  # Other nondisplaced dens fracture, initial encounter for open fracture
        "S12130A",  # Unspecified traumatic displaced spondylolisthesis of second cervical vertebra, initial encounter for closed fracture
        "S12130B",  # Unspecified traumatic displaced spondylolisthesis of second cervical vertebra, initial encounter for open fracture
        "S12131A",  # Unspecified traumatic nondisplaced spondylolisthesis of second cervical vertebra, initial encounter for closed fracture
        "S12131B",  # Unspecified traumatic nondisplaced spondylolisthesis of second cervical vertebra, initial encounter for open fracture
        "S1214XA",  # Type III traumatic spondylolisthesis of second cervical vertebra, initial encounter for closed fracture
        "S1214XB",  # Type III traumatic spondylolisthesis of second cervical vertebra, initial encounter for open fracture
        "S12150A",  # Other traumatic displaced spondylolisthesis of second cervical vertebra, initial encounter for closed fracture
        "S12150B",  # Other traumatic displaced spondylolisthesis of second cervical vertebra, initial encounter for open fracture
        "S12151A",  # Other traumatic nondisplaced spondylolisthesis of second cervical vertebra, initial encounter for closed fracture
        "S12151B",  # Other traumatic nondisplaced spondylolisthesis of second cervical vertebra, initial encounter for open fracture
        "S12190A",  # Other displaced fracture of second cervical vertebra, initial encounter for closed fracture
        "S12190B",  # Other displaced fracture of second cervical vertebra, initial encounter for open fracture
        "S12191A",  # Other nondisplaced fracture of second cervical vertebra, initial encounter for closed fracture
        "S12191B",  # Other nondisplaced fracture of second cervical vertebra, initial encounter for open fracture
        "S12200A",  # Unspecified displaced fracture of third cervical vertebra, initial encounter for closed fracture
        "S12200B",  # Unspecified displaced fracture of third cervical vertebra, initial encounter for open fracture
        "S12201A",  # Unspecified nondisplaced fracture of third cervical vertebra, initial encounter for closed fracture
        "S12201B",  # Unspecified nondisplaced fracture of third cervical vertebra, initial encounter for open fracture
        "S12230A",  # Unspecified traumatic displaced spondylolisthesis of third cervical vertebra, initial encounter for closed fracture
        "S12230B",  # Unspecified traumatic displaced spondylolisthesis of third cervical vertebra, initial encounter for open fracture
        "S12231A",  # Unspecified traumatic nondisplaced spondylolisthesis of third cervical vertebra, initial encounter for closed fracture
        "S12231B",  # Unspecified traumatic nondisplaced spondylolisthesis of third cervical vertebra, initial encounter for open fracture
        "S1224XA",  # Type III traumatic spondylolisthesis of third cervical vertebra, initial encounter for closed fracture
        "S1224XB",  # Type III traumatic spondylolisthesis of third cervical vertebra, initial encounter for open fracture
        "S12250A",  # Other traumatic displaced spondylolisthesis of third cervical vertebra, initial encounter for closed fracture
        "S12250B",  # Other traumatic displaced spondylolisthesis of third cervical vertebra, initial encounter for open fracture
        "S12251A",  # Other traumatic nondisplaced spondylolisthesis of third cervical vertebra, initial encounter for closed fracture
        "S12251B",  # Other traumatic nondisplaced spondylolisthesis of third cervical vertebra, initial encounter for open fracture
        "S12290A",  # Other displaced fracture of third cervical vertebra, initial encounter for closed fracture
        "S12290B",  # Other displaced fracture of third cervical vertebra, initial encounter for open fracture
        "S12291A",  # Other nondisplaced fracture of third cervical vertebra, initial encounter for closed fracture
        "S12291B",  # Other nondisplaced fracture of third cervical vertebra, initial encounter for open fracture
        "S12300A",  # Unspecified displaced fracture of fourth cervical vertebra, initial encounter for closed fracture
        "S12300B",  # Unspecified displaced fracture of fourth cervical vertebra, initial encounter for open fracture
        "S12301A",  # Unspecified nondisplaced fracture of fourth cervical vertebra, initial encounter for closed fracture
        "S12301B",  # Unspecified nondisplaced fracture of fourth cervical vertebra, initial encounter for open fracture
        "S12330A",  # Unspecified traumatic displaced spondylolisthesis of fourth cervical vertebra, initial encounter for closed fracture
        "S12330B",  # Unspecified traumatic displaced spondylolisthesis of fourth cervical vertebra, initial encounter for open fracture
        "S12331A",  # Unspecified traumatic nondisplaced spondylolisthesis of fourth cervical vertebra, initial encounter for closed fracture
        "S12331B",  # Unspecified traumatic nondisplaced spondylolisthesis of fourth cervical vertebra, initial encounter for open fracture
        "S1234XA",  # Type III traumatic spondylolisthesis of fourth cervical vertebra, initial encounter for closed fracture
        "S1234XB",  # Type III traumatic spondylolisthesis of fourth cervical vertebra, initial encounter for open fracture
        "S12350A",  # Other traumatic displaced spondylolisthesis of fourth cervical vertebra, initial encounter for closed fracture
        "S12350B",  # Other traumatic displaced spondylolisthesis of fourth cervical vertebra, initial encounter for open fracture
        "S12351A",  # Other traumatic nondisplaced spondylolisthesis of fourth cervical vertebra, initial encounter for closed fracture
        "S12351B",  # Other traumatic nondisplaced spondylolisthesis of fourth cervical vertebra, initial encounter for open fracture
        "S12390A",  # Other displaced fracture of fourth cervical vertebra, initial encounter for closed fracture
        "S12390B",  # Other displaced fracture of fourth cervical vertebra, initial encounter for open fracture
        "S12391A",  # Other nondisplaced fracture of fourth cervical vertebra, initial encounter for closed fracture
        "S12391B",  # Other nondisplaced fracture of fourth cervical vertebra, initial encounter for open fracture
        "S12400A",  # Unspecified displaced fracture of fifth cervical vertebra, initial encounter for closed fracture
        "S12400B",  # Unspecified displaced fracture of fifth cervical vertebra, initial encounter for open fracture
        "S12401A",  # Unspecified nondisplaced fracture of fifth cervical vertebra, initial encounter for closed fracture
        "S12401B",  # Unspecified nondisplaced fracture of fifth cervical vertebra, initial encounter for open fracture
        "S12430A",  # Unspecified traumatic displaced spondylolisthesis of fifth cervical vertebra, initial encounter for closed fracture
        "S12430B",  # Unspecified traumatic displaced spondylolisthesis of fifth cervical vertebra, initial encounter for open fracture
        "S12431A",  # Unspecified traumatic nondisplaced spondylolisthesis of fifth cervical vertebra, initial encounter for closed fracture
        "S12431B",  # Unspecified traumatic nondisplaced spondylolisthesis of fifth cervical vertebra, initial encounter for open fracture
        "S1244XA",  # Type III traumatic spondylolisthesis of fifth cervical vertebra, initial encounter for closed fracture
        "S1244XB",  # Type III traumatic spondylolisthesis of fifth cervical vertebra, initial encounter for open fracture
        "S12450A",  # Other traumatic displaced spondylolisthesis of fifth cervical vertebra, initial encounter for closed fracture
        "S12450B",  # Other traumatic displaced spondylolisthesis of fifth cervical vertebra, initial encounter for open fracture
        "S12451A",  # Other traumatic nondisplaced spondylolisthesis of fifth cervical vertebra, initial encounter for closed fracture
        "S12451B",  # Other traumatic nondisplaced spondylolisthesis of fifth cervical vertebra, initial encounter for open fracture
        "S12490A",  # Other displaced fracture of fifth cervical vertebra, initial encounter for closed fracture
        "S12490B",  # Other displaced fracture of fifth cervical vertebra, initial encounter for open fracture
        "S12491A",  # Other nondisplaced fracture of fifth cervical vertebra, initial encounter for closed fracture
        "S12491B",  # Other nondisplaced fracture of fifth cervical vertebra, initial encounter for open fracture
        "S12500A",  # Unspecified displaced fracture of sixth cervical vertebra, initial encounter for closed fracture
        "S12500B",  # Unspecified displaced fracture of sixth cervical vertebra, initial encounter for open fracture
        "S12501A",  # Unspecified nondisplaced fracture of sixth cervical vertebra, initial encounter for closed fracture
        "S12501B",  # Unspecified nondisplaced fracture of sixth cervical vertebra, initial encounter for open fracture
        "S12530A",  # Unspecified traumatic displaced spondylolisthesis of sixth cervical vertebra, initial encounter for closed fracture
        "S12530B",  # Unspecified traumatic displaced spondylolisthesis of sixth cervical vertebra, initial encounter for open fracture
        "S12531A",  # Unspecified traumatic nondisplaced spondylolisthesis of sixth cervical vertebra, initial encounter for closed fracture
        "S12531B",  # Unspecified traumatic nondisplaced spondylolisthesis of sixth cervical vertebra, initial encounter for open fracture
        "S1254XA",  # Type III traumatic spondylolisthesis of sixth cervical vertebra, initial encounter for closed fracture
        "S1254XB",  # Type III traumatic spondylolisthesis of sixth cervical vertebra, initial encounter for open fracture
        "S12550A",  # Other traumatic displaced spondylolisthesis of sixth cervical vertebra, initial encounter for closed fracture
        "S12550B",  # Other traumatic displaced spondylolisthesis of sixth cervical vertebra, initial encounter for open fracture
        "S12551A",  # Other traumatic nondisplaced spondylolisthesis of sixth cervical vertebra, initial encounter for closed fracture
        "S12551B",  # Other traumatic nondisplaced spondylolisthesis of sixth cervical vertebra, initial encounter for open fracture
        "S12590A",  # Other displaced fracture of sixth cervical vertebra, initial encounter for closed fracture
        "S12590B",  # Other displaced fracture of sixth cervical vertebra, initial encounter for open fracture
        "S12591A",  # Other nondisplaced fracture of sixth cervical vertebra, initial encounter for closed fracture
        "S12591B",  # Other nondisplaced fracture of sixth cervical vertebra, initial encounter for open fracture
        "S12600A",  # Unspecified displaced fracture of seventh cervical vertebra, initial encounter for closed fracture
        "S12600B",  # Unspecified displaced fracture of seventh cervical vertebra, initial encounter for open fracture
        "S12601A",  # Unspecified nondisplaced fracture of seventh cervical vertebra, initial encounter for closed fracture
        "S12601B",  # Unspecified nondisplaced fracture of seventh cervical vertebra, initial encounter for open fracture
        "S12630A",  # Unspecified traumatic displaced spondylolisthesis of seventh cervical vertebra, initial encounter for closed fracture
        "S12630B",  # Unspecified traumatic displaced spondylolisthesis of seventh cervical vertebra, initial encounter for open fracture
        "S12631A",  # Unspecified traumatic nondisplaced spondylolisthesis of seventh cervical vertebra, initial encounter for closed fracture
        "S12631B",  # Unspecified traumatic nondisplaced spondylolisthesis of seventh cervical vertebra, initial encounter for open fracture
        "S1264XA",  # Type III traumatic spondylolisthesis of seventh cervical vertebra, initial encounter for closed fracture
        "S1264XB",  # Type III traumatic spondylolisthesis of seventh cervical vertebra, initial encounter for open fracture
        "S12650A",  # Other traumatic displaced spondylolisthesis of seventh cervical vertebra, initial encounter for closed fracture
        "S12650B",  # Other traumatic displaced spondylolisthesis of seventh cervical vertebra, initial encounter for open fracture
        "S12651A",  # Other traumatic nondisplaced spondylolisthesis of seventh cervical vertebra, initial encounter for closed fracture
        "S12651B",  # Other traumatic nondisplaced spondylolisthesis of seventh cervical vertebra, initial encounter for open fracture
        "S12690A",  # Other displaced fracture of seventh cervical vertebra, initial encounter for closed fracture
        "S12690B",  # Other displaced fracture of seventh cervical vertebra, initial encounter for open fracture
        "S12691A",  # Other nondisplaced fracture of seventh cervical vertebra, initial encounter for closed fracture
        "S12691B",  # Other nondisplaced fracture of seventh cervical vertebra, initial encounter for open fracture
        "S128XXA",  # Fracture of other parts of neck, initial encounter
        "S129XXA",  # Fracture of neck, unspecified, initial encounter
        "S140XXA",  # Concussion and edema of cervical spinal cord, initial encounter
        "S14111A",  # Complete lesion at C1 level of cervical spinal cord, initial encounter
        "S14112A",  # Complete lesion at C2 level of cervical spinal cord, initial encounter
        "S14113A",  # Complete lesion at C3 level of cervical spinal cord, initial encounter
        "S14114A",  # Complete lesion at C4 level of cervical spinal cord, initial encounter
        "S14115A",  # Complete lesion at C5 level of cervical spinal cord, initial encounter
        "S14116A",  # Complete lesion at C6 level of cervical spinal cord, initial encounter
        "S14117A",  # Complete lesion at C7 level of cervical spinal cord, initial encounter
        "S14118A",  # Complete lesion at C8 level of cervical spinal cord, initial encounter
        "S14119A",  # Complete lesion at unspecified level of cervical spinal cord, initial encounter
        "S14121A",  # Central cord syndrome at C1 level of cervical spinal cord, initial encounter
        "S14122A",  # Central cord syndrome at C2 level of cervical spinal cord, initial encounter
        "S14123A",  # Central cord syndrome at C3 level of cervical spinal cord, initial encounter
        "S14124A",  # Central cord syndrome at C4 level of cervical spinal cord, initial encounter
        "S14125A",  # Central cord syndrome at C5 level of cervical spinal cord, initial encounter
        "S14126A",  # Central cord syndrome at C6 level of cervical spinal cord, initial encounter
        "S14127A",  # Central cord syndrome at C7 level of cervical spinal cord, initial encounter
        "S14128A",  # Central cord syndrome at C8 level of cervical spinal cord, initial encounter
        "S14129A",  # Central cord syndrome at unspecified level of cervical spinal cord, initial encounter
        "S14131A",  # Anterior cord syndrome at C1 level of cervical spinal cord, initial encounter
        "S14132A",  # Anterior cord syndrome at C2 level of cervical spinal cord, initial encounter
        "S14133A",  # Anterior cord syndrome at C3 level of cervical spinal cord, initial encounter
        "S14134A",  # Anterior cord syndrome at C4 level of cervical spinal cord, initial encounter
        "S14135A",  # Anterior cord syndrome at C5 level of cervical spinal cord, initial encounter
        "S14136A",  # Anterior cord syndrome at C6 level of cervical spinal cord, initial encounter
        "S14137A",  # Anterior cord syndrome at C7 level of cervical spinal cord, initial encounter
        "S14138A",  # Anterior cord syndrome at C8 level of cervical spinal cord, initial encounter
        "S14139A",  # Anterior cord syndrome at unspecified level of cervical spinal cord, initial encounter
        "S14141A",  # Brown-Sequard syndrome at C1 level of cervical spinal cord, initial encounter
        "S14142A",  # Brown-Sequard syndrome at C2 level of cervical spinal cord, initial encounter
        "S14143A",  # Brown-Sequard syndrome at C3 level of cervical spinal cord, initial encounter
        "S14144A",  # Brown-Sequard syndrome at C4 level of cervical spinal cord, initial encounter
        "S14145A",  # Brown-Sequard syndrome at C5 level of cervical spinal cord, initial encounter
        "S14146A",  # Brown-Sequard syndrome at C6 level of cervical spinal cord, initial encounter
        "S14147A",  # Brown-Sequard syndrome at C7 level of cervical spinal cord, initial encounter
        "S14148A",  # Brown-Sequard syndrome at C8 level of cervical spinal cord, initial encounter
        "S14149A",  # Brown-Sequard syndrome at unspecified level of cervical spinal cord, initial encounter
        "S14151A",  # Other incomplete lesion at C1 level of cervical spinal cord, initial encounter
        "S14152A",  # Other incomplete lesion at C2 level of cervical spinal cord, initial encounter
        "S14153A",  # Other incomplete lesion at C3 level of cervical spinal cord, initial encounter
        "S14154A",  # Other incomplete lesion at C4 level of cervical spinal cord, initial encounter
        "S14155A",  # Other incomplete lesion at C5 level of cervical spinal cord, initial encounter
        "S14156A",  # Other incomplete lesion at C6 level of cervical spinal cord, initial encounter
        "S14157A",  # Other incomplete lesion at C7 level of cervical spinal cord, initial encounter
        "S14158A",  # Other incomplete lesion at C8 level of cervical spinal cord, initial encounter
        "S14159A",  # Other incomplete lesion at unspecified level of cervical spinal cord, initial encounter
        "S21301A",  # Unspecified open wound of right front wall of thorax with penetration into thoracic cavity, initial encounter
        "S21302A",  # Unspecified open wound of left front wall of thorax with penetration into thoracic cavity, initial encounter
        "S21309A",  # Unspecified open wound of unspecified front wall of thorax with penetration into thoracic cavity, initial encounter
        "S21311A",  # Laceration without foreign body of right front wall of thorax with penetration into thoracic cavity, initial encounter
        "S21312A",  # Laceration without foreign body of left front wall of thorax with penetration into thoracic cavity, initial encounter
        "S21319A",  # Laceration without foreign body of unspecified front wall of thorax with penetration into thoracic cavity, initial encounter
        "S21321A",  # Laceration with foreign body of right front wall of thorax with penetration into thoracic cavity, initial encounter
        "S21322A",  # Laceration with foreign body of left front wall of thorax with penetration into thoracic cavity, initial encounter
        "S21329A",  # Laceration with foreign body of unspecified front wall of thorax with penetration into thoracic cavity, initial encounter
        "S21401A",  # Unspecified open wound of right back wall of thorax with penetration into thoracic cavity, initial encounter
        "S21402A",  # Unspecified open wound of left back wall of thorax with penetration into thoracic cavity, initial encounter
        "S21409A",  # Unspecified open wound of unspecified back wall of thorax with penetration into thoracic cavity, initial encounter
        "S21411A",  # Laceration without foreign body of right back wall of thorax with penetration into thoracic cavity, initial encounter
        "S21412A",  # Laceration without foreign body of left back wall of thorax with penetration into thoracic cavity, initial encounter
        "S21419A",  # Laceration without foreign body of unspecified back wall of thorax with penetration into thoracic cavity, initial encounter
        "S21421A",  # Laceration with foreign body of right back wall of thorax with penetration into thoracic cavity, initial encounter
        "S21422A",  # Laceration with foreign body of left back wall of thorax with penetration into thoracic cavity, initial encounter
        "S21429A",  # Laceration with foreign body of unspecified back wall of thorax with penetration into thoracic cavity, initial encounter
        "S22000A",  # Wedge compression fracture of unspecified thoracic vertebra, initial encounter for closed fracture
        "S22000B",  # Wedge compression fracture of unspecified thoracic vertebra, initial encounter for open fracture
        "S22001A",  # Stable burst fracture of unspecified thoracic vertebra, initial encounter for closed fracture
        "S22001B",  # Stable burst fracture of unspecified thoracic vertebra, initial encounter for open fracture
        "S22002A",  # Unstable burst fracture of unspecified thoracic vertebra, initial encounter for closed fracture
        "S22002B",  # Unstable burst fracture of unspecified thoracic vertebra, initial encounter for open fracture
        "S22008A",  # Other fracture of unspecified thoracic vertebra, initial encounter for closed fracture
        "S22008B",  # Other fracture of unspecified thoracic vertebra, initial encounter for open fracture
        "S22009A",  # Unspecified fracture of unspecified thoracic vertebra, initial encounter for closed fracture
        "S22009B",  # Unspecified fracture of unspecified thoracic vertebra, initial encounter for open fracture
        "S22010A",  # Wedge compression fracture of first thoracic vertebra, initial encounter for closed fracture
        "S22010B",  # Wedge compression fracture of first thoracic vertebra, initial encounter for open fracture
        "S22011A",  # Stable burst fracture of first thoracic vertebra, initial encounter for closed fracture
        "S22011B",  # Stable burst fracture of first thoracic vertebra, initial encounter for open fracture
        "S22012A",  # Unstable burst fracture of first thoracic vertebra, initial encounter for closed fracture
        "S22012B",  # Unstable burst fracture of first thoracic vertebra, initial encounter for open fracture
        "S22018A",  # Other fracture of first thoracic vertebra, initial encounter for closed fracture
        "S22018B",  # Other fracture of first thoracic vertebra, initial encounter for open fracture
        "S22019A",  # Unspecified fracture of first thoracic vertebra, initial encounter for closed fracture
        "S22019B",  # Unspecified fracture of first thoracic vertebra, initial encounter for open fracture
        "S22020A",  # Wedge compression fracture of second thoracic vertebra, initial encounter for closed fracture
        "S22020B",  # Wedge compression fracture of second thoracic vertebra, initial encounter for open fracture
        "S22021A",  # Stable burst fracture of second thoracic vertebra, initial encounter for closed fracture
        "S22021B",  # Stable burst fracture of second thoracic vertebra, initial encounter for open fracture
        "S22022A",  # Unstable burst fracture of second thoracic vertebra, initial encounter for closed fracture
        "S22022B",  # Unstable burst fracture of second thoracic vertebra, initial encounter for open fracture
        "S22028A",  # Other fracture of second thoracic vertebra, initial encounter for closed fracture
        "S22028B",  # Other fracture of second thoracic vertebra, initial encounter for open fracture
        "S22029A",  # Unspecified fracture of second thoracic vertebra, initial encounter for closed fracture
        "S22029B",  # Unspecified fracture of second thoracic vertebra, initial encounter for open fracture
        "S22030A",  # Wedge compression fracture of third thoracic vertebra, initial encounter for closed fracture
        "S22030B",  # Wedge compression fracture of third thoracic vertebra, initial encounter for open fracture
        "S22031A",  # Stable burst fracture of third thoracic vertebra, initial encounter for closed fracture
        "S22031B",  # Stable burst fracture of third thoracic vertebra, initial encounter for open fracture
        "S22032A",  # Unstable burst fracture of third thoracic vertebra, initial encounter for closed fracture
        "S22032B",  # Unstable burst fracture of third thoracic vertebra, initial encounter for open fracture
        "S22038A",  # Other fracture of third thoracic vertebra, initial encounter for closed fracture
        "S22038B",  # Other fracture of third thoracic vertebra, initial encounter for open fracture
        "S22039A",  # Unspecified fracture of third thoracic vertebra, initial encounter for closed fracture
        "S22039B",  # Unspecified fracture of third thoracic vertebra, initial encounter for open fracture
        "S22040A",  # Wedge compression fracture of fourth thoracic vertebra, initial encounter for closed fracture
        "S22040B",  # Wedge compression fracture of fourth thoracic vertebra, initial encounter for open fracture
        "S22041A",  # Stable burst fracture of fourth thoracic vertebra, initial encounter for closed fracture
        "S22041B",  # Stable burst fracture of fourth thoracic vertebra, initial encounter for open fracture
        "S22042A",  # Unstable burst fracture of fourth thoracic vertebra, initial encounter for closed fracture
        "S22042B",  # Unstable burst fracture of fourth thoracic vertebra, initial encounter for open fracture
        "S22048A",  # Other fracture of fourth thoracic vertebra, initial encounter for closed fracture
        "S22048B",  # Other fracture of fourth thoracic vertebra, initial encounter for open fracture
        "S22049A",  # Unspecified fracture of fourth thoracic vertebra, initial encounter for closed fracture
        "S22049B",  # Unspecified fracture of fourth thoracic vertebra, initial encounter for open fracture
        "S22050A",  # Wedge compression fracture of T5-T6 vertebra, initial encounter for closed fracture
        "S22050B",  # Wedge compression fracture of T5-T6 vertebra, initial encounter for open fracture
        "S22051A",  # Stable burst fracture of T5-T6 vertebra, initial encounter for closed fracture
        "S22051B",  # Stable burst fracture of T5-T6 vertebra, initial encounter for open fracture
        "S22052A",  # Unstable burst fracture of T5-T6 vertebra, initial encounter for closed fracture
        "S22052B",  # Unstable burst fracture of T5-T6 vertebra, initial encounter for open fracture
        "S22058A",  # Other fracture of T5-T6 vertebra, initial encounter for closed fracture
        "S22058B",  # Other fracture of T5-T6 vertebra, initial encounter for open fracture
        "S22059A",  # Unspecified fracture of T5-T6 vertebra, initial encounter for closed fracture
        "S22059B",  # Unspecified fracture of T5-T6 vertebra, initial encounter for open fracture
        "S22060A",  # Wedge compression fracture of T7-T8 vertebra, initial encounter for closed fracture
        "S22060B",  # Wedge compression fracture of T7-T8 vertebra, initial encounter for open fracture
        "S22061A",  # Stable burst fracture of T7-T8 vertebra, initial encounter for closed fracture
        "S22061B",  # Stable burst fracture of T7-T8 vertebra, initial encounter for open fracture
        "S22062A",  # Unstable burst fracture of T7-T8 vertebra, initial encounter for closed fracture
        "S22062B",  # Unstable burst fracture of T7-T8 vertebra, initial encounter for open fracture
        "S22068A",  # Other fracture of T7-T8 thoracic vertebra, initial encounter for closed fracture
        "S22068B",  # Other fracture of T7-T8 thoracic vertebra, initial encounter for open fracture
        "S22069A",  # Unspecified fracture of T7-T8 vertebra, initial encounter for closed fracture
        "S22069B",  # Unspecified fracture of T7-T8 vertebra, initial encounter for open fracture
        "S22070A",  # Wedge compression fracture of T9-T10 vertebra, initial encounter for closed fracture
        "S22070B",  # Wedge compression fracture of T9-T10 vertebra, initial encounter for open fracture
        "S22071A",  # Stable burst fracture of T9-T10 vertebra, initial encounter for closed fracture
        "S22071B",  # Stable burst fracture of T9-T10 vertebra, initial encounter for open fracture
        "S22072A",  # Unstable burst fracture of T9-T10 vertebra, initial encounter for closed fracture
        "S22072B",  # Unstable burst fracture of T9-T10 vertebra, initial encounter for open fracture
        "S22078A",  # Other fracture of T9-T10 vertebra, initial encounter for closed fracture
        "S22078B",  # Other fracture of T9-T10 vertebra, initial encounter for open fracture
        "S22079A",  # Unspecified fracture of T9-T10 vertebra, initial encounter for closed fracture
        "S22079B",  # Unspecified fracture of T9-T10 vertebra, initial encounter for open fracture
        "S22080A",  # Wedge compression fracture of T11-T12 vertebra, initial encounter for closed fracture
        "S22080B",  # Wedge compression fracture of T11-T12 vertebra, initial encounter for open fracture
        "S22081A",  # Stable burst fracture of T11-T12 vertebra, initial encounter for closed fracture
        "S22081B",  # Stable burst fracture of T11-T12 vertebra, initial encounter for open fracture
        "S22082A",  # Unstable burst fracture of T11-T12 vertebra, initial encounter for closed fracture
        "S22082B",  # Unstable burst fracture of T11-T12 vertebra, initial encounter for open fracture
        "S22088A",  # Other fracture of T11-T12 vertebra, initial encounter for closed fracture
        "S22088B",  # Other fracture of T11-T12 vertebra, initial encounter for open fracture
        "S22089A",  # Unspecified fracture of T11-T12 vertebra, initial encounter for closed fracture
        "S22089B",  # Unspecified fracture of T11-T12 vertebra, initial encounter for open fracture
        "S2231XA",  # Fracture of one rib, right side, initial encounter for closed fracture
        "S2231XB",  # Fracture of one rib, right side, initial encounter for open fracture
        "S2232XA",  # Fracture of one rib, left side, initial encounter for closed fracture
        "S2232XB",  # Fracture of one rib, left side, initial encounter for open fracture
        "S2239XA",  # Fracture of one rib, unspecified side, initial encounter for closed fracture
        "S2239XB",  # Fracture of one rib, unspecified side, initial encounter for open fracture
        "S2241XA",  # Multiple fractures of ribs, right side, initial encounter for closed fracture
        "S2241XB",  # Multiple fractures of ribs, right side, initial encounter for open fracture
        "S2242XA",  # Multiple fractures of ribs, left side, initial encounter for closed fracture
        "S2242XB",  # Multiple fractures of ribs, left side, initial encounter for open fracture
        "S2243XA",  # Multiple fractures of ribs, bilateral, initial encounter for closed fracture
        "S2243XB",  # Multiple fractures of ribs, bilateral, initial encounter for open fracture
        "S2249XA",  # Multiple fractures of ribs, unspecified side, initial encounter for closed fracture
        "S2249XB",  # Multiple fractures of ribs, unspecified side, initial encounter for open fracture
        "S229XXA",  # Fracture of bony thorax, part unspecified, initial encounter for closed fracture
        "S229XXB",  # Fracture of bony thorax, part unspecified, initial encounter for open fracture
        "S240XXA",  # Concussion and edema of thoracic spinal cord, initial encounter
        "S24111A",  # Complete lesion at T1 level of thoracic spinal cord, initial encounter
        "S24112A",  # Complete lesion at T2-T6 level of thoracic spinal cord, initial encounter
        "S24113A",  # Complete lesion at T7-T10 level of thoracic spinal cord, initial encounter
        "S24114A",  # Complete lesion at T11-T12 level of thoracic spinal cord, initial encounter
        "S24119A",  # Complete lesion at unspecified level of thoracic spinal cord, initial encounter
        "S24131A",  # Anterior cord syndrome at T1 level of thoracic spinal cord, initial encounter
        "S24132A",  # Anterior cord syndrome at T2-T6 level of thoracic spinal cord, initial encounter
        "S24133A",  # Anterior cord syndrome at T7-T10 level of thoracic spinal cord, initial encounter
        "S24134A",  # Anterior cord syndrome at T11-T12 level of thoracic spinal cord, initial encounter
        "S24139A",  # Anterior cord syndrome at unspecified level of thoracic spinal cord, initial encounter
        "S24141A",  # Brown-Sequard syndrome at T1 level of thoracic spinal cord, initial encounter
        "S24142A",  # Brown-Sequard syndrome at T2-T6 level of thoracic spinal cord, initial encounter
        "S24143A",  # Brown-Sequard syndrome at T7-T10 level of thoracic spinal cord, initial encounter
        "S24144A",  # Brown-Sequard syndrome at T11-T12 level of thoracic spinal cord, initial encounter
        "S24149A",  # Brown-Sequard syndrome at unspecified level of thoracic spinal cord, initial encounter
        "S24151A",  # Other incomplete lesion at T1 level of thoracic spinal cord, initial encounter
        "S24152A",  # Other incomplete lesion at T2-T6 level of thoracic spinal cord, initial encounter
        "S24153A",  # Other incomplete lesion at T7-T10 level of thoracic spinal cord, initial encounter
        "S24154A",  # Other incomplete lesion at T11-T12 level of thoracic spinal cord, initial encounter
        "S24159A",  # Other incomplete lesion at unspecified level of thoracic spinal cord, initial encounter
        "S270XXA",  # Traumatic pneumothorax, initial encounter
        "S271XXA",  # Traumatic hemothorax, initial encounter
        "S272XXA",  # Traumatic hemopneumothorax, initial encounter
        "S31001A",  # Unspecified open wound of lower back and pelvis with penetration into retroperitoneum, initial encounter
        "S31011A",  # Laceration without foreign body of lower back and pelvis with penetration into retroperitoneum, initial encounter
        "S31021A",  # Laceration with foreign body of lower back and pelvis with penetration into retroperitoneum, initial encounter
        "S31600A",  # Unspecified open wound of abdominal wall, right upper quadrant with penetration into peritoneal cavity, initial encounter
        "S31601A",  # Unspecified open wound of abdominal wall, left upper quadrant with penetration into peritoneal cavity, initial encounter
        "S31602A",  # Unspecified open wound of abdominal wall, epigastric region with penetration into peritoneal cavity, initial encounter
        "S31603A",  # Unspecified open wound of abdominal wall, right lower quadrant with penetration into peritoneal cavity, initial encounter
        "S31604A",  # Unspecified open wound of abdominal wall, left lower quadrant with penetration into peritoneal cavity, initial encounter
        "S31605A",  # Unspecified open wound of abdominal wall, periumbilic region with penetration into peritoneal cavity, initial encounter
        "S31609A",  # Unspecified open wound of abdominal wall, unspecified quadrant with penetration into peritoneal cavity, initial encounter
        "S31610A",  # Laceration without foreign body of abdominal wall, right upper quadrant with penetration into peritoneal cavity, initial encounter
        "S31611A",  # Laceration without foreign body of abdominal wall, left upper quadrant with penetration into peritoneal cavity, initial encounter
        "S31612A",  # Laceration without foreign body of abdominal wall, epigastric region with penetration into peritoneal cavity, initial encounter
        "S31613A",  # Laceration without foreign body of abdominal wall, right lower quadrant with penetration into peritoneal cavity, initial encounter
        "S31614A",  # Laceration without foreign body of abdominal wall, left lower quadrant with penetration into peritoneal cavity, initial encounter
        "S31615A",  # Laceration without foreign body of abdominal wall, periumbilic region with penetration into peritoneal cavity, initial encounter
        "S31619A",  # Laceration without foreign body of abdominal wall, unspecified quadrant with penetration into peritoneal cavity, initial encounter
        "S31620A",  # Laceration with foreign body of abdominal wall, right upper quadrant with penetration into peritoneal cavity, initial encounter
        "S31621A",  # Laceration with foreign body of abdominal wall, left upper quadrant with penetration into peritoneal cavity, initial encounter
        "S31622A",  # Laceration with foreign body of abdominal wall, epigastric region with penetration into peritoneal cavity, initial encounter
        "S31623A",  # Laceration with foreign body of abdominal wall, right lower quadrant with penetration into peritoneal cavity, initial encounter
        "S31624A",  # Laceration with foreign body of abdominal wall, left lower quadrant with penetration into peritoneal cavity, initial encounter
        "S31625A",  # Laceration with foreign body of abdominal wall, periumbilic region with penetration into peritoneal cavity, initial encounter
        "S31629A",  # Laceration with foreign body of abdominal wall, unspecified quadrant with penetration into peritoneal cavity, initial encounter
        "S32000A",  # Wedge compression fracture of unspecified lumbar vertebra, initial encounter for closed fracture
        "S32000B",  # Wedge compression fracture of unspecified lumbar vertebra, initial encounter for open fracture
        "S32001A",  # Stable burst fracture of unspecified lumbar vertebra, initial encounter for closed fracture
        "S32001B",  # Stable burst fracture of unspecified lumbar vertebra, initial encounter for open fracture
        "S32002A",  # Unstable burst fracture of unspecified lumbar vertebra, initial encounter for closed fracture
        "S32002B",  # Unstable burst fracture of unspecified lumbar vertebra, initial encounter for open fracture
        "S32008A",  # Other fracture of unspecified lumbar vertebra, initial encounter for closed fracture
        "S32008B",  # Other fracture of unspecified lumbar vertebra, initial encounter for open fracture
        "S32009A",  # Unspecified fracture of unspecified lumbar vertebra, initial encounter for closed fracture
        "S32009B",  # Unspecified fracture of unspecified lumbar vertebra, initial encounter for open fracture
        "S32010A",  # Wedge compression fracture of first lumbar vertebra, initial encounter for closed fracture
        "S32010B",  # Wedge compression fracture of first lumbar vertebra, initial encounter for open fracture
        "S32011A",  # Stable burst fracture of first lumbar vertebra, initial encounter for closed fracture
        "S32011B",  # Stable burst fracture of first lumbar vertebra, initial encounter for open fracture
        "S32012A",  # Unstable burst fracture of first lumbar vertebra, initial encounter for closed fracture
        "S32012B",  # Unstable burst fracture of first lumbar vertebra, initial encounter for open fracture
        "S32018A",  # Other fracture of first lumbar vertebra, initial encounter for closed fracture
        "S32018B",  # Other fracture of first lumbar vertebra, initial encounter for open fracture
        "S32019A",  # Unspecified fracture of first lumbar vertebra, initial encounter for closed fracture
        "S32019B",  # Unspecified fracture of first lumbar vertebra, initial encounter for open fracture
        "S32020A",  # Wedge compression fracture of second lumbar vertebra, initial encounter for closed fracture
        "S32020B",  # Wedge compression fracture of second lumbar vertebra, initial encounter for open fracture
        "S32021A",  # Stable burst fracture of second lumbar vertebra, initial encounter for closed fracture
        "S32021B",  # Stable burst fracture of second lumbar vertebra, initial encounter for open fracture
        "S32022A",  # Unstable burst fracture of second lumbar vertebra, initial encounter for closed fracture
        "S32022B",  # Unstable burst fracture of second lumbar vertebra, initial encounter for open fracture
        "S32028A",  # Other fracture of second lumbar vertebra, initial encounter for closed fracture
        "S32028B",  # Other fracture of second lumbar vertebra, initial encounter for open fracture
        "S32029A",  # Unspecified fracture of second lumbar vertebra, initial encounter for closed fracture
        "S32029B",  # Unspecified fracture of second lumbar vertebra, initial encounter for open fracture
        "S32030A",  # Wedge compression fracture of third lumbar vertebra, initial encounter for closed fracture
        "S32030B",  # Wedge compression fracture of third lumbar vertebra, initial encounter for open fracture
        "S32031A",  # Stable burst fracture of third lumbar vertebra, initial encounter for closed fracture
        "S32031B",  # Stable burst fracture of third lumbar vertebra, initial encounter for open fracture
        "S32032A",  # Unstable burst fracture of third lumbar vertebra, initial encounter for closed fracture
        "S32032B",  # Unstable burst fracture of third lumbar vertebra, initial encounter for open fracture
        "S32038A",  # Other fracture of third lumbar vertebra, initial encounter for closed fracture
        "S32038B",  # Other fracture of third lumbar vertebra, initial encounter for open fracture
        "S32039A",  # Unspecified fracture of third lumbar vertebra, initial encounter for closed fracture
        "S32039B",  # Unspecified fracture of third lumbar vertebra, initial encounter for open fracture
        "S32040A",  # Wedge compression fracture of fourth lumbar vertebra, initial encounter for closed fracture
        "S32040B",  # Wedge compression fracture of fourth lumbar vertebra, initial encounter for open fracture
        "S32041A",  # Stable burst fracture of fourth lumbar vertebra, initial encounter for closed fracture
        "S32041B",  # Stable burst fracture of fourth lumbar vertebra, initial encounter for open fracture
        "S32042A",  # Unstable burst fracture of fourth lumbar vertebra, initial encounter for closed fracture
        "S32042B",  # Unstable burst fracture of fourth lumbar vertebra, initial encounter for open fracture
        "S32048A",  # Other fracture of fourth lumbar vertebra, initial encounter for closed fracture
        "S32048B",  # Other fracture of fourth lumbar vertebra, initial encounter for open fracture
        "S32049A",  # Unspecified fracture of fourth lumbar vertebra, initial encounter for closed fracture
        "S32049B",  # Unspecified fracture of fourth lumbar vertebra, initial encounter for open fracture
        "S32050A",  # Wedge compression fracture of fifth lumbar vertebra, initial encounter for closed fracture
        "S32050B",  # Wedge compression fracture of fifth lumbar vertebra, initial encounter for open fracture
        "S32051A",  # Stable burst fracture of fifth lumbar vertebra, initial encounter for closed fracture
        "S32051B",  # Stable burst fracture of fifth lumbar vertebra, initial encounter for open fracture
        "S32052A",  # Unstable burst fracture of fifth lumbar vertebra, initial encounter for closed fracture
        "S32052B",  # Unstable burst fracture of fifth lumbar vertebra, initial encounter for open fracture
        "S32058A",  # Other fracture of fifth lumbar vertebra, initial encounter for closed fracture
        "S32058B",  # Other fracture of fifth lumbar vertebra, initial encounter for open fracture
        "S32059A",  # Unspecified fracture of fifth lumbar vertebra, initial encounter for closed fracture
        "S32059B",  # Unspecified fracture of fifth lumbar vertebra, initial encounter for open fracture
        "S3210XA",  # Unspecified fracture of sacrum, initial encounter for closed fracture
        "S3210XB",  # Unspecified fracture of sacrum, initial encounter for open fracture
        "S32110A",  # Nondisplaced Zone I fracture of sacrum, initial encounter for closed fracture
        "S32110B",  # Nondisplaced Zone I fracture of sacrum, initial encounter for open fracture
        "S32111A",  # Minimally displaced Zone I fracture of sacrum, initial encounter for closed fracture
        "S32111B",  # Minimally displaced Zone I fracture of sacrum, initial encounter for open fracture
        "S32112A",  # Severely displaced Zone I fracture of sacrum, initial encounter for closed fracture
        "S32112B",  # Severely displaced Zone I fracture of sacrum, initial encounter for open fracture
        "S32119A",  # Unspecified Zone I fracture of sacrum, initial encounter for closed fracture
        "S32119B",  # Unspecified Zone I fracture of sacrum, initial encounter for open fracture
        "S32120A",  # Nondisplaced Zone II fracture of sacrum, initial encounter for closed fracture
        "S32120B",  # Nondisplaced Zone II fracture of sacrum, initial encounter for open fracture
        "S32121A",  # Minimally displaced Zone II fracture of sacrum, initial encounter for closed fracture
        "S32121B",  # Minimally displaced Zone II fracture of sacrum, initial encounter for open fracture
        "S32122A",  # Severely displaced Zone II fracture of sacrum, initial encounter for closed fracture
        "S32122B",  # Severely displaced Zone II fracture of sacrum, initial encounter for open fracture
        "S32129A",  # Unspecified Zone II fracture of sacrum, initial encounter for closed fracture
        "S32129B",  # Unspecified Zone II fracture of sacrum, initial encounter for open fracture
        "S32130A",  # Nondisplaced Zone III fracture of sacrum, initial encounter for closed fracture
        "S32130B",  # Nondisplaced Zone III fracture of sacrum, initial encounter for open fracture
        "S32131A",  # Minimally displaced Zone III fracture of sacrum, initial encounter for closed fracture
        "S32131B",  # Minimally displaced Zone III fracture of sacrum, initial encounter for open fracture
        "S32132A",  # Severely displaced Zone III fracture of sacrum, initial encounter for closed fracture
        "S32132B",  # Severely displaced Zone III fracture of sacrum, initial encounter for open fracture
        "S32139A",  # Unspecified Zone III fracture of sacrum, initial encounter for closed fracture
        "S32139B",  # Unspecified Zone III fracture of sacrum, initial encounter for open fracture
        "S3214XA",  # Type 1 fracture of sacrum, initial encounter for closed fracture
        "S3214XB",  # Type 1 fracture of sacrum, initial encounter for open fracture
        "S3215XA",  # Type 2 fracture of sacrum, initial encounter for closed fracture
        "S3215XB",  # Type 2 fracture of sacrum, initial encounter for open fracture
        "S3216XA",  # Type 3 fracture of sacrum, initial encounter for closed fracture
        "S3216XB",  # Type 3 fracture of sacrum, initial encounter for open fracture
        "S3217XA",  # Type 4 fracture of sacrum, initial encounter for closed fracture
        "S3217XB",  # Type 4 fracture of sacrum, initial encounter for open fracture
        "S3219XA",  # Other fracture of sacrum, initial encounter for closed fracture
        "S3219XB",  # Other fracture of sacrum, initial encounter for open fracture
        "S322XXA",  # Fracture of coccyx, initial encounter for closed fracture
        "S322XXB",  # Fracture of coccyx, initial encounter for open fracture
        "S32301A",  # Unspecified fracture of right ilium, initial encounter for closed fracture
        "S32301B",  # Unspecified fracture of right ilium, initial encounter for open fracture
        "S32302A",  # Unspecified fracture of left ilium, initial encounter for closed fracture
        "S32302B",  # Unspecified fracture of left ilium, initial encounter for open fracture
        "S32309A",  # Unspecified fracture of unspecified ilium, initial encounter for closed fracture
        "S32309B",  # Unspecified fracture of unspecified ilium, initial encounter for open fracture
        "S32311A",  # Displaced avulsion fracture of right ilium, initial encounter for closed fracture
        "S32311B",  # Displaced avulsion fracture of right ilium, initial encounter for open fracture
        "S32312A",  # Displaced avulsion fracture of left ilium, initial encounter for closed fracture
        "S32312B",  # Displaced avulsion fracture of left ilium, initial encounter for open fracture
        "S32313A",  # Displaced avulsion fracture of unspecified ilium, initial encounter for closed fracture
        "S32313B",  # Displaced avulsion fracture of unspecified ilium, initial encounter for open fracture
        "S32314A",  # Nondisplaced avulsion fracture of right ilium, initial encounter for closed fracture
        "S32314B",  # Nondisplaced avulsion fracture of right ilium, initial encounter for open fracture
        "S32315A",  # Nondisplaced avulsion fracture of left ilium, initial encounter for closed fracture
        "S32315B",  # Nondisplaced avulsion fracture of left ilium, initial encounter for open fracture
        "S32316A",  # Nondisplaced avulsion fracture of unspecified ilium, initial encounter for closed fracture
        "S32316B",  # Nondisplaced avulsion fracture of unspecified ilium, initial encounter for open fracture
        "S32391A",  # Other fracture of right ilium, initial encounter for closed fracture
        "S32391B",  # Other fracture of right ilium, initial encounter for open fracture
        "S32392A",  # Other fracture of left ilium, initial encounter for closed fracture
        "S32392B",  # Other fracture of left ilium, initial encounter for open fracture
        "S32399A",  # Other fracture of unspecified ilium, initial encounter for closed fracture
        "S32399B",  # Other fracture of unspecified ilium, initial encounter for open fracture
        "S32401A",  # Unspecified fracture of right acetabulum, initial encounter for closed fracture
        "S32401B",  # Unspecified fracture of right acetabulum, initial encounter for open fracture
        "S32402A",  # Unspecified fracture of left acetabulum, initial encounter for closed fracture
        "S32402B",  # Unspecified fracture of left acetabulum, initial encounter for open fracture
        "S32409A",  # Unspecified fracture of unspecified acetabulum, initial encounter for closed fracture
        "S32409B",  # Unspecified fracture of unspecified acetabulum, initial encounter for open fracture
        "S32411A",  # Displaced fracture of anterior wall of right acetabulum, initial encounter for closed fracture
        "S32411B",  # Displaced fracture of anterior wall of right acetabulum, initial encounter for open fracture
        "S32412A",  # Displaced fracture of anterior wall of left acetabulum, initial encounter for closed fracture
        "S32412B",  # Displaced fracture of anterior wall of left acetabulum, initial encounter for open fracture
        "S32413A",  # Displaced fracture of anterior wall of unspecified acetabulum, initial encounter for closed fracture
        "S32413B",  # Displaced fracture of anterior wall of unspecified acetabulum, initial encounter for open fracture
        "S32414A",  # Nondisplaced fracture of anterior wall of right acetabulum, initial encounter for closed fracture
        "S32414B",  # Nondisplaced fracture of anterior wall of right acetabulum, initial encounter for open fracture
        "S32415A",  # Nondisplaced fracture of anterior wall of left acetabulum, initial encounter for closed fracture
        "S32415B",  # Nondisplaced fracture of anterior wall of left acetabulum, initial encounter for open fracture
        "S32416A",  # Nondisplaced fracture of anterior wall of unspecified acetabulum, initial encounter for closed fracture
        "S32416B",  # Nondisplaced fracture of anterior wall of unspecified acetabulum, initial encounter for open fracture
        "S32421A",  # Displaced fracture of posterior wall of right acetabulum, initial encounter for closed fracture
        "S32421B",  # Displaced fracture of posterior wall of right acetabulum, initial encounter for open fracture
        "S32422A",  # Displaced fracture of posterior wall of left acetabulum, initial encounter for closed fracture
        "S32422B",  # Displaced fracture of posterior wall of left acetabulum, initial encounter for open fracture
        "S32423A",  # Displaced fracture of posterior wall of unspecified acetabulum, initial encounter for closed fracture
        "S32423B",  # Displaced fracture of posterior wall of unspecified acetabulum, initial encounter for open fracture
        "S32424A",  # Nondisplaced fracture of posterior wall of right acetabulum, initial encounter for closed fracture
        "S32424B",  # Nondisplaced fracture of posterior wall of right acetabulum, initial encounter for open fracture
        "S32425A",  # Nondisplaced fracture of posterior wall of left acetabulum, initial encounter for closed fracture
        "S32425B",  # Nondisplaced fracture of posterior wall of left acetabulum, initial encounter for open fracture
        "S32426A",  # Nondisplaced fracture of posterior wall of unspecified acetabulum, initial encounter for closed fracture
        "S32426B",  # Nondisplaced fracture of posterior wall of unspecified acetabulum, initial encounter for open fracture
        "S32431A",  # Displaced fracture of anterior column [iliopubic] of right acetabulum, initial encounter for closed fracture
        "S32431B",  # Displaced fracture of anterior column [iliopubic] of right acetabulum, initial encounter for open fracture
        "S32432A",  # Displaced fracture of anterior column [iliopubic] of left acetabulum, initial encounter for closed fracture
        "S32432B",  # Displaced fracture of anterior column [iliopubic] of left acetabulum, initial encounter for open fracture
        "S32433A",  # Displaced fracture of anterior column [iliopubic] of unspecified acetabulum, initial encounter for closed fracture
        "S32433B",  # Displaced fracture of anterior column [iliopubic] of unspecified acetabulum, initial encounter for open fracture
        "S32434A",  # Nondisplaced fracture of anterior column [iliopubic] of right acetabulum, initial encounter for closed fracture
        "S32434B",  # Nondisplaced fracture of anterior column [iliopubic] of right acetabulum, initial encounter for open fracture
        "S32435A",  # Nondisplaced fracture of anterior column [iliopubic] of left acetabulum, initial encounter for closed fracture
        "S32435B",  # Nondisplaced fracture of anterior column [iliopubic] of left acetabulum, initial encounter for open fracture
        "S32436A",  # Nondisplaced fracture of anterior column [iliopubic] of unspecified acetabulum, initial encounter for closed fracture
        "S32436B",  # Nondisplaced fracture of anterior column [iliopubic] of unspecified acetabulum, initial encounter for open fracture
        "S32441A",  # Displaced fracture of posterior column [ilioischial] of right acetabulum, initial encounter for closed fracture
        "S32441B",  # Displaced fracture of posterior column [ilioischial] of right acetabulum, initial encounter for open fracture
        "S32442A",  # Displaced fracture of posterior column [ilioischial] of left acetabulum, initial encounter for closed fracture
        "S32442B",  # Displaced fracture of posterior column [ilioischial] of left acetabulum, initial encounter for open fracture
        "S32443A",  # Displaced fracture of posterior column [ilioischial] of unspecified acetabulum, initial encounter for closed fracture
        "S32443B",  # Displaced fracture of posterior column [ilioischial] of unspecified acetabulum, initial encounter for open fracture
        "S32444A",  # Nondisplaced fracture of posterior column [ilioischial] of right acetabulum, initial encounter for closed fracture
        "S32444B",  # Nondisplaced fracture of posterior column [ilioischial] of right acetabulum, initial encounter for open fracture
        "S32445A",  # Nondisplaced fracture of posterior column [ilioischial] of left acetabulum, initial encounter for closed fracture
        "S32445B",  # Nondisplaced fracture of posterior column [ilioischial] of left acetabulum, initial encounter for open fracture
        "S32446A",  # Nondisplaced fracture of posterior column [ilioischial] of unspecified acetabulum, initial encounter for closed fracture
        "S32446B",  # Nondisplaced fracture of posterior column [ilioischial] of unspecified acetabulum, initial encounter for open fracture
        "S32451A",  # Displaced transverse fracture of right acetabulum, initial encounter for closed fracture
        "S32451B",  # Displaced transverse fracture of right acetabulum, initial encounter for open fracture
        "S32452A",  # Displaced transverse fracture of left acetabulum, initial encounter for closed fracture
        "S32452B",  # Displaced transverse fracture of left acetabulum, initial encounter for open fracture
        "S32453A",  # Displaced transverse fracture of unspecified acetabulum, initial encounter for closed fracture
        "S32453B",  # Displaced transverse fracture of unspecified acetabulum, initial encounter for open fracture
        "S32454A",  # Nondisplaced transverse fracture of right acetabulum, initial encounter for closed fracture
        "S32454B",  # Nondisplaced transverse fracture of right acetabulum, initial encounter for open fracture
        "S32455A",  # Nondisplaced transverse fracture of left acetabulum, initial encounter for closed fracture
        "S32455B",  # Nondisplaced transverse fracture of left acetabulum, initial encounter for open fracture
        "S32456A",  # Nondisplaced transverse fracture of unspecified acetabulum, initial encounter for closed fracture
        "S32456B",  # Nondisplaced transverse fracture of unspecified acetabulum, initial encounter for open fracture
        "S32461A",  # Displaced associated transverse-posterior fracture of right acetabulum, initial encounter for closed fracture
        "S32461B",  # Displaced associated transverse-posterior fracture of right acetabulum, initial encounter for open fracture
        "S32462A",  # Displaced associated transverse-posterior fracture of left acetabulum, initial encounter for closed fracture
        "S32462B",  # Displaced associated transverse-posterior fracture of left acetabulum, initial encounter for open fracture
        "S32463A",  # Displaced associated transverse-posterior fracture of unspecified acetabulum, initial encounter for closed fracture
        "S32463B",  # Displaced associated transverse-posterior fracture of unspecified acetabulum, initial encounter for open fracture
        "S32464A",  # Nondisplaced associated transverse-posterior fracture of right acetabulum, initial encounter for closed fracture
        "S32464B",  # Nondisplaced associated transverse-posterior fracture of right acetabulum, initial encounter for open fracture
        "S32465A",  # Nondisplaced associated transverse-posterior fracture of left acetabulum, initial encounter for closed fracture
        "S32465B",  # Nondisplaced associated transverse-posterior fracture of left acetabulum, initial encounter for open fracture
        "S32466A",  # Nondisplaced associated transverse-posterior fracture of unspecified acetabulum, initial encounter for closed fracture
        "S32466B",  # Nondisplaced associated transverse-posterior fracture of unspecified acetabulum, initial encounter for open fracture
        "S32471A",  # Displaced fracture of medial wall of right acetabulum, initial encounter for closed fracture
        "S32471B",  # Displaced fracture of medial wall of right acetabulum, initial encounter for open fracture
        "S32472A",  # Displaced fracture of medial wall of left acetabulum, initial encounter for closed fracture
        "S32472B",  # Displaced fracture of medial wall of left acetabulum, initial encounter for open fracture
        "S32473A",  # Displaced fracture of medial wall of unspecified acetabulum, initial encounter for closed fracture
        "S32473B",  # Displaced fracture of medial wall of unspecified acetabulum, initial encounter for open fracture
        "S32474A",  # Nondisplaced fracture of medial wall of right acetabulum, initial encounter for closed fracture
        "S32474B",  # Nondisplaced fracture of medial wall of right acetabulum, initial encounter for open fracture
        "S32475A",  # Nondisplaced fracture of medial wall of left acetabulum, initial encounter for closed fracture
        "S32475B",  # Nondisplaced fracture of medial wall of left acetabulum, initial encounter for open fracture
        "S32476A",  # Nondisplaced fracture of medial wall of unspecified acetabulum, initial encounter for closed fracture
        "S32476B",  # Nondisplaced fracture of medial wall of unspecified acetabulum, initial encounter for open fracture
        "S32481A",  # Displaced dome fracture of right acetabulum, initial encounter for closed fracture
        "S32481B",  # Displaced dome fracture of right acetabulum, initial encounter for open fracture
        "S32482A",  # Displaced dome fracture of left acetabulum, initial encounter for closed fracture
        "S32482B",  # Displaced dome fracture of left acetabulum, initial encounter for open fracture
        "S32483A",  # Displaced dome fracture of unspecified acetabulum, initial encounter for closed fracture
        "S32483B",  # Displaced dome fracture of unspecified acetabulum, initial encounter for open fracture
        "S32484A",  # Nondisplaced dome fracture of right acetabulum, initial encounter for closed fracture
        "S32484B",  # Nondisplaced dome fracture of right acetabulum, initial encounter for open fracture
        "S32485A",  # Nondisplaced dome fracture of left acetabulum, initial encounter for closed fracture
        "S32485B",  # Nondisplaced dome fracture of left acetabulum, initial encounter for open fracture
        "S32486A",  # Nondisplaced dome fracture of unspecified acetabulum, initial encounter for closed fracture
        "S32486B",  # Nondisplaced dome fracture of unspecified acetabulum, initial encounter for open fracture
        "S32491A",  # Other specified fracture of right acetabulum, initial encounter for closed fracture
        "S32491B",  # Other specified fracture of right acetabulum, initial encounter for open fracture
        "S32492A",  # Other specified fracture of left acetabulum, initial encounter for closed fracture
        "S32492B",  # Other specified fracture of left acetabulum, initial encounter for open fracture
        "S32499A",  # Other specified fracture of unspecified acetabulum, initial encounter for closed fracture
        "S32499B",  # Other specified fracture of unspecified acetabulum, initial encounter for open fracture
        "S32501A",  # Unspecified fracture of right pubis, initial encounter for closed fracture
        "S32501B",  # Unspecified fracture of right pubis, initial encounter for open fracture
        "S32502A",  # Unspecified fracture of left pubis, initial encounter for closed fracture
        "S32502B",  # Unspecified fracture of left pubis, initial encounter for open fracture
        "S32509A",  # Unspecified fracture of unspecified pubis, initial encounter for closed fracture
        "S32509B",  # Unspecified fracture of unspecified pubis, initial encounter for open fracture
        "S32511A",  # Fracture of superior rim of right pubis, initial encounter for closed fracture
        "S32511B",  # Fracture of superior rim of right pubis, initial encounter for open fracture
        "S32512A",  # Fracture of superior rim of left pubis, initial encounter for closed fracture
        "S32512B",  # Fracture of superior rim of left pubis, initial encounter for open fracture
        "S32519A",  # Fracture of superior rim of unspecified pubis, initial encounter for closed fracture
        "S32519B",  # Fracture of superior rim of unspecified pubis, initial encounter for open fracture
        "S32591A",  # Other specified fracture of right pubis, initial encounter for closed fracture
        "S32591B",  # Other specified fracture of right pubis, initial encounter for open fracture
        "S32592A",  # Other specified fracture of left pubis, initial encounter for closed fracture
        "S32592B",  # Other specified fracture of left pubis, initial encounter for open fracture
        "S32599A",  # Other specified fracture of unspecified pubis, initial encounter for closed fracture
        "S32599B",  # Other specified fracture of unspecified pubis, initial encounter for open fracture
        "S32601A",  # Unspecified fracture of right ischium, initial encounter for closed fracture
        "S32601B",  # Unspecified fracture of right ischium, initial encounter for open fracture
        "S32602A",  # Unspecified fracture of left ischium, initial encounter for closed fracture
        "S32602B",  # Unspecified fracture of left ischium, initial encounter for open fracture
        "S32609A",  # Unspecified fracture of unspecified ischium, initial encounter for closed fracture
        "S32609B",  # Unspecified fracture of unspecified ischium, initial encounter for open fracture
        "S32611A",  # Displaced avulsion fracture of right ischium, initial encounter for closed fracture
        "S32611B",  # Displaced avulsion fracture of right ischium, initial encounter for open fracture
        "S32612A",  # Displaced avulsion fracture of left ischium, initial encounter for closed fracture
        "S32612B",  # Displaced avulsion fracture of left ischium, initial encounter for open fracture
        "S32613A",  # Displaced avulsion fracture of unspecified ischium, initial encounter for closed fracture
        "S32613B",  # Displaced avulsion fracture of unspecified ischium, initial encounter for open fracture
        "S32614A",  # Nondisplaced avulsion fracture of right ischium, initial encounter for closed fracture
        "S32614B",  # Nondisplaced avulsion fracture of right ischium, initial encounter for open fracture
        "S32615A",  # Nondisplaced avulsion fracture of left ischium, initial encounter for closed fracture
        "S32615B",  # Nondisplaced avulsion fracture of left ischium, initial encounter for open fracture
        "S32616A",  # Nondisplaced avulsion fracture of unspecified ischium, initial encounter for closed fracture
        "S32616B",  # Nondisplaced avulsion fracture of unspecified ischium, initial encounter for open fracture
        "S32691A",  # Other specified fracture of right ischium, initial encounter for closed fracture
        "S32691B",  # Other specified fracture of right ischium, initial encounter for open fracture
        "S32692A",  # Other specified fracture of left ischium, initial encounter for closed fracture
        "S32692B",  # Other specified fracture of left ischium, initial encounter for open fracture
        "S32699A",  # Other specified fracture of unspecified ischium, initial encounter for closed fracture
        "S32699B",  # Other specified fracture of unspecified ischium, initial encounter for open fracture
        "S32810A",  # Multiple fractures of pelvis with stable disruption of pelvic ring, initial encounter for closed fracture
        "S32810B",  # Multiple fractures of pelvis with stable disruption of pelvic ring, initial encounter for open fracture
        "S32811A",  # Multiple fractures of pelvis with unstable disruption of pelvic ring, initial encounter for closed fracture
        "S32811B",  # Multiple fractures of pelvis with unstable disruption of pelvic ring, initial encounter for open fracture
        "S3282XA",  # Multiple fractures of pelvis without disruption of pelvic ring, initial encounter for closed fracture
        "S3282XB",  # Multiple fractures of pelvis without disruption of pelvic ring, initial encounter for open fracture
        "S3289XA",  # Fracture of other parts of pelvis, initial encounter for closed fracture
        "S3289XB",  # Fracture of other parts of pelvis, initial encounter for open fracture
        "S329XXA",  # Fracture of unspecified parts of lumbosacral spine and pelvis, initial encounter for closed fracture
        "S329XXB",  # Fracture of unspecified parts of lumbosacral spine and pelvis, initial encounter for open fracture
        "S334XXA",  # Traumatic rupture of symphysis pubis, initial encounter
        "S3401XA",  # Concussion and edema of lumbar spinal cord, initial encounter
        "S3402XA",  # Concussion and edema of sacral spinal cord, initial encounter
        "S34111A",  # Complete lesion of L1 level of lumbar spinal cord, initial encounter
        "S34112A",  # Complete lesion of L2 level of lumbar spinal cord, initial encounter
        "S34113A",  # Complete lesion of L3 level of lumbar spinal cord, initial encounter
        "S34114A",  # Complete lesion of L4 level of lumbar spinal cord, initial encounter
        "S34115A",  # Complete lesion of L5 level of lumbar spinal cord, initial encounter
        "S34119A",  # Complete lesion of unspecified level of lumbar spinal cord, initial encounter
        "S34121A",  # Incomplete lesion of L1 level of lumbar spinal cord, initial encounter
        "S34122A",  # Incomplete lesion of L2 level of lumbar spinal cord, initial encounter
        "S34123A",  # Incomplete lesion of L3 level of lumbar spinal cord, initial encounter
        "S34124A",  # Incomplete lesion of L4 level of lumbar spinal cord, initial encounter
        "S34125A",  # Incomplete lesion of L5 level of lumbar spinal cord, initial encounter
        "S34129A",  # Incomplete lesion of unspecified level of lumbar spinal cord, initial encounter
        "S34131A",  # Complete lesion of sacral spinal cord, initial encounter
        "S34132A",  # Incomplete lesion of sacral spinal cord, initial encounter
        "S36020A",  # Minor contusion of spleen, initial encounter
        "S36021A",  # Major contusion of spleen, initial encounter
        "S36029A",  # Unspecified contusion of spleen, initial encounter
        "S36030A",  # Superficial (capsular) laceration of spleen, initial encounter
        "S36031A",  # Moderate laceration of spleen, initial encounter
        "S36032A",  # Major laceration of spleen, initial encounter
        "S36039A",  # Unspecified laceration of spleen, initial encounter
        "S3609XA",  # Other injury of spleen, initial encounter
        "S36112A",  # Contusion of liver, initial encounter
        "S36113A",  # Laceration of liver, unspecified degree, initial encounter
        "S36114A",  # Minor laceration of liver, initial encounter
        "S36115A",  # Moderate laceration of liver, initial encounter
        "S36116A",  # Major laceration of liver, initial encounter
        "S36118A",  # Other injury of liver, initial encounter
        "S36220A",  # Contusion of head of pancreas, initial encounter
        "S36221A",  # Contusion of body of pancreas, initial encounter
        "S36222A",  # Contusion of tail of pancreas, initial encounter
        "S36229A",  # Contusion of unspecified part of pancreas, initial encounter
        "S36230A",  # Laceration of head of pancreas, unspecified degree, initial encounter
        "S36231A",  # Laceration of body of pancreas, unspecified degree, initial encounter
        "S36232A",  # Laceration of tail of pancreas, unspecified degree, initial encounter
        "S36239A",  # Laceration of unspecified part of pancreas, unspecified degree, initial encounter
        "S36240A",  # Minor laceration of head of pancreas, initial encounter
        "S36241A",  # Minor laceration of body of pancreas, initial encounter
        "S36242A",  # Minor laceration of tail of pancreas, initial encounter
        "S36249A",  # Minor laceration of unspecified part of pancreas, initial encounter
        "S36250A",  # Moderate laceration of head of pancreas, initial encounter
        "S36251A",  # Moderate laceration of body of pancreas, initial encounter
        "S36252A",  # Moderate laceration of tail of pancreas, initial encounter
        "S36259A",  # Moderate laceration of unspecified part of pancreas, initial encounter
        "S36260A",  # Major laceration of head of pancreas, initial encounter
        "S36261A",  # Major laceration of body of pancreas, initial encounter
        "S36262A",  # Major laceration of tail of pancreas, initial encounter
        "S36269A",  # Major laceration of unspecified part of pancreas, initial encounter
        "S36290A",  # Other injury of head of pancreas, initial encounter
        "S36291A",  # Other injury of body of pancreas, initial encounter
        "S36292A",  # Other injury of tail of pancreas, initial encounter
        "S36299A",  # Other injury of unspecified part of pancreas, initial encounter
        "S37011A",  # Minor contusion of right kidney, initial encounter
        "S37012A",  # Minor contusion of left kidney, initial encounter
        "S37019A",  # Minor contusion of unspecified kidney, initial encounter
        "S37021A",  # Major contusion of right kidney, initial encounter
        "S37022A",  # Major contusion of left kidney, initial encounter
        "S37029A",  # Major contusion of unspecified kidney, initial encounter
        "S37031A",  # Laceration of right kidney, unspecified degree, initial encounter
        "S37032A",  # Laceration of left kidney, unspecified degree, initial encounter
        "S37039A",  # Laceration of unspecified kidney, unspecified degree, initial encounter
        "S37041A",  # Minor laceration of right kidney, initial encounter
        "S37042A",  # Minor laceration of left kidney, initial encounter
        "S37049A",  # Minor laceration of unspecified kidney, initial encounter
        "S37051A",  # Moderate laceration of right kidney, initial encounter
        "S37052A",  # Moderate laceration of left kidney, initial encounter
        "S37059A",  # Moderate laceration of unspecified kidney, initial encounter
        "S37061A",  # Major laceration of right kidney, initial encounter
        "S37062A",  # Major laceration of left kidney, initial encounter
        "S37069A",  # Major laceration of unspecified kidney, initial encounter
        "S37091A",  # Other injury of right kidney, initial encounter
        "S37092A",  # Other injury of left kidney, initial encounter
        "S37099A",  # Other injury of unspecified kidney, initial encounter
        "S42001A",  # Fracture of unspecified part of right clavicle, initial encounter for closed fracture
        "S42001B",  # Fracture of unspecified part of right clavicle, initial encounter for open fracture
        "S42002A",  # Fracture of unspecified part of left clavicle, initial encounter for closed fracture
        "S42002B",  # Fracture of unspecified part of left clavicle, initial encounter for open fracture
        "S42009A",  # Fracture of unspecified part of unspecified clavicle, initial encounter for closed fracture
        "S42009B",  # Fracture of unspecified part of unspecified clavicle, initial encounter for open fracture
        "S42011A",  # Anterior displaced fracture of sternal end of right clavicle, initial encounter for closed fracture
        "S42011B",  # Anterior displaced fracture of sternal end of right clavicle, initial encounter for open fracture
        "S42012A",  # Anterior displaced fracture of sternal end of left clavicle, initial encounter for closed fracture
        "S42012B",  # Anterior displaced fracture of sternal end of left clavicle, initial encounter for open fracture
        "S42013A",  # Anterior displaced fracture of sternal end of unspecified clavicle, initial encounter for closed fracture
        "S42013B",  # Anterior displaced fracture of sternal end of unspecified clavicle, initial encounter for open fracture
        "S42014A",  # Posterior displaced fracture of sternal end of right clavicle, initial encounter for closed fracture
        "S42014B",  # Posterior displaced fracture of sternal end of right clavicle, initial encounter for open fracture
        "S42015A",  # Posterior displaced fracture of sternal end of left clavicle, initial encounter for closed fracture
        "S42015B",  # Posterior displaced fracture of sternal end of left clavicle, initial encounter for open fracture
        "S42016A",  # Posterior displaced fracture of sternal end of unspecified clavicle, initial encounter for closed fracture
        "S42016B",  # Posterior displaced fracture of sternal end of unspecified clavicle, initial encounter for open fracture
        "S42017A",  # Nondisplaced fracture of sternal end of right clavicle, initial encounter for closed fracture
        "S42017B",  # Nondisplaced fracture of sternal end of right clavicle, initial encounter for open fracture
        "S42018A",  # Nondisplaced fracture of sternal end of left clavicle, initial encounter for closed fracture
        "S42018B",  # Nondisplaced fracture of sternal end of left clavicle, initial encounter for open fracture
        "S42019A",  # Nondisplaced fracture of sternal end of unspecified clavicle, initial encounter for closed fracture
        "S42019B",  # Nondisplaced fracture of sternal end of unspecified clavicle, initial encounter for open fracture
        "S42021A",  # Displaced fracture of shaft of right clavicle, initial encounter for closed fracture
        "S42021B",  # Displaced fracture of shaft of right clavicle, initial encounter for open fracture
        "S42022A",  # Displaced fracture of shaft of left clavicle, initial encounter for closed fracture
        "S42022B",  # Displaced fracture of shaft of left clavicle, initial encounter for open fracture
        "S42023A",  # Displaced fracture of shaft of unspecified clavicle, initial encounter for closed fracture
        "S42023B",  # Displaced fracture of shaft of unspecified clavicle, initial encounter for open fracture
        "S42024A",  # Nondisplaced fracture of shaft of right clavicle, initial encounter for closed fracture
        "S42024B",  # Nondisplaced fracture of shaft of right clavicle, initial encounter for open fracture
        "S42025A",  # Nondisplaced fracture of shaft of left clavicle, initial encounter for closed fracture
        "S42025B",  # Nondisplaced fracture of shaft of left clavicle, initial encounter for open fracture
        "S42026A",  # Nondisplaced fracture of shaft of unspecified clavicle, initial encounter for closed fracture
        "S42026B",  # Nondisplaced fracture of shaft of unspecified clavicle, initial encounter for open fracture
        "S42031A",  # Displaced fracture of lateral end of right clavicle, initial encounter for closed fracture
        "S42031B",  # Displaced fracture of lateral end of right clavicle, initial encounter for open fracture
        "S42032A",  # Displaced fracture of lateral end of left clavicle, initial encounter for closed fracture
        "S42032B",  # Displaced fracture of lateral end of left clavicle, initial encounter for open fracture
        "S42033A",  # Displaced fracture of lateral end of unspecified clavicle, initial encounter for closed fracture
        "S42033B",  # Displaced fracture of lateral end of unspecified clavicle, initial encounter for open fracture
        "S42034A",  # Nondisplaced fracture of lateral end of right clavicle, initial encounter for closed fracture
        "S42034B",  # Nondisplaced fracture of lateral end of right clavicle, initial encounter for open fracture
        "S42035A",  # Nondisplaced fracture of lateral end of left clavicle, initial encounter for closed fracture
        "S42035B",  # Nondisplaced fracture of lateral end of left clavicle, initial encounter for open fracture
        "S42036A",  # Nondisplaced fracture of lateral end of unspecified clavicle, initial encounter for closed fracture
        "S42036B",  # Nondisplaced fracture of lateral end of unspecified clavicle, initial encounter for open fracture
        "S42101A",  # Fracture of unspecified part of scapula, right shoulder, initial encounter for closed fracture
        "S42101B",  # Fracture of unspecified part of scapula, right shoulder, initial encounter for open fracture
        "S42102A",  # Fracture of unspecified part of scapula, left shoulder, initial encounter for closed fracture
        "S42102B",  # Fracture of unspecified part of scapula, left shoulder, initial encounter for open fracture
        "S42109A",  # Fracture of unspecified part of scapula, unspecified shoulder, initial encounter for closed fracture
        "S42109B",  # Fracture of unspecified part of scapula, unspecified shoulder, initial encounter for open fracture
        "S42111A",  # Displaced fracture of body of scapula, right shoulder, initial encounter for closed fracture
        "S42111B",  # Displaced fracture of body of scapula, right shoulder, initial encounter for open fracture
        "S42112A",  # Displaced fracture of body of scapula, left shoulder, initial encounter for closed fracture
        "S42112B",  # Displaced fracture of body of scapula, left shoulder, initial encounter for open fracture
        "S42113A",  # Displaced fracture of body of scapula, unspecified shoulder, initial encounter for closed fracture
        "S42113B",  # Displaced fracture of body of scapula, unspecified shoulder, initial encounter for open fracture
        "S42114A",  # Nondisplaced fracture of body of scapula, right shoulder, initial encounter for closed fracture
        "S42114B",  # Nondisplaced fracture of body of scapula, right shoulder, initial encounter for open fracture
        "S42115A",  # Nondisplaced fracture of body of scapula, left shoulder, initial encounter for closed fracture
        "S42115B",  # Nondisplaced fracture of body of scapula, left shoulder, initial encounter for open fracture
        "S42116A",  # Nondisplaced fracture of body of scapula, unspecified shoulder, initial encounter for closed fracture
        "S42116B",  # Nondisplaced fracture of body of scapula, unspecified shoulder, initial encounter for open fracture
        "S42121A",  # Displaced fracture of acromial process, right shoulder, initial encounter for closed fracture
        "S42121B",  # Displaced fracture of acromial process, right shoulder, initial encounter for open fracture
        "S42122A",  # Displaced fracture of acromial process, left shoulder, initial encounter for closed fracture
        "S42122B",  # Displaced fracture of acromial process, left shoulder, initial encounter for open fracture
        "S42123A",  # Displaced fracture of acromial process, unspecified shoulder, initial encounter for closed fracture
        "S42123B",  # Displaced fracture of acromial process, unspecified shoulder, initial encounter for open fracture
        "S42124A",  # Nondisplaced fracture of acromial process, right shoulder, initial encounter for closed fracture
        "S42124B",  # Nondisplaced fracture of acromial process, right shoulder, initial encounter for open fracture
        "S42125A",  # Nondisplaced fracture of acromial process, left shoulder, initial encounter for closed fracture
        "S42125B",  # Nondisplaced fracture of acromial process, left shoulder, initial encounter for open fracture
        "S42126A",  # Nondisplaced fracture of acromial process, unspecified shoulder, initial encounter for closed fracture
        "S42126B",  # Nondisplaced fracture of acromial process, unspecified shoulder, initial encounter for open fracture
        "S42131A",  # Displaced fracture of coracoid process, right shoulder, initial encounter for closed fracture
        "S42131B",  # Displaced fracture of coracoid process, right shoulder, initial encounter for open fracture
        "S42132A",  # Displaced fracture of coracoid process, left shoulder, initial encounter for closed fracture
        "S42132B",  # Displaced fracture of coracoid process, left shoulder, initial encounter for open fracture
        "S42133A",  # Displaced fracture of coracoid process, unspecified shoulder, initial encounter for closed fracture
        "S42133B",  # Displaced fracture of coracoid process, unspecified shoulder, initial encounter for open fracture
        "S42134A",  # Nondisplaced fracture of coracoid process, right shoulder, initial encounter for closed fracture
        "S42134B",  # Nondisplaced fracture of coracoid process, right shoulder, initial encounter for open fracture
        "S42135A",  # Nondisplaced fracture of coracoid process, left shoulder, initial encounter for closed fracture
        "S42135B",  # Nondisplaced fracture of coracoid process, left shoulder, initial encounter for open fracture
        "S42136A",  # Nondisplaced fracture of coracoid process, unspecified shoulder, initial encounter for closed fracture
        "S42136B",  # Nondisplaced fracture of coracoid process, unspecified shoulder, initial encounter for open fracture
        "S42141A",  # Displaced fracture of glenoid cavity of scapula, right shoulder, initial encounter for closed fracture
        "S42141B",  # Displaced fracture of glenoid cavity of scapula, right shoulder, initial encounter for open fracture
        "S42142A",  # Displaced fracture of glenoid cavity of scapula, left shoulder, initial encounter for closed fracture
        "S42142B",  # Displaced fracture of glenoid cavity of scapula, left shoulder, initial encounter for open fracture
        "S42143A",  # Displaced fracture of glenoid cavity of scapula, unspecified shoulder, initial encounter for closed fracture
        "S42143B",  # Displaced fracture of glenoid cavity of scapula, unspecified shoulder, initial encounter for open fracture
        "S42144A",  # Nondisplaced fracture of glenoid cavity of scapula, right shoulder, initial encounter for closed fracture
        "S42144B",  # Nondisplaced fracture of glenoid cavity of scapula, right shoulder, initial encounter for open fracture
        "S42145A",  # Nondisplaced fracture of glenoid cavity of scapula, left shoulder, initial encounter for closed fracture
        "S42145B",  # Nondisplaced fracture of glenoid cavity of scapula, left shoulder, initial encounter for open fracture
        "S42146A",  # Nondisplaced fracture of glenoid cavity of scapula, unspecified shoulder, initial encounter for closed fracture
        "S42146B",  # Nondisplaced fracture of glenoid cavity of scapula, unspecified shoulder, initial encounter for open fracture
        "S42151A",  # Displaced fracture of neck of scapula, right shoulder, initial encounter for closed fracture
        "S42151B",  # Displaced fracture of neck of scapula, right shoulder, initial encounter for open fracture
        "S42152A",  # Displaced fracture of neck of scapula, left shoulder, initial encounter for closed fracture
        "S42152B",  # Displaced fracture of neck of scapula, left shoulder, initial encounter for open fracture
        "S42153A",  # Displaced fracture of neck of scapula, unspecified shoulder, initial encounter for closed fracture
        "S42153B",  # Displaced fracture of neck of scapula, unspecified shoulder, initial encounter for open fracture
        "S42154A",  # Nondisplaced fracture of neck of scapula, right shoulder, initial encounter for closed fracture
        "S42154B",  # Nondisplaced fracture of neck of scapula, right shoulder, initial encounter for open fracture
        "S42155A",  # Nondisplaced fracture of neck of scapula, left shoulder, initial encounter for closed fracture
        "S42155B",  # Nondisplaced fracture of neck of scapula, left shoulder, initial encounter for open fracture
        "S42156A",  # Nondisplaced fracture of neck of scapula, unspecified shoulder, initial encounter for closed fracture
        "S42156B",  # Nondisplaced fracture of neck of scapula, unspecified shoulder, initial encounter for open fracture
        "S42191A",  # Fracture of other part of scapula, right shoulder, initial encounter for closed fracture
        "S42191B",  # Fracture of other part of scapula, right shoulder, initial encounter for open fracture
        "S42192A",  # Fracture of other part of scapula, left shoulder, initial encounter for closed fracture
        "S42192B",  # Fracture of other part of scapula, left shoulder, initial encounter for open fracture
        "S42199A",  # Fracture of other part of scapula, unspecified shoulder, initial encounter for closed fracture
        "S42199B",  # Fracture of other part of scapula, unspecified shoulder, initial encounter for open fracture
        "S42201A",  # Unspecified fracture of upper end of right humerus, initial encounter for closed fracture
        "S42201B",  # Unspecified fracture of upper end of right humerus, initial encounter for open fracture
        "S42202A",  # Unspecified fracture of upper end of left humerus, initial encounter for closed fracture
        "S42202B",  # Unspecified fracture of upper end of left humerus, initial encounter for open fracture
        "S42209A",  # Unspecified fracture of upper end of unspecified humerus, initial encounter for closed fracture
        "S42209B",  # Unspecified fracture of upper end of unspecified humerus, initial encounter for open fracture
        "S42211A",  # Unspecified displaced fracture of surgical neck of right humerus, initial encounter for closed fracture
        "S42211B",  # Unspecified displaced fracture of surgical neck of right humerus, initial encounter for open fracture
        "S42212A",  # Unspecified displaced fracture of surgical neck of left humerus, initial encounter for closed fracture
        "S42212B",  # Unspecified displaced fracture of surgical neck of left humerus, initial encounter for open fracture
        "S42213A",  # Unspecified displaced fracture of surgical neck of unspecified humerus, initial encounter for closed fracture
        "S42213B",  # Unspecified displaced fracture of surgical neck of unspecified humerus, initial encounter for open fracture
        "S42214A",  # Unspecified nondisplaced fracture of surgical neck of right humerus, initial encounter for closed fracture
        "S42214B",  # Unspecified nondisplaced fracture of surgical neck of right humerus, initial encounter for open fracture
        "S42215A",  # Unspecified nondisplaced fracture of surgical neck of left humerus, initial encounter for closed fracture
        "S42215B",  # Unspecified nondisplaced fracture of surgical neck of left humerus, initial encounter for open fracture
        "S42216A",  # Unspecified nondisplaced fracture of surgical neck of unspecified humerus, initial encounter for closed fracture
        "S42216B",  # Unspecified nondisplaced fracture of surgical neck of unspecified humerus, initial encounter for open fracture
        "S42221A",  # 2-part displaced fracture of surgical neck of right humerus, initial encounter for closed fracture
        "S42221B",  # 2-part displaced fracture of surgical neck of right humerus, initial encounter for open fracture
        "S42222A",  # 2-part displaced fracture of surgical neck of left humerus, initial encounter for closed fracture
        "S42222B",  # 2-part displaced fracture of surgical neck of left humerus, initial encounter for open fracture
        "S42223A",  # 2-part displaced fracture of surgical neck of unspecified humerus, initial encounter for closed fracture
        "S42223B",  # 2-part displaced fracture of surgical neck of unspecified humerus, initial encounter for open fracture
        "S42224A",  # 2-part nondisplaced fracture of surgical neck of right humerus, initial encounter for closed fracture
        "S42224B",  # 2-part nondisplaced fracture of surgical neck of right humerus, initial encounter for open fracture
        "S42225A",  # 2-part nondisplaced fracture of surgical neck of left humerus, initial encounter for closed fracture
        "S42225B",  # 2-part nondisplaced fracture of surgical neck of left humerus, initial encounter for open fracture
        "S42226A",  # 2-part nondisplaced fracture of surgical neck of unspecified humerus, initial encounter for closed fracture
        "S42226B",  # 2-part nondisplaced fracture of surgical neck of unspecified humerus, initial encounter for open fracture
        "S42231A",  # 3-part fracture of surgical neck of right humerus, initial encounter for closed fracture
        "S42231B",  # 3-part fracture of surgical neck of right humerus, initial encounter for open fracture
        "S42232A",  # 3-part fracture of surgical neck of left humerus, initial encounter for closed fracture
        "S42232B",  # 3-part fracture of surgical neck of left humerus, initial encounter for open fracture
        "S42239A",  # 3-part fracture of surgical neck of unspecified humerus, initial encounter for closed fracture
        "S42239B",  # 3-part fracture of surgical neck of unspecified humerus, initial encounter for open fracture
        "S42241A",  # 4-part fracture of surgical neck of right humerus, initial encounter for closed fracture
        "S42241B",  # 4-part fracture of surgical neck of right humerus, initial encounter for open fracture
        "S42242A",  # 4-part fracture of surgical neck of left humerus, initial encounter for closed fracture
        "S42242B",  # 4-part fracture of surgical neck of left humerus, initial encounter for open fracture
        "S42249A",  # 4-part fracture of surgical neck of unspecified humerus, initial encounter for closed fracture
        "S42249B",  # 4-part fracture of surgical neck of unspecified humerus, initial encounter for open fracture
        "S42251A",  # Displaced fracture of greater tuberosity of right humerus, initial encounter for closed fracture
        "S42251B",  # Displaced fracture of greater tuberosity of right humerus, initial encounter for open fracture
        "S42252A",  # Displaced fracture of greater tuberosity of left humerus, initial encounter for closed fracture
        "S42252B",  # Displaced fracture of greater tuberosity of left humerus, initial encounter for open fracture
        "S42253A",  # Displaced fracture of greater tuberosity of unspecified humerus, initial encounter for closed fracture
        "S42253B",  # Displaced fracture of greater tuberosity of unspecified humerus, initial encounter for open fracture
        "S42254A",  # Nondisplaced fracture of greater tuberosity of right humerus, initial encounter for closed fracture
        "S42254B",  # Nondisplaced fracture of greater tuberosity of right humerus, initial encounter for open fracture
        "S42255A",  # Nondisplaced fracture of greater tuberosity of left humerus, initial encounter for closed fracture
        "S42255B",  # Nondisplaced fracture of greater tuberosity of left humerus, initial encounter for open fracture
        "S42256A",  # Nondisplaced fracture of greater tuberosity of unspecified humerus, initial encounter for closed fracture
        "S42256B",  # Nondisplaced fracture of greater tuberosity of unspecified humerus, initial encounter for open fracture
        "S42261A",  # Displaced fracture of lesser tuberosity of right humerus, initial encounter for closed fracture
        "S42261B",  # Displaced fracture of lesser tuberosity of right humerus, initial encounter for open fracture
        "S42262A",  # Displaced fracture of lesser tuberosity of left humerus, initial encounter for closed fracture
        "S42262B",  # Displaced fracture of lesser tuberosity of left humerus, initial encounter for open fracture
        "S42263A",  # Displaced fracture of lesser tuberosity of unspecified humerus, initial encounter for closed fracture
        "S42263B",  # Displaced fracture of lesser tuberosity of unspecified humerus, initial encounter for open fracture
        "S42264A",  # Nondisplaced fracture of lesser tuberosity of right humerus, initial encounter for closed fracture
        "S42264B",  # Nondisplaced fracture of lesser tuberosity of right humerus, initial encounter for open fracture
        "S42265A",  # Nondisplaced fracture of lesser tuberosity of left humerus, initial encounter for closed fracture
        "S42265B",  # Nondisplaced fracture of lesser tuberosity of left humerus, initial encounter for open fracture
        "S42266A",  # Nondisplaced fracture of lesser tuberosity of unspecified humerus, initial encounter for closed fracture
        "S42266B",  # Nondisplaced fracture of lesser tuberosity of unspecified humerus, initial encounter for open fracture
        "S42271A",  # Torus fracture of upper end of right humerus, initial encounter for closed fracture
        "S42272A",  # Torus fracture of upper end of left humerus, initial encounter for closed fracture
        "S42279A",  # Torus fracture of upper end of unspecified humerus, initial encounter for closed fracture
        "S42291A",  # Other displaced fracture of upper end of right humerus, initial encounter for closed fracture
        "S42291B",  # Other displaced fracture of upper end of right humerus, initial encounter for open fracture
        "S42292A",  # Other displaced fracture of upper end of left humerus, initial encounter for closed fracture
        "S42292B",  # Other displaced fracture of upper end of left humerus, initial encounter for open fracture
        "S42293A",  # Other displaced fracture of upper end of unspecified humerus, initial encounter for closed fracture
        "S42293B",  # Other displaced fracture of upper end of unspecified humerus, initial encounter for open fracture
        "S42294A",  # Other nondisplaced fracture of upper end of right humerus, initial encounter for closed fracture
        "S42294B",  # Other nondisplaced fracture of upper end of right humerus, initial encounter for open fracture
        "S42295A",  # Other nondisplaced fracture of upper end of left humerus, initial encounter for closed fracture
        "S42295B",  # Other nondisplaced fracture of upper end of left humerus, initial encounter for open fracture
        "S42296A",  # Other nondisplaced fracture of upper end of unspecified humerus, initial encounter for closed fracture
        "S42296B",  # Other nondisplaced fracture of upper end of unspecified humerus, initial encounter for open fracture
        "S42301A",  # Unspecified fracture of shaft of humerus, right arm, initial encounter for closed fracture
        "S42301B",  # Unspecified fracture of shaft of humerus, right arm, initial encounter for open fracture
        "S42302A",  # Unspecified fracture of shaft of humerus, left arm, initial encounter for closed fracture
        "S42302B",  # Unspecified fracture of shaft of humerus, left arm, initial encounter for open fracture
        "S42309A",  # Unspecified fracture of shaft of humerus, unspecified arm, initial encounter for closed fracture
        "S42309B",  # Unspecified fracture of shaft of humerus, unspecified arm, initial encounter for open fracture
        "S42311A",  # Greenstick fracture of shaft of humerus, right arm, initial encounter for closed fracture
        "S42312A",  # Greenstick fracture of shaft of humerus, left arm, initial encounter for closed fracture
        "S42319A",  # Greenstick fracture of shaft of humerus, unspecified arm, initial encounter for closed fracture
        "S42321A",  # Displaced transverse fracture of shaft of humerus, right arm, initial encounter for closed fracture
        "S42321B",  # Displaced transverse fracture of shaft of humerus, right arm, initial encounter for open fracture
        "S42322A",  # Displaced transverse fracture of shaft of humerus, left arm, initial encounter for closed fracture
        "S42322B",  # Displaced transverse fracture of shaft of humerus, left arm, initial encounter for open fracture
        "S42323A",  # Displaced transverse fracture of shaft of humerus, unspecified arm, initial encounter for closed fracture
        "S42323B",  # Displaced transverse fracture of shaft of humerus, unspecified arm, initial encounter for open fracture
        "S42324A",  # Nondisplaced transverse fracture of shaft of humerus, right arm, initial encounter for closed fracture
        "S42324B",  # Nondisplaced transverse fracture of shaft of humerus, right arm, initial encounter for open fracture
        "S42325A",  # Nondisplaced transverse fracture of shaft of humerus, left arm, initial encounter for closed fracture
        "S42325B",  # Nondisplaced transverse fracture of shaft of humerus, left arm, initial encounter for open fracture
        "S42326A",  # Nondisplaced transverse fracture of shaft of humerus, unspecified arm, initial encounter for closed fracture
        "S42326B",  # Nondisplaced transverse fracture of shaft of humerus, unspecified arm, initial encounter for open fracture
        "S42331A",  # Displaced oblique fracture of shaft of humerus, right arm, initial encounter for closed fracture
        "S42331B",  # Displaced oblique fracture of shaft of humerus, right arm, initial encounter for open fracture
        "S42332A",  # Displaced oblique fracture of shaft of humerus, left arm, initial encounter for closed fracture
        "S42332B",  # Displaced oblique fracture of shaft of humerus, left arm, initial encounter for open fracture
        "S42333A",  # Displaced oblique fracture of shaft of humerus, unspecified arm, initial encounter for closed fracture
        "S42333B",  # Displaced oblique fracture of shaft of humerus, unspecified arm, initial encounter for open fracture
        "S42334A",  # Nondisplaced oblique fracture of shaft of humerus, right arm, initial encounter for closed fracture
        "S42334B",  # Nondisplaced oblique fracture of shaft of humerus, right arm, initial encounter for open fracture
        "S42335A",  # Nondisplaced oblique fracture of shaft of humerus, left arm, initial encounter for closed fracture
        "S42335B",  # Nondisplaced oblique fracture of shaft of humerus, left arm, initial encounter for open fracture
        "S42336A",  # Nondisplaced oblique fracture of shaft of humerus, unspecified arm, initial encounter for closed fracture
        "S42336B",  # Nondisplaced oblique fracture of shaft of humerus, unspecified arm, initial encounter for open fracture
        "S42341A",  # Displaced spiral fracture of shaft of humerus, right arm, initial encounter for closed fracture
        "S42341B",  # Displaced spiral fracture of shaft of humerus, right arm, initial encounter for open fracture
        "S42342A",  # Displaced spiral fracture of shaft of humerus, left arm, initial encounter for closed fracture
        "S42342B",  # Displaced spiral fracture of shaft of humerus, left arm, initial encounter for open fracture
        "S42343A",  # Displaced spiral fracture of shaft of humerus, unspecified arm, initial encounter for closed fracture
        "S42343B",  # Displaced spiral fracture of shaft of humerus, unspecified arm, initial encounter for open fracture
        "S42344A",  # Nondisplaced spiral fracture of shaft of humerus, right arm, initial encounter for closed fracture
        "S42344B",  # Nondisplaced spiral fracture of shaft of humerus, right arm, initial encounter for open fracture
        "S42345A",  # Nondisplaced spiral fracture of shaft of humerus, left arm, initial encounter for closed fracture
        "S42345B",  # Nondisplaced spiral fracture of shaft of humerus, left arm, initial encounter for open fracture
        "S42346A",  # Nondisplaced spiral fracture of shaft of humerus, unspecified arm, initial encounter for closed fracture
        "S42346B",  # Nondisplaced spiral fracture of shaft of humerus, unspecified arm, initial encounter for open fracture
        "S42351A",  # Displaced comminuted fracture of shaft of humerus, right arm, initial encounter for closed fracture
        "S42351B",  # Displaced comminuted fracture of shaft of humerus, right arm, initial encounter for open fracture
        "S42352A",  # Displaced comminuted fracture of shaft of humerus, left arm, initial encounter for closed fracture
        "S42352B",  # Displaced comminuted fracture of shaft of humerus, left arm, initial encounter for open fracture
        "S42353A",  # Displaced comminuted fracture of shaft of humerus, unspecified arm, initial encounter for closed fracture
        "S42353B",  # Displaced comminuted fracture of shaft of humerus, unspecified arm, initial encounter for open fracture
        "S42354A",  # Nondisplaced comminuted fracture of shaft of humerus, right arm, initial encounter for closed fracture
        "S42354B",  # Nondisplaced comminuted fracture of shaft of humerus, right arm, initial encounter for open fracture
        "S42355A",  # Nondisplaced comminuted fracture of shaft of humerus, left arm, initial encounter for closed fracture
        "S42355B",  # Nondisplaced comminuted fracture of shaft of humerus, left arm, initial encounter for open fracture
        "S42356A",  # Nondisplaced comminuted fracture of shaft of humerus, unspecified arm, initial encounter for closed fracture
        "S42356B",  # Nondisplaced comminuted fracture of shaft of humerus, unspecified arm, initial encounter for open fracture
        "S42361A",  # Displaced segmental fracture of shaft of humerus, right arm, initial encounter for closed fracture
        "S42361B",  # Displaced segmental fracture of shaft of humerus, right arm, initial encounter for open fracture
        "S42362A",  # Displaced segmental fracture of shaft of humerus, left arm, initial encounter for closed fracture
        "S42362B",  # Displaced segmental fracture of shaft of humerus, left arm, initial encounter for open fracture
        "S42363A",  # Displaced segmental fracture of shaft of humerus, unspecified arm, initial encounter for closed fracture
        "S42363B",  # Displaced segmental fracture of shaft of humerus, unspecified arm, initial encounter for open fracture
        "S42364A",  # Nondisplaced segmental fracture of shaft of humerus, right arm, initial encounter for closed fracture
        "S42364B",  # Nondisplaced segmental fracture of shaft of humerus, right arm, initial encounter for open fracture
        "S42365A",  # Nondisplaced segmental fracture of shaft of humerus, left arm, initial encounter for closed fracture
        "S42365B",  # Nondisplaced segmental fracture of shaft of humerus, left arm, initial encounter for open fracture
        "S42366A",  # Nondisplaced segmental fracture of shaft of humerus, unspecified arm, initial encounter for closed fracture
        "S42366B",  # Nondisplaced segmental fracture of shaft of humerus, unspecified arm, initial encounter for open fracture
        "S42391A",  # Other fracture of shaft of right humerus, initial encounter for closed fracture
        "S42391B",  # Other fracture of shaft of right humerus, initial encounter for open fracture
        "S42392A",  # Other fracture of shaft of left humerus, initial encounter for closed fracture
        "S42392B",  # Other fracture of shaft of left humerus, initial encounter for open fracture
        "S42399A",  # Other fracture of shaft of unspecified humerus, initial encounter for closed fracture
        "S42399B",  # Other fracture of shaft of unspecified humerus, initial encounter for open fracture
        "S42401A",  # Unspecified fracture of lower end of right humerus, initial encounter for closed fracture
        "S42401B",  # Unspecified fracture of lower end of right humerus, initial encounter for open fracture
        "S42402A",  # Unspecified fracture of lower end of left humerus, initial encounter for closed fracture
        "S42402B",  # Unspecified fracture of lower end of left humerus, initial encounter for open fracture
        "S42409A",  # Unspecified fracture of lower end of unspecified humerus, initial encounter for closed fracture
        "S42409B",  # Unspecified fracture of lower end of unspecified humerus, initial encounter for open fracture
        "S42411A",  # Displaced simple supracondylar fracture without intercondylar fracture of right humerus, initial encounter for closed fracture
        "S42411B",  # Displaced simple supracondylar fracture without intercondylar fracture of right humerus, initial encounter for open fracture
        "S42412A",  # Displaced simple supracondylar fracture without intercondylar fracture of left humerus, initial encounter for closed fracture
        "S42412B",  # Displaced simple supracondylar fracture without intercondylar fracture of left humerus, initial encounter for open fracture
        "S42413A",  # Displaced simple supracondylar fracture without intercondylar fracture of unspecified humerus, initial encounter for closed fracture
        "S42413B",  # Displaced simple supracondylar fracture without intercondylar fracture of unspecified humerus, initial encounter for open fracture
        "S42414A",  # Nondisplaced simple supracondylar fracture without intercondylar fracture of right humerus, initial encounter for closed fracture
        "S42414B",  # Nondisplaced simple supracondylar fracture without intercondylar fracture of right humerus, initial encounter for open fracture
        "S42415A",  # Nondisplaced simple supracondylar fracture without intercondylar fracture of left humerus, initial encounter for closed fracture
        "S42415B",  # Nondisplaced simple supracondylar fracture without intercondylar fracture of left humerus, initial encounter for open fracture
        "S42416A",  # Nondisplaced simple supracondylar fracture without intercondylar fracture of unspecified humerus, initial encounter for closed fracture
        "S42416B",  # Nondisplaced simple supracondylar fracture without intercondylar fracture of unspecified humerus, initial encounter for open fracture
        "S42421A",  # Displaced comminuted supracondylar fracture without intercondylar fracture of right humerus, initial encounter for closed fracture
        "S42421B",  # Displaced comminuted supracondylar fracture without intercondylar fracture of right humerus, initial encounter for open fracture
        "S42422A",  # Displaced comminuted supracondylar fracture without intercondylar fracture of left humerus, initial encounter for closed fracture
        "S42422B",  # Displaced comminuted supracondylar fracture without intercondylar fracture of left humerus, initial encounter for open fracture
        "S42423A",  # Displaced comminuted supracondylar fracture without intercondylar fracture of unspecified humerus, initial encounter for closed fracture
        "S42423B",  # Displaced comminuted supracondylar fracture without intercondylar fracture of unspecified humerus, initial encounter for open fracture
        "S42424A",  # Nondisplaced comminuted supracondylar fracture without intercondylar fracture of right humerus, initial encounter for closed fracture
        "S42424B",  # Nondisplaced comminuted supracondylar fracture without intercondylar fracture of right humerus, initial encounter for open fracture
        "S42425A",  # Nondisplaced comminuted supracondylar fracture without intercondylar fracture of left humerus, initial encounter for closed fracture
        "S42425B",  # Nondisplaced comminuted supracondylar fracture without intercondylar fracture of left humerus, initial encounter for open fracture
        "S42426A",  # Nondisplaced comminuted supracondylar fracture without intercondylar fracture of unspecified humerus, initial encounter for closed fracture
        "S42426B",  # Nondisplaced comminuted supracondylar fracture without intercondylar fracture of unspecified humerus, initial encounter for open fracture
        "S42431A",  # Displaced fracture (avulsion) of lateral epicondyle of right humerus, initial encounter for closed fracture
        "S42431B",  # Displaced fracture (avulsion) of lateral epicondyle of right humerus, initial encounter for open fracture
        "S42432A",  # Displaced fracture (avulsion) of lateral epicondyle of left humerus, initial encounter for closed fracture
        "S42432B",  # Displaced fracture (avulsion) of lateral epicondyle of left humerus, initial encounter for open fracture
        "S42433A",  # Displaced fracture (avulsion) of lateral epicondyle of unspecified humerus, initial encounter for closed fracture
        "S42433B",  # Displaced fracture (avulsion) of lateral epicondyle of unspecified humerus, initial encounter for open fracture
        "S42434A",  # Nondisplaced fracture (avulsion) of lateral epicondyle of right humerus, initial encounter for closed fracture
        "S42434B",  # Nondisplaced fracture (avulsion) of lateral epicondyle of right humerus, initial encounter for open fracture
        "S42435A",  # Nondisplaced fracture (avulsion) of lateral epicondyle of left humerus, initial encounter for closed fracture
        "S42435B",  # Nondisplaced fracture (avulsion) of lateral epicondyle of left humerus, initial encounter for open fracture
        "S42436A",  # Nondisplaced fracture (avulsion) of lateral epicondyle of unspecified humerus, initial encounter for closed fracture
        "S42436B",  # Nondisplaced fracture (avulsion) of lateral epicondyle of unspecified humerus, initial encounter for open fracture
        "S42441A",  # Displaced fracture (avulsion) of medial epicondyle of right humerus, initial encounter for closed fracture
        "S42441B",  # Displaced fracture (avulsion) of medial epicondyle of right humerus, initial encounter for open fracture
        "S42442A",  # Displaced fracture (avulsion) of medial epicondyle of left humerus, initial encounter for closed fracture
        "S42442B",  # Displaced fracture (avulsion) of medial epicondyle of left humerus, initial encounter for open fracture
        "S42443A",  # Displaced fracture (avulsion) of medial epicondyle of unspecified humerus, initial encounter for closed fracture
        "S42443B",  # Displaced fracture (avulsion) of medial epicondyle of unspecified humerus, initial encounter for open fracture
        "S42444A",  # Nondisplaced fracture (avulsion) of medial epicondyle of right humerus, initial encounter for closed fracture
        "S42444B",  # Nondisplaced fracture (avulsion) of medial epicondyle of right humerus, initial encounter for open fracture
        "S42445A",  # Nondisplaced fracture (avulsion) of medial epicondyle of left humerus, initial encounter for closed fracture
        "S42445B",  # Nondisplaced fracture (avulsion) of medial epicondyle of left humerus, initial encounter for open fracture
        "S42446A",  # Nondisplaced fracture (avulsion) of medial epicondyle of unspecified humerus, initial encounter for closed fracture
        "S42446B",  # Nondisplaced fracture (avulsion) of medial epicondyle of unspecified humerus, initial encounter for open fracture
        "S42447A",  # Incarcerated fracture (avulsion) of medial epicondyle of right humerus, initial encounter for closed fracture
        "S42447B",  # Incarcerated fracture (avulsion) of medial epicondyle of right humerus, initial encounter for open fracture
        "S42448A",  # Incarcerated fracture (avulsion) of medial epicondyle of left humerus, initial encounter for closed fracture
        "S42448B",  # Incarcerated fracture (avulsion) of medial epicondyle of left humerus, initial encounter for open fracture
        "S42449A",  # Incarcerated fracture (avulsion) of medial epicondyle of unspecified humerus, initial encounter for closed fracture
        "S42449B",  # Incarcerated fracture (avulsion) of medial epicondyle of unspecified humerus, initial encounter for open fracture
        "S42451A",  # Displaced fracture of lateral condyle of right humerus, initial encounter for closed fracture
        "S42451B",  # Displaced fracture of lateral condyle of right humerus, initial encounter for open fracture
        "S42452A",  # Displaced fracture of lateral condyle of left humerus, initial encounter for closed fracture
        "S42452B",  # Displaced fracture of lateral condyle of left humerus, initial encounter for open fracture
        "S42453A",  # Displaced fracture of lateral condyle of unspecified humerus, initial encounter for closed fracture
        "S42453B",  # Displaced fracture of lateral condyle of unspecified humerus, initial encounter for open fracture
        "S42454A",  # Nondisplaced fracture of lateral condyle of right humerus, initial encounter for closed fracture
        "S42454B",  # Nondisplaced fracture of lateral condyle of right humerus, initial encounter for open fracture
        "S42455A",  # Nondisplaced fracture of lateral condyle of left humerus, initial encounter for closed fracture
        "S42455B",  # Nondisplaced fracture of lateral condyle of left humerus, initial encounter for open fracture
        "S42456A",  # Nondisplaced fracture of lateral condyle of unspecified humerus, initial encounter for closed fracture
        "S42456B",  # Nondisplaced fracture of lateral condyle of unspecified humerus, initial encounter for open fracture
        "S42461A",  # Displaced fracture of medial condyle of right humerus, initial encounter for closed fracture
        "S42461B",  # Displaced fracture of medial condyle of right humerus, initial encounter for open fracture
        "S42462A",  # Displaced fracture of medial condyle of left humerus, initial encounter for closed fracture
        "S42462B",  # Displaced fracture of medial condyle of left humerus, initial encounter for open fracture
        "S42463A",  # Displaced fracture of medial condyle of unspecified humerus, initial encounter for closed fracture
        "S42463B",  # Displaced fracture of medial condyle of unspecified humerus, initial encounter for open fracture
        "S42464A",  # Nondisplaced fracture of medial condyle of right humerus, initial encounter for closed fracture
        "S42464B",  # Nondisplaced fracture of medial condyle of right humerus, initial encounter for open fracture
        "S42465A",  # Nondisplaced fracture of medial condyle of left humerus, initial encounter for closed fracture
        "S42465B",  # Nondisplaced fracture of medial condyle of left humerus, initial encounter for open fracture
        "S42466A",  # Nondisplaced fracture of medial condyle of unspecified humerus, initial encounter for closed fracture
        "S42466B",  # Nondisplaced fracture of medial condyle of unspecified humerus, initial encounter for open fracture
        "S42471A",  # Displaced transcondylar fracture of right humerus, initial encounter for closed fracture
        "S42471B",  # Displaced transcondylar fracture of right humerus, initial encounter for open fracture
        "S42472A",  # Displaced transcondylar fracture of left humerus, initial encounter for closed fracture
        "S42472B",  # Displaced transcondylar fracture of left humerus, initial encounter for open fracture
        "S42473A",  # Displaced transcondylar fracture of unspecified humerus, initial encounter for closed fracture
        "S42473B",  # Displaced transcondylar fracture of unspecified humerus, initial encounter for open fracture
        "S42474A",  # Nondisplaced transcondylar fracture of right humerus, initial encounter for closed fracture
        "S42474B",  # Nondisplaced transcondylar fracture of right humerus, initial encounter for open fracture
        "S42475A",  # Nondisplaced transcondylar fracture of left humerus, initial encounter for closed fracture
        "S42475B",  # Nondisplaced transcondylar fracture of left humerus, initial encounter for open fracture
        "S42476A",  # Nondisplaced transcondylar fracture of unspecified humerus, initial encounter for closed fracture
        "S42476B",  # Nondisplaced transcondylar fracture of unspecified humerus, initial encounter for open fracture
        "S42481A",  # Torus fracture of lower end of right humerus, initial encounter for closed fracture
        "S42482A",  # Torus fracture of lower end of left humerus, initial encounter for closed fracture
        "S42489A",  # Torus fracture of lower end of unspecified humerus, initial encounter for closed fracture
        "S42491A",  # Other displaced fracture of lower end of right humerus, initial encounter for closed fracture
        "S42491B",  # Other displaced fracture of lower end of right humerus, initial encounter for open fracture
        "S42492A",  # Other displaced fracture of lower end of left humerus, initial encounter for closed fracture
        "S42492B",  # Other displaced fracture of lower end of left humerus, initial encounter for open fracture
        "S42493A",  # Other displaced fracture of lower end of unspecified humerus, initial encounter for closed fracture
        "S42493B",  # Other displaced fracture of lower end of unspecified humerus, initial encounter for open fracture
        "S42494A",  # Other nondisplaced fracture of lower end of right humerus, initial encounter for closed fracture
        "S42494B",  # Other nondisplaced fracture of lower end of right humerus, initial encounter for open fracture
        "S42495A",  # Other nondisplaced fracture of lower end of left humerus, initial encounter for closed fracture
        "S42495B",  # Other nondisplaced fracture of lower end of left humerus, initial encounter for open fracture
        "S42496A",  # Other nondisplaced fracture of lower end of unspecified humerus, initial encounter for closed fracture
        "S42496B",  # Other nondisplaced fracture of lower end of unspecified humerus, initial encounter for open fracture
        "S4290XA",  # Fracture of unspecified shoulder girdle, part unspecified, initial encounter for closed fracture
        "S4290XB",  # Fracture of unspecified shoulder girdle, part unspecified, initial encounter for open fracture
        "S4291XA",  # Fracture of right shoulder girdle, part unspecified, initial encounter for closed fracture
        "S4291XB",  # Fracture of right shoulder girdle, part unspecified, initial encounter for open fracture
        "S4292XA",  # Fracture of left shoulder girdle, part unspecified, initial encounter for closed fracture
        "S4292XB",  # Fracture of left shoulder girdle, part unspecified, initial encounter for open fracture
        "S52001A",  # Unspecified fracture of upper end of right ulna, initial encounter for closed fracture
        "S52001B",  # Unspecified fracture of upper end of right ulna, initial encounter for open fracture type I or II
        "S52001C",  # Unspecified fracture of upper end of right ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52002A",  # Unspecified fracture of upper end of left ulna, initial encounter for closed fracture
        "S52002B",  # Unspecified fracture of upper end of left ulna, initial encounter for open fracture type I or II
        "S52002C",  # Unspecified fracture of upper end of left ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52009A",  # Unspecified fracture of upper end of unspecified ulna, initial encounter for closed fracture
        "S52009B",  # Unspecified fracture of upper end of unspecified ulna, initial encounter for open fracture type I or II
        "S52009C",  # Unspecified fracture of upper end of unspecified ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52011A",  # Torus fracture of upper end of right ulna, initial encounter for closed fracture
        "S52012A",  # Torus fracture of upper end of left ulna, initial encounter for closed fracture
        "S52019A",  # Torus fracture of upper end of unspecified ulna, initial encounter for closed fracture
        "S52021A",  # Displaced fracture of olecranon process without intraarticular extension of right ulna, initial encounter for closed fracture
        "S52021B",  # Displaced fracture of olecranon process without intraarticular extension of right ulna, initial encounter for open fracture type I or II
        "S52021C",  # Displaced fracture of olecranon process without intraarticular extension of right ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52022A",  # Displaced fracture of olecranon process without intraarticular extension of left ulna, initial encounter for closed fracture
        "S52022B",  # Displaced fracture of olecranon process without intraarticular extension of left ulna, initial encounter for open fracture type I or II
        "S52022C",  # Displaced fracture of olecranon process without intraarticular extension of left ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52023A",  # Displaced fracture of olecranon process without intraarticular extension of unspecified ulna, initial encounter for closed fracture
        "S52023B",  # Displaced fracture of olecranon process without intraarticular extension of unspecified ulna, initial encounter for open fracture type I or II
        "S52023C",  # Displaced fracture of olecranon process without intraarticular extension of unspecified ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52024A",  # Nondisplaced fracture of olecranon process without intraarticular extension of right ulna, initial encounter for closed fracture
        "S52024B",  # Nondisplaced fracture of olecranon process without intraarticular extension of right ulna, initial encounter for open fracture type I or II
        "S52024C",  # Nondisplaced fracture of olecranon process without intraarticular extension of right ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52025A",  # Nondisplaced fracture of olecranon process without intraarticular extension of left ulna, initial encounter for closed fracture
        "S52025B",  # Nondisplaced fracture of olecranon process without intraarticular extension of left ulna, initial encounter for open fracture type I or II
        "S52025C",  # Nondisplaced fracture of olecranon process without intraarticular extension of left ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52026A",  # Nondisplaced fracture of olecranon process without intraarticular extension of unspecified ulna, initial encounter for closed fracture
        "S52026B",  # Nondisplaced fracture of olecranon process without intraarticular extension of unspecified ulna, initial encounter for open fracture type I or II
        "S52026C",  # Nondisplaced fracture of olecranon process without intraarticular extension of unspecified ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52031A",  # Displaced fracture of olecranon process with intraarticular extension of right ulna, initial encounter for closed fracture
        "S52031B",  # Displaced fracture of olecranon process with intraarticular extension of right ulna, initial encounter for open fracture type I or II
        "S52031C",  # Displaced fracture of olecranon process with intraarticular extension of right ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52032A",  # Displaced fracture of olecranon process with intraarticular extension of left ulna, initial encounter for closed fracture
        "S52032B",  # Displaced fracture of olecranon process with intraarticular extension of left ulna, initial encounter for open fracture type I or II
        "S52032C",  # Displaced fracture of olecranon process with intraarticular extension of left ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52033A",  # Displaced fracture of olecranon process with intraarticular extension of unspecified ulna, initial encounter for closed fracture
        "S52033B",  # Displaced fracture of olecranon process with intraarticular extension of unspecified ulna, initial encounter for open fracture type I or II
        "S52033C",  # Displaced fracture of olecranon process with intraarticular extension of unspecified ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52034A",  # Nondisplaced fracture of olecranon process with intraarticular extension of right ulna, initial encounter for closed fracture
        "S52034B",  # Nondisplaced fracture of olecranon process with intraarticular extension of right ulna, initial encounter for open fracture type I or II
        "S52034C",  # Nondisplaced fracture of olecranon process with intraarticular extension of right ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52035A",  # Nondisplaced fracture of olecranon process with intraarticular extension of left ulna, initial encounter for closed fracture
        "S52035B",  # Nondisplaced fracture of olecranon process with intraarticular extension of left ulna, initial encounter for open fracture type I or II
        "S52035C",  # Nondisplaced fracture of olecranon process with intraarticular extension of left ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52036A",  # Nondisplaced fracture of olecranon process with intraarticular extension of unspecified ulna, initial encounter for closed fracture
        "S52036B",  # Nondisplaced fracture of olecranon process with intraarticular extension of unspecified ulna, initial encounter for open fracture type I or II
        "S52036C",  # Nondisplaced fracture of olecranon process with intraarticular extension of unspecified ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52041A",  # Displaced fracture of coronoid process of right ulna, initial encounter for closed fracture
        "S52041B",  # Displaced fracture of coronoid process of right ulna, initial encounter for open fracture type I or II
        "S52041C",  # Displaced fracture of coronoid process of right ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52042A",  # Displaced fracture of coronoid process of left ulna, initial encounter for closed fracture
        "S52042B",  # Displaced fracture of coronoid process of left ulna, initial encounter for open fracture type I or II
        "S52042C",  # Displaced fracture of coronoid process of left ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52043A",  # Displaced fracture of coronoid process of unspecified ulna, initial encounter for closed fracture
        "S52043B",  # Displaced fracture of coronoid process of unspecified ulna, initial encounter for open fracture type I or II
        "S52043C",  # Displaced fracture of coronoid process of unspecified ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52044A",  # Nondisplaced fracture of coronoid process of right ulna, initial encounter for closed fracture
        "S52044B",  # Nondisplaced fracture of coronoid process of right ulna, initial encounter for open fracture type I or II
        "S52044C",  # Nondisplaced fracture of coronoid process of right ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52045A",  # Nondisplaced fracture of coronoid process of left ulna, initial encounter for closed fracture
        "S52045B",  # Nondisplaced fracture of coronoid process of left ulna, initial encounter for open fracture type I or II
        "S52045C",  # Nondisplaced fracture of coronoid process of left ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52046A",  # Nondisplaced fracture of coronoid process of unspecified ulna, initial encounter for closed fracture
        "S52046B",  # Nondisplaced fracture of coronoid process of unspecified ulna, initial encounter for open fracture type I or II
        "S52046C",  # Nondisplaced fracture of coronoid process of unspecified ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52091A",  # Other fracture of upper end of right ulna, initial encounter for closed fracture
        "S52091B",  # Other fracture of upper end of right ulna, initial encounter for open fracture type I or II
        "S52091C",  # Other fracture of upper end of right ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52092A",  # Other fracture of upper end of left ulna, initial encounter for closed fracture
        "S52092B",  # Other fracture of upper end of left ulna, initial encounter for open fracture type I or II
        "S52092C",  # Other fracture of upper end of left ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52099A",  # Other fracture of upper end of unspecified ulna, initial encounter for closed fracture
        "S52099B",  # Other fracture of upper end of unspecified ulna, initial encounter for open fracture type I or II
        "S52099C",  # Other fracture of upper end of unspecified ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52101A",  # Unspecified fracture of upper end of right radius, initial encounter for closed fracture
        "S52101B",  # Unspecified fracture of upper end of right radius, initial encounter for open fracture type I or II
        "S52101C",  # Unspecified fracture of upper end of right radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52102A",  # Unspecified fracture of upper end of left radius, initial encounter for closed fracture
        "S52102B",  # Unspecified fracture of upper end of left radius, initial encounter for open fracture type I or II
        "S52102C",  # Unspecified fracture of upper end of left radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52109A",  # Unspecified fracture of upper end of unspecified radius, initial encounter for closed fracture
        "S52109B",  # Unspecified fracture of upper end of unspecified radius, initial encounter for open fracture type I or II
        "S52109C",  # Unspecified fracture of upper end of unspecified radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52111A",  # Torus fracture of upper end of right radius, initial encounter for closed fracture
        "S52112A",  # Torus fracture of upper end of left radius, initial encounter for closed fracture
        "S52119A",  # Torus fracture of upper end of unspecified radius, initial encounter for closed fracture
        "S52121A",  # Displaced fracture of head of right radius, initial encounter for closed fracture
        "S52121B",  # Displaced fracture of head of right radius, initial encounter for open fracture type I or II
        "S52121C",  # Displaced fracture of head of right radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52122A",  # Displaced fracture of head of left radius, initial encounter for closed fracture
        "S52122B",  # Displaced fracture of head of left radius, initial encounter for open fracture type I or II
        "S52122C",  # Displaced fracture of head of left radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52123A",  # Displaced fracture of head of unspecified radius, initial encounter for closed fracture
        "S52123B",  # Displaced fracture of head of unspecified radius, initial encounter for open fracture type I or II
        "S52123C",  # Displaced fracture of head of unspecified radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52124A",  # Nondisplaced fracture of head of right radius, initial encounter for closed fracture
        "S52124B",  # Nondisplaced fracture of head of right radius, initial encounter for open fracture type I or II
        "S52124C",  # Nondisplaced fracture of head of right radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52125A",  # Nondisplaced fracture of head of left radius, initial encounter for closed fracture
        "S52125B",  # Nondisplaced fracture of head of left radius, initial encounter for open fracture type I or II
        "S52125C",  # Nondisplaced fracture of head of left radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52126A",  # Nondisplaced fracture of head of unspecified radius, initial encounter for closed fracture
        "S52126B",  # Nondisplaced fracture of head of unspecified radius, initial encounter for open fracture type I or II
        "S52126C",  # Nondisplaced fracture of head of unspecified radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52131A",  # Displaced fracture of neck of right radius, initial encounter for closed fracture
        "S52131B",  # Displaced fracture of neck of right radius, initial encounter for open fracture type I or II
        "S52131C",  # Displaced fracture of neck of right radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52132A",  # Displaced fracture of neck of left radius, initial encounter for closed fracture
        "S52132B",  # Displaced fracture of neck of left radius, initial encounter for open fracture type I or II
        "S52132C",  # Displaced fracture of neck of left radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52133A",  # Displaced fracture of neck of unspecified radius, initial encounter for closed fracture
        "S52133B",  # Displaced fracture of neck of unspecified radius, initial encounter for open fracture type I or II
        "S52133C",  # Displaced fracture of neck of unspecified radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52134A",  # Nondisplaced fracture of neck of right radius, initial encounter for closed fracture
        "S52134B",  # Nondisplaced fracture of neck of right radius, initial encounter for open fracture type I or II
        "S52134C",  # Nondisplaced fracture of neck of right radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52135A",  # Nondisplaced fracture of neck of left radius, initial encounter for closed fracture
        "S52135B",  # Nondisplaced fracture of neck of left radius, initial encounter for open fracture type I or II
        "S52135C",  # Nondisplaced fracture of neck of left radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52136A",  # Nondisplaced fracture of neck of unspecified radius, initial encounter for closed fracture
        "S52136B",  # Nondisplaced fracture of neck of unspecified radius, initial encounter for open fracture type I or II
        "S52136C",  # Nondisplaced fracture of neck of unspecified radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52181A",  # Other fracture of upper end of right radius, initial encounter for closed fracture
        "S52181B",  # Other fracture of upper end of right radius, initial encounter for open fracture type I or II
        "S52181C",  # Other fracture of upper end of right radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52182A",  # Other fracture of upper end of left radius, initial encounter for closed fracture
        "S52182B",  # Other fracture of upper end of left radius, initial encounter for open fracture type I or II
        "S52182C",  # Other fracture of upper end of left radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52189A",  # Other fracture of upper end of unspecified radius, initial encounter for closed fracture
        "S52189B",  # Other fracture of upper end of unspecified radius, initial encounter for open fracture type I or II
        "S52189C",  # Other fracture of upper end of unspecified radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52201A",  # Unspecified fracture of shaft of right ulna, initial encounter for closed fracture
        "S52201B",  # Unspecified fracture of shaft of right ulna, initial encounter for open fracture type I or II
        "S52201C",  # Unspecified fracture of shaft of right ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52202A",  # Unspecified fracture of shaft of left ulna, initial encounter for closed fracture
        "S52202B",  # Unspecified fracture of shaft of left ulna, initial encounter for open fracture type I or II
        "S52202C",  # Unspecified fracture of shaft of left ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52209A",  # Unspecified fracture of shaft of unspecified ulna, initial encounter for closed fracture
        "S52209B",  # Unspecified fracture of shaft of unspecified ulna, initial encounter for open fracture type I or II
        "S52209C",  # Unspecified fracture of shaft of unspecified ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52211A",  # Greenstick fracture of shaft of right ulna, initial encounter for closed fracture
        "S52212A",  # Greenstick fracture of shaft of left ulna, initial encounter for closed fracture
        "S52219A",  # Greenstick fracture of shaft of unspecified ulna, initial encounter for closed fracture
        "S52221A",  # Displaced transverse fracture of shaft of right ulna, initial encounter for closed fracture
        "S52221B",  # Displaced transverse fracture of shaft of right ulna, initial encounter for open fracture type I or II
        "S52221C",  # Displaced transverse fracture of shaft of right ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52222A",  # Displaced transverse fracture of shaft of left ulna, initial encounter for closed fracture
        "S52222B",  # Displaced transverse fracture of shaft of left ulna, initial encounter for open fracture type I or II
        "S52222C",  # Displaced transverse fracture of shaft of left ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52223A",  # Displaced transverse fracture of shaft of unspecified ulna, initial encounter for closed fracture
        "S52223B",  # Displaced transverse fracture of shaft of unspecified ulna, initial encounter for open fracture type I or II
        "S52223C",  # Displaced transverse fracture of shaft of unspecified ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52224A",  # Nondisplaced transverse fracture of shaft of right ulna, initial encounter for closed fracture
        "S52224B",  # Nondisplaced transverse fracture of shaft of right ulna, initial encounter for open fracture type I or II
        "S52224C",  # Nondisplaced transverse fracture of shaft of right ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52225A",  # Nondisplaced transverse fracture of shaft of left ulna, initial encounter for closed fracture
        "S52225B",  # Nondisplaced transverse fracture of shaft of left ulna, initial encounter for open fracture type I or II
        "S52225C",  # Nondisplaced transverse fracture of shaft of left ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52226A",  # Nondisplaced transverse fracture of shaft of unspecified ulna, initial encounter for closed fracture
        "S52226B",  # Nondisplaced transverse fracture of shaft of unspecified ulna, initial encounter for open fracture type I or II
        "S52226C",  # Nondisplaced transverse fracture of shaft of unspecified ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52231A",  # Displaced oblique fracture of shaft of right ulna, initial encounter for closed fracture
        "S52231B",  # Displaced oblique fracture of shaft of right ulna, initial encounter for open fracture type I or II
        "S52231C",  # Displaced oblique fracture of shaft of right ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52232A",  # Displaced oblique fracture of shaft of left ulna, initial encounter for closed fracture
        "S52232B",  # Displaced oblique fracture of shaft of left ulna, initial encounter for open fracture type I or II
        "S52232C",  # Displaced oblique fracture of shaft of left ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52233A",  # Displaced oblique fracture of shaft of unspecified ulna, initial encounter for closed fracture
        "S52233B",  # Displaced oblique fracture of shaft of unspecified ulna, initial encounter for open fracture type I or II
        "S52233C",  # Displaced oblique fracture of shaft of unspecified ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52234A",  # Nondisplaced oblique fracture of shaft of right ulna, initial encounter for closed fracture
        "S52234B",  # Nondisplaced oblique fracture of shaft of right ulna, initial encounter for open fracture type I or II
        "S52234C",  # Nondisplaced oblique fracture of shaft of right ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52235A",  # Nondisplaced oblique fracture of shaft of left ulna, initial encounter for closed fracture
        "S52235B",  # Nondisplaced oblique fracture of shaft of left ulna, initial encounter for open fracture type I or II
        "S52235C",  # Nondisplaced oblique fracture of shaft of left ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52236A",  # Nondisplaced oblique fracture of shaft of unspecified ulna, initial encounter for closed fracture
        "S52236B",  # Nondisplaced oblique fracture of shaft of unspecified ulna, initial encounter for open fracture type I or II
        "S52236C",  # Nondisplaced oblique fracture of shaft of unspecified ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52241A",  # Displaced spiral fracture of shaft of ulna, right arm, initial encounter for closed fracture
        "S52241B",  # Displaced spiral fracture of shaft of ulna, right arm, initial encounter for open fracture type I or II
        "S52241C",  # Displaced spiral fracture of shaft of ulna, right arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52242A",  # Displaced spiral fracture of shaft of ulna, left arm, initial encounter for closed fracture
        "S52242B",  # Displaced spiral fracture of shaft of ulna, left arm, initial encounter for open fracture type I or II
        "S52242C",  # Displaced spiral fracture of shaft of ulna, left arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52243A",  # Displaced spiral fracture of shaft of ulna, unspecified arm, initial encounter for closed fracture
        "S52243B",  # Displaced spiral fracture of shaft of ulna, unspecified arm, initial encounter for open fracture type I or II
        "S52243C",  # Displaced spiral fracture of shaft of ulna, unspecified arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52244A",  # Nondisplaced spiral fracture of shaft of ulna, right arm, initial encounter for closed fracture
        "S52244B",  # Nondisplaced spiral fracture of shaft of ulna, right arm, initial encounter for open fracture type I or II
        "S52244C",  # Nondisplaced spiral fracture of shaft of ulna, right arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52245A",  # Nondisplaced spiral fracture of shaft of ulna, left arm, initial encounter for closed fracture
        "S52245B",  # Nondisplaced spiral fracture of shaft of ulna, left arm, initial encounter for open fracture type I or II
        "S52245C",  # Nondisplaced spiral fracture of shaft of ulna, left arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52246A",  # Nondisplaced spiral fracture of shaft of ulna, unspecified arm, initial encounter for closed fracture
        "S52246B",  # Nondisplaced spiral fracture of shaft of ulna, unspecified arm, initial encounter for open fracture type I or II
        "S52246C",  # Nondisplaced spiral fracture of shaft of ulna, unspecified arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52251A",  # Displaced comminuted fracture of shaft of ulna, right arm, initial encounter for closed fracture
        "S52251B",  # Displaced comminuted fracture of shaft of ulna, right arm, initial encounter for open fracture type I or II
        "S52251C",  # Displaced comminuted fracture of shaft of ulna, right arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52252A",  # Displaced comminuted fracture of shaft of ulna, left arm, initial encounter for closed fracture
        "S52252B",  # Displaced comminuted fracture of shaft of ulna, left arm, initial encounter for open fracture type I or II
        "S52252C",  # Displaced comminuted fracture of shaft of ulna, left arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52253A",  # Displaced comminuted fracture of shaft of ulna, unspecified arm, initial encounter for closed fracture
        "S52253B",  # Displaced comminuted fracture of shaft of ulna, unspecified arm, initial encounter for open fracture type I or II
        "S52253C",  # Displaced comminuted fracture of shaft of ulna, unspecified arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52254A",  # Nondisplaced comminuted fracture of shaft of ulna, right arm, initial encounter for closed fracture
        "S52254B",  # Nondisplaced comminuted fracture of shaft of ulna, right arm, initial encounter for open fracture type I or II
        "S52254C",  # Nondisplaced comminuted fracture of shaft of ulna, right arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52255A",  # Nondisplaced comminuted fracture of shaft of ulna, left arm, initial encounter for closed fracture
        "S52255B",  # Nondisplaced comminuted fracture of shaft of ulna, left arm, initial encounter for open fracture type I or II
        "S52255C",  # Nondisplaced comminuted fracture of shaft of ulna, left arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52256A",  # Nondisplaced comminuted fracture of shaft of ulna, unspecified arm, initial encounter for closed fracture
        "S52256B",  # Nondisplaced comminuted fracture of shaft of ulna, unspecified arm, initial encounter for open fracture type I or II
        "S52256C",  # Nondisplaced comminuted fracture of shaft of ulna, unspecified arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52261A",  # Displaced segmental fracture of shaft of ulna, right arm, initial encounter for closed fracture
        "S52261B",  # Displaced segmental fracture of shaft of ulna, right arm, initial encounter for open fracture type I or II
        "S52261C",  # Displaced segmental fracture of shaft of ulna, right arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52262A",  # Displaced segmental fracture of shaft of ulna, left arm, initial encounter for closed fracture
        "S52262B",  # Displaced segmental fracture of shaft of ulna, left arm, initial encounter for open fracture type I or II
        "S52262C",  # Displaced segmental fracture of shaft of ulna, left arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52263A",  # Displaced segmental fracture of shaft of ulna, unspecified arm, initial encounter for closed fracture
        "S52263B",  # Displaced segmental fracture of shaft of ulna, unspecified arm, initial encounter for open fracture type I or II
        "S52263C",  # Displaced segmental fracture of shaft of ulna, unspecified arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52264A",  # Nondisplaced segmental fracture of shaft of ulna, right arm, initial encounter for closed fracture
        "S52264B",  # Nondisplaced segmental fracture of shaft of ulna, right arm, initial encounter for open fracture type I or II
        "S52264C",  # Nondisplaced segmental fracture of shaft of ulna, right arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52265A",  # Nondisplaced segmental fracture of shaft of ulna, left arm, initial encounter for closed fracture
        "S52265B",  # Nondisplaced segmental fracture of shaft of ulna, left arm, initial encounter for open fracture type I or II
        "S52265C",  # Nondisplaced segmental fracture of shaft of ulna, left arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52266A",  # Nondisplaced segmental fracture of shaft of ulna, unspecified arm, initial encounter for closed fracture
        "S52266B",  # Nondisplaced segmental fracture of shaft of ulna, unspecified arm, initial encounter for open fracture type I or II
        "S52266C",  # Nondisplaced segmental fracture of shaft of ulna, unspecified arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52271A",  # Monteggia's fracture of right ulna, initial encounter for closed fracture
        "S52271B",  # Monteggia's fracture of right ulna, initial encounter for open fracture type I or II
        "S52271C",  # Monteggia's fracture of right ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52272A",  # Monteggia's fracture of left ulna, initial encounter for closed fracture
        "S52272B",  # Monteggia's fracture of left ulna, initial encounter for open fracture type I or II
        "S52272C",  # Monteggia's fracture of left ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52279A",  # Monteggia's fracture of unspecified ulna, initial encounter for closed fracture
        "S52279B",  # Monteggia's fracture of unspecified ulna, initial encounter for open fracture type I or II
        "S52279C",  # Monteggia's fracture of unspecified ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52281A",  # Bent bone of right ulna, initial encounter for closed fracture
        "S52281B",  # Bent bone of right ulna, initial encounter for open fracture type I or II
        "S52281C",  # Bent bone of right ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52282A",  # Bent bone of left ulna, initial encounter for closed fracture
        "S52282B",  # Bent bone of left ulna, initial encounter for open fracture type I or II
        "S52282C",  # Bent bone of left ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52283A",  # Bent bone of unspecified ulna, initial encounter for closed fracture
        "S52283B",  # Bent bone of unspecified ulna, initial encounter for open fracture type I or II
        "S52283C",  # Bent bone of unspecified ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52291A",  # Other fracture of shaft of right ulna, initial encounter for closed fracture
        "S52291B",  # Other fracture of shaft of right ulna, initial encounter for open fracture type I or II
        "S52291C",  # Other fracture of shaft of right ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52292A",  # Other fracture of shaft of left ulna, initial encounter for closed fracture
        "S52292B",  # Other fracture of shaft of left ulna, initial encounter for open fracture type I or II
        "S52292C",  # Other fracture of shaft of left ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52299A",  # Other fracture of shaft of unspecified ulna, initial encounter for closed fracture
        "S52299B",  # Other fracture of shaft of unspecified ulna, initial encounter for open fracture type I or II
        "S52299C",  # Other fracture of shaft of unspecified ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52301A",  # Unspecified fracture of shaft of right radius, initial encounter for closed fracture
        "S52301B",  # Unspecified fracture of shaft of right radius, initial encounter for open fracture type I or II
        "S52301C",  # Unspecified fracture of shaft of right radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52302A",  # Unspecified fracture of shaft of left radius, initial encounter for closed fracture
        "S52302B",  # Unspecified fracture of shaft of left radius, initial encounter for open fracture type I or II
        "S52302C",  # Unspecified fracture of shaft of left radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52309A",  # Unspecified fracture of shaft of unspecified radius, initial encounter for closed fracture
        "S52309B",  # Unspecified fracture of shaft of unspecified radius, initial encounter for open fracture type I or II
        "S52309C",  # Unspecified fracture of shaft of unspecified radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52311A",  # Greenstick fracture of shaft of radius, right arm, initial encounter for closed fracture
        "S52312A",  # Greenstick fracture of shaft of radius, left arm, initial encounter for closed fracture
        "S52319A",  # Greenstick fracture of shaft of radius, unspecified arm, initial encounter for closed fracture
        "S52321A",  # Displaced transverse fracture of shaft of right radius, initial encounter for closed fracture
        "S52321B",  # Displaced transverse fracture of shaft of right radius, initial encounter for open fracture type I or II
        "S52321C",  # Displaced transverse fracture of shaft of right radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52322A",  # Displaced transverse fracture of shaft of left radius, initial encounter for closed fracture
        "S52322B",  # Displaced transverse fracture of shaft of left radius, initial encounter for open fracture type I or II
        "S52322C",  # Displaced transverse fracture of shaft of left radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52323A",  # Displaced transverse fracture of shaft of unspecified radius, initial encounter for closed fracture
        "S52323B",  # Displaced transverse fracture of shaft of unspecified radius, initial encounter for open fracture type I or II
        "S52323C",  # Displaced transverse fracture of shaft of unspecified radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52324A",  # Nondisplaced transverse fracture of shaft of right radius, initial encounter for closed fracture
        "S52324B",  # Nondisplaced transverse fracture of shaft of right radius, initial encounter for open fracture type I or II
        "S52324C",  # Nondisplaced transverse fracture of shaft of right radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52325A",  # Nondisplaced transverse fracture of shaft of left radius, initial encounter for closed fracture
        "S52325B",  # Nondisplaced transverse fracture of shaft of left radius, initial encounter for open fracture type I or II
        "S52325C",  # Nondisplaced transverse fracture of shaft of left radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52326A",  # Nondisplaced transverse fracture of shaft of unspecified radius, initial encounter for closed fracture
        "S52326B",  # Nondisplaced transverse fracture of shaft of unspecified radius, initial encounter for open fracture type I or II
        "S52326C",  # Nondisplaced transverse fracture of shaft of unspecified radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52331A",  # Displaced oblique fracture of shaft of right radius, initial encounter for closed fracture
        "S52331B",  # Displaced oblique fracture of shaft of right radius, initial encounter for open fracture type I or II
        "S52331C",  # Displaced oblique fracture of shaft of right radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52332A",  # Displaced oblique fracture of shaft of left radius, initial encounter for closed fracture
        "S52332B",  # Displaced oblique fracture of shaft of left radius, initial encounter for open fracture type I or II
        "S52332C",  # Displaced oblique fracture of shaft of left radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52333A",  # Displaced oblique fracture of shaft of unspecified radius, initial encounter for closed fracture
        "S52333B",  # Displaced oblique fracture of shaft of unspecified radius, initial encounter for open fracture type I or II
        "S52333C",  # Displaced oblique fracture of shaft of unspecified radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52334A",  # Nondisplaced oblique fracture of shaft of right radius, initial encounter for closed fracture
        "S52334B",  # Nondisplaced oblique fracture of shaft of right radius, initial encounter for open fracture type I or II
        "S52334C",  # Nondisplaced oblique fracture of shaft of right radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52335A",  # Nondisplaced oblique fracture of shaft of left radius, initial encounter for closed fracture
        "S52335B",  # Nondisplaced oblique fracture of shaft of left radius, initial encounter for open fracture type I or II
        "S52335C",  # Nondisplaced oblique fracture of shaft of left radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52336A",  # Nondisplaced oblique fracture of shaft of unspecified radius, initial encounter for closed fracture
        "S52336B",  # Nondisplaced oblique fracture of shaft of unspecified radius, initial encounter for open fracture type I or II
        "S52336C",  # Nondisplaced oblique fracture of shaft of unspecified radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52341A",  # Displaced spiral fracture of shaft of radius, right arm, initial encounter for closed fracture
        "S52341B",  # Displaced spiral fracture of shaft of radius, right arm, initial encounter for open fracture type I or II
        "S52341C",  # Displaced spiral fracture of shaft of radius, right arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52342A",  # Displaced spiral fracture of shaft of radius, left arm, initial encounter for closed fracture
        "S52342B",  # Displaced spiral fracture of shaft of radius, left arm, initial encounter for open fracture type I or II
        "S52342C",  # Displaced spiral fracture of shaft of radius, left arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52343A",  # Displaced spiral fracture of shaft of radius, unspecified arm, initial encounter for closed fracture
        "S52343B",  # Displaced spiral fracture of shaft of radius, unspecified arm, initial encounter for open fracture type I or II
        "S52343C",  # Displaced spiral fracture of shaft of radius, unspecified arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52344A",  # Nondisplaced spiral fracture of shaft of radius, right arm, initial encounter for closed fracture
        "S52344B",  # Nondisplaced spiral fracture of shaft of radius, right arm, initial encounter for open fracture type I or II
        "S52344C",  # Nondisplaced spiral fracture of shaft of radius, right arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52345A",  # Nondisplaced spiral fracture of shaft of radius, left arm, initial encounter for closed fracture
        "S52345B",  # Nondisplaced spiral fracture of shaft of radius, left arm, initial encounter for open fracture type I or II
        "S52345C",  # Nondisplaced spiral fracture of shaft of radius, left arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52346A",  # Nondisplaced spiral fracture of shaft of radius, unspecified arm, initial encounter for closed fracture
        "S52346B",  # Nondisplaced spiral fracture of shaft of radius, unspecified arm, initial encounter for open fracture type I or II
        "S52346C",  # Nondisplaced spiral fracture of shaft of radius, unspecified arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52351A",  # Displaced comminuted fracture of shaft of radius, right arm, initial encounter for closed fracture
        "S52351B",  # Displaced comminuted fracture of shaft of radius, right arm, initial encounter for open fracture type I or II
        "S52351C",  # Displaced comminuted fracture of shaft of radius, right arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52352A",  # Displaced comminuted fracture of shaft of radius, left arm, initial encounter for closed fracture
        "S52352B",  # Displaced comminuted fracture of shaft of radius, left arm, initial encounter for open fracture type I or II
        "S52352C",  # Displaced comminuted fracture of shaft of radius, left arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52353A",  # Displaced comminuted fracture of shaft of radius, unspecified arm, initial encounter for closed fracture
        "S52353B",  # Displaced comminuted fracture of shaft of radius, unspecified arm, initial encounter for open fracture type I or II
        "S52353C",  # Displaced comminuted fracture of shaft of radius, unspecified arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52354A",  # Nondisplaced comminuted fracture of shaft of radius, right arm, initial encounter for closed fracture
        "S52354B",  # Nondisplaced comminuted fracture of shaft of radius, right arm, initial encounter for open fracture type I or II
        "S52354C",  # Nondisplaced comminuted fracture of shaft of radius, right arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52355A",  # Nondisplaced comminuted fracture of shaft of radius, left arm, initial encounter for closed fracture
        "S52355B",  # Nondisplaced comminuted fracture of shaft of radius, left arm, initial encounter for open fracture type I or II
        "S52355C",  # Nondisplaced comminuted fracture of shaft of radius, left arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52356A",  # Nondisplaced comminuted fracture of shaft of radius, unspecified arm, initial encounter for closed fracture
        "S52356B",  # Nondisplaced comminuted fracture of shaft of radius, unspecified arm, initial encounter for open fracture type I or II
        "S52356C",  # Nondisplaced comminuted fracture of shaft of radius, unspecified arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52361A",  # Displaced segmental fracture of shaft of radius, right arm, initial encounter for closed fracture
        "S52361B",  # Displaced segmental fracture of shaft of radius, right arm, initial encounter for open fracture type I or II
        "S52361C",  # Displaced segmental fracture of shaft of radius, right arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52362A",  # Displaced segmental fracture of shaft of radius, left arm, initial encounter for closed fracture
        "S52362B",  # Displaced segmental fracture of shaft of radius, left arm, initial encounter for open fracture type I or II
        "S52362C",  # Displaced segmental fracture of shaft of radius, left arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52363A",  # Displaced segmental fracture of shaft of radius, unspecified arm, initial encounter for closed fracture
        "S52363B",  # Displaced segmental fracture of shaft of radius, unspecified arm, initial encounter for open fracture type I or II
        "S52363C",  # Displaced segmental fracture of shaft of radius, unspecified arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52364A",  # Nondisplaced segmental fracture of shaft of radius, right arm, initial encounter for closed fracture
        "S52364B",  # Nondisplaced segmental fracture of shaft of radius, right arm, initial encounter for open fracture type I or II
        "S52364C",  # Nondisplaced segmental fracture of shaft of radius, right arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52365A",  # Nondisplaced segmental fracture of shaft of radius, left arm, initial encounter for closed fracture
        "S52365B",  # Nondisplaced segmental fracture of shaft of radius, left arm, initial encounter for open fracture type I or II
        "S52365C",  # Nondisplaced segmental fracture of shaft of radius, left arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52366A",  # Nondisplaced segmental fracture of shaft of radius, unspecified arm, initial encounter for closed fracture
        "S52366B",  # Nondisplaced segmental fracture of shaft of radius, unspecified arm, initial encounter for open fracture type I or II
        "S52366C",  # Nondisplaced segmental fracture of shaft of radius, unspecified arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52371A",  # Galeazzi's fracture of right radius, initial encounter for closed fracture
        "S52371B",  # Galeazzi's fracture of right radius, initial encounter for open fracture type I or II
        "S52371C",  # Galeazzi's fracture of right radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52372A",  # Galeazzi's fracture of left radius, initial encounter for closed fracture
        "S52372B",  # Galeazzi's fracture of left radius, initial encounter for open fracture type I or II
        "S52372C",  # Galeazzi's fracture of left radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52379A",  # Galeazzi's fracture of unspecified radius, initial encounter for closed fracture
        "S52379B",  # Galeazzi's fracture of unspecified radius, initial encounter for open fracture type I or II
        "S52379C",  # Galeazzi's fracture of unspecified radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52381A",  # Bent bone of right radius, initial encounter for closed fracture
        "S52381B",  # Bent bone of right radius, initial encounter for open fracture type I or II
        "S52381C",  # Bent bone of right radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52382A",  # Bent bone of left radius, initial encounter for closed fracture
        "S52382B",  # Bent bone of left radius, initial encounter for open fracture type I or II
        "S52382C",  # Bent bone of left radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52389A",  # Bent bone of unspecified radius, initial encounter for closed fracture
        "S52389B",  # Bent bone of unspecified radius, initial encounter for open fracture type I or II
        "S52389C",  # Bent bone of unspecified radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52391A",  # Other fracture of shaft of radius, right arm, initial encounter for closed fracture
        "S52391B",  # Other fracture of shaft of radius, right arm, initial encounter for open fracture type I or II
        "S52391C",  # Other fracture of shaft of radius, right arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52392A",  # Other fracture of shaft of radius, left arm, initial encounter for closed fracture
        "S52392B",  # Other fracture of shaft of radius, left arm, initial encounter for open fracture type I or II
        "S52392C",  # Other fracture of shaft of radius, left arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52399A",  # Other fracture of shaft of radius, unspecified arm, initial encounter for closed fracture
        "S52399B",  # Other fracture of shaft of radius, unspecified arm, initial encounter for open fracture type I or II
        "S52399C",  # Other fracture of shaft of radius, unspecified arm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52501A",  # Unspecified fracture of the lower end of right radius, initial encounter for closed fracture
        "S52501B",  # Unspecified fracture of the lower end of right radius, initial encounter for open fracture type I or II
        "S52501C",  # Unspecified fracture of the lower end of right radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52502A",  # Unspecified fracture of the lower end of left radius, initial encounter for closed fracture
        "S52502B",  # Unspecified fracture of the lower end of left radius, initial encounter for open fracture type I or II
        "S52502C",  # Unspecified fracture of the lower end of left radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52509A",  # Unspecified fracture of the lower end of unspecified radius, initial encounter for closed fracture
        "S52509B",  # Unspecified fracture of the lower end of unspecified radius, initial encounter for open fracture type I or II
        "S52509C",  # Unspecified fracture of the lower end of unspecified radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52511A",  # Displaced fracture of right radial styloid process, initial encounter for closed fracture
        "S52511B",  # Displaced fracture of right radial styloid process, initial encounter for open fracture type I or II
        "S52511C",  # Displaced fracture of right radial styloid process, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52512A",  # Displaced fracture of left radial styloid process, initial encounter for closed fracture
        "S52512B",  # Displaced fracture of left radial styloid process, initial encounter for open fracture type I or II
        "S52512C",  # Displaced fracture of left radial styloid process, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52513A",  # Displaced fracture of unspecified radial styloid process, initial encounter for closed fracture
        "S52513B",  # Displaced fracture of unspecified radial styloid process, initial encounter for open fracture type I or II
        "S52513C",  # Displaced fracture of unspecified radial styloid process, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52514A",  # Nondisplaced fracture of right radial styloid process, initial encounter for closed fracture
        "S52514B",  # Nondisplaced fracture of right radial styloid process, initial encounter for open fracture type I or II
        "S52514C",  # Nondisplaced fracture of right radial styloid process, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52515A",  # Nondisplaced fracture of left radial styloid process, initial encounter for closed fracture
        "S52515B",  # Nondisplaced fracture of left radial styloid process, initial encounter for open fracture type I or II
        "S52515C",  # Nondisplaced fracture of left radial styloid process, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52516A",  # Nondisplaced fracture of unspecified radial styloid process, initial encounter for closed fracture
        "S52516B",  # Nondisplaced fracture of unspecified radial styloid process, initial encounter for open fracture type I or II
        "S52516C",  # Nondisplaced fracture of unspecified radial styloid process, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52521A",  # Torus fracture of lower end of right radius, initial encounter for closed fracture
        "S52522A",  # Torus fracture of lower end of left radius, initial encounter for closed fracture
        "S52529A",  # Torus fracture of lower end of unspecified radius, initial encounter for closed fracture
        "S52531A",  # Colles' fracture of right radius, initial encounter for closed fracture
        "S52531B",  # Colles' fracture of right radius, initial encounter for open fracture type I or II
        "S52531C",  # Colles' fracture of right radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52532A",  # Colles' fracture of left radius, initial encounter for closed fracture
        "S52532B",  # Colles' fracture of left radius, initial encounter for open fracture type I or II
        "S52532C",  # Colles' fracture of left radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52539A",  # Colles' fracture of unspecified radius, initial encounter for closed fracture
        "S52539B",  # Colles' fracture of unspecified radius, initial encounter for open fracture type I or II
        "S52539C",  # Colles' fracture of unspecified radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52541A",  # Smith's fracture of right radius, initial encounter for closed fracture
        "S52541B",  # Smith's fracture of right radius, initial encounter for open fracture type I or II
        "S52541C",  # Smith's fracture of right radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52542A",  # Smith's fracture of left radius, initial encounter for closed fracture
        "S52542B",  # Smith's fracture of left radius, initial encounter for open fracture type I or II
        "S52542C",  # Smith's fracture of left radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52549A",  # Smith's fracture of unspecified radius, initial encounter for closed fracture
        "S52549B",  # Smith's fracture of unspecified radius, initial encounter for open fracture type I or II
        "S52549C",  # Smith's fracture of unspecified radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52551A",  # Other extraarticular fracture of lower end of right radius, initial encounter for closed fracture
        "S52551B",  # Other extraarticular fracture of lower end of right radius, initial encounter for open fracture type I or II
        "S52551C",  # Other extraarticular fracture of lower end of right radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52552A",  # Other extraarticular fracture of lower end of left radius, initial encounter for closed fracture
        "S52552B",  # Other extraarticular fracture of lower end of left radius, initial encounter for open fracture type I or II
        "S52552C",  # Other extraarticular fracture of lower end of left radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52559A",  # Other extraarticular fracture of lower end of unspecified radius, initial encounter for closed fracture
        "S52559B",  # Other extraarticular fracture of lower end of unspecified radius, initial encounter for open fracture type I or II
        "S52559C",  # Other extraarticular fracture of lower end of unspecified radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52561A",  # Barton's fracture of right radius, initial encounter for closed fracture
        "S52561B",  # Barton's fracture of right radius, initial encounter for open fracture type I or II
        "S52561C",  # Barton's fracture of right radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52562A",  # Barton's fracture of left radius, initial encounter for closed fracture
        "S52562B",  # Barton's fracture of left radius, initial encounter for open fracture type I or II
        "S52562C",  # Barton's fracture of left radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52569A",  # Barton's fracture of unspecified radius, initial encounter for closed fracture
        "S52569B",  # Barton's fracture of unspecified radius, initial encounter for open fracture type I or II
        "S52569C",  # Barton's fracture of unspecified radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52571A",  # Other intraarticular fracture of lower end of right radius, initial encounter for closed fracture
        "S52571B",  # Other intraarticular fracture of lower end of right radius, initial encounter for open fracture type I or II
        "S52571C",  # Other intraarticular fracture of lower end of right radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52572A",  # Other intraarticular fracture of lower end of left radius, initial encounter for closed fracture
        "S52572B",  # Other intraarticular fracture of lower end of left radius, initial encounter for open fracture type I or II
        "S52572C",  # Other intraarticular fracture of lower end of left radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52579A",  # Other intraarticular fracture of lower end of unspecified radius, initial encounter for closed fracture
        "S52579B",  # Other intraarticular fracture of lower end of unspecified radius, initial encounter for open fracture type I or II
        "S52579C",  # Other intraarticular fracture of lower end of unspecified radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52591A",  # Other fractures of lower end of right radius, initial encounter for closed fracture
        "S52591B",  # Other fractures of lower end of right radius, initial encounter for open fracture type I or II
        "S52591C",  # Other fractures of lower end of right radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52592A",  # Other fractures of lower end of left radius, initial encounter for closed fracture
        "S52592B",  # Other fractures of lower end of left radius, initial encounter for open fracture type I or II
        "S52592C",  # Other fractures of lower end of left radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52599A",  # Other fractures of lower end of unspecified radius, initial encounter for closed fracture
        "S52599B",  # Other fractures of lower end of unspecified radius, initial encounter for open fracture type I or II
        "S52599C",  # Other fractures of lower end of unspecified radius, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52601A",  # Unspecified fracture of lower end of right ulna, initial encounter for closed fracture
        "S52601B",  # Unspecified fracture of lower end of right ulna, initial encounter for open fracture type I or II
        "S52601C",  # Unspecified fracture of lower end of right ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52602A",  # Unspecified fracture of lower end of left ulna, initial encounter for closed fracture
        "S52602B",  # Unspecified fracture of lower end of left ulna, initial encounter for open fracture type I or II
        "S52602C",  # Unspecified fracture of lower end of left ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52609A",  # Unspecified fracture of lower end of unspecified ulna, initial encounter for closed fracture
        "S52609B",  # Unspecified fracture of lower end of unspecified ulna, initial encounter for open fracture type I or II
        "S52609C",  # Unspecified fracture of lower end of unspecified ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52611A",  # Displaced fracture of right ulna styloid process, initial encounter for closed fracture
        "S52611B",  # Displaced fracture of right ulna styloid process, initial encounter for open fracture type I or II
        "S52611C",  # Displaced fracture of right ulna styloid process, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52612A",  # Displaced fracture of left ulna styloid process, initial encounter for closed fracture
        "S52612B",  # Displaced fracture of left ulna styloid process, initial encounter for open fracture type I or II
        "S52612C",  # Displaced fracture of left ulna styloid process, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52613A",  # Displaced fracture of unspecified ulna styloid process, initial encounter for closed fracture
        "S52613B",  # Displaced fracture of unspecified ulna styloid process, initial encounter for open fracture type I or II
        "S52613C",  # Displaced fracture of unspecified ulna styloid process, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52614A",  # Nondisplaced fracture of right ulna styloid process, initial encounter for closed fracture
        "S52614B",  # Nondisplaced fracture of right ulna styloid process, initial encounter for open fracture type I or II
        "S52614C",  # Nondisplaced fracture of right ulna styloid process, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52615A",  # Nondisplaced fracture of left ulna styloid process, initial encounter for closed fracture
        "S52615B",  # Nondisplaced fracture of left ulna styloid process, initial encounter for open fracture type I or II
        "S52615C",  # Nondisplaced fracture of left ulna styloid process, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52616A",  # Nondisplaced fracture of unspecified ulna styloid process, initial encounter for closed fracture
        "S52616B",  # Nondisplaced fracture of unspecified ulna styloid process, initial encounter for open fracture type I or II
        "S52616C",  # Nondisplaced fracture of unspecified ulna styloid process, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52621A",  # Torus fracture of lower end of right ulna, initial encounter for closed fracture
        "S52622A",  # Torus fracture of lower end of left ulna, initial encounter for closed fracture
        "S52629A",  # Torus fracture of lower end of unspecified ulna, initial encounter for closed fracture
        "S52691A",  # Other fracture of lower end of right ulna, initial encounter for closed fracture
        "S52691B",  # Other fracture of lower end of right ulna, initial encounter for open fracture type I or II
        "S52691C",  # Other fracture of lower end of right ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52692A",  # Other fracture of lower end of left ulna, initial encounter for closed fracture
        "S52692B",  # Other fracture of lower end of left ulna, initial encounter for open fracture type I or II
        "S52692C",  # Other fracture of lower end of left ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S52699A",  # Other fracture of lower end of unspecified ulna, initial encounter for closed fracture
        "S52699B",  # Other fracture of lower end of unspecified ulna, initial encounter for open fracture type I or II
        "S52699C",  # Other fracture of lower end of unspecified ulna, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S5290XA",  # Unspecified fracture of unspecified forearm, initial encounter for closed fracture
        "S5290XB",  # Unspecified fracture of unspecified forearm, initial encounter for open fracture type I or II
        "S5290XC",  # Unspecified fracture of unspecified forearm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S5291XA",  # Unspecified fracture of right forearm, initial encounter for closed fracture
        "S5291XB",  # Unspecified fracture of right forearm, initial encounter for open fracture type I or II
        "S5291XC",  # Unspecified fracture of right forearm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S5292XA",  # Unspecified fracture of left forearm, initial encounter for closed fracture
        "S5292XB",  # Unspecified fracture of left forearm, initial encounter for open fracture type I or II
        "S5292XC",  # Unspecified fracture of left forearm, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S62001A",  # Unspecified fracture of navicular [scaphoid] bone of right wrist, initial encounter for closed fracture
        "S62001B",  # Unspecified fracture of navicular [scaphoid] bone of right wrist, initial encounter for open fracture
        "S62002A",  # Unspecified fracture of navicular [scaphoid] bone of left wrist, initial encounter for closed fracture
        "S62002B",  # Unspecified fracture of navicular [scaphoid] bone of left wrist, initial encounter for open fracture
        "S62009A",  # Unspecified fracture of navicular [scaphoid] bone of unspecified wrist, initial encounter for closed fracture
        "S62009B",  # Unspecified fracture of navicular [scaphoid] bone of unspecified wrist, initial encounter for open fracture
        "S62011A",  # Displaced fracture of distal pole of navicular [scaphoid] bone of right wrist, initial encounter for closed fracture
        "S62011B",  # Displaced fracture of distal pole of navicular [scaphoid] bone of right wrist, initial encounter for open fracture
        "S62012A",  # Displaced fracture of distal pole of navicular [scaphoid] bone of left wrist, initial encounter for closed fracture
        "S62012B",  # Displaced fracture of distal pole of navicular [scaphoid] bone of left wrist, initial encounter for open fracture
        "S62013A",  # Displaced fracture of distal pole of navicular [scaphoid] bone of unspecified wrist, initial encounter for closed fracture
        "S62013B",  # Displaced fracture of distal pole of navicular [scaphoid] bone of unspecified wrist, initial encounter for open fracture
        "S62014A",  # Nondisplaced fracture of distal pole of navicular [scaphoid] bone of right wrist, initial encounter for closed fracture
        "S62014B",  # Nondisplaced fracture of distal pole of navicular [scaphoid] bone of right wrist, initial encounter for open fracture
        "S62015A",  # Nondisplaced fracture of distal pole of navicular [scaphoid] bone of left wrist, initial encounter for closed fracture
        "S62015B",  # Nondisplaced fracture of distal pole of navicular [scaphoid] bone of left wrist, initial encounter for open fracture
        "S62016A",  # Nondisplaced fracture of distal pole of navicular [scaphoid] bone of unspecified wrist, initial encounter for closed fracture
        "S62016B",  # Nondisplaced fracture of distal pole of navicular [scaphoid] bone of unspecified wrist, initial encounter for open fracture
        "S62021A",  # Displaced fracture of middle third of navicular [scaphoid] bone of right wrist, initial encounter for closed fracture
        "S62021B",  # Displaced fracture of middle third of navicular [scaphoid] bone of right wrist, initial encounter for open fracture
        "S62022A",  # Displaced fracture of middle third of navicular [scaphoid] bone of left wrist, initial encounter for closed fracture
        "S62022B",  # Displaced fracture of middle third of navicular [scaphoid] bone of left wrist, initial encounter for open fracture
        "S62023A",  # Displaced fracture of middle third of navicular [scaphoid] bone of unspecified wrist, initial encounter for closed fracture
        "S62023B",  # Displaced fracture of middle third of navicular [scaphoid] bone of unspecified wrist, initial encounter for open fracture
        "S62024A",  # Nondisplaced fracture of middle third of navicular [scaphoid] bone of right wrist, initial encounter for closed fracture
        "S62024B",  # Nondisplaced fracture of middle third of navicular [scaphoid] bone of right wrist, initial encounter for open fracture
        "S62025A",  # Nondisplaced fracture of middle third of navicular [scaphoid] bone of left wrist, initial encounter for closed fracture
        "S62025B",  # Nondisplaced fracture of middle third of navicular [scaphoid] bone of left wrist, initial encounter for open fracture
        "S62026A",  # Nondisplaced fracture of middle third of navicular [scaphoid] bone of unspecified wrist, initial encounter for closed fracture
        "S62026B",  # Nondisplaced fracture of middle third of navicular [scaphoid] bone of unspecified wrist, initial encounter for open fracture
        "S62031A",  # Displaced fracture of proximal third of navicular [scaphoid] bone of right wrist, initial encounter for closed fracture
        "S62031B",  # Displaced fracture of proximal third of navicular [scaphoid] bone of right wrist, initial encounter for open fracture
        "S62032A",  # Displaced fracture of proximal third of navicular [scaphoid] bone of left wrist, initial encounter for closed fracture
        "S62032B",  # Displaced fracture of proximal third of navicular [scaphoid] bone of left wrist, initial encounter for open fracture
        "S62033A",  # Displaced fracture of proximal third of navicular [scaphoid] bone of unspecified wrist, initial encounter for closed fracture
        "S62033B",  # Displaced fracture of proximal third of navicular [scaphoid] bone of unspecified wrist, initial encounter for open fracture
        "S62034A",  # Nondisplaced fracture of proximal third of navicular [scaphoid] bone of right wrist, initial encounter for closed fracture
        "S62034B",  # Nondisplaced fracture of proximal third of navicular [scaphoid] bone of right wrist, initial encounter for open fracture
        "S62035A",  # Nondisplaced fracture of proximal third of navicular [scaphoid] bone of left wrist, initial encounter for closed fracture
        "S62035B",  # Nondisplaced fracture of proximal third of navicular [scaphoid] bone of left wrist, initial encounter for open fracture
        "S62036A",  # Nondisplaced fracture of proximal third of navicular [scaphoid] bone of unspecified wrist, initial encounter for closed fracture
        "S62036B",  # Nondisplaced fracture of proximal third of navicular [scaphoid] bone of unspecified wrist, initial encounter for open fracture
        "S62101A",  # Fracture of unspecified carpal bone, right wrist, initial encounter for closed fracture
        "S62101B",  # Fracture of unspecified carpal bone, right wrist, initial encounter for open fracture
        "S62102A",  # Fracture of unspecified carpal bone, left wrist, initial encounter for closed fracture
        "S62102B",  # Fracture of unspecified carpal bone, left wrist, initial encounter for open fracture
        "S62109A",  # Fracture of unspecified carpal bone, unspecified wrist, initial encounter for closed fracture
        "S62109B",  # Fracture of unspecified carpal bone, unspecified wrist, initial encounter for open fracture
        "S62111A",  # Displaced fracture of triquetrum [cuneiform] bone, right wrist, initial encounter for closed fracture
        "S62111B",  # Displaced fracture of triquetrum [cuneiform] bone, right wrist, initial encounter for open fracture
        "S62112A",  # Displaced fracture of triquetrum [cuneiform] bone, left wrist, initial encounter for closed fracture
        "S62112B",  # Displaced fracture of triquetrum [cuneiform] bone, left wrist, initial encounter for open fracture
        "S62113A",  # Displaced fracture of triquetrum [cuneiform] bone, unspecified wrist, initial encounter for closed fracture
        "S62113B",  # Displaced fracture of triquetrum [cuneiform] bone, unspecified wrist, initial encounter for open fracture
        "S62114A",  # Nondisplaced fracture of triquetrum [cuneiform] bone, right wrist, initial encounter for closed fracture
        "S62114B",  # Nondisplaced fracture of triquetrum [cuneiform] bone, right wrist, initial encounter for open fracture
        "S62115A",  # Nondisplaced fracture of triquetrum [cuneiform] bone, left wrist, initial encounter for closed fracture
        "S62115B",  # Nondisplaced fracture of triquetrum [cuneiform] bone, left wrist, initial encounter for open fracture
        "S62116A",  # Nondisplaced fracture of triquetrum [cuneiform] bone, unspecified wrist, initial encounter for closed fracture
        "S62116B",  # Nondisplaced fracture of triquetrum [cuneiform] bone, unspecified wrist, initial encounter for open fracture
        "S62121A",  # Displaced fracture of lunate [semilunar], right wrist, initial encounter for closed fracture
        "S62121B",  # Displaced fracture of lunate [semilunar], right wrist, initial encounter for open fracture
        "S62122A",  # Displaced fracture of lunate [semilunar], left wrist, initial encounter for closed fracture
        "S62122B",  # Displaced fracture of lunate [semilunar], left wrist, initial encounter for open fracture
        "S62123A",  # Displaced fracture of lunate [semilunar], unspecified wrist, initial encounter for closed fracture
        "S62123B",  # Displaced fracture of lunate [semilunar], unspecified wrist, initial encounter for open fracture
        "S62124A",  # Nondisplaced fracture of lunate [semilunar], right wrist, initial encounter for closed fracture
        "S62124B",  # Nondisplaced fracture of lunate [semilunar], right wrist, initial encounter for open fracture
        "S62125A",  # Nondisplaced fracture of lunate [semilunar], left wrist, initial encounter for closed fracture
        "S62125B",  # Nondisplaced fracture of lunate [semilunar], left wrist, initial encounter for open fracture
        "S62126A",  # Nondisplaced fracture of lunate [semilunar], unspecified wrist, initial encounter for closed fracture
        "S62126B",  # Nondisplaced fracture of lunate [semilunar], unspecified wrist, initial encounter for open fracture
        "S62131A",  # Displaced fracture of capitate [os magnum] bone, right wrist, initial encounter for closed fracture
        "S62131B",  # Displaced fracture of capitate [os magnum] bone, right wrist, initial encounter for open fracture
        "S62132A",  # Displaced fracture of capitate [os magnum] bone, left wrist, initial encounter for closed fracture
        "S62132B",  # Displaced fracture of capitate [os magnum] bone, left wrist, initial encounter for open fracture
        "S62133A",  # Displaced fracture of capitate [os magnum] bone, unspecified wrist, initial encounter for closed fracture
        "S62133B",  # Displaced fracture of capitate [os magnum] bone, unspecified wrist, initial encounter for open fracture
        "S62134A",  # Nondisplaced fracture of capitate [os magnum] bone, right wrist, initial encounter for closed fracture
        "S62134B",  # Nondisplaced fracture of capitate [os magnum] bone, right wrist, initial encounter for open fracture
        "S62135A",  # Nondisplaced fracture of capitate [os magnum] bone, left wrist, initial encounter for closed fracture
        "S62135B",  # Nondisplaced fracture of capitate [os magnum] bone, left wrist, initial encounter for open fracture
        "S62136A",  # Nondisplaced fracture of capitate [os magnum] bone, unspecified wrist, initial encounter for closed fracture
        "S62136B",  # Nondisplaced fracture of capitate [os magnum] bone, unspecified wrist, initial encounter for open fracture
        "S62141A",  # Displaced fracture of body of hamate [unciform] bone, right wrist, initial encounter for closed fracture
        "S62141B",  # Displaced fracture of body of hamate [unciform] bone, right wrist, initial encounter for open fracture
        "S62142A",  # Displaced fracture of body of hamate [unciform] bone, left wrist, initial encounter for closed fracture
        "S62142B",  # Displaced fracture of body of hamate [unciform] bone, left wrist, initial encounter for open fracture
        "S62143A",  # Displaced fracture of body of hamate [unciform] bone, unspecified wrist, initial encounter for closed fracture
        "S62143B",  # Displaced fracture of body of hamate [unciform] bone, unspecified wrist, initial encounter for open fracture
        "S62144A",  # Nondisplaced fracture of body of hamate [unciform] bone, right wrist, initial encounter for closed fracture
        "S62144B",  # Nondisplaced fracture of body of hamate [unciform] bone, right wrist, initial encounter for open fracture
        "S62145A",  # Nondisplaced fracture of body of hamate [unciform] bone, left wrist, initial encounter for closed fracture
        "S62145B",  # Nondisplaced fracture of body of hamate [unciform] bone, left wrist, initial encounter for open fracture
        "S62146A",  # Nondisplaced fracture of body of hamate [unciform] bone, unspecified wrist, initial encounter for closed fracture
        "S62146B",  # Nondisplaced fracture of body of hamate [unciform] bone, unspecified wrist, initial encounter for open fracture
        "S62151A",  # Displaced fracture of hook process of hamate [unciform] bone, right wrist, initial encounter for closed fracture
        "S62151B",  # Displaced fracture of hook process of hamate [unciform] bone, right wrist, initial encounter for open fracture
        "S62152A",  # Displaced fracture of hook process of hamate [unciform] bone, left wrist, initial encounter for closed fracture
        "S62152B",  # Displaced fracture of hook process of hamate [unciform] bone, left wrist, initial encounter for open fracture
        "S62153A",  # Displaced fracture of hook process of hamate [unciform] bone, unspecified wrist, initial encounter for closed fracture
        "S62153B",  # Displaced fracture of hook process of hamate [unciform] bone, unspecified wrist, initial encounter for open fracture
        "S62154A",  # Nondisplaced fracture of hook process of hamate [unciform] bone, right wrist, initial encounter for closed fracture
        "S62154B",  # Nondisplaced fracture of hook process of hamate [unciform] bone, right wrist, initial encounter for open fracture
        "S62155A",  # Nondisplaced fracture of hook process of hamate [unciform] bone, left wrist, initial encounter for closed fracture
        "S62155B",  # Nondisplaced fracture of hook process of hamate [unciform] bone, left wrist, initial encounter for open fracture
        "S62156A",  # Nondisplaced fracture of hook process of hamate [unciform] bone, unspecified wrist, initial encounter for closed fracture
        "S62156B",  # Nondisplaced fracture of hook process of hamate [unciform] bone, unspecified wrist, initial encounter for open fracture
        "S62161A",  # Displaced fracture of pisiform, right wrist, initial encounter for closed fracture
        "S62161B",  # Displaced fracture of pisiform, right wrist, initial encounter for open fracture
        "S62162A",  # Displaced fracture of pisiform, left wrist, initial encounter for closed fracture
        "S62162B",  # Displaced fracture of pisiform, left wrist, initial encounter for open fracture
        "S62163A",  # Displaced fracture of pisiform, unspecified wrist, initial encounter for closed fracture
        "S62163B",  # Displaced fracture of pisiform, unspecified wrist, initial encounter for open fracture
        "S62164A",  # Nondisplaced fracture of pisiform, right wrist, initial encounter for closed fracture
        "S62164B",  # Nondisplaced fracture of pisiform, right wrist, initial encounter for open fracture
        "S62165A",  # Nondisplaced fracture of pisiform, left wrist, initial encounter for closed fracture
        "S62165B",  # Nondisplaced fracture of pisiform, left wrist, initial encounter for open fracture
        "S62166A",  # Nondisplaced fracture of pisiform, unspecified wrist, initial encounter for closed fracture
        "S62166B",  # Nondisplaced fracture of pisiform, unspecified wrist, initial encounter for open fracture
        "S62171A",  # Displaced fracture of trapezium [larger multangular], right wrist, initial encounter for closed fracture
        "S62171B",  # Displaced fracture of trapezium [larger multangular], right wrist, initial encounter for open fracture
        "S62172A",  # Displaced fracture of trapezium [larger multangular], left wrist, initial encounter for closed fracture
        "S62172B",  # Displaced fracture of trapezium [larger multangular], left wrist, initial encounter for open fracture
        "S62173A",  # Displaced fracture of trapezium [larger multangular], unspecified wrist, initial encounter for closed fracture
        "S62173B",  # Displaced fracture of trapezium [larger multangular], unspecified wrist, initial encounter for open fracture
        "S62174A",  # Nondisplaced fracture of trapezium [larger multangular], right wrist, initial encounter for closed fracture
        "S62174B",  # Nondisplaced fracture of trapezium [larger multangular], right wrist, initial encounter for open fracture
        "S62175A",  # Nondisplaced fracture of trapezium [larger multangular], left wrist, initial encounter for closed fracture
        "S62175B",  # Nondisplaced fracture of trapezium [larger multangular], left wrist, initial encounter for open fracture
        "S62176A",  # Nondisplaced fracture of trapezium [larger multangular], unspecified wrist, initial encounter for closed fracture
        "S62176B",  # Nondisplaced fracture of trapezium [larger multangular], unspecified wrist, initial encounter for open fracture
        "S62181A",  # Displaced fracture of trapezoid [smaller multangular], right wrist, initial encounter for closed fracture
        "S62181B",  # Displaced fracture of trapezoid [smaller multangular], right wrist, initial encounter for open fracture
        "S62182A",  # Displaced fracture of trapezoid [smaller multangular], left wrist, initial encounter for closed fracture
        "S62182B",  # Displaced fracture of trapezoid [smaller multangular], left wrist, initial encounter for open fracture
        "S62183A",  # Displaced fracture of trapezoid [smaller multangular], unspecified wrist, initial encounter for closed fracture
        "S62183B",  # Displaced fracture of trapezoid [smaller multangular], unspecified wrist, initial encounter for open fracture
        "S62184A",  # Nondisplaced fracture of trapezoid [smaller multangular], right wrist, initial encounter for closed fracture
        "S62184B",  # Nondisplaced fracture of trapezoid [smaller multangular], right wrist, initial encounter for open fracture
        "S62185A",  # Nondisplaced fracture of trapezoid [smaller multangular], left wrist, initial encounter for closed fracture
        "S62185B",  # Nondisplaced fracture of trapezoid [smaller multangular], left wrist, initial encounter for open fracture
        "S62186A",  # Nondisplaced fracture of trapezoid [smaller multangular], unspecified wrist, initial encounter for closed fracture
        "S62186B",  # Nondisplaced fracture of trapezoid [smaller multangular], unspecified wrist, initial encounter for open fracture
        "S62201A",  # Unspecified fracture of first metacarpal bone, right hand, initial encounter for closed fracture
        "S62201B",  # Unspecified fracture of first metacarpal bone, right hand, initial encounter for open fracture
        "S62202A",  # Unspecified fracture of first metacarpal bone, left hand, initial encounter for closed fracture
        "S62202B",  # Unspecified fracture of first metacarpal bone, left hand, initial encounter for open fracture
        "S62209A",  # Unspecified fracture of first metacarpal bone, unspecified hand, initial encounter for closed fracture
        "S62209B",  # Unspecified fracture of first metacarpal bone, unspecified hand, initial encounter for open fracture
        "S62211A",  # Bennett's fracture, right hand, initial encounter for closed fracture
        "S62211B",  # Bennett's fracture, right hand, initial encounter for open fracture
        "S62212A",  # Bennett's fracture, left hand, initial encounter for closed fracture
        "S62212B",  # Bennett's fracture, left hand, initial encounter for open fracture
        "S62213A",  # Bennett's fracture, unspecified hand, initial encounter for closed fracture
        "S62213B",  # Bennett's fracture, unspecified hand, initial encounter for open fracture
        "S62221A",  # Displaced Rolando's fracture, right hand, initial encounter for closed fracture
        "S62221B",  # Displaced Rolando's fracture, right hand, initial encounter for open fracture
        "S62222A",  # Displaced Rolando's fracture, left hand, initial encounter for closed fracture
        "S62222B",  # Displaced Rolando's fracture, left hand, initial encounter for open fracture
        "S62223A",  # Displaced Rolando's fracture, unspecified hand, initial encounter for closed fracture
        "S62223B",  # Displaced Rolando's fracture, unspecified hand, initial encounter for open fracture
        "S62224A",  # Nondisplaced Rolando's fracture, right hand, initial encounter for closed fracture
        "S62224B",  # Nondisplaced Rolando's fracture, right hand, initial encounter for open fracture
        "S62225A",  # Nondisplaced Rolando's fracture, left hand, initial encounter for closed fracture
        "S62225B",  # Nondisplaced Rolando's fracture, left hand, initial encounter for open fracture
        "S62226A",  # Nondisplaced Rolando's fracture, unspecified hand, initial encounter for closed fracture
        "S62226B",  # Nondisplaced Rolando's fracture, unspecified hand, initial encounter for open fracture
        "S62231A",  # Other displaced fracture of base of first metacarpal bone, right hand, initial encounter for closed fracture
        "S62231B",  # Other displaced fracture of base of first metacarpal bone, right hand, initial encounter for open fracture
        "S62232A",  # Other displaced fracture of base of first metacarpal bone, left hand, initial encounter for closed fracture
        "S62232B",  # Other displaced fracture of base of first metacarpal bone, left hand, initial encounter for open fracture
        "S62233A",  # Other displaced fracture of base of first metacarpal bone, unspecified hand, initial encounter for closed fracture
        "S62233B",  # Other displaced fracture of base of first metacarpal bone, unspecified hand, initial encounter for open fracture
        "S62234A",  # Other nondisplaced fracture of base of first metacarpal bone, right hand, initial encounter for closed fracture
        "S62234B",  # Other nondisplaced fracture of base of first metacarpal bone, right hand, initial encounter for open fracture
        "S62235A",  # Other nondisplaced fracture of base of first metacarpal bone, left hand, initial encounter for closed fracture
        "S62235B",  # Other nondisplaced fracture of base of first metacarpal bone, left hand, initial encounter for open fracture
        "S62236A",  # Other nondisplaced fracture of base of first metacarpal bone, unspecified hand, initial encounter for closed fracture
        "S62236B",  # Other nondisplaced fracture of base of first metacarpal bone, unspecified hand, initial encounter for open fracture
        "S62241A",  # Displaced fracture of shaft of first metacarpal bone, right hand, initial encounter for closed fracture
        "S62241B",  # Displaced fracture of shaft of first metacarpal bone, right hand, initial encounter for open fracture
        "S62242A",  # Displaced fracture of shaft of first metacarpal bone, left hand, initial encounter for closed fracture
        "S62242B",  # Displaced fracture of shaft of first metacarpal bone, left hand, initial encounter for open fracture
        "S62243A",  # Displaced fracture of shaft of first metacarpal bone, unspecified hand, initial encounter for closed fracture
        "S62243B",  # Displaced fracture of shaft of first metacarpal bone, unspecified hand, initial encounter for open fracture
        "S62244A",  # Nondisplaced fracture of shaft of first metacarpal bone, right hand, initial encounter for closed fracture
        "S62244B",  # Nondisplaced fracture of shaft of first metacarpal bone, right hand, initial encounter for open fracture
        "S62245A",  # Nondisplaced fracture of shaft of first metacarpal bone, left hand, initial encounter for closed fracture
        "S62245B",  # Nondisplaced fracture of shaft of first metacarpal bone, left hand, initial encounter for open fracture
        "S62246A",  # Nondisplaced fracture of shaft of first metacarpal bone, unspecified hand, initial encounter for closed fracture
        "S62246B",  # Nondisplaced fracture of shaft of first metacarpal bone, unspecified hand, initial encounter for open fracture
        "S62251A",  # Displaced fracture of neck of first metacarpal bone, right hand, initial encounter for closed fracture
        "S62251B",  # Displaced fracture of neck of first metacarpal bone, right hand, initial encounter for open fracture
        "S62252A",  # Displaced fracture of neck of first metacarpal bone, left hand, initial encounter for closed fracture
        "S62252B",  # Displaced fracture of neck of first metacarpal bone, left hand, initial encounter for open fracture
        "S62253A",  # Displaced fracture of neck of first metacarpal bone, unspecified hand, initial encounter for closed fracture
        "S62253B",  # Displaced fracture of neck of first metacarpal bone, unspecified hand, initial encounter for open fracture
        "S62254A",  # Nondisplaced fracture of neck of first metacarpal bone, right hand, initial encounter for closed fracture
        "S62254B",  # Nondisplaced fracture of neck of first metacarpal bone, right hand, initial encounter for open fracture
        "S62255A",  # Nondisplaced fracture of neck of first metacarpal bone, left hand, initial encounter for closed fracture
        "S62255B",  # Nondisplaced fracture of neck of first metacarpal bone, left hand, initial encounter for open fracture
        "S62256A",  # Nondisplaced fracture of neck of first metacarpal bone, unspecified hand, initial encounter for closed fracture
        "S62256B",  # Nondisplaced fracture of neck of first metacarpal bone, unspecified hand, initial encounter for open fracture
        "S62291A",  # Other fracture of first metacarpal bone, right hand, initial encounter for closed fracture
        "S62291B",  # Other fracture of first metacarpal bone, right hand, initial encounter for open fracture
        "S62292A",  # Other fracture of first metacarpal bone, left hand, initial encounter for closed fracture
        "S62292B",  # Other fracture of first metacarpal bone, left hand, initial encounter for open fracture
        "S62299A",  # Other fracture of first metacarpal bone, unspecified hand, initial encounter for closed fracture
        "S62299B",  # Other fracture of first metacarpal bone, unspecified hand, initial encounter for open fracture
        "S62300A",  # Unspecified fracture of second metacarpal bone, right hand, initial encounter for closed fracture
        "S62300B",  # Unspecified fracture of second metacarpal bone, right hand, initial encounter for open fracture
        "S62301A",  # Unspecified fracture of second metacarpal bone, left hand, initial encounter for closed fracture
        "S62301B",  # Unspecified fracture of second metacarpal bone, left hand, initial encounter for open fracture
        "S62302A",  # Unspecified fracture of third metacarpal bone, right hand, initial encounter for closed fracture
        "S62302B",  # Unspecified fracture of third metacarpal bone, right hand, initial encounter for open fracture
        "S62303A",  # Unspecified fracture of third metacarpal bone, left hand, initial encounter for closed fracture
        "S62303B",  # Unspecified fracture of third metacarpal bone, left hand, initial encounter for open fracture
        "S62304A",  # Unspecified fracture of fourth metacarpal bone, right hand, initial encounter for closed fracture
        "S62304B",  # Unspecified fracture of fourth metacarpal bone, right hand, initial encounter for open fracture
        "S62305A",  # Unspecified fracture of fourth metacarpal bone, left hand, initial encounter for closed fracture
        "S62305B",  # Unspecified fracture of fourth metacarpal bone, left hand, initial encounter for open fracture
        "S62306A",  # Unspecified fracture of fifth metacarpal bone, right hand, initial encounter for closed fracture
        "S62306B",  # Unspecified fracture of fifth metacarpal bone, right hand, initial encounter for open fracture
        "S62307A",  # Unspecified fracture of fifth metacarpal bone, left hand, initial encounter for closed fracture
        "S62307B",  # Unspecified fracture of fifth metacarpal bone, left hand, initial encounter for open fracture
        "S62308A",  # Unspecified fracture of other metacarpal bone, initial encounter for closed fracture
        "S62308B",  # Unspecified fracture of other metacarpal bone, initial encounter for open fracture
        "S62309A",  # Unspecified fracture of unspecified metacarpal bone, initial encounter for closed fracture
        "S62309B",  # Unspecified fracture of unspecified metacarpal bone, initial encounter for open fracture
        "S62310A",  # Displaced fracture of base of second metacarpal bone, right hand, initial encounter for closed fracture
        "S62310B",  # Displaced fracture of base of second metacarpal bone, right hand, initial encounter for open fracture
        "S62311A",  # Displaced fracture of base of second metacarpal bone, left hand, initial encounter for closed fracture
        "S62311B",  # Displaced fracture of base of second metacarpal bone, left hand, initial encounter for open fracture
        "S62312A",  # Displaced fracture of base of third metacarpal bone, right hand, initial encounter for closed fracture
        "S62312B",  # Displaced fracture of base of third metacarpal bone, right hand, initial encounter for open fracture
        "S62313A",  # Displaced fracture of base of third metacarpal bone, left hand, initial encounter for closed fracture
        "S62313B",  # Displaced fracture of base of third metacarpal bone, left hand, initial encounter for open fracture
        "S62314A",  # Displaced fracture of base of fourth metacarpal bone, right hand, initial encounter for closed fracture
        "S62314B",  # Displaced fracture of base of fourth metacarpal bone, right hand, initial encounter for open fracture
        "S62315A",  # Displaced fracture of base of fourth metacarpal bone, left hand, initial encounter for closed fracture
        "S62315B",  # Displaced fracture of base of fourth metacarpal bone, left hand, initial encounter for open fracture
        "S62316A",  # Displaced fracture of base of fifth metacarpal bone, right hand, initial encounter for closed fracture
        "S62316B",  # Displaced fracture of base of fifth metacarpal bone, right hand, initial encounter for open fracture
        "S62317A",  # Displaced fracture of base of fifth metacarpal bone, left hand, initial encounter for closed fracture
        "S62317B",  # Displaced fracture of base of fifth metacarpal bone, left hand, initial encounter for open fracture
        "S62318A",  # Displaced fracture of base of other metacarpal bone, initial encounter for closed fracture
        "S62318B",  # Displaced fracture of base of other metacarpal bone, initial encounter for open fracture
        "S62319A",  # Displaced fracture of base of unspecified metacarpal bone, initial encounter for closed fracture
        "S62319B",  # Displaced fracture of base of unspecified metacarpal bone, initial encounter for open fracture
        "S62320A",  # Displaced fracture of shaft of second metacarpal bone, right hand, initial encounter for closed fracture
        "S62320B",  # Displaced fracture of shaft of second metacarpal bone, right hand, initial encounter for open fracture
        "S62321A",  # Displaced fracture of shaft of second metacarpal bone, left hand, initial encounter for closed fracture
        "S62321B",  # Displaced fracture of shaft of second metacarpal bone, left hand, initial encounter for open fracture
        "S62322A",  # Displaced fracture of shaft of third metacarpal bone, right hand, initial encounter for closed fracture
        "S62322B",  # Displaced fracture of shaft of third metacarpal bone, right hand, initial encounter for open fracture
        "S62323A",  # Displaced fracture of shaft of third metacarpal bone, left hand, initial encounter for closed fracture
        "S62323B",  # Displaced fracture of shaft of third metacarpal bone, left hand, initial encounter for open fracture
        "S62324A",  # Displaced fracture of shaft of fourth metacarpal bone, right hand, initial encounter for closed fracture
        "S62324B",  # Displaced fracture of shaft of fourth metacarpal bone, right hand, initial encounter for open fracture
        "S62325A",  # Displaced fracture of shaft of fourth metacarpal bone, left hand, initial encounter for closed fracture
        "S62325B",  # Displaced fracture of shaft of fourth metacarpal bone, left hand, initial encounter for open fracture
        "S62326A",  # Displaced fracture of shaft of fifth metacarpal bone, right hand, initial encounter for closed fracture
        "S62326B",  # Displaced fracture of shaft of fifth metacarpal bone, right hand, initial encounter for open fracture
        "S62327A",  # Displaced fracture of shaft of fifth metacarpal bone, left hand, initial encounter for closed fracture
        "S62327B",  # Displaced fracture of shaft of fifth metacarpal bone, left hand, initial encounter for open fracture
        "S62328A",  # Displaced fracture of shaft of other metacarpal bone, initial encounter for closed fracture
        "S62328B",  # Displaced fracture of shaft of other metacarpal bone, initial encounter for open fracture
        "S62329A",  # Displaced fracture of shaft of unspecified metacarpal bone, initial encounter for closed fracture
        "S62329B",  # Displaced fracture of shaft of unspecified metacarpal bone, initial encounter for open fracture
        "S62330A",  # Displaced fracture of neck of second metacarpal bone, right hand, initial encounter for closed fracture
        "S62330B",  # Displaced fracture of neck of second metacarpal bone, right hand, initial encounter for open fracture
        "S62331A",  # Displaced fracture of neck of second metacarpal bone, left hand, initial encounter for closed fracture
        "S62331B",  # Displaced fracture of neck of second metacarpal bone, left hand, initial encounter for open fracture
        "S62332A",  # Displaced fracture of neck of third metacarpal bone, right hand, initial encounter for closed fracture
        "S62332B",  # Displaced fracture of neck of third metacarpal bone, right hand, initial encounter for open fracture
        "S62333A",  # Displaced fracture of neck of third metacarpal bone, left hand, initial encounter for closed fracture
        "S62333B",  # Displaced fracture of neck of third metacarpal bone, left hand, initial encounter for open fracture
        "S62334A",  # Displaced fracture of neck of fourth metacarpal bone, right hand, initial encounter for closed fracture
        "S62334B",  # Displaced fracture of neck of fourth metacarpal bone, right hand, initial encounter for open fracture
        "S62335A",  # Displaced fracture of neck of fourth metacarpal bone, left hand, initial encounter for closed fracture
        "S62335B",  # Displaced fracture of neck of fourth metacarpal bone, left hand, initial encounter for open fracture
        "S62336A",  # Displaced fracture of neck of fifth metacarpal bone, right hand, initial encounter for closed fracture
        "S62336B",  # Displaced fracture of neck of fifth metacarpal bone, right hand, initial encounter for open fracture
        "S62337A",  # Displaced fracture of neck of fifth metacarpal bone, left hand, initial encounter for closed fracture
        "S62337B",  # Displaced fracture of neck of fifth metacarpal bone, left hand, initial encounter for open fracture
        "S62338A",  # Displaced fracture of neck of other metacarpal bone, initial encounter for closed fracture
        "S62338B",  # Displaced fracture of neck of other metacarpal bone, initial encounter for open fracture
        "S62339A",  # Displaced fracture of neck of unspecified metacarpal bone, initial encounter for closed fracture
        "S62339B",  # Displaced fracture of neck of unspecified metacarpal bone, initial encounter for open fracture
        "S62340A",  # Nondisplaced fracture of base of second metacarpal bone, right hand, initial encounter for closed fracture
        "S62340B",  # Nondisplaced fracture of base of second metacarpal bone, right hand, initial encounter for open fracture
        "S62341A",  # Nondisplaced fracture of base of second metacarpal bone, left hand, initial encounter for closed fracture
        "S62341B",  # Nondisplaced fracture of base of second metacarpal bone, left hand, initial encounter for open fracture
        "S62342A",  # Nondisplaced fracture of base of third metacarpal bone, right hand, initial encounter for closed fracture
        "S62342B",  # Nondisplaced fracture of base of third metacarpal bone, right hand, initial encounter for open fracture
        "S62343A",  # Nondisplaced fracture of base of third metacarpal bone, left hand, initial encounter for closed fracture
        "S62343B",  # Nondisplaced fracture of base of third metacarpal bone, left hand, initial encounter for open fracture
        "S62344A",  # Nondisplaced fracture of base of fourth metacarpal bone, right hand, initial encounter for closed fracture
        "S62344B",  # Nondisplaced fracture of base of fourth metacarpal bone, right hand, initial encounter for open fracture
        "S62345A",  # Nondisplaced fracture of base of fourth metacarpal bone, left hand, initial encounter for closed fracture
        "S62345B",  # Nondisplaced fracture of base of fourth metacarpal bone, left hand, initial encounter for open fracture
        "S62346A",  # Nondisplaced fracture of base of fifth metacarpal bone, right hand, initial encounter for closed fracture
        "S62346B",  # Nondisplaced fracture of base of fifth metacarpal bone, right hand, initial encounter for open fracture
        "S62347A",  # Nondisplaced fracture of base of fifth metacarpal bone, left hand, initial encounter for closed fracture
        "S62347B",  # Nondisplaced fracture of base of fifth metacarpal bone, left hand, initial encounter for open fracture
        "S62348A",  # Nondisplaced fracture of base of other metacarpal bone, initial encounter for closed fracture
        "S62348B",  # Nondisplaced fracture of base of other metacarpal bone, initial encounter for open fracture
        "S62349A",  # Nondisplaced fracture of base of unspecified metacarpal bone, initial encounter for closed fracture
        "S62349B",  # Nondisplaced fracture of base of unspecified metacarpal bone, initial encounter for open fracture
        "S62350A",  # Nondisplaced fracture of shaft of second metacarpal bone, right hand, initial encounter for closed fracture
        "S62350B",  # Nondisplaced fracture of shaft of second metacarpal bone, right hand, initial encounter for open fracture
        "S62351A",  # Nondisplaced fracture of shaft of second metacarpal bone, left hand, initial encounter for closed fracture
        "S62351B",  # Nondisplaced fracture of shaft of second metacarpal bone, left hand, initial encounter for open fracture
        "S62352A",  # Nondisplaced fracture of shaft of third metacarpal bone, right hand, initial encounter for closed fracture
        "S62352B",  # Nondisplaced fracture of shaft of third metacarpal bone, right hand, initial encounter for open fracture
        "S62353A",  # Nondisplaced fracture of shaft of third metacarpal bone, left hand, initial encounter for closed fracture
        "S62353B",  # Nondisplaced fracture of shaft of third metacarpal bone, left hand, initial encounter for open fracture
        "S62354A",  # Nondisplaced fracture of shaft of fourth metacarpal bone, right hand, initial encounter for closed fracture
        "S62354B",  # Nondisplaced fracture of shaft of fourth metacarpal bone, right hand, initial encounter for open fracture
        "S62355A",  # Nondisplaced fracture of shaft of fourth metacarpal bone, left hand, initial encounter for closed fracture
        "S62355B",  # Nondisplaced fracture of shaft of fourth metacarpal bone, left hand, initial encounter for open fracture
        "S62356A",  # Nondisplaced fracture of shaft of fifth metacarpal bone, right hand, initial encounter for closed fracture
        "S62356B",  # Nondisplaced fracture of shaft of fifth metacarpal bone, right hand, initial encounter for open fracture
        "S62357A",  # Nondisplaced fracture of shaft of fifth metacarpal bone, left hand, initial encounter for closed fracture
        "S62357B",  # Nondisplaced fracture of shaft of fifth metacarpal bone, left hand, initial encounter for open fracture
        "S62358A",  # Nondisplaced fracture of shaft of other metacarpal bone, initial encounter for closed fracture
        "S62358B",  # Nondisplaced fracture of shaft of other metacarpal bone, initial encounter for open fracture
        "S62359A",  # Nondisplaced fracture of shaft of unspecified metacarpal bone, initial encounter for closed fracture
        "S62359B",  # Nondisplaced fracture of shaft of unspecified metacarpal bone, initial encounter for open fracture
        "S62360A",  # Nondisplaced fracture of neck of second metacarpal bone, right hand, initial encounter for closed fracture
        "S62360B",  # Nondisplaced fracture of neck of second metacarpal bone, right hand, initial encounter for open fracture
        "S62361A",  # Nondisplaced fracture of neck of second metacarpal bone, left hand, initial encounter for closed fracture
        "S62361B",  # Nondisplaced fracture of neck of second metacarpal bone, left hand, initial encounter for open fracture
        "S62362A",  # Nondisplaced fracture of neck of third metacarpal bone, right hand, initial encounter for closed fracture
        "S62362B",  # Nondisplaced fracture of neck of third metacarpal bone, right hand, initial encounter for open fracture
        "S62363A",  # Nondisplaced fracture of neck of third metacarpal bone, left hand, initial encounter for closed fracture
        "S62363B",  # Nondisplaced fracture of neck of third metacarpal bone, left hand, initial encounter for open fracture
        "S62364A",  # Nondisplaced fracture of neck of fourth metacarpal bone, right hand, initial encounter for closed fracture
        "S62364B",  # Nondisplaced fracture of neck of fourth metacarpal bone, right hand, initial encounter for open fracture
        "S62365A",  # Nondisplaced fracture of neck of fourth metacarpal bone, left hand, initial encounter for closed fracture
        "S62365B",  # Nondisplaced fracture of neck of fourth metacarpal bone, left hand, initial encounter for open fracture
        "S62366A",  # Nondisplaced fracture of neck of fifth metacarpal bone, right hand, initial encounter for closed fracture
        "S62366B",  # Nondisplaced fracture of neck of fifth metacarpal bone, right hand, initial encounter for open fracture
        "S62367A",  # Nondisplaced fracture of neck of fifth metacarpal bone, left hand, initial encounter for closed fracture
        "S62367B",  # Nondisplaced fracture of neck of fifth metacarpal bone, left hand, initial encounter for open fracture
        "S62368A",  # Nondisplaced fracture of neck of other metacarpal bone, initial encounter for closed fracture
        "S62368B",  # Nondisplaced fracture of neck of other metacarpal bone, initial encounter for open fracture
        "S62369A",  # Nondisplaced fracture of neck of unspecified metacarpal bone, initial encounter for closed fracture
        "S62369B",  # Nondisplaced fracture of neck of unspecified metacarpal bone, initial encounter for open fracture
        "S62390A",  # Other fracture of second metacarpal bone, right hand, initial encounter for closed fracture
        "S62390B",  # Other fracture of second metacarpal bone, right hand, initial encounter for open fracture
        "S62391A",  # Other fracture of second metacarpal bone, left hand, initial encounter for closed fracture
        "S62391B",  # Other fracture of second metacarpal bone, left hand, initial encounter for open fracture
        "S62392A",  # Other fracture of third metacarpal bone, right hand, initial encounter for closed fracture
        "S62392B",  # Other fracture of third metacarpal bone, right hand, initial encounter for open fracture
        "S62393A",  # Other fracture of third metacarpal bone, left hand, initial encounter for closed fracture
        "S62393B",  # Other fracture of third metacarpal bone, left hand, initial encounter for open fracture
        "S62394A",  # Other fracture of fourth metacarpal bone, right hand, initial encounter for closed fracture
        "S62394B",  # Other fracture of fourth metacarpal bone, right hand, initial encounter for open fracture
        "S62395A",  # Other fracture of fourth metacarpal bone, left hand, initial encounter for closed fracture
        "S62395B",  # Other fracture of fourth metacarpal bone, left hand, initial encounter for open fracture
        "S62396A",  # Other fracture of fifth metacarpal bone, right hand, initial encounter for closed fracture
        "S62396B",  # Other fracture of fifth metacarpal bone, right hand, initial encounter for open fracture
        "S62397A",  # Other fracture of fifth metacarpal bone, left hand, initial encounter for closed fracture
        "S62397B",  # Other fracture of fifth metacarpal bone, left hand, initial encounter for open fracture
        "S62398A",  # Other fracture of other metacarpal bone, initial encounter for closed fracture
        "S62398B",  # Other fracture of other metacarpal bone, initial encounter for open fracture
        "S62399A",  # Other fracture of unspecified metacarpal bone, initial encounter for closed fracture
        "S62399B",  # Other fracture of unspecified metacarpal bone, initial encounter for open fracture
        "S6290XA",  # Unspecified fracture of unspecified wrist and hand, initial encounter for closed fracture
        "S6290XB",  # Unspecified fracture of unspecified wrist and hand, initial encounter for open fracture
        "S6291XA",  # Unspecified fracture of right wrist and hand, initial encounter for closed fracture
        "S6291XB",  # Unspecified fracture of right wrist and hand, initial encounter for open fracture
        "S6292XA",  # Unspecified fracture of left wrist and hand, initial encounter for closed fracture
        "S6292XB",  # Unspecified fracture of left wrist and hand, initial encounter for open fracture
        "S72001A",  # Fracture of unspecified part of neck of right femur, initial encounter for closed fracture
        "S72001B",  # Fracture of unspecified part of neck of right femur, initial encounter for open fracture type I or II
        "S72001C",  # Fracture of unspecified part of neck of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72002A",  # Fracture of unspecified part of neck of left femur, initial encounter for closed fracture
        "S72002B",  # Fracture of unspecified part of neck of left femur, initial encounter for open fracture type I or II
        "S72002C",  # Fracture of unspecified part of neck of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72009A",  # Fracture of unspecified part of neck of unspecified femur, initial encounter for closed fracture
        "S72009B",  # Fracture of unspecified part of neck of unspecified femur, initial encounter for open fracture type I or II
        "S72009C",  # Fracture of unspecified part of neck of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72011A",  # Unspecified intracapsular fracture of right femur, initial encounter for closed fracture
        "S72011B",  # Unspecified intracapsular fracture of right femur, initial encounter for open fracture type I or II
        "S72011C",  # Unspecified intracapsular fracture of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72012A",  # Unspecified intracapsular fracture of left femur, initial encounter for closed fracture
        "S72012B",  # Unspecified intracapsular fracture of left femur, initial encounter for open fracture type I or II
        "S72012C",  # Unspecified intracapsular fracture of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72019A",  # Unspecified intracapsular fracture of unspecified femur, initial encounter for closed fracture
        "S72019B",  # Unspecified intracapsular fracture of unspecified femur, initial encounter for open fracture type I or II
        "S72019C",  # Unspecified intracapsular fracture of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72031A",  # Displaced midcervical fracture of right femur, initial encounter for closed fracture
        "S72031B",  # Displaced midcervical fracture of right femur, initial encounter for open fracture type I or II
        "S72031C",  # Displaced midcervical fracture of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72032A",  # Displaced midcervical fracture of left femur, initial encounter for closed fracture
        "S72032B",  # Displaced midcervical fracture of left femur, initial encounter for open fracture type I or II
        "S72032C",  # Displaced midcervical fracture of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72033A",  # Displaced midcervical fracture of unspecified femur, initial encounter for closed fracture
        "S72033B",  # Displaced midcervical fracture of unspecified femur, initial encounter for open fracture type I or II
        "S72033C",  # Displaced midcervical fracture of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72034A",  # Nondisplaced midcervical fracture of right femur, initial encounter for closed fracture
        "S72034B",  # Nondisplaced midcervical fracture of right femur, initial encounter for open fracture type I or II
        "S72034C",  # Nondisplaced midcervical fracture of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72035A",  # Nondisplaced midcervical fracture of left femur, initial encounter for closed fracture
        "S72035B",  # Nondisplaced midcervical fracture of left femur, initial encounter for open fracture type I or II
        "S72035C",  # Nondisplaced midcervical fracture of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72036A",  # Nondisplaced midcervical fracture of unspecified femur, initial encounter for closed fracture
        "S72036B",  # Nondisplaced midcervical fracture of unspecified femur, initial encounter for open fracture type I or II
        "S72036C",  # Nondisplaced midcervical fracture of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72041A",  # Displaced fracture of base of neck of right femur, initial encounter for closed fracture
        "S72041B",  # Displaced fracture of base of neck of right femur, initial encounter for open fracture type I or II
        "S72041C",  # Displaced fracture of base of neck of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72042A",  # Displaced fracture of base of neck of left femur, initial encounter for closed fracture
        "S72042B",  # Displaced fracture of base of neck of left femur, initial encounter for open fracture type I or II
        "S72042C",  # Displaced fracture of base of neck of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72043A",  # Displaced fracture of base of neck of unspecified femur, initial encounter for closed fracture
        "S72043B",  # Displaced fracture of base of neck of unspecified femur, initial encounter for open fracture type I or II
        "S72043C",  # Displaced fracture of base of neck of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72044A",  # Nondisplaced fracture of base of neck of right femur, initial encounter for closed fracture
        "S72044B",  # Nondisplaced fracture of base of neck of right femur, initial encounter for open fracture type I or II
        "S72044C",  # Nondisplaced fracture of base of neck of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72045A",  # Nondisplaced fracture of base of neck of left femur, initial encounter for closed fracture
        "S72045B",  # Nondisplaced fracture of base of neck of left femur, initial encounter for open fracture type I or II
        "S72045C",  # Nondisplaced fracture of base of neck of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72046A",  # Nondisplaced fracture of base of neck of unspecified femur, initial encounter for closed fracture
        "S72046B",  # Nondisplaced fracture of base of neck of unspecified femur, initial encounter for open fracture type I or II
        "S72046C",  # Nondisplaced fracture of base of neck of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72051A",  # Unspecified fracture of head of right femur, initial encounter for closed fracture
        "S72051B",  # Unspecified fracture of head of right femur, initial encounter for open fracture type I or II
        "S72051C",  # Unspecified fracture of head of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72052A",  # Unspecified fracture of head of left femur, initial encounter for closed fracture
        "S72052B",  # Unspecified fracture of head of left femur, initial encounter for open fracture type I or II
        "S72052C",  # Unspecified fracture of head of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72059A",  # Unspecified fracture of head of unspecified femur, initial encounter for closed fracture
        "S72059B",  # Unspecified fracture of head of unspecified femur, initial encounter for open fracture type I or II
        "S72059C",  # Unspecified fracture of head of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72061A",  # Displaced articular fracture of head of right femur, initial encounter for closed fracture
        "S72061B",  # Displaced articular fracture of head of right femur, initial encounter for open fracture type I or II
        "S72061C",  # Displaced articular fracture of head of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72062A",  # Displaced articular fracture of head of left femur, initial encounter for closed fracture
        "S72062B",  # Displaced articular fracture of head of left femur, initial encounter for open fracture type I or II
        "S72062C",  # Displaced articular fracture of head of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72063A",  # Displaced articular fracture of head of unspecified femur, initial encounter for closed fracture
        "S72063B",  # Displaced articular fracture of head of unspecified femur, initial encounter for open fracture type I or II
        "S72063C",  # Displaced articular fracture of head of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72064A",  # Nondisplaced articular fracture of head of right femur, initial encounter for closed fracture
        "S72064B",  # Nondisplaced articular fracture of head of right femur, initial encounter for open fracture type I or II
        "S72064C",  # Nondisplaced articular fracture of head of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72065A",  # Nondisplaced articular fracture of head of left femur, initial encounter for closed fracture
        "S72065B",  # Nondisplaced articular fracture of head of left femur, initial encounter for open fracture type I or II
        "S72065C",  # Nondisplaced articular fracture of head of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72066A",  # Nondisplaced articular fracture of head of unspecified femur, initial encounter for closed fracture
        "S72066B",  # Nondisplaced articular fracture of head of unspecified femur, initial encounter for open fracture type I or II
        "S72066C",  # Nondisplaced articular fracture of head of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72091A",  # Other fracture of head and neck of right femur, initial encounter for closed fracture
        "S72091B",  # Other fracture of head and neck of right femur, initial encounter for open fracture type I or II
        "S72091C",  # Other fracture of head and neck of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72092A",  # Other fracture of head and neck of left femur, initial encounter for closed fracture
        "S72092B",  # Other fracture of head and neck of left femur, initial encounter for open fracture type I or II
        "S72092C",  # Other fracture of head and neck of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72099A",  # Other fracture of head and neck of unspecified femur, initial encounter for closed fracture
        "S72099B",  # Other fracture of head and neck of unspecified femur, initial encounter for open fracture type I or II
        "S72099C",  # Other fracture of head and neck of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72101A",  # Unspecified trochanteric fracture of right femur, initial encounter for closed fracture
        "S72101B",  # Unspecified trochanteric fracture of right femur, initial encounter for open fracture type I or II
        "S72101C",  # Unspecified trochanteric fracture of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72102A",  # Unspecified trochanteric fracture of left femur, initial encounter for closed fracture
        "S72102B",  # Unspecified trochanteric fracture of left femur, initial encounter for open fracture type I or II
        "S72102C",  # Unspecified trochanteric fracture of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72109A",  # Unspecified trochanteric fracture of unspecified femur, initial encounter for closed fracture
        "S72109B",  # Unspecified trochanteric fracture of unspecified femur, initial encounter for open fracture type I or II
        "S72109C",  # Unspecified trochanteric fracture of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72111A",  # Displaced fracture of greater trochanter of right femur, initial encounter for closed fracture
        "S72111B",  # Displaced fracture of greater trochanter of right femur, initial encounter for open fracture type I or II
        "S72111C",  # Displaced fracture of greater trochanter of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72112A",  # Displaced fracture of greater trochanter of left femur, initial encounter for closed fracture
        "S72112B",  # Displaced fracture of greater trochanter of left femur, initial encounter for open fracture type I or II
        "S72112C",  # Displaced fracture of greater trochanter of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72113A",  # Displaced fracture of greater trochanter of unspecified femur, initial encounter for closed fracture
        "S72113B",  # Displaced fracture of greater trochanter of unspecified femur, initial encounter for open fracture type I or II
        "S72113C",  # Displaced fracture of greater trochanter of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72114A",  # Nondisplaced fracture of greater trochanter of right femur, initial encounter for closed fracture
        "S72114B",  # Nondisplaced fracture of greater trochanter of right femur, initial encounter for open fracture type I or II
        "S72114C",  # Nondisplaced fracture of greater trochanter of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72115A",  # Nondisplaced fracture of greater trochanter of left femur, initial encounter for closed fracture
        "S72115B",  # Nondisplaced fracture of greater trochanter of left femur, initial encounter for open fracture type I or II
        "S72115C",  # Nondisplaced fracture of greater trochanter of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72116A",  # Nondisplaced fracture of greater trochanter of unspecified femur, initial encounter for closed fracture
        "S72116B",  # Nondisplaced fracture of greater trochanter of unspecified femur, initial encounter for open fracture type I or II
        "S72116C",  # Nondisplaced fracture of greater trochanter of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72121A",  # Displaced fracture of lesser trochanter of right femur, initial encounter for closed fracture
        "S72121B",  # Displaced fracture of lesser trochanter of right femur, initial encounter for open fracture type I or II
        "S72121C",  # Displaced fracture of lesser trochanter of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72122A",  # Displaced fracture of lesser trochanter of left femur, initial encounter for closed fracture
        "S72122B",  # Displaced fracture of lesser trochanter of left femur, initial encounter for open fracture type I or II
        "S72122C",  # Displaced fracture of lesser trochanter of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72123A",  # Displaced fracture of lesser trochanter of unspecified femur, initial encounter for closed fracture
        "S72123B",  # Displaced fracture of lesser trochanter of unspecified femur, initial encounter for open fracture type I or II
        "S72123C",  # Displaced fracture of lesser trochanter of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72124A",  # Nondisplaced fracture of lesser trochanter of right femur, initial encounter for closed fracture
        "S72124B",  # Nondisplaced fracture of lesser trochanter of right femur, initial encounter for open fracture type I or II
        "S72124C",  # Nondisplaced fracture of lesser trochanter of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72125A",  # Nondisplaced fracture of lesser trochanter of left femur, initial encounter for closed fracture
        "S72125B",  # Nondisplaced fracture of lesser trochanter of left femur, initial encounter for open fracture type I or II
        "S72125C",  # Nondisplaced fracture of lesser trochanter of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72126A",  # Nondisplaced fracture of lesser trochanter of unspecified femur, initial encounter for closed fracture
        "S72126B",  # Nondisplaced fracture of lesser trochanter of unspecified femur, initial encounter for open fracture type I or II
        "S72126C",  # Nondisplaced fracture of lesser trochanter of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72141A",  # Displaced intertrochanteric fracture of right femur, initial encounter for closed fracture
        "S72141B",  # Displaced intertrochanteric fracture of right femur, initial encounter for open fracture type I or II
        "S72141C",  # Displaced intertrochanteric fracture of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72142A",  # Displaced intertrochanteric fracture of left femur, initial encounter for closed fracture
        "S72142B",  # Displaced intertrochanteric fracture of left femur, initial encounter for open fracture type I or II
        "S72142C",  # Displaced intertrochanteric fracture of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72143A",  # Displaced intertrochanteric fracture of unspecified femur, initial encounter for closed fracture
        "S72143B",  # Displaced intertrochanteric fracture of unspecified femur, initial encounter for open fracture type I or II
        "S72143C",  # Displaced intertrochanteric fracture of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72144A",  # Nondisplaced intertrochanteric fracture of right femur, initial encounter for closed fracture
        "S72144B",  # Nondisplaced intertrochanteric fracture of right femur, initial encounter for open fracture type I or II
        "S72144C",  # Nondisplaced intertrochanteric fracture of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72145A",  # Nondisplaced intertrochanteric fracture of left femur, initial encounter for closed fracture
        "S72145B",  # Nondisplaced intertrochanteric fracture of left femur, initial encounter for open fracture type I or II
        "S72145C",  # Nondisplaced intertrochanteric fracture of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72146A",  # Nondisplaced intertrochanteric fracture of unspecified femur, initial encounter for closed fracture
        "S72146B",  # Nondisplaced intertrochanteric fracture of unspecified femur, initial encounter for open fracture type I or II
        "S72146C",  # Nondisplaced intertrochanteric fracture of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S7221XA",  # Displaced subtrochanteric fracture of right femur, initial encounter for closed fracture
        "S7221XB",  # Displaced subtrochanteric fracture of right femur, initial encounter for open fracture type I or II
        "S7221XC",  # Displaced subtrochanteric fracture of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S7222XA",  # Displaced subtrochanteric fracture of left femur, initial encounter for closed fracture
        "S7222XB",  # Displaced subtrochanteric fracture of left femur, initial encounter for open fracture type I or II
        "S7222XC",  # Displaced subtrochanteric fracture of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S7223XA",  # Displaced subtrochanteric fracture of unspecified femur, initial encounter for closed fracture
        "S7223XB",  # Displaced subtrochanteric fracture of unspecified femur, initial encounter for open fracture type I or II
        "S7223XC",  # Displaced subtrochanteric fracture of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S7224XA",  # Nondisplaced subtrochanteric fracture of right femur, initial encounter for closed fracture
        "S7224XB",  # Nondisplaced subtrochanteric fracture of right femur, initial encounter for open fracture type I or II
        "S7224XC",  # Nondisplaced subtrochanteric fracture of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S7225XA",  # Nondisplaced subtrochanteric fracture of left femur, initial encounter for closed fracture
        "S7225XB",  # Nondisplaced subtrochanteric fracture of left femur, initial encounter for open fracture type I or II
        "S7225XC",  # Nondisplaced subtrochanteric fracture of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S7226XA",  # Nondisplaced subtrochanteric fracture of unspecified femur, initial encounter for closed fracture
        "S7226XB",  # Nondisplaced subtrochanteric fracture of unspecified femur, initial encounter for open fracture type I or II
        "S7226XC",  # Nondisplaced subtrochanteric fracture of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72301A",  # Unspecified fracture of shaft of right femur, initial encounter for closed fracture
        "S72301B",  # Unspecified fracture of shaft of right femur, initial encounter for open fracture type I or II
        "S72301C",  # Unspecified fracture of shaft of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72302A",  # Unspecified fracture of shaft of left femur, initial encounter for closed fracture
        "S72302B",  # Unspecified fracture of shaft of left femur, initial encounter for open fracture type I or II
        "S72302C",  # Unspecified fracture of shaft of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72309A",  # Unspecified fracture of shaft of unspecified femur, initial encounter for closed fracture
        "S72309B",  # Unspecified fracture of shaft of unspecified femur, initial encounter for open fracture type I or II
        "S72309C",  # Unspecified fracture of shaft of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72321A",  # Displaced transverse fracture of shaft of right femur, initial encounter for closed fracture
        "S72321B",  # Displaced transverse fracture of shaft of right femur, initial encounter for open fracture type I or II
        "S72321C",  # Displaced transverse fracture of shaft of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72322A",  # Displaced transverse fracture of shaft of left femur, initial encounter for closed fracture
        "S72322B",  # Displaced transverse fracture of shaft of left femur, initial encounter for open fracture type I or II
        "S72322C",  # Displaced transverse fracture of shaft of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72323A",  # Displaced transverse fracture of shaft of unspecified femur, initial encounter for closed fracture
        "S72323B",  # Displaced transverse fracture of shaft of unspecified femur, initial encounter for open fracture type I or II
        "S72323C",  # Displaced transverse fracture of shaft of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72324A",  # Nondisplaced transverse fracture of shaft of right femur, initial encounter for closed fracture
        "S72324B",  # Nondisplaced transverse fracture of shaft of right femur, initial encounter for open fracture type I or II
        "S72324C",  # Nondisplaced transverse fracture of shaft of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72325A",  # Nondisplaced transverse fracture of shaft of left femur, initial encounter for closed fracture
        "S72325B",  # Nondisplaced transverse fracture of shaft of left femur, initial encounter for open fracture type I or II
        "S72325C",  # Nondisplaced transverse fracture of shaft of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72326A",  # Nondisplaced transverse fracture of shaft of unspecified femur, initial encounter for closed fracture
        "S72326B",  # Nondisplaced transverse fracture of shaft of unspecified femur, initial encounter for open fracture type I or II
        "S72326C",  # Nondisplaced transverse fracture of shaft of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72331A",  # Displaced oblique fracture of shaft of right femur, initial encounter for closed fracture
        "S72331B",  # Displaced oblique fracture of shaft of right femur, initial encounter for open fracture type I or II
        "S72331C",  # Displaced oblique fracture of shaft of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72332A",  # Displaced oblique fracture of shaft of left femur, initial encounter for closed fracture
        "S72332B",  # Displaced oblique fracture of shaft of left femur, initial encounter for open fracture type I or II
        "S72332C",  # Displaced oblique fracture of shaft of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72333A",  # Displaced oblique fracture of shaft of unspecified femur, initial encounter for closed fracture
        "S72333B",  # Displaced oblique fracture of shaft of unspecified femur, initial encounter for open fracture type I or II
        "S72333C",  # Displaced oblique fracture of shaft of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72334A",  # Nondisplaced oblique fracture of shaft of right femur, initial encounter for closed fracture
        "S72334B",  # Nondisplaced oblique fracture of shaft of right femur, initial encounter for open fracture type I or II
        "S72334C",  # Nondisplaced oblique fracture of shaft of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72335A",  # Nondisplaced oblique fracture of shaft of left femur, initial encounter for closed fracture
        "S72335B",  # Nondisplaced oblique fracture of shaft of left femur, initial encounter for open fracture type I or II
        "S72335C",  # Nondisplaced oblique fracture of shaft of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72336A",  # Nondisplaced oblique fracture of shaft of unspecified femur, initial encounter for closed fracture
        "S72336B",  # Nondisplaced oblique fracture of shaft of unspecified femur, initial encounter for open fracture type I or II
        "S72336C",  # Nondisplaced oblique fracture of shaft of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72341A",  # Displaced spiral fracture of shaft of right femur, initial encounter for closed fracture
        "S72341B",  # Displaced spiral fracture of shaft of right femur, initial encounter for open fracture type I or II
        "S72341C",  # Displaced spiral fracture of shaft of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72342A",  # Displaced spiral fracture of shaft of left femur, initial encounter for closed fracture
        "S72342B",  # Displaced spiral fracture of shaft of left femur, initial encounter for open fracture type I or II
        "S72342C",  # Displaced spiral fracture of shaft of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72343A",  # Displaced spiral fracture of shaft of unspecified femur, initial encounter for closed fracture
        "S72343B",  # Displaced spiral fracture of shaft of unspecified femur, initial encounter for open fracture type I or II
        "S72343C",  # Displaced spiral fracture of shaft of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72344A",  # Nondisplaced spiral fracture of shaft of right femur, initial encounter for closed fracture
        "S72344B",  # Nondisplaced spiral fracture of shaft of right femur, initial encounter for open fracture type I or II
        "S72344C",  # Nondisplaced spiral fracture of shaft of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72345A",  # Nondisplaced spiral fracture of shaft of left femur, initial encounter for closed fracture
        "S72345B",  # Nondisplaced spiral fracture of shaft of left femur, initial encounter for open fracture type I or II
        "S72345C",  # Nondisplaced spiral fracture of shaft of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72346A",  # Nondisplaced spiral fracture of shaft of unspecified femur, initial encounter for closed fracture
        "S72346B",  # Nondisplaced spiral fracture of shaft of unspecified femur, initial encounter for open fracture type I or II
        "S72346C",  # Nondisplaced spiral fracture of shaft of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72351A",  # Displaced comminuted fracture of shaft of right femur, initial encounter for closed fracture
        "S72351B",  # Displaced comminuted fracture of shaft of right femur, initial encounter for open fracture type I or II
        "S72351C",  # Displaced comminuted fracture of shaft of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72352A",  # Displaced comminuted fracture of shaft of left femur, initial encounter for closed fracture
        "S72352B",  # Displaced comminuted fracture of shaft of left femur, initial encounter for open fracture type I or II
        "S72352C",  # Displaced comminuted fracture of shaft of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72353A",  # Displaced comminuted fracture of shaft of unspecified femur, initial encounter for closed fracture
        "S72353B",  # Displaced comminuted fracture of shaft of unspecified femur, initial encounter for open fracture type I or II
        "S72353C",  # Displaced comminuted fracture of shaft of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72354A",  # Nondisplaced comminuted fracture of shaft of right femur, initial encounter for closed fracture
        "S72354B",  # Nondisplaced comminuted fracture of shaft of right femur, initial encounter for open fracture type I or II
        "S72354C",  # Nondisplaced comminuted fracture of shaft of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72355A",  # Nondisplaced comminuted fracture of shaft of left femur, initial encounter for closed fracture
        "S72355B",  # Nondisplaced comminuted fracture of shaft of left femur, initial encounter for open fracture type I or II
        "S72355C",  # Nondisplaced comminuted fracture of shaft of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72356A",  # Nondisplaced comminuted fracture of shaft of unspecified femur, initial encounter for closed fracture
        "S72356B",  # Nondisplaced comminuted fracture of shaft of unspecified femur, initial encounter for open fracture type I or II
        "S72356C",  # Nondisplaced comminuted fracture of shaft of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72361A",  # Displaced segmental fracture of shaft of right femur, initial encounter for closed fracture
        "S72361B",  # Displaced segmental fracture of shaft of right femur, initial encounter for open fracture type I or II
        "S72361C",  # Displaced segmental fracture of shaft of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72362A",  # Displaced segmental fracture of shaft of left femur, initial encounter for closed fracture
        "S72362B",  # Displaced segmental fracture of shaft of left femur, initial encounter for open fracture type I or II
        "S72362C",  # Displaced segmental fracture of shaft of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72363A",  # Displaced segmental fracture of shaft of unspecified femur, initial encounter for closed fracture
        "S72363B",  # Displaced segmental fracture of shaft of unspecified femur, initial encounter for open fracture type I or II
        "S72363C",  # Displaced segmental fracture of shaft of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72364A",  # Nondisplaced segmental fracture of shaft of right femur, initial encounter for closed fracture
        "S72364B",  # Nondisplaced segmental fracture of shaft of right femur, initial encounter for open fracture type I or II
        "S72364C",  # Nondisplaced segmental fracture of shaft of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72365A",  # Nondisplaced segmental fracture of shaft of left femur, initial encounter for closed fracture
        "S72365B",  # Nondisplaced segmental fracture of shaft of left femur, initial encounter for open fracture type I or II
        "S72365C",  # Nondisplaced segmental fracture of shaft of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72366A",  # Nondisplaced segmental fracture of shaft of unspecified femur, initial encounter for closed fracture
        "S72366B",  # Nondisplaced segmental fracture of shaft of unspecified femur, initial encounter for open fracture type I or II
        "S72366C",  # Nondisplaced segmental fracture of shaft of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72391A",  # Other fracture of shaft of right femur, initial encounter for closed fracture
        "S72391B",  # Other fracture of shaft of right femur, initial encounter for open fracture type I or II
        "S72391C",  # Other fracture of shaft of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72392A",  # Other fracture of shaft of left femur, initial encounter for closed fracture
        "S72392B",  # Other fracture of shaft of left femur, initial encounter for open fracture type I or II
        "S72392C",  # Other fracture of shaft of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72399A",  # Other fracture of shaft of unspecified femur, initial encounter for closed fracture
        "S72399B",  # Other fracture of shaft of unspecified femur, initial encounter for open fracture type I or II
        "S72399C",  # Other fracture of shaft of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72401A",  # Unspecified fracture of lower end of right femur, initial encounter for closed fracture
        "S72401B",  # Unspecified fracture of lower end of right femur, initial encounter for open fracture type I or II
        "S72401C",  # Unspecified fracture of lower end of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72402A",  # Unspecified fracture of lower end of left femur, initial encounter for closed fracture
        "S72402B",  # Unspecified fracture of lower end of left femur, initial encounter for open fracture type I or II
        "S72402C",  # Unspecified fracture of lower end of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72409A",  # Unspecified fracture of lower end of unspecified femur, initial encounter for closed fracture
        "S72409B",  # Unspecified fracture of lower end of unspecified femur, initial encounter for open fracture type I or II
        "S72409C",  # Unspecified fracture of lower end of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72411A",  # Displaced unspecified condyle fracture of lower end of right femur, initial encounter for closed fracture
        "S72411B",  # Displaced unspecified condyle fracture of lower end of right femur, initial encounter for open fracture type I or II
        "S72411C",  # Displaced unspecified condyle fracture of lower end of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72412A",  # Displaced unspecified condyle fracture of lower end of left femur, initial encounter for closed fracture
        "S72412B",  # Displaced unspecified condyle fracture of lower end of left femur, initial encounter for open fracture type I or II
        "S72412C",  # Displaced unspecified condyle fracture of lower end of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72413A",  # Displaced unspecified condyle fracture of lower end of unspecified femur, initial encounter for closed fracture
        "S72413B",  # Displaced unspecified condyle fracture of lower end of unspecified femur, initial encounter for open fracture type I or II
        "S72413C",  # Displaced unspecified condyle fracture of lower end of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72414A",  # Nondisplaced unspecified condyle fracture of lower end of right femur, initial encounter for closed fracture
        "S72414B",  # Nondisplaced unspecified condyle fracture of lower end of right femur, initial encounter for open fracture type I or II
        "S72414C",  # Nondisplaced unspecified condyle fracture of lower end of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72415A",  # Nondisplaced unspecified condyle fracture of lower end of left femur, initial encounter for closed fracture
        "S72415B",  # Nondisplaced unspecified condyle fracture of lower end of left femur, initial encounter for open fracture type I or II
        "S72415C",  # Nondisplaced unspecified condyle fracture of lower end of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72416A",  # Nondisplaced unspecified condyle fracture of lower end of unspecified femur, initial encounter for closed fracture
        "S72416B",  # Nondisplaced unspecified condyle fracture of lower end of unspecified femur, initial encounter for open fracture type I or II
        "S72416C",  # Nondisplaced unspecified condyle fracture of lower end of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72421A",  # Displaced fracture of lateral condyle of right femur, initial encounter for closed fracture
        "S72421B",  # Displaced fracture of lateral condyle of right femur, initial encounter for open fracture type I or II
        "S72421C",  # Displaced fracture of lateral condyle of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72422A",  # Displaced fracture of lateral condyle of left femur, initial encounter for closed fracture
        "S72422B",  # Displaced fracture of lateral condyle of left femur, initial encounter for open fracture type I or II
        "S72422C",  # Displaced fracture of lateral condyle of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72423A",  # Displaced fracture of lateral condyle of unspecified femur, initial encounter for closed fracture
        "S72423B",  # Displaced fracture of lateral condyle of unspecified femur, initial encounter for open fracture type I or II
        "S72423C",  # Displaced fracture of lateral condyle of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72424A",  # Nondisplaced fracture of lateral condyle of right femur, initial encounter for closed fracture
        "S72424B",  # Nondisplaced fracture of lateral condyle of right femur, initial encounter for open fracture type I or II
        "S72424C",  # Nondisplaced fracture of lateral condyle of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72425A",  # Nondisplaced fracture of lateral condyle of left femur, initial encounter for closed fracture
        "S72425B",  # Nondisplaced fracture of lateral condyle of left femur, initial encounter for open fracture type I or II
        "S72425C",  # Nondisplaced fracture of lateral condyle of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72426A",  # Nondisplaced fracture of lateral condyle of unspecified femur, initial encounter for closed fracture
        "S72426B",  # Nondisplaced fracture of lateral condyle of unspecified femur, initial encounter for open fracture type I or II
        "S72426C",  # Nondisplaced fracture of lateral condyle of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72431A",  # Displaced fracture of medial condyle of right femur, initial encounter for closed fracture
        "S72431B",  # Displaced fracture of medial condyle of right femur, initial encounter for open fracture type I or II
        "S72431C",  # Displaced fracture of medial condyle of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72432A",  # Displaced fracture of medial condyle of left femur, initial encounter for closed fracture
        "S72432B",  # Displaced fracture of medial condyle of left femur, initial encounter for open fracture type I or II
        "S72432C",  # Displaced fracture of medial condyle of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72433A",  # Displaced fracture of medial condyle of unspecified femur, initial encounter for closed fracture
        "S72433B",  # Displaced fracture of medial condyle of unspecified femur, initial encounter for open fracture type I or II
        "S72433C",  # Displaced fracture of medial condyle of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72434A",  # Nondisplaced fracture of medial condyle of right femur, initial encounter for closed fracture
        "S72434B",  # Nondisplaced fracture of medial condyle of right femur, initial encounter for open fracture type I or II
        "S72434C",  # Nondisplaced fracture of medial condyle of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72435A",  # Nondisplaced fracture of medial condyle of left femur, initial encounter for closed fracture
        "S72435B",  # Nondisplaced fracture of medial condyle of left femur, initial encounter for open fracture type I or II
        "S72435C",  # Nondisplaced fracture of medial condyle of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72436A",  # Nondisplaced fracture of medial condyle of unspecified femur, initial encounter for closed fracture
        "S72436B",  # Nondisplaced fracture of medial condyle of unspecified femur, initial encounter for open fracture type I or II
        "S72436C",  # Nondisplaced fracture of medial condyle of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72451A",  # Displaced supracondylar fracture without intracondylar extension of lower end of right femur, initial encounter for closed fracture
        "S72451B",  # Displaced supracondylar fracture without intracondylar extension of lower end of right femur, initial encounter for open fracture type I or II
        "S72451C",  # Displaced supracondylar fracture without intracondylar extension of lower end of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72452A",  # Displaced supracondylar fracture without intracondylar extension of lower end of left femur, initial encounter for closed fracture
        "S72452B",  # Displaced supracondylar fracture without intracondylar extension of lower end of left femur, initial encounter for open fracture type I or II
        "S72452C",  # Displaced supracondylar fracture without intracondylar extension of lower end of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72453A",  # Displaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, initial encounter for closed fracture
        "S72453B",  # Displaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, initial encounter for open fracture type I or II
        "S72453C",  # Displaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72454A",  # Nondisplaced supracondylar fracture without intracondylar extension of lower end of right femur, initial encounter for closed fracture
        "S72454B",  # Nondisplaced supracondylar fracture without intracondylar extension of lower end of right femur, initial encounter for open fracture type I or II
        "S72454C",  # Nondisplaced supracondylar fracture without intracondylar extension of lower end of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72455A",  # Nondisplaced supracondylar fracture without intracondylar extension of lower end of left femur, initial encounter for closed fracture
        "S72455B",  # Nondisplaced supracondylar fracture without intracondylar extension of lower end of left femur, initial encounter for open fracture type I or II
        "S72455C",  # Nondisplaced supracondylar fracture without intracondylar extension of lower end of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72456A",  # Nondisplaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, initial encounter for closed fracture
        "S72456B",  # Nondisplaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, initial encounter for open fracture type I or II
        "S72456C",  # Nondisplaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72461A",  # Displaced supracondylar fracture with intracondylar extension of lower end of right femur, initial encounter for closed fracture
        "S72461B",  # Displaced supracondylar fracture with intracondylar extension of lower end of right femur, initial encounter for open fracture type I or II
        "S72461C",  # Displaced supracondylar fracture with intracondylar extension of lower end of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72462A",  # Displaced supracondylar fracture with intracondylar extension of lower end of left femur, initial encounter for closed fracture
        "S72462B",  # Displaced supracondylar fracture with intracondylar extension of lower end of left femur, initial encounter for open fracture type I or II
        "S72462C",  # Displaced supracondylar fracture with intracondylar extension of lower end of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72463A",  # Displaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, initial encounter for closed fracture
        "S72463B",  # Displaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, initial encounter for open fracture type I or II
        "S72463C",  # Displaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72464A",  # Nondisplaced supracondylar fracture with intracondylar extension of lower end of right femur, initial encounter for closed fracture
        "S72464B",  # Nondisplaced supracondylar fracture with intracondylar extension of lower end of right femur, initial encounter for open fracture type I or II
        "S72464C",  # Nondisplaced supracondylar fracture with intracondylar extension of lower end of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72465A",  # Nondisplaced supracondylar fracture with intracondylar extension of lower end of left femur, initial encounter for closed fracture
        "S72465B",  # Nondisplaced supracondylar fracture with intracondylar extension of lower end of left femur, initial encounter for open fracture type I or II
        "S72465C",  # Nondisplaced supracondylar fracture with intracondylar extension of lower end of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72466A",  # Nondisplaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, initial encounter for closed fracture
        "S72466B",  # Nondisplaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, initial encounter for open fracture type I or II
        "S72466C",  # Nondisplaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72471A",  # Torus fracture of lower end of right femur, initial encounter for closed fracture
        "S72472A",  # Torus fracture of lower end of left femur, initial encounter for closed fracture
        "S72479A",  # Torus fracture of lower end of unspecified femur, initial encounter for closed fracture
        "S72491A",  # Other fracture of lower end of right femur, initial encounter for closed fracture
        "S72491B",  # Other fracture of lower end of right femur, initial encounter for open fracture type I or II
        "S72491C",  # Other fracture of lower end of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72492A",  # Other fracture of lower end of left femur, initial encounter for closed fracture
        "S72492B",  # Other fracture of lower end of left femur, initial encounter for open fracture type I or II
        "S72492C",  # Other fracture of lower end of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S72499A",  # Other fracture of lower end of unspecified femur, initial encounter for closed fracture
        "S72499B",  # Other fracture of lower end of unspecified femur, initial encounter for open fracture type I or II
        "S72499C",  # Other fracture of lower end of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S728X1A",  # Other fracture of right femur, initial encounter for closed fracture
        "S728X1B",  # Other fracture of right femur, initial encounter for open fracture type I or II
        "S728X1C",  # Other fracture of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S728X2A",  # Other fracture of left femur, initial encounter for closed fracture
        "S728X2B",  # Other fracture of left femur, initial encounter for open fracture type I or II
        "S728X2C",  # Other fracture of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S728X9A",  # Other fracture of unspecified femur, initial encounter for closed fracture
        "S728X9B",  # Other fracture of unspecified femur, initial encounter for open fracture type I or II
        "S728X9C",  # Other fracture of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S7290XA",  # Unspecified fracture of unspecified femur, initial encounter for closed fracture
        "S7290XB",  # Unspecified fracture of unspecified femur, initial encounter for open fracture type I or II
        "S7290XC",  # Unspecified fracture of unspecified femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S7291XA",  # Unspecified fracture of right femur, initial encounter for closed fracture
        "S7291XB",  # Unspecified fracture of right femur, initial encounter for open fracture type I or II
        "S7291XC",  # Unspecified fracture of right femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S7292XA",  # Unspecified fracture of left femur, initial encounter for closed fracture
        "S7292XB",  # Unspecified fracture of left femur, initial encounter for open fracture type I or II
        "S7292XC",  # Unspecified fracture of left femur, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82001A",  # Unspecified fracture of right patella, initial encounter for closed fracture
        "S82001B",  # Unspecified fracture of right patella, initial encounter for open fracture type I or II
        "S82001C",  # Unspecified fracture of right patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82002A",  # Unspecified fracture of left patella, initial encounter for closed fracture
        "S82002B",  # Unspecified fracture of left patella, initial encounter for open fracture type I or II
        "S82002C",  # Unspecified fracture of left patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82009A",  # Unspecified fracture of unspecified patella, initial encounter for closed fracture
        "S82009B",  # Unspecified fracture of unspecified patella, initial encounter for open fracture type I or II
        "S82009C",  # Unspecified fracture of unspecified patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82011A",  # Displaced osteochondral fracture of right patella, initial encounter for closed fracture
        "S82011B",  # Displaced osteochondral fracture of right patella, initial encounter for open fracture type I or II
        "S82011C",  # Displaced osteochondral fracture of right patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82012A",  # Displaced osteochondral fracture of left patella, initial encounter for closed fracture
        "S82012B",  # Displaced osteochondral fracture of left patella, initial encounter for open fracture type I or II
        "S82012C",  # Displaced osteochondral fracture of left patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82013A",  # Displaced osteochondral fracture of unspecified patella, initial encounter for closed fracture
        "S82013B",  # Displaced osteochondral fracture of unspecified patella, initial encounter for open fracture type I or II
        "S82013C",  # Displaced osteochondral fracture of unspecified patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82014A",  # Nondisplaced osteochondral fracture of right patella, initial encounter for closed fracture
        "S82014B",  # Nondisplaced osteochondral fracture of right patella, initial encounter for open fracture type I or II
        "S82014C",  # Nondisplaced osteochondral fracture of right patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82015A",  # Nondisplaced osteochondral fracture of left patella, initial encounter for closed fracture
        "S82015B",  # Nondisplaced osteochondral fracture of left patella, initial encounter for open fracture type I or II
        "S82015C",  # Nondisplaced osteochondral fracture of left patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82016A",  # Nondisplaced osteochondral fracture of unspecified patella, initial encounter for closed fracture
        "S82016B",  # Nondisplaced osteochondral fracture of unspecified patella, initial encounter for open fracture type I or II
        "S82016C",  # Nondisplaced osteochondral fracture of unspecified patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82021A",  # Displaced longitudinal fracture of right patella, initial encounter for closed fracture
        "S82021B",  # Displaced longitudinal fracture of right patella, initial encounter for open fracture type I or II
        "S82021C",  # Displaced longitudinal fracture of right patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82022A",  # Displaced longitudinal fracture of left patella, initial encounter for closed fracture
        "S82022B",  # Displaced longitudinal fracture of left patella, initial encounter for open fracture type I or II
        "S82022C",  # Displaced longitudinal fracture of left patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82023A",  # Displaced longitudinal fracture of unspecified patella, initial encounter for closed fracture
        "S82023B",  # Displaced longitudinal fracture of unspecified patella, initial encounter for open fracture type I or II
        "S82023C",  # Displaced longitudinal fracture of unspecified patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82024A",  # Nondisplaced longitudinal fracture of right patella, initial encounter for closed fracture
        "S82024B",  # Nondisplaced longitudinal fracture of right patella, initial encounter for open fracture type I or II
        "S82024C",  # Nondisplaced longitudinal fracture of right patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82025A",  # Nondisplaced longitudinal fracture of left patella, initial encounter for closed fracture
        "S82025B",  # Nondisplaced longitudinal fracture of left patella, initial encounter for open fracture type I or II
        "S82025C",  # Nondisplaced longitudinal fracture of left patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82026A",  # Nondisplaced longitudinal fracture of unspecified patella, initial encounter for closed fracture
        "S82026B",  # Nondisplaced longitudinal fracture of unspecified patella, initial encounter for open fracture type I or II
        "S82026C",  # Nondisplaced longitudinal fracture of unspecified patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82031A",  # Displaced transverse fracture of right patella, initial encounter for closed fracture
        "S82031B",  # Displaced transverse fracture of right patella, initial encounter for open fracture type I or II
        "S82031C",  # Displaced transverse fracture of right patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82032A",  # Displaced transverse fracture of left patella, initial encounter for closed fracture
        "S82032B",  # Displaced transverse fracture of left patella, initial encounter for open fracture type I or II
        "S82032C",  # Displaced transverse fracture of left patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82033A",  # Displaced transverse fracture of unspecified patella, initial encounter for closed fracture
        "S82033B",  # Displaced transverse fracture of unspecified patella, initial encounter for open fracture type I or II
        "S82033C",  # Displaced transverse fracture of unspecified patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82034A",  # Nondisplaced transverse fracture of right patella, initial encounter for closed fracture
        "S82034B",  # Nondisplaced transverse fracture of right patella, initial encounter for open fracture type I or II
        "S82034C",  # Nondisplaced transverse fracture of right patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82035A",  # Nondisplaced transverse fracture of left patella, initial encounter for closed fracture
        "S82035B",  # Nondisplaced transverse fracture of left patella, initial encounter for open fracture type I or II
        "S82035C",  # Nondisplaced transverse fracture of left patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82036A",  # Nondisplaced transverse fracture of unspecified patella, initial encounter for closed fracture
        "S82036B",  # Nondisplaced transverse fracture of unspecified patella, initial encounter for open fracture type I or II
        "S82036C",  # Nondisplaced transverse fracture of unspecified patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82041A",  # Displaced comminuted fracture of right patella, initial encounter for closed fracture
        "S82041B",  # Displaced comminuted fracture of right patella, initial encounter for open fracture type I or II
        "S82041C",  # Displaced comminuted fracture of right patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82042A",  # Displaced comminuted fracture of left patella, initial encounter for closed fracture
        "S82042B",  # Displaced comminuted fracture of left patella, initial encounter for open fracture type I or II
        "S82042C",  # Displaced comminuted fracture of left patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82043A",  # Displaced comminuted fracture of unspecified patella, initial encounter for closed fracture
        "S82043B",  # Displaced comminuted fracture of unspecified patella, initial encounter for open fracture type I or II
        "S82043C",  # Displaced comminuted fracture of unspecified patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82044A",  # Nondisplaced comminuted fracture of right patella, initial encounter for closed fracture
        "S82044B",  # Nondisplaced comminuted fracture of right patella, initial encounter for open fracture type I or II
        "S82044C",  # Nondisplaced comminuted fracture of right patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82045A",  # Nondisplaced comminuted fracture of left patella, initial encounter for closed fracture
        "S82045B",  # Nondisplaced comminuted fracture of left patella, initial encounter for open fracture type I or II
        "S82045C",  # Nondisplaced comminuted fracture of left patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82046A",  # Nondisplaced comminuted fracture of unspecified patella, initial encounter for closed fracture
        "S82046B",  # Nondisplaced comminuted fracture of unspecified patella, initial encounter for open fracture type I or II
        "S82046C",  # Nondisplaced comminuted fracture of unspecified patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82091A",  # Other fracture of right patella, initial encounter for closed fracture
        "S82091B",  # Other fracture of right patella, initial encounter for open fracture type I or II
        "S82091C",  # Other fracture of right patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82092A",  # Other fracture of left patella, initial encounter for closed fracture
        "S82092B",  # Other fracture of left patella, initial encounter for open fracture type I or II
        "S82092C",  # Other fracture of left patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82099A",  # Other fracture of unspecified patella, initial encounter for closed fracture
        "S82099B",  # Other fracture of unspecified patella, initial encounter for open fracture type I or II
        "S82099C",  # Other fracture of unspecified patella, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82101A",  # Unspecified fracture of upper end of right tibia, initial encounter for closed fracture
        "S82101B",  # Unspecified fracture of upper end of right tibia, initial encounter for open fracture type I or II
        "S82101C",  # Unspecified fracture of upper end of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82102A",  # Unspecified fracture of upper end of left tibia, initial encounter for closed fracture
        "S82102B",  # Unspecified fracture of upper end of left tibia, initial encounter for open fracture type I or II
        "S82102C",  # Unspecified fracture of upper end of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82109A",  # Unspecified fracture of upper end of unspecified tibia, initial encounter for closed fracture
        "S82109B",  # Unspecified fracture of upper end of unspecified tibia, initial encounter for open fracture type I or II
        "S82109C",  # Unspecified fracture of upper end of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82111A",  # Displaced fracture of right tibial spine, initial encounter for closed fracture
        "S82111B",  # Displaced fracture of right tibial spine, initial encounter for open fracture type I or II
        "S82111C",  # Displaced fracture of right tibial spine, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82112A",  # Displaced fracture of left tibial spine, initial encounter for closed fracture
        "S82112B",  # Displaced fracture of left tibial spine, initial encounter for open fracture type I or II
        "S82112C",  # Displaced fracture of left tibial spine, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82113A",  # Displaced fracture of unspecified tibial spine, initial encounter for closed fracture
        "S82113B",  # Displaced fracture of unspecified tibial spine, initial encounter for open fracture type I or II
        "S82113C",  # Displaced fracture of unspecified tibial spine, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82114A",  # Nondisplaced fracture of right tibial spine, initial encounter for closed fracture
        "S82114B",  # Nondisplaced fracture of right tibial spine, initial encounter for open fracture type I or II
        "S82114C",  # Nondisplaced fracture of right tibial spine, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82115A",  # Nondisplaced fracture of left tibial spine, initial encounter for closed fracture
        "S82115B",  # Nondisplaced fracture of left tibial spine, initial encounter for open fracture type I or II
        "S82115C",  # Nondisplaced fracture of left tibial spine, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82116A",  # Nondisplaced fracture of unspecified tibial spine, initial encounter for closed fracture
        "S82116B",  # Nondisplaced fracture of unspecified tibial spine, initial encounter for open fracture type I or II
        "S82116C",  # Nondisplaced fracture of unspecified tibial spine, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82121A",  # Displaced fracture of lateral condyle of right tibia, initial encounter for closed fracture
        "S82121B",  # Displaced fracture of lateral condyle of right tibia, initial encounter for open fracture type I or II
        "S82121C",  # Displaced fracture of lateral condyle of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82122A",  # Displaced fracture of lateral condyle of left tibia, initial encounter for closed fracture
        "S82122B",  # Displaced fracture of lateral condyle of left tibia, initial encounter for open fracture type I or II
        "S82122C",  # Displaced fracture of lateral condyle of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82123A",  # Displaced fracture of lateral condyle of unspecified tibia, initial encounter for closed fracture
        "S82123B",  # Displaced fracture of lateral condyle of unspecified tibia, initial encounter for open fracture type I or II
        "S82123C",  # Displaced fracture of lateral condyle of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82124A",  # Nondisplaced fracture of lateral condyle of right tibia, initial encounter for closed fracture
        "S82124B",  # Nondisplaced fracture of lateral condyle of right tibia, initial encounter for open fracture type I or II
        "S82124C",  # Nondisplaced fracture of lateral condyle of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82125A",  # Nondisplaced fracture of lateral condyle of left tibia, initial encounter for closed fracture
        "S82125B",  # Nondisplaced fracture of lateral condyle of left tibia, initial encounter for open fracture type I or II
        "S82125C",  # Nondisplaced fracture of lateral condyle of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82126A",  # Nondisplaced fracture of lateral condyle of unspecified tibia, initial encounter for closed fracture
        "S82126B",  # Nondisplaced fracture of lateral condyle of unspecified tibia, initial encounter for open fracture type I or II
        "S82126C",  # Nondisplaced fracture of lateral condyle of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82131A",  # Displaced fracture of medial condyle of right tibia, initial encounter for closed fracture
        "S82131B",  # Displaced fracture of medial condyle of right tibia, initial encounter for open fracture type I or II
        "S82131C",  # Displaced fracture of medial condyle of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82132A",  # Displaced fracture of medial condyle of left tibia, initial encounter for closed fracture
        "S82132B",  # Displaced fracture of medial condyle of left tibia, initial encounter for open fracture type I or II
        "S82132C",  # Displaced fracture of medial condyle of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82133A",  # Displaced fracture of medial condyle of unspecified tibia, initial encounter for closed fracture
        "S82133B",  # Displaced fracture of medial condyle of unspecified tibia, initial encounter for open fracture type I or II
        "S82133C",  # Displaced fracture of medial condyle of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82134A",  # Nondisplaced fracture of medial condyle of right tibia, initial encounter for closed fracture
        "S82134B",  # Nondisplaced fracture of medial condyle of right tibia, initial encounter for open fracture type I or II
        "S82134C",  # Nondisplaced fracture of medial condyle of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82135A",  # Nondisplaced fracture of medial condyle of left tibia, initial encounter for closed fracture
        "S82135B",  # Nondisplaced fracture of medial condyle of left tibia, initial encounter for open fracture type I or II
        "S82135C",  # Nondisplaced fracture of medial condyle of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82136A",  # Nondisplaced fracture of medial condyle of unspecified tibia, initial encounter for closed fracture
        "S82136B",  # Nondisplaced fracture of medial condyle of unspecified tibia, initial encounter for open fracture type I or II
        "S82136C",  # Nondisplaced fracture of medial condyle of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82141A",  # Displaced bicondylar fracture of right tibia, initial encounter for closed fracture
        "S82141B",  # Displaced bicondylar fracture of right tibia, initial encounter for open fracture type I or II
        "S82141C",  # Displaced bicondylar fracture of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82142A",  # Displaced bicondylar fracture of left tibia, initial encounter for closed fracture
        "S82142B",  # Displaced bicondylar fracture of left tibia, initial encounter for open fracture type I or II
        "S82142C",  # Displaced bicondylar fracture of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82143A",  # Displaced bicondylar fracture of unspecified tibia, initial encounter for closed fracture
        "S82143B",  # Displaced bicondylar fracture of unspecified tibia, initial encounter for open fracture type I or II
        "S82143C",  # Displaced bicondylar fracture of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82144A",  # Nondisplaced bicondylar fracture of right tibia, initial encounter for closed fracture
        "S82144B",  # Nondisplaced bicondylar fracture of right tibia, initial encounter for open fracture type I or II
        "S82144C",  # Nondisplaced bicondylar fracture of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82145A",  # Nondisplaced bicondylar fracture of left tibia, initial encounter for closed fracture
        "S82145B",  # Nondisplaced bicondylar fracture of left tibia, initial encounter for open fracture type I or II
        "S82145C",  # Nondisplaced bicondylar fracture of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82146A",  # Nondisplaced bicondylar fracture of unspecified tibia, initial encounter for closed fracture
        "S82146B",  # Nondisplaced bicondylar fracture of unspecified tibia, initial encounter for open fracture type I or II
        "S82146C",  # Nondisplaced bicondylar fracture of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82151A",  # Displaced fracture of right tibial tuberosity, initial encounter for closed fracture
        "S82151B",  # Displaced fracture of right tibial tuberosity, initial encounter for open fracture type I or II
        "S82151C",  # Displaced fracture of right tibial tuberosity, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82152A",  # Displaced fracture of left tibial tuberosity, initial encounter for closed fracture
        "S82152B",  # Displaced fracture of left tibial tuberosity, initial encounter for open fracture type I or II
        "S82152C",  # Displaced fracture of left tibial tuberosity, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82153A",  # Displaced fracture of unspecified tibial tuberosity, initial encounter for closed fracture
        "S82153B",  # Displaced fracture of unspecified tibial tuberosity, initial encounter for open fracture type I or II
        "S82153C",  # Displaced fracture of unspecified tibial tuberosity, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82154A",  # Nondisplaced fracture of right tibial tuberosity, initial encounter for closed fracture
        "S82154B",  # Nondisplaced fracture of right tibial tuberosity, initial encounter for open fracture type I or II
        "S82154C",  # Nondisplaced fracture of right tibial tuberosity, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82155A",  # Nondisplaced fracture of left tibial tuberosity, initial encounter for closed fracture
        "S82155B",  # Nondisplaced fracture of left tibial tuberosity, initial encounter for open fracture type I or II
        "S82155C",  # Nondisplaced fracture of left tibial tuberosity, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82156A",  # Nondisplaced fracture of unspecified tibial tuberosity, initial encounter for closed fracture
        "S82156B",  # Nondisplaced fracture of unspecified tibial tuberosity, initial encounter for open fracture type I or II
        "S82156C",  # Nondisplaced fracture of unspecified tibial tuberosity, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82161A",  # Torus fracture of upper end of right tibia, initial encounter for closed fracture
        "S82162A",  # Torus fracture of upper end of left tibia, initial encounter for closed fracture
        "S82169A",  # Torus fracture of upper end of unspecified tibia, initial encounter for closed fracture
        "S82191A",  # Other fracture of upper end of right tibia, initial encounter for closed fracture
        "S82191B",  # Other fracture of upper end of right tibia, initial encounter for open fracture type I or II
        "S82191C",  # Other fracture of upper end of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82192A",  # Other fracture of upper end of left tibia, initial encounter for closed fracture
        "S82192B",  # Other fracture of upper end of left tibia, initial encounter for open fracture type I or II
        "S82192C",  # Other fracture of upper end of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82199A",  # Other fracture of upper end of unspecified tibia, initial encounter for closed fracture
        "S82199B",  # Other fracture of upper end of unspecified tibia, initial encounter for open fracture type I or II
        "S82199C",  # Other fracture of upper end of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82201A",  # Unspecified fracture of shaft of right tibia, initial encounter for closed fracture
        "S82201B",  # Unspecified fracture of shaft of right tibia, initial encounter for open fracture type I or II
        "S82201C",  # Unspecified fracture of shaft of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82202A",  # Unspecified fracture of shaft of left tibia, initial encounter for closed fracture
        "S82202B",  # Unspecified fracture of shaft of left tibia, initial encounter for open fracture type I or II
        "S82202C",  # Unspecified fracture of shaft of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82209A",  # Unspecified fracture of shaft of unspecified tibia, initial encounter for closed fracture
        "S82209B",  # Unspecified fracture of shaft of unspecified tibia, initial encounter for open fracture type I or II
        "S82209C",  # Unspecified fracture of shaft of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82221A",  # Displaced transverse fracture of shaft of right tibia, initial encounter for closed fracture
        "S82221B",  # Displaced transverse fracture of shaft of right tibia, initial encounter for open fracture type I or II
        "S82221C",  # Displaced transverse fracture of shaft of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82222A",  # Displaced transverse fracture of shaft of left tibia, initial encounter for closed fracture
        "S82222B",  # Displaced transverse fracture of shaft of left tibia, initial encounter for open fracture type I or II
        "S82222C",  # Displaced transverse fracture of shaft of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82223A",  # Displaced transverse fracture of shaft of unspecified tibia, initial encounter for closed fracture
        "S82223B",  # Displaced transverse fracture of shaft of unspecified tibia, initial encounter for open fracture type I or II
        "S82223C",  # Displaced transverse fracture of shaft of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82224A",  # Nondisplaced transverse fracture of shaft of right tibia, initial encounter for closed fracture
        "S82224B",  # Nondisplaced transverse fracture of shaft of right tibia, initial encounter for open fracture type I or II
        "S82224C",  # Nondisplaced transverse fracture of shaft of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82225A",  # Nondisplaced transverse fracture of shaft of left tibia, initial encounter for closed fracture
        "S82225B",  # Nondisplaced transverse fracture of shaft of left tibia, initial encounter for open fracture type I or II
        "S82225C",  # Nondisplaced transverse fracture of shaft of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82226A",  # Nondisplaced transverse fracture of shaft of unspecified tibia, initial encounter for closed fracture
        "S82226B",  # Nondisplaced transverse fracture of shaft of unspecified tibia, initial encounter for open fracture type I or II
        "S82226C",  # Nondisplaced transverse fracture of shaft of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82231A",  # Displaced oblique fracture of shaft of right tibia, initial encounter for closed fracture
        "S82231B",  # Displaced oblique fracture of shaft of right tibia, initial encounter for open fracture type I or II
        "S82231C",  # Displaced oblique fracture of shaft of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82232A",  # Displaced oblique fracture of shaft of left tibia, initial encounter for closed fracture
        "S82232B",  # Displaced oblique fracture of shaft of left tibia, initial encounter for open fracture type I or II
        "S82232C",  # Displaced oblique fracture of shaft of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82233A",  # Displaced oblique fracture of shaft of unspecified tibia, initial encounter for closed fracture
        "S82233B",  # Displaced oblique fracture of shaft of unspecified tibia, initial encounter for open fracture type I or II
        "S82233C",  # Displaced oblique fracture of shaft of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82234A",  # Nondisplaced oblique fracture of shaft of right tibia, initial encounter for closed fracture
        "S82234B",  # Nondisplaced oblique fracture of shaft of right tibia, initial encounter for open fracture type I or II
        "S82234C",  # Nondisplaced oblique fracture of shaft of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82235A",  # Nondisplaced oblique fracture of shaft of left tibia, initial encounter for closed fracture
        "S82235B",  # Nondisplaced oblique fracture of shaft of left tibia, initial encounter for open fracture type I or II
        "S82235C",  # Nondisplaced oblique fracture of shaft of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82236A",  # Nondisplaced oblique fracture of shaft of unspecified tibia, initial encounter for closed fracture
        "S82236B",  # Nondisplaced oblique fracture of shaft of unspecified tibia, initial encounter for open fracture type I or II
        "S82236C",  # Nondisplaced oblique fracture of shaft of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82241A",  # Displaced spiral fracture of shaft of right tibia, initial encounter for closed fracture
        "S82241B",  # Displaced spiral fracture of shaft of right tibia, initial encounter for open fracture type I or II
        "S82241C",  # Displaced spiral fracture of shaft of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82242A",  # Displaced spiral fracture of shaft of left tibia, initial encounter for closed fracture
        "S82242B",  # Displaced spiral fracture of shaft of left tibia, initial encounter for open fracture type I or II
        "S82242C",  # Displaced spiral fracture of shaft of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82243A",  # Displaced spiral fracture of shaft of unspecified tibia, initial encounter for closed fracture
        "S82243B",  # Displaced spiral fracture of shaft of unspecified tibia, initial encounter for open fracture type I or II
        "S82243C",  # Displaced spiral fracture of shaft of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82244A",  # Nondisplaced spiral fracture of shaft of right tibia, initial encounter for closed fracture
        "S82244B",  # Nondisplaced spiral fracture of shaft of right tibia, initial encounter for open fracture type I or II
        "S82244C",  # Nondisplaced spiral fracture of shaft of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82245A",  # Nondisplaced spiral fracture of shaft of left tibia, initial encounter for closed fracture
        "S82245B",  # Nondisplaced spiral fracture of shaft of left tibia, initial encounter for open fracture type I or II
        "S82245C",  # Nondisplaced spiral fracture of shaft of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82246A",  # Nondisplaced spiral fracture of shaft of unspecified tibia, initial encounter for closed fracture
        "S82246B",  # Nondisplaced spiral fracture of shaft of unspecified tibia, initial encounter for open fracture type I or II
        "S82246C",  # Nondisplaced spiral fracture of shaft of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82251A",  # Displaced comminuted fracture of shaft of right tibia, initial encounter for closed fracture
        "S82251B",  # Displaced comminuted fracture of shaft of right tibia, initial encounter for open fracture type I or II
        "S82251C",  # Displaced comminuted fracture of shaft of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82252A",  # Displaced comminuted fracture of shaft of left tibia, initial encounter for closed fracture
        "S82252B",  # Displaced comminuted fracture of shaft of left tibia, initial encounter for open fracture type I or II
        "S82252C",  # Displaced comminuted fracture of shaft of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82253A",  # Displaced comminuted fracture of shaft of unspecified tibia, initial encounter for closed fracture
        "S82253B",  # Displaced comminuted fracture of shaft of unspecified tibia, initial encounter for open fracture type I or II
        "S82253C",  # Displaced comminuted fracture of shaft of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82254A",  # Nondisplaced comminuted fracture of shaft of right tibia, initial encounter for closed fracture
        "S82254B",  # Nondisplaced comminuted fracture of shaft of right tibia, initial encounter for open fracture type I or II
        "S82254C",  # Nondisplaced comminuted fracture of shaft of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82255A",  # Nondisplaced comminuted fracture of shaft of left tibia, initial encounter for closed fracture
        "S82255B",  # Nondisplaced comminuted fracture of shaft of left tibia, initial encounter for open fracture type I or II
        "S82255C",  # Nondisplaced comminuted fracture of shaft of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82256A",  # Nondisplaced comminuted fracture of shaft of unspecified tibia, initial encounter for closed fracture
        "S82256B",  # Nondisplaced comminuted fracture of shaft of unspecified tibia, initial encounter for open fracture type I or II
        "S82256C",  # Nondisplaced comminuted fracture of shaft of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82261A",  # Displaced segmental fracture of shaft of right tibia, initial encounter for closed fracture
        "S82261B",  # Displaced segmental fracture of shaft of right tibia, initial encounter for open fracture type I or II
        "S82261C",  # Displaced segmental fracture of shaft of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82262A",  # Displaced segmental fracture of shaft of left tibia, initial encounter for closed fracture
        "S82262B",  # Displaced segmental fracture of shaft of left tibia, initial encounter for open fracture type I or II
        "S82262C",  # Displaced segmental fracture of shaft of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82263A",  # Displaced segmental fracture of shaft of unspecified tibia, initial encounter for closed fracture
        "S82263B",  # Displaced segmental fracture of shaft of unspecified tibia, initial encounter for open fracture type I or II
        "S82263C",  # Displaced segmental fracture of shaft of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82264A",  # Nondisplaced segmental fracture of shaft of right tibia, initial encounter for closed fracture
        "S82264B",  # Nondisplaced segmental fracture of shaft of right tibia, initial encounter for open fracture type I or II
        "S82264C",  # Nondisplaced segmental fracture of shaft of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82265A",  # Nondisplaced segmental fracture of shaft of left tibia, initial encounter for closed fracture
        "S82265B",  # Nondisplaced segmental fracture of shaft of left tibia, initial encounter for open fracture type I or II
        "S82265C",  # Nondisplaced segmental fracture of shaft of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82266A",  # Nondisplaced segmental fracture of shaft of unspecified tibia, initial encounter for closed fracture
        "S82266B",  # Nondisplaced segmental fracture of shaft of unspecified tibia, initial encounter for open fracture type I or II
        "S82266C",  # Nondisplaced segmental fracture of shaft of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82291A",  # Other fracture of shaft of right tibia, initial encounter for closed fracture
        "S82291B",  # Other fracture of shaft of right tibia, initial encounter for open fracture type I or II
        "S82291C",  # Other fracture of shaft of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82292A",  # Other fracture of shaft of left tibia, initial encounter for closed fracture
        "S82292B",  # Other fracture of shaft of left tibia, initial encounter for open fracture type I or II
        "S82292C",  # Other fracture of shaft of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82299A",  # Other fracture of shaft of unspecified tibia, initial encounter for closed fracture
        "S82299B",  # Other fracture of shaft of unspecified tibia, initial encounter for open fracture type I or II
        "S82299C",  # Other fracture of shaft of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82301A",  # Unspecified fracture of lower end of right tibia, initial encounter for closed fracture
        "S82301B",  # Unspecified fracture of lower end of right tibia, initial encounter for open fracture type I or II
        "S82301C",  # Unspecified fracture of lower end of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82302A",  # Unspecified fracture of lower end of left tibia, initial encounter for closed fracture
        "S82302B",  # Unspecified fracture of lower end of left tibia, initial encounter for open fracture type I or II
        "S82302C",  # Unspecified fracture of lower end of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82309A",  # Unspecified fracture of lower end of unspecified tibia, initial encounter for closed fracture
        "S82309B",  # Unspecified fracture of lower end of unspecified tibia, initial encounter for open fracture type I or II
        "S82309C",  # Unspecified fracture of lower end of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82311A",  # Torus fracture of lower end of right tibia, initial encounter for closed fracture
        "S82312A",  # Torus fracture of lower end of left tibia, initial encounter for closed fracture
        "S82319A",  # Torus fracture of lower end of unspecified tibia, initial encounter for closed fracture
        "S82391A",  # Other fracture of lower end of right tibia, initial encounter for closed fracture
        "S82391B",  # Other fracture of lower end of right tibia, initial encounter for open fracture type I or II
        "S82391C",  # Other fracture of lower end of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82392A",  # Other fracture of lower end of left tibia, initial encounter for closed fracture
        "S82392B",  # Other fracture of lower end of left tibia, initial encounter for open fracture type I or II
        "S82392C",  # Other fracture of lower end of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82399A",  # Other fracture of lower end of unspecified tibia, initial encounter for closed fracture
        "S82399B",  # Other fracture of lower end of unspecified tibia, initial encounter for open fracture type I or II
        "S82399C",  # Other fracture of lower end of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82401A",  # Unspecified fracture of shaft of right fibula, initial encounter for closed fracture
        "S82401B",  # Unspecified fracture of shaft of right fibula, initial encounter for open fracture type I or II
        "S82401C",  # Unspecified fracture of shaft of right fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82402A",  # Unspecified fracture of shaft of left fibula, initial encounter for closed fracture
        "S82402B",  # Unspecified fracture of shaft of left fibula, initial encounter for open fracture type I or II
        "S82402C",  # Unspecified fracture of shaft of left fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82409A",  # Unspecified fracture of shaft of unspecified fibula, initial encounter for closed fracture
        "S82409B",  # Unspecified fracture of shaft of unspecified fibula, initial encounter for open fracture type I or II
        "S82409C",  # Unspecified fracture of shaft of unspecified fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82421A",  # Displaced transverse fracture of shaft of right fibula, initial encounter for closed fracture
        "S82421B",  # Displaced transverse fracture of shaft of right fibula, initial encounter for open fracture type I or II
        "S82421C",  # Displaced transverse fracture of shaft of right fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82422A",  # Displaced transverse fracture of shaft of left fibula, initial encounter for closed fracture
        "S82422B",  # Displaced transverse fracture of shaft of left fibula, initial encounter for open fracture type I or II
        "S82422C",  # Displaced transverse fracture of shaft of left fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82423A",  # Displaced transverse fracture of shaft of unspecified fibula, initial encounter for closed fracture
        "S82423B",  # Displaced transverse fracture of shaft of unspecified fibula, initial encounter for open fracture type I or II
        "S82423C",  # Displaced transverse fracture of shaft of unspecified fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82424A",  # Nondisplaced transverse fracture of shaft of right fibula, initial encounter for closed fracture
        "S82424B",  # Nondisplaced transverse fracture of shaft of right fibula, initial encounter for open fracture type I or II
        "S82424C",  # Nondisplaced transverse fracture of shaft of right fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82425A",  # Nondisplaced transverse fracture of shaft of left fibula, initial encounter for closed fracture
        "S82425B",  # Nondisplaced transverse fracture of shaft of left fibula, initial encounter for open fracture type I or II
        "S82425C",  # Nondisplaced transverse fracture of shaft of left fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82426A",  # Nondisplaced transverse fracture of shaft of unspecified fibula, initial encounter for closed fracture
        "S82426B",  # Nondisplaced transverse fracture of shaft of unspecified fibula, initial encounter for open fracture type I or II
        "S82426C",  # Nondisplaced transverse fracture of shaft of unspecified fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82431A",  # Displaced oblique fracture of shaft of right fibula, initial encounter for closed fracture
        "S82431B",  # Displaced oblique fracture of shaft of right fibula, initial encounter for open fracture type I or II
        "S82431C",  # Displaced oblique fracture of shaft of right fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82432A",  # Displaced oblique fracture of shaft of left fibula, initial encounter for closed fracture
        "S82432B",  # Displaced oblique fracture of shaft of left fibula, initial encounter for open fracture type I or II
        "S82432C",  # Displaced oblique fracture of shaft of left fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82433A",  # Displaced oblique fracture of shaft of unspecified fibula, initial encounter for closed fracture
        "S82433B",  # Displaced oblique fracture of shaft of unspecified fibula, initial encounter for open fracture type I or II
        "S82433C",  # Displaced oblique fracture of shaft of unspecified fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82434A",  # Nondisplaced oblique fracture of shaft of right fibula, initial encounter for closed fracture
        "S82434B",  # Nondisplaced oblique fracture of shaft of right fibula, initial encounter for open fracture type I or II
        "S82434C",  # Nondisplaced oblique fracture of shaft of right fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82435A",  # Nondisplaced oblique fracture of shaft of left fibula, initial encounter for closed fracture
        "S82435B",  # Nondisplaced oblique fracture of shaft of left fibula, initial encounter for open fracture type I or II
        "S82435C",  # Nondisplaced oblique fracture of shaft of left fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82436A",  # Nondisplaced oblique fracture of shaft of unspecified fibula, initial encounter for closed fracture
        "S82436B",  # Nondisplaced oblique fracture of shaft of unspecified fibula, initial encounter for open fracture type I or II
        "S82436C",  # Nondisplaced oblique fracture of shaft of unspecified fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82441A",  # Displaced spiral fracture of shaft of right fibula, initial encounter for closed fracture
        "S82441B",  # Displaced spiral fracture of shaft of right fibula, initial encounter for open fracture type I or II
        "S82441C",  # Displaced spiral fracture of shaft of right fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82442A",  # Displaced spiral fracture of shaft of left fibula, initial encounter for closed fracture
        "S82442B",  # Displaced spiral fracture of shaft of left fibula, initial encounter for open fracture type I or II
        "S82442C",  # Displaced spiral fracture of shaft of left fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82443A",  # Displaced spiral fracture of shaft of unspecified fibula, initial encounter for closed fracture
        "S82443B",  # Displaced spiral fracture of shaft of unspecified fibula, initial encounter for open fracture type I or II
        "S82443C",  # Displaced spiral fracture of shaft of unspecified fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82444A",  # Nondisplaced spiral fracture of shaft of right fibula, initial encounter for closed fracture
        "S82444B",  # Nondisplaced spiral fracture of shaft of right fibula, initial encounter for open fracture type I or II
        "S82444C",  # Nondisplaced spiral fracture of shaft of right fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82445A",  # Nondisplaced spiral fracture of shaft of left fibula, initial encounter for closed fracture
        "S82445B",  # Nondisplaced spiral fracture of shaft of left fibula, initial encounter for open fracture type I or II
        "S82445C",  # Nondisplaced spiral fracture of shaft of left fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82446A",  # Nondisplaced spiral fracture of shaft of unspecified fibula, initial encounter for closed fracture
        "S82446B",  # Nondisplaced spiral fracture of shaft of unspecified fibula, initial encounter for open fracture type I or II
        "S82446C",  # Nondisplaced spiral fracture of shaft of unspecified fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82451A",  # Displaced comminuted fracture of shaft of right fibula, initial encounter for closed fracture
        "S82451B",  # Displaced comminuted fracture of shaft of right fibula, initial encounter for open fracture type I or II
        "S82451C",  # Displaced comminuted fracture of shaft of right fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82452A",  # Displaced comminuted fracture of shaft of left fibula, initial encounter for closed fracture
        "S82452B",  # Displaced comminuted fracture of shaft of left fibula, initial encounter for open fracture type I or II
        "S82452C",  # Displaced comminuted fracture of shaft of left fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82453A",  # Displaced comminuted fracture of shaft of unspecified fibula, initial encounter for closed fracture
        "S82453B",  # Displaced comminuted fracture of shaft of unspecified fibula, initial encounter for open fracture type I or II
        "S82453C",  # Displaced comminuted fracture of shaft of unspecified fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82454A",  # Nondisplaced comminuted fracture of shaft of right fibula, initial encounter for closed fracture
        "S82454B",  # Nondisplaced comminuted fracture of shaft of right fibula, initial encounter for open fracture type I or II
        "S82454C",  # Nondisplaced comminuted fracture of shaft of right fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82455A",  # Nondisplaced comminuted fracture of shaft of left fibula, initial encounter for closed fracture
        "S82455B",  # Nondisplaced comminuted fracture of shaft of left fibula, initial encounter for open fracture type I or II
        "S82455C",  # Nondisplaced comminuted fracture of shaft of left fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82456A",  # Nondisplaced comminuted fracture of shaft of unspecified fibula, initial encounter for closed fracture
        "S82456B",  # Nondisplaced comminuted fracture of shaft of unspecified fibula, initial encounter for open fracture type I or II
        "S82456C",  # Nondisplaced comminuted fracture of shaft of unspecified fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82461A",  # Displaced segmental fracture of shaft of right fibula, initial encounter for closed fracture
        "S82461B",  # Displaced segmental fracture of shaft of right fibula, initial encounter for open fracture type I or II
        "S82461C",  # Displaced segmental fracture of shaft of right fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82462A",  # Displaced segmental fracture of shaft of left fibula, initial encounter for closed fracture
        "S82462B",  # Displaced segmental fracture of shaft of left fibula, initial encounter for open fracture type I or II
        "S82462C",  # Displaced segmental fracture of shaft of left fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82463A",  # Displaced segmental fracture of shaft of unspecified fibula, initial encounter for closed fracture
        "S82463B",  # Displaced segmental fracture of shaft of unspecified fibula, initial encounter for open fracture type I or II
        "S82463C",  # Displaced segmental fracture of shaft of unspecified fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82464A",  # Nondisplaced segmental fracture of shaft of right fibula, initial encounter for closed fracture
        "S82464B",  # Nondisplaced segmental fracture of shaft of right fibula, initial encounter for open fracture type I or II
        "S82464C",  # Nondisplaced segmental fracture of shaft of right fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82465A",  # Nondisplaced segmental fracture of shaft of left fibula, initial encounter for closed fracture
        "S82465B",  # Nondisplaced segmental fracture of shaft of left fibula, initial encounter for open fracture type I or II
        "S82465C",  # Nondisplaced segmental fracture of shaft of left fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82466A",  # Nondisplaced segmental fracture of shaft of unspecified fibula, initial encounter for closed fracture
        "S82466B",  # Nondisplaced segmental fracture of shaft of unspecified fibula, initial encounter for open fracture type I or II
        "S82466C",  # Nondisplaced segmental fracture of shaft of unspecified fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82491A",  # Other fracture of shaft of right fibula, initial encounter for closed fracture
        "S82491B",  # Other fracture of shaft of right fibula, initial encounter for open fracture type I or II
        "S82491C",  # Other fracture of shaft of right fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82492A",  # Other fracture of shaft of left fibula, initial encounter for closed fracture
        "S82492B",  # Other fracture of shaft of left fibula, initial encounter for open fracture type I or II
        "S82492C",  # Other fracture of shaft of left fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82499A",  # Other fracture of shaft of unspecified fibula, initial encounter for closed fracture
        "S82499B",  # Other fracture of shaft of unspecified fibula, initial encounter for open fracture type I or II
        "S82499C",  # Other fracture of shaft of unspecified fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S8251XA",  # Displaced fracture of medial malleolus of right tibia, initial encounter for closed fracture
        "S8251XB",  # Displaced fracture of medial malleolus of right tibia, initial encounter for open fracture type I or II
        "S8251XC",  # Displaced fracture of medial malleolus of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S8252XA",  # Displaced fracture of medial malleolus of left tibia, initial encounter for closed fracture
        "S8252XB",  # Displaced fracture of medial malleolus of left tibia, initial encounter for open fracture type I or II
        "S8252XC",  # Displaced fracture of medial malleolus of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S8253XA",  # Displaced fracture of medial malleolus of unspecified tibia, initial encounter for closed fracture
        "S8253XB",  # Displaced fracture of medial malleolus of unspecified tibia, initial encounter for open fracture type I or II
        "S8253XC",  # Displaced fracture of medial malleolus of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S8254XA",  # Nondisplaced fracture of medial malleolus of right tibia, initial encounter for closed fracture
        "S8254XB",  # Nondisplaced fracture of medial malleolus of right tibia, initial encounter for open fracture type I or II
        "S8254XC",  # Nondisplaced fracture of medial malleolus of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S8255XA",  # Nondisplaced fracture of medial malleolus of left tibia, initial encounter for closed fracture
        "S8255XB",  # Nondisplaced fracture of medial malleolus of left tibia, initial encounter for open fracture type I or II
        "S8255XC",  # Nondisplaced fracture of medial malleolus of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S8256XA",  # Nondisplaced fracture of medial malleolus of unspecified tibia, initial encounter for closed fracture
        "S8256XB",  # Nondisplaced fracture of medial malleolus of unspecified tibia, initial encounter for open fracture type I or II
        "S8256XC",  # Nondisplaced fracture of medial malleolus of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S8261XA",  # Displaced fracture of lateral malleolus of right fibula, initial encounter for closed fracture
        "S8261XB",  # Displaced fracture of lateral malleolus of right fibula, initial encounter for open fracture type I or II
        "S8261XC",  # Displaced fracture of lateral malleolus of right fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S8262XA",  # Displaced fracture of lateral malleolus of left fibula, initial encounter for closed fracture
        "S8262XB",  # Displaced fracture of lateral malleolus of left fibula, initial encounter for open fracture type I or II
        "S8262XC",  # Displaced fracture of lateral malleolus of left fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S8263XA",  # Displaced fracture of lateral malleolus of unspecified fibula, initial encounter for closed fracture
        "S8263XB",  # Displaced fracture of lateral malleolus of unspecified fibula, initial encounter for open fracture type I or II
        "S8263XC",  # Displaced fracture of lateral malleolus of unspecified fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S8264XA",  # Nondisplaced fracture of lateral malleolus of right fibula, initial encounter for closed fracture
        "S8264XB",  # Nondisplaced fracture of lateral malleolus of right fibula, initial encounter for open fracture type I or II
        "S8264XC",  # Nondisplaced fracture of lateral malleolus of right fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S8265XA",  # Nondisplaced fracture of lateral malleolus of left fibula, initial encounter for closed fracture
        "S8265XB",  # Nondisplaced fracture of lateral malleolus of left fibula, initial encounter for open fracture type I or II
        "S8265XC",  # Nondisplaced fracture of lateral malleolus of left fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S8266XA",  # Nondisplaced fracture of lateral malleolus of unspecified fibula, initial encounter for closed fracture
        "S8266XB",  # Nondisplaced fracture of lateral malleolus of unspecified fibula, initial encounter for open fracture type I or II
        "S8266XC",  # Nondisplaced fracture of lateral malleolus of unspecified fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82811A",  # Torus fracture of upper end of right fibula, initial encounter for closed fracture
        "S82812A",  # Torus fracture of upper end of left fibula, initial encounter for closed fracture
        "S82819A",  # Torus fracture of upper end of unspecified fibula, initial encounter for closed fracture
        "S82821A",  # Torus fracture of lower end of right fibula, initial encounter for closed fracture
        "S82822A",  # Torus fracture of lower end of left fibula, initial encounter for closed fracture
        "S82829A",  # Torus fracture of lower end of unspecified fibula, initial encounter for closed fracture
        "S82831A",  # Other fracture of upper and lower end of right fibula, initial encounter for closed fracture
        "S82831B",  # Other fracture of upper and lower end of right fibula, initial encounter for open fracture type I or II
        "S82831C",  # Other fracture of upper and lower end of right fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82832A",  # Other fracture of upper and lower end of left fibula, initial encounter for closed fracture
        "S82832B",  # Other fracture of upper and lower end of left fibula, initial encounter for open fracture type I or II
        "S82832C",  # Other fracture of upper and lower end of left fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82839A",  # Other fracture of upper and lower end of unspecified fibula, initial encounter for closed fracture
        "S82839B",  # Other fracture of upper and lower end of unspecified fibula, initial encounter for open fracture type I or II
        "S82839C",  # Other fracture of upper and lower end of unspecified fibula, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82841A",  # Displaced bimalleolar fracture of right lower leg, initial encounter for closed fracture
        "S82841B",  # Displaced bimalleolar fracture of right lower leg, initial encounter for open fracture type I or II
        "S82841C",  # Displaced bimalleolar fracture of right lower leg, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82842A",  # Displaced bimalleolar fracture of left lower leg, initial encounter for closed fracture
        "S82842B",  # Displaced bimalleolar fracture of left lower leg, initial encounter for open fracture type I or II
        "S82842C",  # Displaced bimalleolar fracture of left lower leg, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82843A",  # Displaced bimalleolar fracture of unspecified lower leg, initial encounter for closed fracture
        "S82843B",  # Displaced bimalleolar fracture of unspecified lower leg, initial encounter for open fracture type I or II
        "S82843C",  # Displaced bimalleolar fracture of unspecified lower leg, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82844A",  # Nondisplaced bimalleolar fracture of right lower leg, initial encounter for closed fracture
        "S82844B",  # Nondisplaced bimalleolar fracture of right lower leg, initial encounter for open fracture type I or II
        "S82844C",  # Nondisplaced bimalleolar fracture of right lower leg, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82845A",  # Nondisplaced bimalleolar fracture of left lower leg, initial encounter for closed fracture
        "S82845B",  # Nondisplaced bimalleolar fracture of left lower leg, initial encounter for open fracture type I or II
        "S82845C",  # Nondisplaced bimalleolar fracture of left lower leg, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82846A",  # Nondisplaced bimalleolar fracture of unspecified lower leg, initial encounter for closed fracture
        "S82846B",  # Nondisplaced bimalleolar fracture of unspecified lower leg, initial encounter for open fracture type I or II
        "S82846C",  # Nondisplaced bimalleolar fracture of unspecified lower leg, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82851A",  # Displaced trimalleolar fracture of right lower leg, initial encounter for closed fracture
        "S82851B",  # Displaced trimalleolar fracture of right lower leg, initial encounter for open fracture type I or II
        "S82851C",  # Displaced trimalleolar fracture of right lower leg, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82852A",  # Displaced trimalleolar fracture of left lower leg, initial encounter for closed fracture
        "S82852B",  # Displaced trimalleolar fracture of left lower leg, initial encounter for open fracture type I or II
        "S82852C",  # Displaced trimalleolar fracture of left lower leg, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82853A",  # Displaced trimalleolar fracture of unspecified lower leg, initial encounter for closed fracture
        "S82853B",  # Displaced trimalleolar fracture of unspecified lower leg, initial encounter for open fracture type I or II
        "S82853C",  # Displaced trimalleolar fracture of unspecified lower leg, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82854A",  # Nondisplaced trimalleolar fracture of right lower leg, initial encounter for closed fracture
        "S82854B",  # Nondisplaced trimalleolar fracture of right lower leg, initial encounter for open fracture type I or II
        "S82854C",  # Nondisplaced trimalleolar fracture of right lower leg, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82855A",  # Nondisplaced trimalleolar fracture of left lower leg, initial encounter for closed fracture
        "S82855B",  # Nondisplaced trimalleolar fracture of left lower leg, initial encounter for open fracture type I or II
        "S82855C",  # Nondisplaced trimalleolar fracture of left lower leg, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82856A",  # Nondisplaced trimalleolar fracture of unspecified lower leg, initial encounter for closed fracture
        "S82856B",  # Nondisplaced trimalleolar fracture of unspecified lower leg, initial encounter for open fracture type I or II
        "S82856C",  # Nondisplaced trimalleolar fracture of unspecified lower leg, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82861A",  # Displaced Maisonneuve's fracture of right leg, initial encounter for closed fracture
        "S82861B",  # Displaced Maisonneuve's fracture of right leg, initial encounter for open fracture type I or II
        "S82861C",  # Displaced Maisonneuve's fracture of right leg, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82862A",  # Displaced Maisonneuve's fracture of left leg, initial encounter for closed fracture
        "S82862B",  # Displaced Maisonneuve's fracture of left leg, initial encounter for open fracture type I or II
        "S82862C",  # Displaced Maisonneuve's fracture of left leg, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82863A",  # Displaced Maisonneuve's fracture of unspecified leg, initial encounter for closed fracture
        "S82863B",  # Displaced Maisonneuve's fracture of unspecified leg, initial encounter for open fracture type I or II
        "S82863C",  # Displaced Maisonneuve's fracture of unspecified leg, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82864A",  # Nondisplaced Maisonneuve's fracture of right leg, initial encounter for closed fracture
        "S82864B",  # Nondisplaced Maisonneuve's fracture of right leg, initial encounter for open fracture type I or II
        "S82864C",  # Nondisplaced Maisonneuve's fracture of right leg, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82865A",  # Nondisplaced Maisonneuve's fracture of left leg, initial encounter for closed fracture
        "S82865B",  # Nondisplaced Maisonneuve's fracture of left leg, initial encounter for open fracture type I or II
        "S82865C",  # Nondisplaced Maisonneuve's fracture of left leg, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82866A",  # Nondisplaced Maisonneuve's fracture of unspecified leg, initial encounter for closed fracture
        "S82866B",  # Nondisplaced Maisonneuve's fracture of unspecified leg, initial encounter for open fracture type I or II
        "S82866C",  # Nondisplaced Maisonneuve's fracture of unspecified leg, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82871A",  # Displaced pilon fracture of right tibia, initial encounter for closed fracture
        "S82871B",  # Displaced pilon fracture of right tibia, initial encounter for open fracture type I or II
        "S82871C",  # Displaced pilon fracture of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82872A",  # Displaced pilon fracture of left tibia, initial encounter for closed fracture
        "S82872B",  # Displaced pilon fracture of left tibia, initial encounter for open fracture type I or II
        "S82872C",  # Displaced pilon fracture of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82873A",  # Displaced pilon fracture of unspecified tibia, initial encounter for closed fracture
        "S82873B",  # Displaced pilon fracture of unspecified tibia, initial encounter for open fracture type I or II
        "S82873C",  # Displaced pilon fracture of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82874A",  # Nondisplaced pilon fracture of right tibia, initial encounter for closed fracture
        "S82874B",  # Nondisplaced pilon fracture of right tibia, initial encounter for open fracture type I or II
        "S82874C",  # Nondisplaced pilon fracture of right tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82875A",  # Nondisplaced pilon fracture of left tibia, initial encounter for closed fracture
        "S82875B",  # Nondisplaced pilon fracture of left tibia, initial encounter for open fracture type I or II
        "S82875C",  # Nondisplaced pilon fracture of left tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82876A",  # Nondisplaced pilon fracture of unspecified tibia, initial encounter for closed fracture
        "S82876B",  # Nondisplaced pilon fracture of unspecified tibia, initial encounter for open fracture type I or II
        "S82876C",  # Nondisplaced pilon fracture of unspecified tibia, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82891A",  # Other fracture of right lower leg, initial encounter for closed fracture
        "S82891B",  # Other fracture of right lower leg, initial encounter for open fracture type I or II
        "S82891C",  # Other fracture of right lower leg, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82892A",  # Other fracture of left lower leg, initial encounter for closed fracture
        "S82892B",  # Other fracture of left lower leg, initial encounter for open fracture type I or II
        "S82892C",  # Other fracture of left lower leg, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S82899A",  # Other fracture of unspecified lower leg, initial encounter for closed fracture
        "S82899B",  # Other fracture of unspecified lower leg, initial encounter for open fracture type I or II
        "S82899C",  # Other fracture of unspecified lower leg, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S8290XA",  # Unspecified fracture of unspecified lower leg, initial encounter for closed fracture
        "S8290XB",  # Unspecified fracture of unspecified lower leg, initial encounter for open fracture type I or II
        "S8290XC",  # Unspecified fracture of unspecified lower leg, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S8291XA",  # Unspecified fracture of right lower leg, initial encounter for closed fracture
        "S8291XB",  # Unspecified fracture of right lower leg, initial encounter for open fracture type I or II
        "S8291XC",  # Unspecified fracture of right lower leg, initial encounter for open fracture type IIIA, IIIB, or IIIC
        "S8292XA",  # Unspecified fracture of left lower leg, initial encounter for closed fracture
        "S8292XB",  # Unspecified fracture of left lower leg, initial encounter for open fracture type I or II
        "S8292XC",  # Unspecified fracture of left lower leg, initial encounter for open fracture type IIIA, IIIB, or IIIC
    }

class MalignantBoneDisease(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for malignant bone disease

    **Data Element Scope:** This value set may use a model element related to Diagnosis

    **Inclusion Criteria:** Includes concepts for malignant bone disease

    **Exclusion Criteria:** N/A
    """

    VALUE_SET_NAME = "Malignant Bone Disease"
    OID = "2.16.840.1.113762.1.4.1248.24"
    DEFINITION_VERSION = "20221006"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "C4000",  # Malignant neoplasm of scapula and long bones of unspecified upper limb
        "C4001",  # Malignant neoplasm of scapula and long bones of right upper limb
        "C4002",  # Malignant neoplasm of scapula and long bones of left upper limb
        "C4010",  # Malignant neoplasm of short bones of unspecified upper limb
        "C4011",  # Malignant neoplasm of short bones of right upper limb
        "C4012",  # Malignant neoplasm of short bones of left upper limb
        "C4020",  # Malignant neoplasm of long bones of unspecified lower limb
        "C4021",  # Malignant neoplasm of long bones of right lower limb
        "C4022",  # Malignant neoplasm of long bones of left lower limb
        "C4030",  # Malignant neoplasm of short bones of unspecified lower limb
        "C4031",  # Malignant neoplasm of short bones of right lower limb
        "C4032",  # Malignant neoplasm of short bones of left lower limb
        "C4080",  # Malignant neoplasm of overlapping sites of bone and articular cartilage of unspecified limb
        "C4081",  # Malignant neoplasm of overlapping sites of bone and articular cartilage of right limb
        "C4082",  # Malignant neoplasm of overlapping sites of bone and articular cartilage of left limb
        "C4090",  # Malignant neoplasm of unspecified bones and articular cartilage of unspecified limb
        "C4091",  # Malignant neoplasm of unspecified bones and articular cartilage of right limb
        "C4092",  # Malignant neoplasm of unspecified bones and articular cartilage of left limb
        "C410",  # Malignant neoplasm of bones of skull and face
        "C411",  # Malignant neoplasm of mandible
        "C412",  # Malignant neoplasm of vertebral column
        "C413",  # Malignant neoplasm of ribs, sternum and clavicle
        "C414",  # Malignant neoplasm of pelvic bones, sacrum and coccyx
        "C419",  # Malignant neoplasm of bone and articular cartilage, unspecified
        "C7951",  # Secondary malignant neoplasm of bone
        "C7952",  # Secondary malignant neoplasm of bone marrow
        "C800",  # Disseminated malignant neoplasm, unspecified
    }

class Malnutrition(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for malnutrition

    **Data Element Scope:** This value set may use a model element related to Diagnosis

    **Inclusion Criteria:** Includes concepts representing malnutrition

    **Exclusion Criteria:** N/A
    """

    VALUE_SET_NAME = "Malnutrition"
    OID = "2.16.840.1.113762.1.4.1272.1"
    DEFINITION_VERSION = "20241012"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "E40",  # Kwashiorkor
        "E41",  # Nutritional marasmus
        "E42",  # Marasmic kwashiorkor
        "E43",  # Unspecified severe protein-calorie malnutrition
        "E440",  # Moderate protein-calorie malnutrition
        "E441",  # Mild protein-calorie malnutrition
        "E46",  # Unspecified protein-calorie malnutrition
        "E640",  # Sequelae of protein-calorie malnutrition
        "O2510",  # Malnutrition in pregnancy, unspecified trimester
        "O2511",  # Malnutrition in pregnancy, first trimester
        "O2512",  # Malnutrition in pregnancy, second trimester
        "O2513",  # Malnutrition in pregnancy, third trimester
        "O252",  # Malnutrition in childbirth
        "O253",  # Malnutrition in the puerperium
    }

class ModerateInjuries(ValueSet):
    """
    **Clinical Focus:** The purpose of this ICD-10-CM value set is to identify moderate injuries that could occur as a result of a fall

    **Data Element Scope:** This value set may use a model element related to Diagnosis

    **Inclusion Criteria:** Includes ICD-10-CM concepts that represent moderate injuries that could occur as a result of a fall (such as lacerations, open wounds, dislocations, sprains, and muscle strains.)

    **Exclusion Criteria:** Excludes major injuries (such as large bone fractures, closed head injuries, internal bleeding, and death.) Excludes minor injuries (such as abrasions, small bone fractures.)
    """

    VALUE_SET_NAME = "Moderate Injuries"
    OID = "2.16.840.1.113762.1.4.1248.205"
    DEFINITION_VERSION = "20240112"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "S0100XA",  # Unspecified open wound of scalp, initial encounter
        "S0101XA",  # Laceration without foreign body of scalp, initial encounter
        "S0102XA",  # Laceration with foreign body of scalp, initial encounter
        "S01101A",  # Unspecified open wound of right eyelid and periocular area, initial encounter
        "S01102A",  # Unspecified open wound of left eyelid and periocular area, initial encounter
        "S01109A",  # Unspecified open wound of unspecified eyelid and periocular area, initial encounter
        "S01111A",  # Laceration without foreign body of right eyelid and periocular area, initial encounter
        "S01112A",  # Laceration without foreign body of left eyelid and periocular area, initial encounter
        "S01119A",  # Laceration without foreign body of unspecified eyelid and periocular area, initial encounter
        "S01121A",  # Laceration with foreign body of right eyelid and periocular area, initial encounter
        "S01122A",  # Laceration with foreign body of left eyelid and periocular area, initial encounter
        "S01129A",  # Laceration with foreign body of unspecified eyelid and periocular area, initial encounter
        "S0120XA",  # Unspecified open wound of nose, initial encounter
        "S0121XA",  # Laceration without foreign body of nose, initial encounter
        "S0122XA",  # Laceration with foreign body of nose, initial encounter
        "S01301A",  # Unspecified open wound of right ear, initial encounter
        "S01302A",  # Unspecified open wound of left ear, initial encounter
        "S01309A",  # Unspecified open wound of unspecified ear, initial encounter
        "S01311A",  # Laceration without foreign body of right ear, initial encounter
        "S01312A",  # Laceration without foreign body of left ear, initial encounter
        "S01319A",  # Laceration without foreign body of unspecified ear, initial encounter
        "S01321A",  # Laceration with foreign body of right ear, initial encounter
        "S01322A",  # Laceration with foreign body of left ear, initial encounter
        "S01329A",  # Laceration with foreign body of unspecified ear, initial encounter
        "S01401A",  # Unspecified open wound of right cheek and temporomandibular area, initial encounter
        "S01402A",  # Unspecified open wound of left cheek and temporomandibular area, initial encounter
        "S01409A",  # Unspecified open wound of unspecified cheek and temporomandibular area, initial encounter
        "S01411A",  # Laceration without foreign body of right cheek and temporomandibular area, initial encounter
        "S01412A",  # Laceration without foreign body of left cheek and temporomandibular area, initial encounter
        "S01419A",  # Laceration without foreign body of unspecified cheek and temporomandibular area, initial encounter
        "S01421A",  # Laceration with foreign body of right cheek and temporomandibular area, initial encounter
        "S01422A",  # Laceration with foreign body of left cheek and temporomandibular area, initial encounter
        "S01429A",  # Laceration with foreign body of unspecified cheek and temporomandibular area, initial encounter
        "S01501A",  # Unspecified open wound of lip, initial encounter
        "S01502A",  # Unspecified open wound of oral cavity, initial encounter
        "S01511A",  # Laceration without foreign body of lip, initial encounter
        "S01512A",  # Laceration without foreign body of oral cavity, initial encounter
        "S01521A",  # Laceration with foreign body of lip, initial encounter
        "S01522A",  # Laceration with foreign body of oral cavity, initial encounter
        "S0180XA",  # Unspecified open wound of other part of head, initial encounter
        "S0181XA",  # Laceration without foreign body of other part of head, initial encounter
        "S0182XA",  # Laceration with foreign body of other part of head, initial encounter
        "S0190XA",  # Unspecified open wound of unspecified part of head, initial encounter
        "S0191XA",  # Laceration without foreign body of unspecified part of head, initial encounter
        "S0192XA",  # Laceration with foreign body of unspecified part of head, initial encounter
        "S0300XA",  # Dislocation of jaw, unspecified side, initial encounter
        "S0301XA",  # Dislocation of jaw, right side, initial encounter
        "S0302XA",  # Dislocation of jaw, left side, initial encounter
        "S0303XA",  # Dislocation of jaw, bilateral, initial encounter
        "S031XXA",  # Dislocation of septal cartilage of nose, initial encounter
        "S0340XA",  # Sprain of jaw, unspecified side, initial encounter
        "S0341XA",  # Sprain of jaw, right side, initial encounter
        "S0342XA",  # Sprain of jaw, left side, initial encounter
        "S0343XA",  # Sprain of jaw, bilateral, initial encounter
        "S038XXA",  # Sprain of joints and ligaments of other parts of head, initial encounter
        "S039XXA",  # Sprain of joints and ligaments of unspecified parts of head, initial encounter
        "S0911XA",  # Strain of muscle and tendon of head, initial encounter
        "S1180XA",  # Unspecified open wound of other specified part of neck, initial encounter
        "S1181XA",  # Laceration without foreign body of other specified part of neck, initial encounter
        "S1182XA",  # Laceration with foreign body of other specified part of neck, initial encounter
        "S1189XA",  # Other open wound of other specified part of neck, initial encounter
        "S1190XA",  # Unspecified open wound of unspecified part of neck, initial encounter
        "S1191XA",  # Laceration without foreign body of unspecified part of neck, initial encounter
        "S1192XA",  # Laceration with foreign body of unspecified part of neck, initial encounter
        "S13101A",  # Dislocation of unspecified cervical vertebrae, initial encounter
        "S13111A",  # Dislocation of C0/C1 cervical vertebrae, initial encounter
        "S13121A",  # Dislocation of C1/C2 cervical vertebrae, initial encounter
        "S13131A",  # Dislocation of C2/C3 cervical vertebrae, initial encounter
        "S13141A",  # Dislocation of C3/C4 cervical vertebrae, initial encounter
        "S13151A",  # Dislocation of C4/C5 cervical vertebrae, initial encounter
        "S13161A",  # Dislocation of C5/C6 cervical vertebrae, initial encounter
        "S13171A",  # Dislocation of C6/C7 cervical vertebrae, initial encounter
        "S13181A",  # Dislocation of C7/T1 cervical vertebrae, initial encounter
        "S1320XA",  # Dislocation of unspecified parts of neck, initial encounter
        "S1329XA",  # Dislocation of other parts of neck, initial encounter
        "S134XXA",  # Sprain of ligaments of cervical spine, initial encounter
        "S135XXA",  # Sprain of thyroid region, initial encounter
        "S138XXA",  # Sprain of joints and ligaments of other parts of neck, initial encounter
        "S139XXA",  # Sprain of joints and ligaments of unspecified parts of neck, initial encounter
        "S161XXA",  # Strain of muscle, fascia and tendon at neck level, initial encounter
        "S21001A",  # Unspecified open wound of right breast, initial encounter
        "S21002A",  # Unspecified open wound of left breast, initial encounter
        "S21009A",  # Unspecified open wound of unspecified breast, initial encounter
        "S21011A",  # Laceration without foreign body of right breast, initial encounter
        "S21012A",  # Laceration without foreign body of left breast, initial encounter
        "S21019A",  # Laceration without foreign body of unspecified breast, initial encounter
        "S21021A",  # Laceration with foreign body of right breast, initial encounter
        "S21022A",  # Laceration with foreign body of left breast, initial encounter
        "S21029A",  # Laceration with foreign body of unspecified breast, initial encounter
        "S21101A",  # Unspecified open wound of right front wall of thorax without penetration into thoracic cavity, initial encounter
        "S21102A",  # Unspecified open wound of left front wall of thorax without penetration into thoracic cavity, initial encounter
        "S21109A",  # Unspecified open wound of unspecified front wall of thorax without penetration into thoracic cavity, initial encounter
        "S21111A",  # Laceration without foreign body of right front wall of thorax without penetration into thoracic cavity, initial encounter
        "S21112A",  # Laceration without foreign body of left front wall of thorax without penetration into thoracic cavity, initial encounter
        "S21119A",  # Laceration without foreign body of unspecified front wall of thorax without penetration into thoracic cavity, initial encounter
        "S21121A",  # Laceration with foreign body of right front wall of thorax without penetration into thoracic cavity, initial encounter
        "S21122A",  # Laceration with foreign body of left front wall of thorax without penetration into thoracic cavity, initial encounter
        "S21129A",  # Laceration with foreign body of unspecified front wall of thorax without penetration into thoracic cavity, initial encounter
        "S21201A",  # Unspecified open wound of right back wall of thorax without penetration into thoracic cavity, initial encounter
        "S21202A",  # Unspecified open wound of left back wall of thorax without penetration into thoracic cavity, initial encounter
        "S21209A",  # Unspecified open wound of unspecified back wall of thorax without penetration into thoracic cavity, initial encounter
        "S21211A",  # Laceration without foreign body of right back wall of thorax without penetration into thoracic cavity, initial encounter
        "S21212A",  # Laceration without foreign body of left back wall of thorax without penetration into thoracic cavity, initial encounter
        "S21219A",  # Laceration without foreign body of unspecified back wall of thorax without penetration into thoracic cavity, initial encounter
        "S21221A",  # Laceration with foreign body of right back wall of thorax without penetration into thoracic cavity, initial encounter
        "S21222A",  # Laceration with foreign body of left back wall of thorax without penetration into thoracic cavity, initial encounter
        "S21229A",  # Laceration with foreign body of unspecified back wall of thorax without penetration into thoracic cavity, initial encounter
        "S2190XA",  # Unspecified open wound of unspecified part of thorax, initial encounter
        "S2191XA",  # Laceration without foreign body of unspecified part of thorax, initial encounter
        "S2192XA",  # Laceration with foreign body of unspecified part of thorax, initial encounter
        "S23101A",  # Dislocation of unspecified thoracic vertebra, initial encounter
        "S23111A",  # Dislocation of T1/T2 thoracic vertebra, initial encounter
        "S23121A",  # Dislocation of T2/T3 thoracic vertebra, initial encounter
        "S23123A",  # Dislocation of T3/T4 thoracic vertebra, initial encounter
        "S23131A",  # Dislocation of T4/T5 thoracic vertebra, initial encounter
        "S23133A",  # Dislocation of T5/T6 thoracic vertebra, initial encounter
        "S23141A",  # Dislocation of T6/T7 thoracic vertebra, initial encounter
        "S23143A",  # Dislocation of T7/T8 thoracic vertebra, initial encounter
        "S23151A",  # Dislocation of T8/T9 thoracic vertebra, initial encounter
        "S23153A",  # Dislocation of T9/T10 thoracic vertebra, initial encounter
        "S23161A",  # Dislocation of T10/T11 thoracic vertebra, initial encounter
        "S23163A",  # Dislocation of T11/T12 thoracic vertebra, initial encounter
        "S23171A",  # Dislocation of T12/L1 thoracic vertebra, initial encounter
        "S2320XA",  # Dislocation of unspecified part of thorax, initial encounter
        "S2329XA",  # Dislocation of other parts of thorax, initial encounter
        "S233XXA",  # Sprain of ligaments of thoracic spine, initial encounter
        "S2341XA",  # Sprain of ribs, initial encounter
        "S23420A",  # Sprain of sternoclavicular (joint) (ligament), initial encounter
        "S23421A",  # Sprain of chondrosternal joint, initial encounter
        "S23428A",  # Other sprain of sternum, initial encounter
        "S23429A",  # Unspecified sprain of sternum, initial encounter
        "S238XXA",  # Sprain of other specified parts of thorax, initial encounter
        "S239XXA",  # Sprain of unspecified parts of thorax, initial encounter
        "S29011A",  # Strain of muscle and tendon of front wall of thorax, initial encounter
        "S29012A",  # Strain of muscle and tendon of back wall of thorax, initial encounter
        "S29019A",  # Strain of muscle and tendon of unspecified wall of thorax, initial encounter
        "S31000A",  # Unspecified open wound of lower back and pelvis without penetration into retroperitoneum, initial encounter
        "S31010A",  # Laceration without foreign body of lower back and pelvis without penetration into retroperitoneum, initial encounter
        "S31020A",  # Laceration with foreign body of lower back and pelvis without penetration into retroperitoneum, initial encounter
        "S31100A",  # Unspecified open wound of abdominal wall, right upper quadrant without penetration into peritoneal cavity, initial encounter
        "S31101A",  # Unspecified open wound of abdominal wall, left upper quadrant without penetration into peritoneal cavity, initial encounter
        "S31102A",  # Unspecified open wound of abdominal wall, epigastric region without penetration into peritoneal cavity, initial encounter
        "S31103A",  # Unspecified open wound of abdominal wall, right lower quadrant without penetration into peritoneal cavity, initial encounter
        "S31104A",  # Unspecified open wound of abdominal wall, left lower quadrant without penetration into peritoneal cavity, initial encounter
        "S31105A",  # Unspecified open wound of abdominal wall, periumbilic region without penetration into peritoneal cavity, initial encounter
        "S31109A",  # Unspecified open wound of abdominal wall, unspecified quadrant without penetration into peritoneal cavity, initial encounter
        "S31110A",  # Laceration without foreign body of abdominal wall, right upper quadrant without penetration into peritoneal cavity, initial encounter
        "S31111A",  # Laceration without foreign body of abdominal wall, left upper quadrant without penetration into peritoneal cavity, initial encounter
        "S31112A",  # Laceration without foreign body of abdominal wall, epigastric region without penetration into peritoneal cavity, initial encounter
        "S31113A",  # Laceration without foreign body of abdominal wall, right lower quadrant without penetration into peritoneal cavity, initial encounter
        "S31114A",  # Laceration without foreign body of abdominal wall, left lower quadrant without penetration into peritoneal cavity, initial encounter
        "S31115A",  # Laceration without foreign body of abdominal wall, periumbilic region without penetration into peritoneal cavity, initial encounter
        "S31119A",  # Laceration without foreign body of abdominal wall, unspecified quadrant without penetration into peritoneal cavity, initial encounter
        "S31120A",  # Laceration of abdominal wall with foreign body, right upper quadrant without penetration into peritoneal cavity, initial encounter
        "S31121A",  # Laceration of abdominal wall with foreign body, left upper quadrant without penetration into peritoneal cavity, initial encounter
        "S31122A",  # Laceration of abdominal wall with foreign body, epigastric region without penetration into peritoneal cavity, initial encounter
        "S31123A",  # Laceration of abdominal wall with foreign body, right lower quadrant without penetration into peritoneal cavity, initial encounter
        "S31124A",  # Laceration of abdominal wall with foreign body, left lower quadrant without penetration into peritoneal cavity, initial encounter
        "S31125A",  # Laceration of abdominal wall with foreign body, periumbilic region without penetration into peritoneal cavity, initial encounter
        "S31129A",  # Laceration of abdominal wall with foreign body, unspecified quadrant without penetration into peritoneal cavity, initial encounter
        "S3120XA",  # Unspecified open wound of penis, initial encounter
        "S3121XA",  # Laceration without foreign body of penis, initial encounter
        "S3122XA",  # Laceration with foreign body of penis, initial encounter
        "S3130XA",  # Unspecified open wound of scrotum and testes, initial encounter
        "S3131XA",  # Laceration without foreign body of scrotum and testes, initial encounter
        "S3132XA",  # Laceration with foreign body of scrotum and testes, initial encounter
        "S3140XA",  # Unspecified open wound of vagina and vulva, initial encounter
        "S3141XA",  # Laceration without foreign body of vagina and vulva, initial encounter
        "S3142XA",  # Laceration with foreign body of vagina and vulva, initial encounter
        "S31501A",  # Unspecified open wound of unspecified external genital organs, male, initial encounter
        "S31502A",  # Unspecified open wound of unspecified external genital organs, female, initial encounter
        "S31511A",  # Laceration without foreign body of unspecified external genital organs, male, initial encounter
        "S31512A",  # Laceration without foreign body of unspecified external genital organs, female, initial encounter
        "S31521A",  # Laceration with foreign body of unspecified external genital organs, male, initial encounter
        "S31522A",  # Laceration with foreign body of unspecified external genital organs, female, initial encounter
        "S31801A",  # Laceration without foreign body of unspecified buttock, initial encounter
        "S31802A",  # Laceration with foreign body of unspecified buttock, initial encounter
        "S31809A",  # Unspecified open wound of unspecified buttock, initial encounter
        "S31811A",  # Laceration without foreign body of right buttock, initial encounter
        "S31812A",  # Laceration with foreign body of right buttock, initial encounter
        "S31819A",  # Unspecified open wound of right buttock, initial encounter
        "S31821A",  # Laceration without foreign body of left buttock, initial encounter
        "S31822A",  # Laceration with foreign body of left buttock, initial encounter
        "S31829A",  # Unspecified open wound of left buttock, initial encounter
        "S31839A",  # Unspecified open wound of anus, initial encounter
        "S33101A",  # Dislocation of unspecified lumbar vertebra, initial encounter
        "S33111A",  # Dislocation of L1/L2 lumbar vertebra, initial encounter
        "S33121A",  # Dislocation of L2/L3 lumbar vertebra, initial encounter
        "S33131A",  # Dislocation of L3/L4 lumbar vertebra, initial encounter
        "S33141A",  # Dislocation of L4/L5 lumbar vertebra, initial encounter
        "S332XXA",  # Dislocation of sacroiliac and sacrococcygeal joint, initial encounter
        "S3330XA",  # Dislocation of unspecified parts of lumbar spine and pelvis, initial encounter
        "S3339XA",  # Dislocation of other parts of lumbar spine and pelvis, initial encounter
        "S335XXA",  # Sprain of ligaments of lumbar spine, initial encounter
        "S336XXA",  # Sprain of sacroiliac joint, initial encounter
        "S338XXA",  # Sprain of other parts of lumbar spine and pelvis, initial encounter
        "S339XXA",  # Sprain of unspecified parts of lumbar spine and pelvis, initial encounter
        "S39011A",  # Strain of muscle, fascia and tendon of abdomen, initial encounter
        "S39012A",  # Strain of muscle, fascia and tendon of lower back, initial encounter
        "S39013A",  # Strain of muscle, fascia and tendon of pelvis, initial encounter
        "S41001A",  # Unspecified open wound of right shoulder, initial encounter
        "S41002A",  # Unspecified open wound of left shoulder, initial encounter
        "S41009A",  # Unspecified open wound of unspecified shoulder, initial encounter
        "S41011A",  # Laceration without foreign body of right shoulder, initial encounter
        "S41012A",  # Laceration without foreign body of left shoulder, initial encounter
        "S41019A",  # Laceration without foreign body of unspecified shoulder, initial encounter
        "S41021A",  # Laceration with foreign body of right shoulder, initial encounter
        "S41022A",  # Laceration with foreign body of left shoulder, initial encounter
        "S41029A",  # Laceration with foreign body of unspecified shoulder, initial encounter
        "S41101A",  # Unspecified open wound of right upper arm, initial encounter
        "S41102A",  # Unspecified open wound of left upper arm, initial encounter
        "S41109A",  # Unspecified open wound of unspecified upper arm, initial encounter
        "S41111A",  # Laceration without foreign body of right upper arm, initial encounter
        "S41112A",  # Laceration without foreign body of left upper arm, initial encounter
        "S41119A",  # Laceration without foreign body of unspecified upper arm, initial encounter
        "S41121A",  # Laceration with foreign body of right upper arm, initial encounter
        "S41122A",  # Laceration with foreign body of left upper arm, initial encounter
        "S41129A",  # Laceration with foreign body of unspecified upper arm, initial encounter
        "S43004A",  # Unspecified dislocation of right shoulder joint, initial encounter
        "S43005A",  # Unspecified dislocation of left shoulder joint, initial encounter
        "S43006A",  # Unspecified dislocation of unspecified shoulder joint, initial encounter
        "S43014A",  # Anterior dislocation of right humerus, initial encounter
        "S43015A",  # Anterior dislocation of left humerus, initial encounter
        "S43016A",  # Anterior dislocation of unspecified humerus, initial encounter
        "S43024A",  # Posterior dislocation of right humerus, initial encounter
        "S43025A",  # Posterior dislocation of left humerus, initial encounter
        "S43026A",  # Posterior dislocation of unspecified humerus, initial encounter
        "S43034A",  # Inferior dislocation of right humerus, initial encounter
        "S43035A",  # Inferior dislocation of left humerus, initial encounter
        "S43036A",  # Inferior dislocation of unspecified humerus, initial encounter
        "S43084A",  # Other dislocation of right shoulder joint, initial encounter
        "S43085A",  # Other dislocation of left shoulder joint, initial encounter
        "S43086A",  # Other dislocation of unspecified shoulder joint, initial encounter
        "S43101A",  # Unspecified dislocation of right acromioclavicular joint, initial encounter
        "S43102A",  # Unspecified dislocation of left acromioclavicular joint, initial encounter
        "S43109A",  # Unspecified dislocation of unspecified acromioclavicular joint, initial encounter
        "S43121A",  # Dislocation of right acromioclavicular joint, 100%-200% displacement, initial encounter
        "S43122A",  # Dislocation of left acromioclavicular joint, 100%-200% displacement, initial encounter
        "S43129A",  # Dislocation of unspecified acromioclavicular joint, 100%-200% displacement, initial encounter
        "S43131A",  # Dislocation of right acromioclavicular joint, greater than 200% displacement, initial encounter
        "S43132A",  # Dislocation of left acromioclavicular joint, greater than 200% displacement, initial encounter
        "S43139A",  # Dislocation of unspecified acromioclavicular joint, greater than 200% displacement, initial encounter
        "S43141A",  # Inferior dislocation of right acromioclavicular joint, initial encounter
        "S43142A",  # Inferior dislocation of left acromioclavicular joint, initial encounter
        "S43149A",  # Inferior dislocation of unspecified acromioclavicular joint, initial encounter
        "S43151A",  # Posterior dislocation of right acromioclavicular joint, initial encounter
        "S43152A",  # Posterior dislocation of left acromioclavicular joint, initial encounter
        "S43159A",  # Posterior dislocation of unspecified acromioclavicular joint, initial encounter
        "S43204A",  # Unspecified dislocation of right sternoclavicular joint, initial encounter
        "S43205A",  # Unspecified dislocation of left sternoclavicular joint, initial encounter
        "S43206A",  # Unspecified dislocation of unspecified sternoclavicular joint, initial encounter
        "S43214A",  # Anterior dislocation of right sternoclavicular joint, initial encounter
        "S43215A",  # Anterior dislocation of left sternoclavicular joint, initial encounter
        "S43216A",  # Anterior dislocation of unspecified sternoclavicular joint, initial encounter
        "S43224A",  # Posterior dislocation of right sternoclavicular joint, initial encounter
        "S43225A",  # Posterior dislocation of left sternoclavicular joint, initial encounter
        "S43226A",  # Posterior dislocation of unspecified sternoclavicular joint, initial encounter
        "S43304A",  # Dislocation of unspecified parts of right shoulder girdle, initial encounter
        "S43305A",  # Dislocation of unspecified parts of left shoulder girdle, initial encounter
        "S43306A",  # Dislocation of unspecified parts of unspecified shoulder girdle, initial encounter
        "S43314A",  # Dislocation of right scapula, initial encounter
        "S43315A",  # Dislocation of left scapula, initial encounter
        "S43316A",  # Dislocation of unspecified scapula, initial encounter
        "S43394A",  # Dislocation of other parts of right shoulder girdle, initial encounter
        "S43395A",  # Dislocation of other parts of left shoulder girdle, initial encounter
        "S43396A",  # Dislocation of other parts of unspecified shoulder girdle, initial encounter
        "S43401A",  # Unspecified sprain of right shoulder joint, initial encounter
        "S43402A",  # Unspecified sprain of left shoulder joint, initial encounter
        "S43409A",  # Unspecified sprain of unspecified shoulder joint, initial encounter
        "S43411A",  # Sprain of right coracohumeral (ligament), initial encounter
        "S43412A",  # Sprain of left coracohumeral (ligament), initial encounter
        "S43419A",  # Sprain of unspecified coracohumeral (ligament), initial encounter
        "S43421A",  # Sprain of right rotator cuff capsule, initial encounter
        "S43422A",  # Sprain of left rotator cuff capsule, initial encounter
        "S43429A",  # Sprain of unspecified rotator cuff capsule, initial encounter
        "S43491A",  # Other sprain of right shoulder joint, initial encounter
        "S43492A",  # Other sprain of left shoulder joint, initial encounter
        "S43499A",  # Other sprain of unspecified shoulder joint, initial encounter
        "S4350XA",  # Sprain of unspecified acromioclavicular joint, initial encounter
        "S4351XA",  # Sprain of right acromioclavicular joint, initial encounter
        "S4352XA",  # Sprain of left acromioclavicular joint, initial encounter
        "S4360XA",  # Sprain of unspecified sternoclavicular joint, initial encounter
        "S4361XA",  # Sprain of right sternoclavicular joint, initial encounter
        "S4362XA",  # Sprain of left sternoclavicular joint, initial encounter
        "S4380XA",  # Sprain of other specified parts of unspecified shoulder girdle, initial encounter
        "S4381XA",  # Sprain of other specified parts of right shoulder girdle, initial encounter
        "S4382XA",  # Sprain of other specified parts of left shoulder girdle, initial encounter
        "S4390XA",  # Sprain of unspecified parts of unspecified shoulder girdle, initial encounter
        "S4391XA",  # Sprain of unspecified parts of right shoulder girdle, initial encounter
        "S4392XA",  # Sprain of unspecified parts of left shoulder girdle, initial encounter
        "S46011A",  # Strain of muscle(s) and tendon(s) of the rotator cuff of right shoulder, initial encounter
        "S46012A",  # Strain of muscle(s) and tendon(s) of the rotator cuff of left shoulder, initial encounter
        "S46019A",  # Strain of muscle(s) and tendon(s) of the rotator cuff of unspecified shoulder, initial encounter
        "S46111A",  # Strain of muscle, fascia and tendon of long head of biceps, right arm, initial encounter
        "S46112A",  # Strain of muscle, fascia and tendon of long head of biceps, left arm, initial encounter
        "S46119A",  # Strain of muscle, fascia and tendon of long head of biceps, unspecified arm, initial encounter
        "S46211A",  # Strain of muscle, fascia and tendon of other parts of biceps, right arm, initial encounter
        "S46212A",  # Strain of muscle, fascia and tendon of other parts of biceps, left arm, initial encounter
        "S46219A",  # Strain of muscle, fascia and tendon of other parts of biceps, unspecified arm, initial encounter
        "S46311A",  # Strain of muscle, fascia and tendon of triceps, right arm, initial encounter
        "S46312A",  # Strain of muscle, fascia and tendon of triceps, left arm, initial encounter
        "S46319A",  # Strain of muscle, fascia and tendon of triceps, unspecified arm, initial encounter
        "S46811A",  # Strain of other muscles, fascia and tendons at shoulder and upper arm level, right arm, initial encounter
        "S46812A",  # Strain of other muscles, fascia and tendons at shoulder and upper arm level, left arm, initial encounter
        "S46819A",  # Strain of other muscles, fascia and tendons at shoulder and upper arm level, unspecified arm, initial encounter
        "S46911A",  # Strain of unspecified muscle, fascia and tendon at shoulder and upper arm level, right arm, initial encounter
        "S46912A",  # Strain of unspecified muscle, fascia and tendon at shoulder and upper arm level, left arm, initial encounter
        "S46919A",  # Strain of unspecified muscle, fascia and tendon at shoulder and upper arm level, unspecified arm, initial encounter
        "S51001A",  # Unspecified open wound of right elbow, initial encounter
        "S51002A",  # Unspecified open wound of left elbow, initial encounter
        "S51009A",  # Unspecified open wound of unspecified elbow, initial encounter
        "S51011A",  # Laceration without foreign body of right elbow, initial encounter
        "S51012A",  # Laceration without foreign body of left elbow, initial encounter
        "S51019A",  # Laceration without foreign body of unspecified elbow, initial encounter
        "S51021A",  # Laceration with foreign body of right elbow, initial encounter
        "S51022A",  # Laceration with foreign body of left elbow, initial encounter
        "S51029A",  # Laceration with foreign body of unspecified elbow, initial encounter
        "S51801A",  # Unspecified open wound of right forearm, initial encounter
        "S51802A",  # Unspecified open wound of left forearm, initial encounter
        "S51809A",  # Unspecified open wound of unspecified forearm, initial encounter
        "S51811A",  # Laceration without foreign body of right forearm, initial encounter
        "S51812A",  # Laceration without foreign body of left forearm, initial encounter
        "S51819A",  # Laceration without foreign body of unspecified forearm, initial encounter
        "S51821A",  # Laceration with foreign body of right forearm, initial encounter
        "S51822A",  # Laceration with foreign body of left forearm, initial encounter
        "S51829A",  # Laceration with foreign body of unspecified forearm, initial encounter
        "S53004A",  # Unspecified dislocation of right radial head, initial encounter
        "S53005A",  # Unspecified dislocation of left radial head, initial encounter
        "S53006A",  # Unspecified dislocation of unspecified radial head, initial encounter
        "S53014A",  # Anterior dislocation of right radial head, initial encounter
        "S53015A",  # Anterior dislocation of left radial head, initial encounter
        "S53016A",  # Anterior dislocation of unspecified radial head, initial encounter
        "S53024A",  # Posterior dislocation of right radial head, initial encounter
        "S53025A",  # Posterior dislocation of left radial head, initial encounter
        "S53026A",  # Posterior dislocation of unspecified radial head, initial encounter
        "S53094A",  # Other dislocation of right radial head, initial encounter
        "S53095A",  # Other dislocation of left radial head, initial encounter
        "S53096A",  # Other dislocation of unspecified radial head, initial encounter
        "S53104A",  # Unspecified dislocation of right ulnohumeral joint, initial encounter
        "S53105A",  # Unspecified dislocation of left ulnohumeral joint, initial encounter
        "S53106A",  # Unspecified dislocation of unspecified ulnohumeral joint, initial encounter
        "S53114A",  # Anterior dislocation of right ulnohumeral joint, initial encounter
        "S53115A",  # Anterior dislocation of left ulnohumeral joint, initial encounter
        "S53116A",  # Anterior dislocation of unspecified ulnohumeral joint, initial encounter
        "S53124A",  # Posterior dislocation of right ulnohumeral joint, initial encounter
        "S53125A",  # Posterior dislocation of left ulnohumeral joint, initial encounter
        "S53126A",  # Posterior dislocation of unspecified ulnohumeral joint, initial encounter
        "S53134A",  # Medial dislocation of right ulnohumeral joint, initial encounter
        "S53135A",  # Medial dislocation of left ulnohumeral joint, initial encounter
        "S53136A",  # Medial dislocation of unspecified ulnohumeral joint, initial encounter
        "S53144A",  # Lateral dislocation of right ulnohumeral joint, initial encounter
        "S53145A",  # Lateral dislocation of left ulnohumeral joint, initial encounter
        "S53146A",  # Lateral dislocation of unspecified ulnohumeral joint, initial encounter
        "S53194A",  # Other dislocation of right ulnohumeral joint, initial encounter
        "S53195A",  # Other dislocation of left ulnohumeral joint, initial encounter
        "S53196A",  # Other dislocation of unspecified ulnohumeral joint, initial encounter
        "S53401A",  # Unspecified sprain of right elbow, initial encounter
        "S53402A",  # Unspecified sprain of left elbow, initial encounter
        "S53409A",  # Unspecified sprain of unspecified elbow, initial encounter
        "S53411A",  # Radiohumeral (joint) sprain of right elbow, initial encounter
        "S53412A",  # Radiohumeral (joint) sprain of left elbow, initial encounter
        "S53419A",  # Radiohumeral (joint) sprain of unspecified elbow, initial encounter
        "S53421A",  # Ulnohumeral (joint) sprain of right elbow, initial encounter
        "S53422A",  # Ulnohumeral (joint) sprain of left elbow, initial encounter
        "S53429A",  # Ulnohumeral (joint) sprain of unspecified elbow, initial encounter
        "S53431A",  # Radial collateral ligament sprain of right elbow, initial encounter
        "S53432A",  # Radial collateral ligament sprain of left elbow, initial encounter
        "S53439A",  # Radial collateral ligament sprain of unspecified elbow, initial encounter
        "S53441A",  # Ulnar collateral ligament sprain of right elbow, initial encounter
        "S53442A",  # Ulnar collateral ligament sprain of left elbow, initial encounter
        "S53449A",  # Ulnar collateral ligament sprain of unspecified elbow, initial encounter
        "S53491A",  # Other sprain of right elbow, initial encounter
        "S53492A",  # Other sprain of left elbow, initial encounter
        "S53499A",  # Other sprain of unspecified elbow, initial encounter
        "S56011A",  # Strain of flexor muscle, fascia and tendon of right thumb at forearm level, initial encounter
        "S56012A",  # Strain of flexor muscle, fascia and tendon of left thumb at forearm level, initial encounter
        "S56019A",  # Strain of flexor muscle, fascia and tendon of unspecified thumb at forearm level, initial encounter
        "S56111A",  # Strain of flexor muscle, fascia and tendon of right index finger at forearm level, initial encounter
        "S56112A",  # Strain of flexor muscle, fascia and tendon of left index finger at forearm level, initial encounter
        "S56113A",  # Strain of flexor muscle, fascia and tendon of right middle finger at forearm level, initial encounter
        "S56114A",  # Strain of flexor muscle, fascia and tendon of left middle finger at forearm level, initial encounter
        "S56115A",  # Strain of flexor muscle, fascia and tendon of right ring finger at forearm level, initial encounter
        "S56116A",  # Strain of flexor muscle, fascia and tendon of left ring finger at forearm level, initial encounter
        "S56117A",  # Strain of flexor muscle, fascia and tendon of right little finger at forearm level, initial encounter
        "S56118A",  # Strain of flexor muscle, fascia and tendon of left little finger at forearm level, initial encounter
        "S56119A",  # Strain of flexor muscle, fascia and tendon of finger of unspecified finger at forearm level, initial encounter
        "S56211A",  # Strain of other flexor muscle, fascia and tendon at forearm level, right arm, initial encounter
        "S56212A",  # Strain of other flexor muscle, fascia and tendon at forearm level, left arm, initial encounter
        "S56219A",  # Strain of other flexor muscle, fascia and tendon at forearm level, unspecified arm, initial encounter
        "S56311A",  # Strain of extensor or abductor muscles, fascia and tendons of right thumb at forearm level, initial encounter
        "S56312A",  # Strain of extensor or abductor muscles, fascia and tendons of left thumb at forearm level, initial encounter
        "S56319A",  # Strain of extensor or abductor muscles, fascia and tendons of unspecified thumb at forearm level, initial encounter
        "S56411A",  # Strain of extensor muscle, fascia and tendon of right index finger at forearm level, initial encounter
        "S56412A",  # Strain of extensor muscle, fascia and tendon of left index finger at forearm level, initial encounter
        "S56413A",  # Strain of extensor muscle, fascia and tendon of right middle finger at forearm level, initial encounter
        "S56414A",  # Strain of extensor muscle, fascia and tendon of left middle finger at forearm level, initial encounter
        "S56415A",  # Strain of extensor muscle, fascia and tendon of right ring finger at forearm level, initial encounter
        "S56416A",  # Strain of extensor muscle, fascia and tendon of left ring finger at forearm level, initial encounter
        "S56417A",  # Strain of extensor muscle, fascia and tendon of right little finger at forearm level, initial encounter
        "S56418A",  # Strain of extensor muscle, fascia and tendon of left little finger at forearm level, initial encounter
        "S56419A",  # Strain of extensor muscle, fascia and tendon of finger, unspecified finger at forearm level, initial encounter
        "S56511A",  # Strain of other extensor muscle, fascia and tendon at forearm level, right arm, initial encounter
        "S56512A",  # Strain of other extensor muscle, fascia and tendon at forearm level, left arm, initial encounter
        "S56519A",  # Strain of other extensor muscle, fascia and tendon at forearm level, unspecified arm, initial encounter
        "S56811A",  # Strain of other muscles, fascia and tendons at forearm level, right arm, initial encounter
        "S56812A",  # Strain of other muscles, fascia and tendons at forearm level, left arm, initial encounter
        "S56819A",  # Strain of other muscles, fascia and tendons at forearm level, unspecified arm, initial encounter
        "S56911A",  # Strain of unspecified muscles, fascia and tendons at forearm level, right arm, initial encounter
        "S56912A",  # Strain of unspecified muscles, fascia and tendons at forearm level, left arm, initial encounter
        "S56919A",  # Strain of unspecified muscles, fascia and tendons at forearm level, unspecified arm, initial encounter
        "S61001A",  # Unspecified open wound of right thumb without damage to nail, initial encounter
        "S61002A",  # Unspecified open wound of left thumb without damage to nail, initial encounter
        "S61009A",  # Unspecified open wound of unspecified thumb without damage to nail, initial encounter
        "S61011A",  # Laceration without foreign body of right thumb without damage to nail, initial encounter
        "S61012A",  # Laceration without foreign body of left thumb without damage to nail, initial encounter
        "S61019A",  # Laceration without foreign body of unspecified thumb without damage to nail, initial encounter
        "S61021A",  # Laceration with foreign body of right thumb without damage to nail, initial encounter
        "S61022A",  # Laceration with foreign body of left thumb without damage to nail, initial encounter
        "S61029A",  # Laceration with foreign body of unspecified thumb without damage to nail, initial encounter
        "S61101A",  # Unspecified open wound of right thumb with damage to nail, initial encounter
        "S61102A",  # Unspecified open wound of left thumb with damage to nail, initial encounter
        "S61109A",  # Unspecified open wound of unspecified thumb with damage to nail, initial encounter
        "S61111A",  # Laceration without foreign body of right thumb with damage to nail, initial encounter
        "S61112A",  # Laceration without foreign body of left thumb with damage to nail, initial encounter
        "S61119A",  # Laceration without foreign body of unspecified thumb with damage to nail, initial encounter
        "S61121A",  # Laceration with foreign body of right thumb with damage to nail, initial encounter
        "S61122A",  # Laceration with foreign body of left thumb with damage to nail, initial encounter
        "S61129A",  # Laceration with foreign body of unspecified thumb with damage to nail, initial encounter
        "S61200A",  # Unspecified open wound of right index finger without damage to nail, initial encounter
        "S61201A",  # Unspecified open wound of left index finger without damage to nail, initial encounter
        "S61202A",  # Unspecified open wound of right middle finger without damage to nail, initial encounter
        "S61203A",  # Unspecified open wound of left middle finger without damage to nail, initial encounter
        "S61204A",  # Unspecified open wound of right ring finger without damage to nail, initial encounter
        "S61205A",  # Unspecified open wound of left ring finger without damage to nail, initial encounter
        "S61206A",  # Unspecified open wound of right little finger without damage to nail, initial encounter
        "S61207A",  # Unspecified open wound of left little finger without damage to nail, initial encounter
        "S61208A",  # Unspecified open wound of other finger without damage to nail, initial encounter
        "S61209A",  # Unspecified open wound of unspecified finger without damage to nail, initial encounter
        "S61210A",  # Laceration without foreign body of right index finger without damage to nail, initial encounter
        "S61211A",  # Laceration without foreign body of left index finger without damage to nail, initial encounter
        "S61212A",  # Laceration without foreign body of right middle finger without damage to nail, initial encounter
        "S61213A",  # Laceration without foreign body of left middle finger without damage to nail, initial encounter
        "S61214A",  # Laceration without foreign body of right ring finger without damage to nail, initial encounter
        "S61215A",  # Laceration without foreign body of left ring finger without damage to nail, initial encounter
        "S61216A",  # Laceration without foreign body of right little finger without damage to nail, initial encounter
        "S61217A",  # Laceration without foreign body of left little finger without damage to nail, initial encounter
        "S61218A",  # Laceration without foreign body of other finger without damage to nail, initial encounter
        "S61219A",  # Laceration without foreign body of unspecified finger without damage to nail, initial encounter
        "S61220A",  # Laceration with foreign body of right index finger without damage to nail, initial encounter
        "S61221A",  # Laceration with foreign body of left index finger without damage to nail, initial encounter
        "S61222A",  # Laceration with foreign body of right middle finger without damage to nail, initial encounter
        "S61223A",  # Laceration with foreign body of left middle finger without damage to nail, initial encounter
        "S61224A",  # Laceration with foreign body of right ring finger without damage to nail, initial encounter
        "S61225A",  # Laceration with foreign body of left ring finger without damage to nail, initial encounter
        "S61226A",  # Laceration with foreign body of right little finger without damage to nail, initial encounter
        "S61227A",  # Laceration with foreign body of left little finger without damage to nail, initial encounter
        "S61228A",  # Laceration with foreign body of other finger without damage to nail, initial encounter
        "S61229A",  # Laceration with foreign body of unspecified finger without damage to nail, initial encounter
        "S61300A",  # Unspecified open wound of right index finger with damage to nail, initial encounter
        "S61301A",  # Unspecified open wound of left index finger with damage to nail, initial encounter
        "S61302A",  # Unspecified open wound of right middle finger with damage to nail, initial encounter
        "S61303A",  # Unspecified open wound of left middle finger with damage to nail, initial encounter
        "S61304A",  # Unspecified open wound of right ring finger with damage to nail, initial encounter
        "S61305A",  # Unspecified open wound of left ring finger with damage to nail, initial encounter
        "S61306A",  # Unspecified open wound of right little finger with damage to nail, initial encounter
        "S61307A",  # Unspecified open wound of left little finger with damage to nail, initial encounter
        "S61308A",  # Unspecified open wound of other finger with damage to nail, initial encounter
        "S61309A",  # Unspecified open wound of unspecified finger with damage to nail, initial encounter
        "S61310A",  # Laceration without foreign body of right index finger with damage to nail, initial encounter
        "S61311A",  # Laceration without foreign body of left index finger with damage to nail, initial encounter
        "S61312A",  # Laceration without foreign body of right middle finger with damage to nail, initial encounter
        "S61313A",  # Laceration without foreign body of left middle finger with damage to nail, initial encounter
        "S61314A",  # Laceration without foreign body of right ring finger with damage to nail, initial encounter
        "S61315A",  # Laceration without foreign body of left ring finger with damage to nail, initial encounter
        "S61316A",  # Laceration without foreign body of right little finger with damage to nail, initial encounter
        "S61317A",  # Laceration without foreign body of left little finger with damage to nail, initial encounter
        "S61318A",  # Laceration without foreign body of other finger with damage to nail, initial encounter
        "S61319A",  # Laceration without foreign body of unspecified finger with damage to nail, initial encounter
        "S61320A",  # Laceration with foreign body of right index finger with damage to nail, initial encounter
        "S61321A",  # Laceration with foreign body of left index finger with damage to nail, initial encounter
        "S61322A",  # Laceration with foreign body of right middle finger with damage to nail, initial encounter
        "S61323A",  # Laceration with foreign body of left middle finger with damage to nail, initial encounter
        "S61324A",  # Laceration with foreign body of right ring finger with damage to nail, initial encounter
        "S61325A",  # Laceration with foreign body of left ring finger with damage to nail, initial encounter
        "S61326A",  # Laceration with foreign body of right little finger with damage to nail, initial encounter
        "S61327A",  # Laceration with foreign body of left little finger with damage to nail, initial encounter
        "S61328A",  # Laceration with foreign body of other finger with damage to nail, initial encounter
        "S61329A",  # Laceration with foreign body of unspecified finger with damage to nail, initial encounter
        "S61401A",  # Unspecified open wound of right hand, initial encounter
        "S61402A",  # Unspecified open wound of left hand, initial encounter
        "S61409A",  # Unspecified open wound of unspecified hand, initial encounter
        "S61411A",  # Laceration without foreign body of right hand, initial encounter
        "S61412A",  # Laceration without foreign body of left hand, initial encounter
        "S61419A",  # Laceration without foreign body of unspecified hand, initial encounter
        "S61421A",  # Laceration with foreign body of right hand, initial encounter
        "S61422A",  # Laceration with foreign body of left hand, initial encounter
        "S61429A",  # Laceration with foreign body of unspecified hand, initial encounter
        "S61501A",  # Unspecified open wound of right wrist, initial encounter
        "S61502A",  # Unspecified open wound of left wrist, initial encounter
        "S61509A",  # Unspecified open wound of unspecified wrist, initial encounter
        "S61511A",  # Laceration without foreign body of right wrist, initial encounter
        "S61512A",  # Laceration without foreign body of left wrist, initial encounter
        "S61519A",  # Laceration without foreign body of unspecified wrist, initial encounter
        "S61521A",  # Laceration with foreign body of right wrist, initial encounter
        "S61522A",  # Laceration with foreign body of left wrist, initial encounter
        "S61529A",  # Laceration with foreign body of unspecified wrist, initial encounter
        "S63004A",  # Unspecified dislocation of right wrist and hand, initial encounter
        "S63005A",  # Unspecified dislocation of left wrist and hand, initial encounter
        "S63006A",  # Unspecified dislocation of unspecified wrist and hand, initial encounter
        "S63014A",  # Dislocation of distal radioulnar joint of right wrist, initial encounter
        "S63015A",  # Dislocation of distal radioulnar joint of left wrist, initial encounter
        "S63016A",  # Dislocation of distal radioulnar joint of unspecified wrist, initial encounter
        "S63024A",  # Dislocation of radiocarpal joint of right wrist, initial encounter
        "S63025A",  # Dislocation of radiocarpal joint of left wrist, initial encounter
        "S63026A",  # Dislocation of radiocarpal joint of unspecified wrist, initial encounter
        "S63034A",  # Dislocation of midcarpal joint of right wrist, initial encounter
        "S63035A",  # Dislocation of midcarpal joint of left wrist, initial encounter
        "S63036A",  # Dislocation of midcarpal joint of unspecified wrist, initial encounter
        "S63044A",  # Dislocation of carpometacarpal joint of right thumb, initial encounter
        "S63045A",  # Dislocation of carpometacarpal joint of left thumb, initial encounter
        "S63046A",  # Dislocation of carpometacarpal joint of unspecified thumb, initial encounter
        "S63054A",  # Dislocation of other carpometacarpal joint of right hand, initial encounter
        "S63055A",  # Dislocation of other carpometacarpal joint of left hand, initial encounter
        "S63056A",  # Dislocation of other carpometacarpal joint of unspecified hand, initial encounter
        "S63064A",  # Dislocation of metacarpal (bone), proximal end of right hand, initial encounter
        "S63065A",  # Dislocation of metacarpal (bone), proximal end of left hand, initial encounter
        "S63066A",  # Dislocation of metacarpal (bone), proximal end of unspecified hand, initial encounter
        "S63074A",  # Dislocation of distal end of right ulna, initial encounter
        "S63075A",  # Dislocation of distal end of left ulna, initial encounter
        "S63076A",  # Dislocation of distal end of unspecified ulna, initial encounter
        "S63094A",  # Other dislocation of right wrist and hand, initial encounter
        "S63095A",  # Other dislocation of left wrist and hand, initial encounter
        "S63096A",  # Other dislocation of unspecified wrist and hand, initial encounter
        "S63501A",  # Unspecified sprain of right wrist, initial encounter
        "S63502A",  # Unspecified sprain of left wrist, initial encounter
        "S63509A",  # Unspecified sprain of unspecified wrist, initial encounter
        "S63511A",  # Sprain of carpal joint of right wrist, initial encounter
        "S63512A",  # Sprain of carpal joint of left wrist, initial encounter
        "S63519A",  # Sprain of carpal joint of unspecified wrist, initial encounter
        "S63521A",  # Sprain of radiocarpal joint of right wrist, initial encounter
        "S63522A",  # Sprain of radiocarpal joint of left wrist, initial encounter
        "S63529A",  # Sprain of radiocarpal joint of unspecified wrist, initial encounter
        "S63591A",  # Other specified sprain of right wrist, initial encounter
        "S63592A",  # Other specified sprain of left wrist, initial encounter
        "S63599A",  # Other specified sprain of unspecified wrist, initial encounter
        "S63601A",  # Unspecified sprain of right thumb, initial encounter
        "S63602A",  # Unspecified sprain of left thumb, initial encounter
        "S63609A",  # Unspecified sprain of unspecified thumb, initial encounter
        "S63610A",  # Unspecified sprain of right index finger, initial encounter
        "S63611A",  # Unspecified sprain of left index finger, initial encounter
        "S63612A",  # Unspecified sprain of right middle finger, initial encounter
        "S63613A",  # Unspecified sprain of left middle finger, initial encounter
        "S63614A",  # Unspecified sprain of right ring finger, initial encounter
        "S63615A",  # Unspecified sprain of left ring finger, initial encounter
        "S63616A",  # Unspecified sprain of right little finger, initial encounter
        "S63617A",  # Unspecified sprain of left little finger, initial encounter
        "S63618A",  # Unspecified sprain of other finger, initial encounter
        "S63619A",  # Unspecified sprain of unspecified finger, initial encounter
        "S63621A",  # Sprain of interphalangeal joint of right thumb, initial encounter
        "S63622A",  # Sprain of interphalangeal joint of left thumb, initial encounter
        "S63629A",  # Sprain of interphalangeal joint of unspecified thumb, initial encounter
        "S63630A",  # Sprain of interphalangeal joint of right index finger, initial encounter
        "S63631A",  # Sprain of interphalangeal joint of left index finger, initial encounter
        "S63632A",  # Sprain of interphalangeal joint of right middle finger, initial encounter
        "S63633A",  # Sprain of interphalangeal joint of left middle finger, initial encounter
        "S63634A",  # Sprain of interphalangeal joint of right ring finger, initial encounter
        "S63635A",  # Sprain of interphalangeal joint of left ring finger, initial encounter
        "S63636A",  # Sprain of interphalangeal joint of right little finger, initial encounter
        "S63637A",  # Sprain of interphalangeal joint of left little finger, initial encounter
        "S63638A",  # Sprain of interphalangeal joint of other finger, initial encounter
        "S63639A",  # Sprain of interphalangeal joint of unspecified finger, initial encounter
        "S63641A",  # Sprain of metacarpophalangeal joint of right thumb, initial encounter
        "S63642A",  # Sprain of metacarpophalangeal joint of left thumb, initial encounter
        "S63649A",  # Sprain of metacarpophalangeal joint of unspecified thumb, initial encounter
        "S63650A",  # Sprain of metacarpophalangeal joint of right index finger, initial encounter
        "S63651A",  # Sprain of metacarpophalangeal joint of left index finger, initial encounter
        "S63652A",  # Sprain of metacarpophalangeal joint of right middle finger, initial encounter
        "S63653A",  # Sprain of metacarpophalangeal joint of left middle finger, initial encounter
        "S63654A",  # Sprain of metacarpophalangeal joint of right ring finger, initial encounter
        "S63655A",  # Sprain of metacarpophalangeal joint of left ring finger, initial encounter
        "S63656A",  # Sprain of metacarpophalangeal joint of right little finger, initial encounter
        "S63657A",  # Sprain of metacarpophalangeal joint of left little finger, initial encounter
        "S63658A",  # Sprain of metacarpophalangeal joint of other finger, initial encounter
        "S63659A",  # Sprain of metacarpophalangeal joint of unspecified finger, initial encounter
        "S63681A",  # Other sprain of right thumb, initial encounter
        "S63682A",  # Other sprain of left thumb, initial encounter
        "S63689A",  # Other sprain of unspecified thumb, initial encounter
        "S63690A",  # Other sprain of right index finger, initial encounter
        "S63691A",  # Other sprain of left index finger, initial encounter
        "S63692A",  # Other sprain of right middle finger, initial encounter
        "S63693A",  # Other sprain of left middle finger, initial encounter
        "S63694A",  # Other sprain of right ring finger, initial encounter
        "S63695A",  # Other sprain of left ring finger, initial encounter
        "S63696A",  # Other sprain of right little finger, initial encounter
        "S63697A",  # Other sprain of left little finger, initial encounter
        "S63698A",  # Other sprain of other finger, initial encounter
        "S63699A",  # Other sprain of unspecified finger, initial encounter
        "S638X1A",  # Sprain of other part of right wrist and hand, initial encounter
        "S638X2A",  # Sprain of other part of left wrist and hand, initial encounter
        "S638X9A",  # Sprain of other part of unspecified wrist and hand, initial encounter
        "S6390XA",  # Sprain of unspecified part of unspecified wrist and hand, initial encounter
        "S6391XA",  # Sprain of unspecified part of right wrist and hand, initial encounter
        "S6392XA",  # Sprain of unspecified part of left wrist and hand, initial encounter
        "S66011A",  # Strain of long flexor muscle, fascia and tendon of right thumb at wrist and hand level, initial encounter
        "S66012A",  # Strain of long flexor muscle, fascia and tendon of left thumb at wrist and hand level, initial encounter
        "S66019A",  # Strain of long flexor muscle, fascia and tendon of unspecified thumb at wrist and hand level, initial encounter
        "S66110A",  # Strain of flexor muscle, fascia and tendon of right index finger at wrist and hand level, initial encounter
        "S66111A",  # Strain of flexor muscle, fascia and tendon of left index finger at wrist and hand level, initial encounter
        "S66112A",  # Strain of flexor muscle, fascia and tendon of right middle finger at wrist and hand level, initial encounter
        "S66113A",  # Strain of flexor muscle, fascia and tendon of left middle finger at wrist and hand level, initial encounter
        "S66114A",  # Strain of flexor muscle, fascia and tendon of right ring finger at wrist and hand level, initial encounter
        "S66115A",  # Strain of flexor muscle, fascia and tendon of left ring finger at wrist and hand level, initial encounter
        "S66116A",  # Strain of flexor muscle, fascia and tendon of right little finger at wrist and hand level, initial encounter
        "S66117A",  # Strain of flexor muscle, fascia and tendon of left little finger at wrist and hand level, initial encounter
        "S66118A",  # Strain of flexor muscle, fascia and tendon of other finger at wrist and hand level, initial encounter
        "S66119A",  # Strain of flexor muscle, fascia and tendon of unspecified finger at wrist and hand level, initial encounter
        "S66211A",  # Strain of extensor muscle, fascia and tendon of right thumb at wrist and hand level, initial encounter
        "S66212A",  # Strain of extensor muscle, fascia and tendon of left thumb at wrist and hand level, initial encounter
        "S66219A",  # Strain of extensor muscle, fascia and tendon of unspecified thumb at wrist and hand level, initial encounter
        "S66310A",  # Strain of extensor muscle, fascia and tendon of right index finger at wrist and hand level, initial encounter
        "S66311A",  # Strain of extensor muscle, fascia and tendon of left index finger at wrist and hand level, initial encounter
        "S66312A",  # Strain of extensor muscle, fascia and tendon of right middle finger at wrist and hand level, initial encounter
        "S66313A",  # Strain of extensor muscle, fascia and tendon of left middle finger at wrist and hand level, initial encounter
        "S66314A",  # Strain of extensor muscle, fascia and tendon of right ring finger at wrist and hand level, initial encounter
        "S66315A",  # Strain of extensor muscle, fascia and tendon of left ring finger at wrist and hand level, initial encounter
        "S66316A",  # Strain of extensor muscle, fascia and tendon of right little finger at wrist and hand level, initial encounter
        "S66317A",  # Strain of extensor muscle, fascia and tendon of left little finger at wrist and hand level, initial encounter
        "S66318A",  # Strain of extensor muscle, fascia and tendon of other finger at wrist and hand level, initial encounter
        "S66319A",  # Strain of extensor muscle, fascia and tendon of unspecified finger at wrist and hand level, initial encounter
        "S66411A",  # Strain of intrinsic muscle, fascia and tendon of right thumb at wrist and hand level, initial encounter
        "S66412A",  # Strain of intrinsic muscle, fascia and tendon of left thumb at wrist and hand level, initial encounter
        "S66419A",  # Strain of intrinsic muscle, fascia and tendon of unspecified thumb at wrist and hand level, initial encounter
        "S66510A",  # Strain of intrinsic muscle, fascia and tendon of right index finger at wrist and hand level, initial encounter
        "S66511A",  # Strain of intrinsic muscle, fascia and tendon of left index finger at wrist and hand level, initial encounter
        "S66512A",  # Strain of intrinsic muscle, fascia and tendon of right middle finger at wrist and hand level, initial encounter
        "S66513A",  # Strain of intrinsic muscle, fascia and tendon of left middle finger at wrist and hand level, initial encounter
        "S66514A",  # Strain of intrinsic muscle, fascia and tendon of right ring finger at wrist and hand level, initial encounter
        "S66515A",  # Strain of intrinsic muscle, fascia and tendon of left ring finger at wrist and hand level, initial encounter
        "S66516A",  # Strain of intrinsic muscle, fascia and tendon of right little finger at wrist and hand level, initial encounter
        "S66517A",  # Strain of intrinsic muscle, fascia and tendon of left little finger at wrist and hand level, initial encounter
        "S66518A",  # Strain of intrinsic muscle, fascia and tendon of other finger at wrist and hand level, initial encounter
        "S66519A",  # Strain of intrinsic muscle, fascia and tendon of unspecified finger at wrist and hand level, initial encounter
        "S66811A",  # Strain of other specified muscles, fascia and tendons at wrist and hand level, right hand, initial encounter
        "S66812A",  # Strain of other specified muscles, fascia and tendons at wrist and hand level, left hand, initial encounter
        "S66819A",  # Strain of other specified muscles, fascia and tendons at wrist and hand level, unspecified hand, initial encounter
        "S66911A",  # Strain of unspecified muscle, fascia and tendon at wrist and hand level, right hand, initial encounter
        "S66912A",  # Strain of unspecified muscle, fascia and tendon at wrist and hand level, left hand, initial encounter
        "S66919A",  # Strain of unspecified muscle, fascia and tendon at wrist and hand level, unspecified hand, initial encounter
        "S71001A",  # Unspecified open wound, right hip, initial encounter
        "S71002A",  # Unspecified open wound, left hip, initial encounter
        "S71009A",  # Unspecified open wound, unspecified hip, initial encounter
        "S71011A",  # Laceration without foreign body, right hip, initial encounter
        "S71012A",  # Laceration without foreign body, left hip, initial encounter
        "S71019A",  # Laceration without foreign body, unspecified hip, initial encounter
        "S71021A",  # Laceration with foreign body, right hip, initial encounter
        "S71022A",  # Laceration with foreign body, left hip, initial encounter
        "S71029A",  # Laceration with foreign body, unspecified hip, initial encounter
        "S71101A",  # Unspecified open wound, right thigh, initial encounter
        "S71102A",  # Unspecified open wound, left thigh, initial encounter
        "S71109A",  # Unspecified open wound, unspecified thigh, initial encounter
        "S71111A",  # Laceration without foreign body, right thigh, initial encounter
        "S71112A",  # Laceration without foreign body, left thigh, initial encounter
        "S71119A",  # Laceration without foreign body, unspecified thigh, initial encounter
        "S71121A",  # Laceration with foreign body, right thigh, initial encounter
        "S71122A",  # Laceration with foreign body, left thigh, initial encounter
        "S71129A",  # Laceration with foreign body, unspecified thigh, initial encounter
        "S73004A",  # Unspecified dislocation of right hip, initial encounter
        "S73005A",  # Unspecified dislocation of left hip, initial encounter
        "S73006A",  # Unspecified dislocation of unspecified hip, initial encounter
        "S73014A",  # Posterior dislocation of right hip, initial encounter
        "S73015A",  # Posterior dislocation of left hip, initial encounter
        "S73016A",  # Posterior dislocation of unspecified hip, initial encounter
        "S73024A",  # Obturator dislocation of right hip, initial encounter
        "S73025A",  # Obturator dislocation of left hip, initial encounter
        "S73026A",  # Obturator dislocation of unspecified hip, initial encounter
        "S73034A",  # Other anterior dislocation of right hip, initial encounter
        "S73035A",  # Other anterior dislocation of left hip, initial encounter
        "S73036A",  # Other anterior dislocation of unspecified hip, initial encounter
        "S73044A",  # Central dislocation of right hip, initial encounter
        "S73045A",  # Central dislocation of left hip, initial encounter
        "S73046A",  # Central dislocation of unspecified hip, initial encounter
        "S73101A",  # Unspecified sprain of right hip, initial encounter
        "S73102A",  # Unspecified sprain of left hip, initial encounter
        "S73109A",  # Unspecified sprain of unspecified hip, initial encounter
        "S73111A",  # Iliofemoral ligament sprain of right hip, initial encounter
        "S73112A",  # Iliofemoral ligament sprain of left hip, initial encounter
        "S73119A",  # Iliofemoral ligament sprain of unspecified hip, initial encounter
        "S73121A",  # Ischiocapsular ligament sprain of right hip, initial encounter
        "S73122A",  # Ischiocapsular ligament sprain of left hip, initial encounter
        "S73129A",  # Ischiocapsular ligament sprain of unspecified hip, initial encounter
        "S73191A",  # Other sprain of right hip, initial encounter
        "S73192A",  # Other sprain of left hip, initial encounter
        "S73199A",  # Other sprain of unspecified hip, initial encounter
        "S76011A",  # Strain of muscle, fascia and tendon of right hip, initial encounter
        "S76012A",  # Strain of muscle, fascia and tendon of left hip, initial encounter
        "S76019A",  # Strain of muscle, fascia and tendon of unspecified hip, initial encounter
        "S76111A",  # Strain of right quadriceps muscle, fascia and tendon, initial encounter
        "S76112A",  # Strain of left quadriceps muscle, fascia and tendon, initial encounter
        "S76119A",  # Strain of unspecified quadriceps muscle, fascia and tendon, initial encounter
        "S76211A",  # Strain of adductor muscle, fascia and tendon of right thigh, initial encounter
        "S76212A",  # Strain of adductor muscle, fascia and tendon of left thigh, initial encounter
        "S76219A",  # Strain of adductor muscle, fascia and tendon of unspecified thigh, initial encounter
        "S76311A",  # Strain of muscle, fascia and tendon of the posterior muscle group at thigh level, right thigh, initial encounter
        "S76312A",  # Strain of muscle, fascia and tendon of the posterior muscle group at thigh level, left thigh, initial encounter
        "S76319A",  # Strain of muscle, fascia and tendon of the posterior muscle group at thigh level, unspecified thigh, initial encounter
        "S76811A",  # Strain of other specified muscles, fascia and tendons at thigh level, right thigh, initial encounter
        "S76812A",  # Strain of other specified muscles, fascia and tendons at thigh level, left thigh, initial encounter
        "S76819A",  # Strain of other specified muscles, fascia and tendons at thigh level, unspecified thigh, initial encounter
        "S76911A",  # Strain of unspecified muscles, fascia and tendons at thigh level, right thigh, initial encounter
        "S76912A",  # Strain of unspecified muscles, fascia and tendons at thigh level, left thigh, initial encounter
        "S76919A",  # Strain of unspecified muscles, fascia and tendons at thigh level, unspecified thigh, initial encounter
        "S81001A",  # Unspecified open wound, right knee, initial encounter
        "S81002A",  # Unspecified open wound, left knee, initial encounter
        "S81009A",  # Unspecified open wound, unspecified knee, initial encounter
        "S81011A",  # Laceration without foreign body, right knee, initial encounter
        "S81012A",  # Laceration without foreign body, left knee, initial encounter
        "S81019A",  # Laceration without foreign body, unspecified knee, initial encounter
        "S81021A",  # Laceration with foreign body, right knee, initial encounter
        "S81022A",  # Laceration with foreign body, left knee, initial encounter
        "S81029A",  # Laceration with foreign body, unspecified knee, initial encounter
        "S81801A",  # Unspecified open wound, right lower leg, initial encounter
        "S81802A",  # Unspecified open wound, left lower leg, initial encounter
        "S81809A",  # Unspecified open wound, unspecified lower leg, initial encounter
        "S81811A",  # Laceration without foreign body, right lower leg, initial encounter
        "S81812A",  # Laceration without foreign body, left lower leg, initial encounter
        "S81819A",  # Laceration without foreign body, unspecified lower leg, initial encounter
        "S81821A",  # Laceration with foreign body, right lower leg, initial encounter
        "S81822A",  # Laceration with foreign body, left lower leg, initial encounter
        "S81829A",  # Laceration with foreign body, unspecified lower leg, initial encounter
        "S83004A",  # Unspecified dislocation of right patella, initial encounter
        "S83005A",  # Unspecified dislocation of left patella, initial encounter
        "S83006A",  # Unspecified dislocation of unspecified patella, initial encounter
        "S83014A",  # Lateral dislocation of right patella, initial encounter
        "S83015A",  # Lateral dislocation of left patella, initial encounter
        "S83016A",  # Lateral dislocation of unspecified patella, initial encounter
        "S83094A",  # Other dislocation of right patella, initial encounter
        "S83095A",  # Other dislocation of left patella, initial encounter
        "S83096A",  # Other dislocation of unspecified patella, initial encounter
        "S83104A",  # Unspecified dislocation of right knee, initial encounter
        "S83105A",  # Unspecified dislocation of left knee, initial encounter
        "S83106A",  # Unspecified dislocation of unspecified knee, initial encounter
        "S83114A",  # Anterior dislocation of proximal end of tibia, right knee, initial encounter
        "S83115A",  # Anterior dislocation of proximal end of tibia, left knee, initial encounter
        "S83116A",  # Anterior dislocation of proximal end of tibia, unspecified knee, initial encounter
        "S83124A",  # Posterior dislocation of proximal end of tibia, right knee, initial encounter
        "S83125A",  # Posterior dislocation of proximal end of tibia, left knee, initial encounter
        "S83126A",  # Posterior dislocation of proximal end of tibia, unspecified knee, initial encounter
        "S83134A",  # Medial dislocation of proximal end of tibia, right knee, initial encounter
        "S83135A",  # Medial dislocation of proximal end of tibia, left knee, initial encounter
        "S83136A",  # Medial dislocation of proximal end of tibia, unspecified knee, initial encounter
        "S83144A",  # Lateral dislocation of proximal end of tibia, right knee, initial encounter
        "S83145A",  # Lateral dislocation of proximal end of tibia, left knee, initial encounter
        "S83146A",  # Lateral dislocation of proximal end of tibia, unspecified knee, initial encounter
        "S83194A",  # Other dislocation of right knee, initial encounter
        "S83195A",  # Other dislocation of left knee, initial encounter
        "S83196A",  # Other dislocation of unspecified knee, initial encounter
        "S83401A",  # Sprain of unspecified collateral ligament of right knee, initial encounter
        "S83402A",  # Sprain of unspecified collateral ligament of left knee, initial encounter
        "S83409A",  # Sprain of unspecified collateral ligament of unspecified knee, initial encounter
        "S83411A",  # Sprain of medial collateral ligament of right knee, initial encounter
        "S83412A",  # Sprain of medial collateral ligament of left knee, initial encounter
        "S83419A",  # Sprain of medial collateral ligament of unspecified knee, initial encounter
        "S83421A",  # Sprain of lateral collateral ligament of right knee, initial encounter
        "S83422A",  # Sprain of lateral collateral ligament of left knee, initial encounter
        "S83429A",  # Sprain of lateral collateral ligament of unspecified knee, initial encounter
        "S83501A",  # Sprain of unspecified cruciate ligament of right knee, initial encounter
        "S83502A",  # Sprain of unspecified cruciate ligament of left knee, initial encounter
        "S83509A",  # Sprain of unspecified cruciate ligament of unspecified knee, initial encounter
        "S83511A",  # Sprain of anterior cruciate ligament of right knee, initial encounter
        "S83512A",  # Sprain of anterior cruciate ligament of left knee, initial encounter
        "S83519A",  # Sprain of anterior cruciate ligament of unspecified knee, initial encounter
        "S83521A",  # Sprain of posterior cruciate ligament of right knee, initial encounter
        "S83522A",  # Sprain of posterior cruciate ligament of left knee, initial encounter
        "S83529A",  # Sprain of posterior cruciate ligament of unspecified knee, initial encounter
        "S8360XA",  # Sprain of the superior tibiofibular joint and ligament, unspecified knee, initial encounter
        "S8361XA",  # Sprain of the superior tibiofibular joint and ligament, right knee, initial encounter
        "S8362XA",  # Sprain of the superior tibiofibular joint and ligament, left knee, initial encounter
        "S838X1A",  # Sprain of other specified parts of right knee, initial encounter
        "S838X2A",  # Sprain of other specified parts of left knee, initial encounter
        "S838X9A",  # Sprain of other specified parts of unspecified knee, initial encounter
        "S8390XA",  # Sprain of unspecified site of unspecified knee, initial encounter
        "S8391XA",  # Sprain of unspecified site of right knee, initial encounter
        "S8392XA",  # Sprain of unspecified site of left knee, initial encounter
        "S86011A",  # Strain of right Achilles tendon, initial encounter
        "S86012A",  # Strain of left Achilles tendon, initial encounter
        "S86019A",  # Strain of unspecified Achilles tendon, initial encounter
        "S86111A",  # Strain of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, right leg, initial encounter
        "S86112A",  # Strain of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, left leg, initial encounter
        "S86119A",  # Strain of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, unspecified leg, initial encounter
        "S86211A",  # Strain of muscle(s) and tendon(s) of anterior muscle group at lower leg level, right leg, initial encounter
        "S86212A",  # Strain of muscle(s) and tendon(s) of anterior muscle group at lower leg level, left leg, initial encounter
        "S86219A",  # Strain of muscle(s) and tendon(s) of anterior muscle group at lower leg level, unspecified leg, initial encounter
        "S86311A",  # Strain of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, right leg, initial encounter
        "S86312A",  # Strain of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, left leg, initial encounter
        "S86319A",  # Strain of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, unspecified leg, initial encounter
        "S86811A",  # Strain of other muscle(s) and tendon(s) at lower leg level, right leg, initial encounter
        "S86812A",  # Strain of other muscle(s) and tendon(s) at lower leg level, left leg, initial encounter
        "S86819A",  # Strain of other muscle(s) and tendon(s) at lower leg level, unspecified leg, initial encounter
        "S86911A",  # Strain of unspecified muscle(s) and tendon(s) at lower leg level, right leg, initial encounter
        "S86912A",  # Strain of unspecified muscle(s) and tendon(s) at lower leg level, left leg, initial encounter
        "S86919A",  # Strain of unspecified muscle(s) and tendon(s) at lower leg level, unspecified leg, initial encounter
        "S91001A",  # Unspecified open wound, right ankle, initial encounter
        "S91002A",  # Unspecified open wound, left ankle, initial encounter
        "S91009A",  # Unspecified open wound, unspecified ankle, initial encounter
        "S91011A",  # Laceration without foreign body, right ankle, initial encounter
        "S91012A",  # Laceration without foreign body, left ankle, initial encounter
        "S91019A",  # Laceration without foreign body, unspecified ankle, initial encounter
        "S91021A",  # Laceration with foreign body, right ankle, initial encounter
        "S91022A",  # Laceration with foreign body, left ankle, initial encounter
        "S91029A",  # Laceration with foreign body, unspecified ankle, initial encounter
        "S91301A",  # Unspecified open wound, right foot, initial encounter
        "S91302A",  # Unspecified open wound, left foot, initial encounter
        "S91309A",  # Unspecified open wound, unspecified foot, initial encounter
        "S91311A",  # Laceration without foreign body, right foot, initial encounter
        "S91312A",  # Laceration without foreign body, left foot, initial encounter
        "S91319A",  # Laceration without foreign body, unspecified foot, initial encounter
        "S91321A",  # Laceration with foreign body, right foot, initial encounter
        "S91322A",  # Laceration with foreign body, left foot, initial encounter
        "S91329A",  # Laceration with foreign body, unspecified foot, initial encounter
        "S9304XA",  # Dislocation of right ankle joint, initial encounter
        "S9305XA",  # Dislocation of left ankle joint, initial encounter
        "S9306XA",  # Dislocation of unspecified ankle joint, initial encounter
        "S93304A",  # Unspecified dislocation of right foot, initial encounter
        "S93305A",  # Unspecified dislocation of left foot, initial encounter
        "S93306A",  # Unspecified dislocation of unspecified foot, initial encounter
        "S93314A",  # Dislocation of tarsal joint of right foot, initial encounter
        "S93315A",  # Dislocation of tarsal joint of left foot, initial encounter
        "S93316A",  # Dislocation of tarsal joint of unspecified foot, initial encounter
        "S93324A",  # Dislocation of tarsometatarsal joint of right foot, initial encounter
        "S93325A",  # Dislocation of tarsometatarsal joint of left foot, initial encounter
        "S93326A",  # Dislocation of tarsometatarsal joint of unspecified foot, initial encounter
        "S93334A",  # Other dislocation of right foot, initial encounter
        "S93335A",  # Other dislocation of left foot, initial encounter
        "S93336A",  # Other dislocation of unspecified foot, initial encounter
        "S93401A",  # Sprain of unspecified ligament of right ankle, initial encounter
        "S93402A",  # Sprain of unspecified ligament of left ankle, initial encounter
        "S93409A",  # Sprain of unspecified ligament of unspecified ankle, initial encounter
        "S93411A",  # Sprain of calcaneofibular ligament of right ankle, initial encounter
        "S93412A",  # Sprain of calcaneofibular ligament of left ankle, initial encounter
        "S93419A",  # Sprain of calcaneofibular ligament of unspecified ankle, initial encounter
        "S93421A",  # Sprain of deltoid ligament of right ankle, initial encounter
        "S93422A",  # Sprain of deltoid ligament of left ankle, initial encounter
        "S93429A",  # Sprain of deltoid ligament of unspecified ankle, initial encounter
        "S93431A",  # Sprain of tibiofibular ligament of right ankle, initial encounter
        "S93432A",  # Sprain of tibiofibular ligament of left ankle, initial encounter
        "S93439A",  # Sprain of tibiofibular ligament of unspecified ankle, initial encounter
        "S93491A",  # Sprain of other ligament of right ankle, initial encounter
        "S93492A",  # Sprain of other ligament of left ankle, initial encounter
        "S93499A",  # Sprain of other ligament of unspecified ankle, initial encounter
        "S93601A",  # Unspecified sprain of right foot, initial encounter
        "S93602A",  # Unspecified sprain of left foot, initial encounter
        "S93609A",  # Unspecified sprain of unspecified foot, initial encounter
        "S93611A",  # Sprain of tarsal ligament of right foot, initial encounter
        "S93612A",  # Sprain of tarsal ligament of left foot, initial encounter
        "S93619A",  # Sprain of tarsal ligament of unspecified foot, initial encounter
        "S93621A",  # Sprain of tarsometatarsal ligament of right foot, initial encounter
        "S93622A",  # Sprain of tarsometatarsal ligament of left foot, initial encounter
        "S93629A",  # Sprain of tarsometatarsal ligament of unspecified foot, initial encounter
        "S93691A",  # Other sprain of right foot, initial encounter
        "S93692A",  # Other sprain of left foot, initial encounter
        "S93699A",  # Other sprain of unspecified foot, initial encounter
        "S96011A",  # Strain of muscle and tendon of long flexor muscle of toe at ankle and foot level, right foot, initial encounter
        "S96012A",  # Strain of muscle and tendon of long flexor muscle of toe at ankle and foot level, left foot, initial encounter
        "S96019A",  # Strain of muscle and tendon of long flexor muscle of toe at ankle and foot level, unspecified foot, initial encounter
        "S96111A",  # Strain of muscle and tendon of long extensor muscle of toe at ankle and foot level, right foot, initial encounter
        "S96112A",  # Strain of muscle and tendon of long extensor muscle of toe at ankle and foot level, left foot, initial encounter
        "S96119A",  # Strain of muscle and tendon of long extensor muscle of toe at ankle and foot level, unspecified foot, initial encounter
        "S96211A",  # Strain of intrinsic muscle and tendon at ankle and foot level, right foot, initial encounter
        "S96212A",  # Strain of intrinsic muscle and tendon at ankle and foot level, left foot, initial encounter
        "S96219A",  # Strain of intrinsic muscle and tendon at ankle and foot level, unspecified foot, initial encounter
        "S96811A",  # Strain of other specified muscles and tendons at ankle and foot level, right foot, initial encounter
        "S96812A",  # Strain of other specified muscles and tendons at ankle and foot level, left foot, initial encounter
        "S96819A",  # Strain of other specified muscles and tendons at ankle and foot level, unspecified foot, initial encounter
        "S96911A",  # Strain of unspecified muscle and tendon at ankle and foot level, right foot, initial encounter
        "S96912A",  # Strain of unspecified muscle and tendon at ankle and foot level, left foot, initial encounter
        "S96919A",  # Strain of unspecified muscle and tendon at ankle and foot level, unspecified foot, initial encounter
    }

class NeurologicMovementAndRelatedDisorders(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for neurologic movement and related disorders

    **Data Element Scope:** This value set may use a model element related to Diagnosis

    **Inclusion Criteria:** Includes concepts that represent neurologic movement disorders, including Parkinson's, dystonia, and chorea; and related disorders, including multiple sclerosis, demyelinating diseases of the central nervous system, narcolepsy, hydrocephalus, brain disorders and brain death, and encephalopathy

    **Exclusion Criteria:** N/A
    """

    VALUE_SET_NAME = "Neurologic Movement and Related Disorders"
    OID = "2.16.840.1.113762.1.4.1248.174"
    DEFINITION_VERSION = "20221006"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "G08",  # Intracranial and intraspinal phlebitis and thrombophlebitis
        "G1111",  # Friedreich ataxia
        "G112",  # Late-onset cerebellar ataxia
        "G1220",  # Motor neuron disease, unspecified
        "G1221",  # Amyotrophic lateral sclerosis
        "G1222",  # Progressive bulbar palsy
        "G1223",  # Primary lateral sclerosis
        "G1224",  # Familial motor neuron disease
        "G1225",  # Progressive spinal muscle atrophy
        "G1229",  # Other motor neuron disease
        "G128",  # Other spinal muscular atrophies and related syndromes
        "G129",  # Spinal muscular atrophy, unspecified
        "G130",  # Paraneoplastic neuromyopathy and neuropathy
        "G131",  # Other systemic atrophy primarily affecting central nervous system in neoplastic disease
        "G132",  # Systemic atrophy primarily affecting the central nervous system in myxedema
        "G138",  # Systemic atrophy primarily affecting central nervous system in other diseases classified elsewhere
        "G20A1",  # Parkinson's disease without dyskinesia, without mention of fluctuations
        "G20A2",  # Parkinson's disease without dyskinesia, with fluctuations
        "G20B1",  # Parkinson's disease with dyskinesia, without mention of fluctuations
        "G20B2",  # Parkinson's disease with dyskinesia, with fluctuations
        "G20C",  # Parkinsonism, unspecified
        "G210",  # Malignant neuroleptic syndrome
        "G2111",  # Neuroleptic induced parkinsonism
        "G2119",  # Other drug induced secondary parkinsonism
        "G212",  # Secondary parkinsonism due to other external agents
        "G213",  # Postencephalitic parkinsonism
        "G214",  # Vascular parkinsonism
        "G218",  # Other secondary parkinsonism
        "G219",  # Secondary parkinsonism, unspecified
        "G232",  # Striatonigral degeneration
        "G233",  # Hypomyelination with atrophy of the basal ganglia and cerebellum
        "G238",  # Other specified degenerative diseases of basal ganglia
        "G239",  # Degenerative disease of basal ganglia, unspecified
        "G2409",  # Other drug induced dystonia
        "G242",  # Idiopathic nonfamilial dystonia
        "G248",  # Other dystonia
        "G254",  # Drug-induced chorea
        "G255",  # Other chorea
        "G2570",  # Drug induced movement disorder, unspecified
        "G2571",  # Drug induced akathisia
        "G2579",  # Other drug induced movement disorders
        "G2583",  # Benign shuddering attacks
        "G2589",  # Other specified extrapyramidal and movement disorders
        "G259",  # Extrapyramidal and movement disorder, unspecified
        "G26",  # Extrapyramidal and movement disorders in diseases classified elsewhere
        "G320",  # Subacute combined degeneration of spinal cord in diseases classified elsewhere
        "G3281",  # Cerebellar ataxia in diseases classified elsewhere
        "G3289",  # Other specified degenerative disorders of nervous system in diseases classified elsewhere
        "G35",  # Multiple sclerosis
        "G360",  # Neuromyelitis optica [Devic]
        "G368",  # Other specified acute disseminated demyelination
        "G369",  # Acute disseminated demyelination, unspecified
        "G370",  # Diffuse sclerosis of central nervous system
        "G371",  # Central demyelination of corpus callosum
        "G372",  # Central pontine myelinolysis
        "G373",  # Acute transverse myelitis in demyelinating disease of central nervous system
        "G374",  # Subacute necrotizing myelitis of central nervous system
        "G375",  # Concentric sclerosis [Balo] of central nervous system
        "G3781",  # Myelin oligodendrocyte glycoprotein antibody disease
        "G3789",  # Other specified demyelinating diseases of central nervous system
        "G379",  # Demyelinating disease of central nervous system, unspecified
        "G47411",  # Narcolepsy with cataplexy
        "G47419",  # Narcolepsy without cataplexy
        "G47421",  # Narcolepsy in conditions classified elsewhere with cataplexy
        "G47429",  # Narcolepsy in conditions classified elsewhere without cataplexy
        "G890",  # Central pain syndrome
        "G910",  # Communicating hydrocephalus
        "G911",  # Obstructive hydrocephalus
        "G912",  # (Idiopathic) normal pressure hydrocephalus
        "G913",  # Post-traumatic hydrocephalus, unspecified
        "G914",  # Hydrocephalus in diseases classified elsewhere
        "G918",  # Other hydrocephalus
        "G919",  # Hydrocephalus, unspecified
        "G930",  # Cerebral cysts
        "G9340",  # Encephalopathy, unspecified
        "G9341",  # Metabolic encephalopathy
        "G9342",  # Megalencephalic leukoencephalopathy with subcortical cysts
        "G9343",  # Leukoencephalopathy with calcifications and cysts
        "G9344",  # Adult-onset leukodystrophy with axonal spheroids
        "G9349",  # Other encephalopathy
        "G935",  # Compression of brain
        "G936",  # Cerebral edema
        "G9381",  # Temporal sclerosis
        "G9382",  # Brain death
        "G9389",  # Other specified disorders of brain
        "G939",  # Disorder of brain, unspecified
        "G94",  # Other disorders of brain in diseases classified elsewhere
        "O99350",  # Diseases of the nervous system complicating pregnancy, unspecified trimester
        "O99351",  # Diseases of the nervous system complicating pregnancy, first trimester
        "O99352",  # Diseases of the nervous system complicating pregnancy, second trimester
        "O99353",  # Diseases of the nervous system complicating pregnancy, third trimester
        "O99354",  # Diseases of the nervous system complicating childbirth
        "O99355",  # Diseases of the nervous system complicating the puerperium
        "P9160",  # Hypoxic ischemic encephalopathy [HIE], unspecified
        "P9161",  # Mild hypoxic ischemic encephalopathy [HIE]
        "P9162",  # Moderate hypoxic ischemic encephalopathy [HIE]
        "P9163",  # Severe hypoxic ischemic encephalopathy [HIE]
    }

class NotPresentOnAdmissionOrDocumentationInsufficientToDetermine(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for indicating a diagnosis is not present on admission (N) or Documentation insufficient to determine if the condition was present at the time of inpatient admission (U).

    **Data Element Scope:** This value set may use a model element related to Encounter diagnosis.

    **Inclusion Criteria:** Includes PresentOnAdmission concepts that represent diagnosis is not present on admission (N) or Documentation insufficient to determine if the condition was present at the time of inpatient admission (U).

    **Exclusion Criteria:** N/A
    """

    VALUE_SET_NAME = "Not Present On Admission or Documentation Insufficient to Determine"
    OID = "2.16.840.1.113762.1.4.1147.198"
    DEFINITION_VERSION = "20220415"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    PresentOnAdmission = {
        "N",  # Diagnosis was not present at time of inpatient admission
        "U",  # Documentation insufficient to determine if the condition was present at the time of inpatient admission
    }

class Obesity(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for obesity

    **Data Element Scope:** This value set may use a model element related to Diagnosis

    **Inclusion Criteria:** Includes concepts representing obesity

    **Exclusion Criteria:** N/A
    """

    VALUE_SET_NAME = "Obesity"
    OID = "2.16.840.1.113762.1.4.1248.162"
    DEFINITION_VERSION = "20250211"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "E6601",  # Morbid (severe) obesity due to excess calories
        "E6609",  # Other obesity due to excess calories
        "E661",  # Drug-induced obesity
        "E662",  # Morbid (severe) obesity with alveolar hypoventilation
        "E669",  # Obesity, unspecified
        "O99210",  # Obesity complicating pregnancy, unspecified trimester
        "O99211",  # Obesity complicating pregnancy, first trimester
        "O99212",  # Obesity complicating pregnancy, second trimester
        "O99213",  # Obesity complicating pregnancy, third trimester
        "O99214",  # Obesity complicating childbirth
        "O99215",  # Obesity complicating the puerperium
        "Z6830",  # Body mass index [BMI] 30.0-30.9, adult
        "Z6831",  # Body mass index [BMI] 31.0-31.9, adult
        "Z6832",  # Body mass index [BMI] 32.0-32.9, adult
        "Z6833",  # Body mass index [BMI] 33.0-33.9, adult
        "Z6834",  # Body mass index [BMI] 34.0-34.9, adult
        "Z6835",  # Body mass index [BMI] 35.0-35.9, adult
        "Z6836",  # Body mass index [BMI] 36.0-36.9, adult
        "Z6837",  # Body mass index [BMI] 37.0-37.9, adult
        "Z6838",  # Body mass index [BMI] 38.0-38.9, adult
        "Z6839",  # Body mass index [BMI] 39.0-39.9, adult
        "Z6841",  # Body mass index [BMI] 40.0-44.9, adult
        "Z6842",  # Body mass index [BMI] 45.0-49.9, adult
        "Z6843",  # Body mass index [BMI] 50.0-59.9, adult
        "Z6844",  # Body mass index [BMI] 60.0-69.9, adult
        "Z6845",  # Body mass index [BMI] 70 or greater, adult
    }

class Osteoporosis(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for osteoporosis diagnoses

    **Data Element Scope:** This value set may use a model element related to Diagnosis or Condition

    **Inclusion Criteria:** Includes concepts that represent osteoporosis diagnoses

    **Exclusion Criteria:** Excludes encounter for screening for osteoporosis and family history of osteoporosis
    """

    VALUE_SET_NAME = "Osteoporosis"
    OID = "2.16.840.1.113762.1.4.1248.256"
    DEFINITION_VERSION = "20250206"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "M8000XA",  # Age-related osteoporosis with current pathological fracture, unspecified site, initial encounter for fracture
        "M8000XD",  # Age-related osteoporosis with current pathological fracture, unspecified site, subsequent encounter for fracture with routine healing
        "M8000XG",  # Age-related osteoporosis with current pathological fracture, unspecified site, subsequent encounter for fracture with delayed healing
        "M8000XK",  # Age-related osteoporosis with current pathological fracture, unspecified site, subsequent encounter for fracture with nonunion
        "M8000XP",  # Age-related osteoporosis with current pathological fracture, unspecified site, subsequent encounter for fracture with malunion
        "M8000XS",  # Age-related osteoporosis with current pathological fracture, unspecified site, sequela
        "M80011A",  # Age-related osteoporosis with current pathological fracture, right shoulder, initial encounter for fracture
        "M80011D",  # Age-related osteoporosis with current pathological fracture, right shoulder, subsequent encounter for fracture with routine healing
        "M80011G",  # Age-related osteoporosis with current pathological fracture, right shoulder, subsequent encounter for fracture with delayed healing
        "M80011K",  # Age-related osteoporosis with current pathological fracture, right shoulder, subsequent encounter for fracture with nonunion
        "M80011P",  # Age-related osteoporosis with current pathological fracture, right shoulder, subsequent encounter for fracture with malunion
        "M80011S",  # Age-related osteoporosis with current pathological fracture, right shoulder, sequela
        "M80012A",  # Age-related osteoporosis with current pathological fracture, left shoulder, initial encounter for fracture
        "M80012D",  # Age-related osteoporosis with current pathological fracture, left shoulder, subsequent encounter for fracture with routine healing
        "M80012G",  # Age-related osteoporosis with current pathological fracture, left shoulder, subsequent encounter for fracture with delayed healing
        "M80012K",  # Age-related osteoporosis with current pathological fracture, left shoulder, subsequent encounter for fracture with nonunion
        "M80012P",  # Age-related osteoporosis with current pathological fracture, left shoulder, subsequent encounter for fracture with malunion
        "M80012S",  # Age-related osteoporosis with current pathological fracture, left shoulder, sequela
        "M80019A",  # Age-related osteoporosis with current pathological fracture, unspecified shoulder, initial encounter for fracture
        "M80019D",  # Age-related osteoporosis with current pathological fracture, unspecified shoulder, subsequent encounter for fracture with routine healing
        "M80019G",  # Age-related osteoporosis with current pathological fracture, unspecified shoulder, subsequent encounter for fracture with delayed healing
        "M80019K",  # Age-related osteoporosis with current pathological fracture, unspecified shoulder, subsequent encounter for fracture with nonunion
        "M80019P",  # Age-related osteoporosis with current pathological fracture, unspecified shoulder, subsequent encounter for fracture with malunion
        "M80019S",  # Age-related osteoporosis with current pathological fracture, unspecified shoulder, sequela
        "M80021A",  # Age-related osteoporosis with current pathological fracture, right humerus, initial encounter for fracture
        "M80021D",  # Age-related osteoporosis with current pathological fracture, right humerus, subsequent encounter for fracture with routine healing
        "M80021G",  # Age-related osteoporosis with current pathological fracture, right humerus, subsequent encounter for fracture with delayed healing
        "M80021K",  # Age-related osteoporosis with current pathological fracture, right humerus, subsequent encounter for fracture with nonunion
        "M80021P",  # Age-related osteoporosis with current pathological fracture, right humerus, subsequent encounter for fracture with malunion
        "M80021S",  # Age-related osteoporosis with current pathological fracture, right humerus, sequela
        "M80022A",  # Age-related osteoporosis with current pathological fracture, left humerus, initial encounter for fracture
        "M80022D",  # Age-related osteoporosis with current pathological fracture, left humerus, subsequent encounter for fracture with routine healing
        "M80022G",  # Age-related osteoporosis with current pathological fracture, left humerus, subsequent encounter for fracture with delayed healing
        "M80022K",  # Age-related osteoporosis with current pathological fracture, left humerus, subsequent encounter for fracture with nonunion
        "M80022P",  # Age-related osteoporosis with current pathological fracture, left humerus, subsequent encounter for fracture with malunion
        "M80022S",  # Age-related osteoporosis with current pathological fracture, left humerus, sequela
        "M80029A",  # Age-related osteoporosis with current pathological fracture, unspecified humerus, initial encounter for fracture
        "M80029D",  # Age-related osteoporosis with current pathological fracture, unspecified humerus, subsequent encounter for fracture with routine healing
        "M80029G",  # Age-related osteoporosis with current pathological fracture, unspecified humerus, subsequent encounter for fracture with delayed healing
        "M80029K",  # Age-related osteoporosis with current pathological fracture, unspecified humerus, subsequent encounter for fracture with nonunion
        "M80029P",  # Age-related osteoporosis with current pathological fracture, unspecified humerus, subsequent encounter for fracture with malunion
        "M80029S",  # Age-related osteoporosis with current pathological fracture, unspecified humerus, sequela
        "M80031A",  # Age-related osteoporosis with current pathological fracture, right forearm, initial encounter for fracture
        "M80031D",  # Age-related osteoporosis with current pathological fracture, right forearm, subsequent encounter for fracture with routine healing
        "M80031G",  # Age-related osteoporosis with current pathological fracture, right forearm, subsequent encounter for fracture with delayed healing
        "M80031K",  # Age-related osteoporosis with current pathological fracture, right forearm, subsequent encounter for fracture with nonunion
        "M80031P",  # Age-related osteoporosis with current pathological fracture, right forearm, subsequent encounter for fracture with malunion
        "M80031S",  # Age-related osteoporosis with current pathological fracture, right forearm, sequela
        "M80032A",  # Age-related osteoporosis with current pathological fracture, left forearm, initial encounter for fracture
        "M80032D",  # Age-related osteoporosis with current pathological fracture, left forearm, subsequent encounter for fracture with routine healing
        "M80032G",  # Age-related osteoporosis with current pathological fracture, left forearm, subsequent encounter for fracture with delayed healing
        "M80032K",  # Age-related osteoporosis with current pathological fracture, left forearm, subsequent encounter for fracture with nonunion
        "M80032P",  # Age-related osteoporosis with current pathological fracture, left forearm, subsequent encounter for fracture with malunion
        "M80032S",  # Age-related osteoporosis with current pathological fracture, left forearm, sequela
        "M80039A",  # Age-related osteoporosis with current pathological fracture, unspecified forearm, initial encounter for fracture
        "M80039D",  # Age-related osteoporosis with current pathological fracture, unspecified forearm, subsequent encounter for fracture with routine healing
        "M80039G",  # Age-related osteoporosis with current pathological fracture, unspecified forearm, subsequent encounter for fracture with delayed healing
        "M80039K",  # Age-related osteoporosis with current pathological fracture, unspecified forearm, subsequent encounter for fracture with nonunion
        "M80039P",  # Age-related osteoporosis with current pathological fracture, unspecified forearm, subsequent encounter for fracture with malunion
        "M80039S",  # Age-related osteoporosis with current pathological fracture, unspecified forearm, sequela
        "M80041A",  # Age-related osteoporosis with current pathological fracture, right hand, initial encounter for fracture
        "M80041D",  # Age-related osteoporosis with current pathological fracture, right hand, subsequent encounter for fracture with routine healing
        "M80041G",  # Age-related osteoporosis with current pathological fracture, right hand, subsequent encounter for fracture with delayed healing
        "M80041K",  # Age-related osteoporosis with current pathological fracture, right hand, subsequent encounter for fracture with nonunion
        "M80041P",  # Age-related osteoporosis with current pathological fracture, right hand, subsequent encounter for fracture with malunion
        "M80041S",  # Age-related osteoporosis with current pathological fracture, right hand, sequela
        "M80042A",  # Age-related osteoporosis with current pathological fracture, left hand, initial encounter for fracture
        "M80042D",  # Age-related osteoporosis with current pathological fracture, left hand, subsequent encounter for fracture with routine healing
        "M80042G",  # Age-related osteoporosis with current pathological fracture, left hand, subsequent encounter for fracture with delayed healing
        "M80042K",  # Age-related osteoporosis with current pathological fracture, left hand, subsequent encounter for fracture with nonunion
        "M80042P",  # Age-related osteoporosis with current pathological fracture, left hand, subsequent encounter for fracture with malunion
        "M80042S",  # Age-related osteoporosis with current pathological fracture, left hand, sequela
        "M80049A",  # Age-related osteoporosis with current pathological fracture, unspecified hand, initial encounter for fracture
        "M80049D",  # Age-related osteoporosis with current pathological fracture, unspecified hand, subsequent encounter for fracture with routine healing
        "M80049G",  # Age-related osteoporosis with current pathological fracture, unspecified hand, subsequent encounter for fracture with delayed healing
        "M80049K",  # Age-related osteoporosis with current pathological fracture, unspecified hand, subsequent encounter for fracture with nonunion
        "M80049P",  # Age-related osteoporosis with current pathological fracture, unspecified hand, subsequent encounter for fracture with malunion
        "M80049S",  # Age-related osteoporosis with current pathological fracture, unspecified hand, sequela
        "M80051A",  # Age-related osteoporosis with current pathological fracture, right femur, initial encounter for fracture
        "M80051D",  # Age-related osteoporosis with current pathological fracture, right femur, subsequent encounter for fracture with routine healing
        "M80051G",  # Age-related osteoporosis with current pathological fracture, right femur, subsequent encounter for fracture with delayed healing
        "M80051K",  # Age-related osteoporosis with current pathological fracture, right femur, subsequent encounter for fracture with nonunion
        "M80051P",  # Age-related osteoporosis with current pathological fracture, right femur, subsequent encounter for fracture with malunion
        "M80051S",  # Age-related osteoporosis with current pathological fracture, right femur, sequela
        "M80052A",  # Age-related osteoporosis with current pathological fracture, left femur, initial encounter for fracture
        "M80052D",  # Age-related osteoporosis with current pathological fracture, left femur, subsequent encounter for fracture with routine healing
        "M80052G",  # Age-related osteoporosis with current pathological fracture, left femur, subsequent encounter for fracture with delayed healing
        "M80052K",  # Age-related osteoporosis with current pathological fracture, left femur, subsequent encounter for fracture with nonunion
        "M80052P",  # Age-related osteoporosis with current pathological fracture, left femur, subsequent encounter for fracture with malunion
        "M80052S",  # Age-related osteoporosis with current pathological fracture, left femur, sequela
        "M80059A",  # Age-related osteoporosis with current pathological fracture, unspecified femur, initial encounter for fracture
        "M80059D",  # Age-related osteoporosis with current pathological fracture, unspecified femur, subsequent encounter for fracture with routine healing
        "M80059G",  # Age-related osteoporosis with current pathological fracture, unspecified femur, subsequent encounter for fracture with delayed healing
        "M80059K",  # Age-related osteoporosis with current pathological fracture, unspecified femur, subsequent encounter for fracture with nonunion
        "M80059P",  # Age-related osteoporosis with current pathological fracture, unspecified femur, subsequent encounter for fracture with malunion
        "M80059S",  # Age-related osteoporosis with current pathological fracture, unspecified femur, sequela
        "M80061A",  # Age-related osteoporosis with current pathological fracture, right lower leg, initial encounter for fracture
        "M80061D",  # Age-related osteoporosis with current pathological fracture, right lower leg, subsequent encounter for fracture with routine healing
        "M80061G",  # Age-related osteoporosis with current pathological fracture, right lower leg, subsequent encounter for fracture with delayed healing
        "M80061K",  # Age-related osteoporosis with current pathological fracture, right lower leg, subsequent encounter for fracture with nonunion
        "M80061P",  # Age-related osteoporosis with current pathological fracture, right lower leg, subsequent encounter for fracture with malunion
        "M80061S",  # Age-related osteoporosis with current pathological fracture, right lower leg, sequela
        "M80062A",  # Age-related osteoporosis with current pathological fracture, left lower leg, initial encounter for fracture
        "M80062D",  # Age-related osteoporosis with current pathological fracture, left lower leg, subsequent encounter for fracture with routine healing
        "M80062G",  # Age-related osteoporosis with current pathological fracture, left lower leg, subsequent encounter for fracture with delayed healing
        "M80062K",  # Age-related osteoporosis with current pathological fracture, left lower leg, subsequent encounter for fracture with nonunion
        "M80062P",  # Age-related osteoporosis with current pathological fracture, left lower leg, subsequent encounter for fracture with malunion
        "M80062S",  # Age-related osteoporosis with current pathological fracture, left lower leg, sequela
        "M80069A",  # Age-related osteoporosis with current pathological fracture, unspecified lower leg, initial encounter for fracture
        "M80069D",  # Age-related osteoporosis with current pathological fracture, unspecified lower leg, subsequent encounter for fracture with routine healing
        "M80069G",  # Age-related osteoporosis with current pathological fracture, unspecified lower leg, subsequent encounter for fracture with delayed healing
        "M80069K",  # Age-related osteoporosis with current pathological fracture, unspecified lower leg, subsequent encounter for fracture with nonunion
        "M80069P",  # Age-related osteoporosis with current pathological fracture, unspecified lower leg, subsequent encounter for fracture with malunion
        "M80069S",  # Age-related osteoporosis with current pathological fracture, unspecified lower leg, sequela
        "M80071A",  # Age-related osteoporosis with current pathological fracture, right ankle and foot, initial encounter for fracture
        "M80071D",  # Age-related osteoporosis with current pathological fracture, right ankle and foot, subsequent encounter for fracture with routine healing
        "M80071G",  # Age-related osteoporosis with current pathological fracture, right ankle and foot, subsequent encounter for fracture with delayed healing
        "M80071K",  # Age-related osteoporosis with current pathological fracture, right ankle and foot, subsequent encounter for fracture with nonunion
        "M80071P",  # Age-related osteoporosis with current pathological fracture, right ankle and foot, subsequent encounter for fracture with malunion
        "M80071S",  # Age-related osteoporosis with current pathological fracture, right ankle and foot, sequela
        "M80072A",  # Age-related osteoporosis with current pathological fracture, left ankle and foot, initial encounter for fracture
        "M80072D",  # Age-related osteoporosis with current pathological fracture, left ankle and foot, subsequent encounter for fracture with routine healing
        "M80072G",  # Age-related osteoporosis with current pathological fracture, left ankle and foot, subsequent encounter for fracture with delayed healing
        "M80072K",  # Age-related osteoporosis with current pathological fracture, left ankle and foot, subsequent encounter for fracture with nonunion
        "M80072P",  # Age-related osteoporosis with current pathological fracture, left ankle and foot, subsequent encounter for fracture with malunion
        "M80072S",  # Age-related osteoporosis with current pathological fracture, left ankle and foot, sequela
        "M80079A",  # Age-related osteoporosis with current pathological fracture, unspecified ankle and foot, initial encounter for fracture
        "M80079D",  # Age-related osteoporosis with current pathological fracture, unspecified ankle and foot, subsequent encounter for fracture with routine healing
        "M80079G",  # Age-related osteoporosis with current pathological fracture, unspecified ankle and foot, subsequent encounter for fracture with delayed healing
        "M80079K",  # Age-related osteoporosis with current pathological fracture, unspecified ankle and foot, subsequent encounter for fracture with nonunion
        "M80079P",  # Age-related osteoporosis with current pathological fracture, unspecified ankle and foot, subsequent encounter for fracture with malunion
        "M80079S",  # Age-related osteoporosis with current pathological fracture, unspecified ankle and foot, sequela
        "M8008XA",  # Age-related osteoporosis with current pathological fracture, vertebra(e), initial encounter for fracture
        "M8008XD",  # Age-related osteoporosis with current pathological fracture, vertebra(e), subsequent encounter for fracture with routine healing
        "M8008XG",  # Age-related osteoporosis with current pathological fracture, vertebra(e), subsequent encounter for fracture with delayed healing
        "M8008XK",  # Age-related osteoporosis with current pathological fracture, vertebra(e), subsequent encounter for fracture with nonunion
        "M8008XP",  # Age-related osteoporosis with current pathological fracture, vertebra(e), subsequent encounter for fracture with malunion
        "M8008XS",  # Age-related osteoporosis with current pathological fracture, vertebra(e), sequela
        "M800AXA",  # Age-related osteoporosis with current pathological fracture, other site, initial encounter for fracture
        "M800AXD",  # Age-related osteoporosis with current pathological fracture, other site, subsequent encounter for fracture with routine healing
        "M800AXG",  # Age-related osteoporosis with current pathological fracture, other site, subsequent encounter for fracture with delayed healing
        "M800AXK",  # Age-related osteoporosis with current pathological fracture, other site, subsequent encounter for fracture with nonunion
        "M800AXP",  # Age-related osteoporosis with current pathological fracture, other site, subsequent encounter for fracture with malunion
        "M800AXS",  # Age-related osteoporosis with current pathological fracture, other site, sequela
        "M800B1A",  # Age-related osteoporosis with current pathological fracture, right pelvis, initial encounter for fracture
        "M800B1D",  # Age-related osteoporosis with current pathological fracture, right pelvis, subsequent encounter for fracture with routine healing
        "M800B1G",  # Age-related osteoporosis with current pathological fracture, right pelvis, subsequent encounter for fracture with delayed healing
        "M800B1K",  # Age-related osteoporosis with current pathological fracture, right pelvis, subsequent encounter for fracture with nonunion
        "M800B1P",  # Age-related osteoporosis with current pathological fracture, right pelvis, subsequent encounter for fracture with malunion
        "M800B1S",  # Age-related osteoporosis with current pathological fracture, right pelvis, sequela
        "M800B2A",  # Age-related osteoporosis with current pathological fracture, left pelvis, initial encounter for fracture
        "M800B2D",  # Age-related osteoporosis with current pathological fracture, left pelvis, subsequent encounter for fracture with routine healing
        "M800B2G",  # Age-related osteoporosis with current pathological fracture, left pelvis, subsequent encounter for fracture with delayed healing
        "M800B2K",  # Age-related osteoporosis with current pathological fracture, left pelvis, subsequent encounter for fracture with nonunion
        "M800B2P",  # Age-related osteoporosis with current pathological fracture, left pelvis, subsequent encounter for fracture with malunion
        "M800B2S",  # Age-related osteoporosis with current pathological fracture, left pelvis, sequela
        "M800B9A",  # Age-related osteoporosis with current pathological fracture, unspecified pelvis, initial encounter for fracture
        "M800B9D",  # Age-related osteoporosis with current pathological fracture, unspecified pelvis, subsequent encounter for fracture with routine healing
        "M800B9G",  # Age-related osteoporosis with current pathological fracture, unspecified pelvis, subsequent encounter for fracture with delayed healing
        "M800B9K",  # Age-related osteoporosis with current pathological fracture, unspecified pelvis, subsequent encounter for fracture with nonunion
        "M800B9P",  # Age-related osteoporosis with current pathological fracture, unspecified pelvis, subsequent encounter for fracture with malunion
        "M800B9S",  # Age-related osteoporosis with current pathological fracture, unspecified pelvis, sequela
        "M8080XA",  # Other osteoporosis with current pathological fracture, unspecified site, initial encounter for fracture
        "M8080XD",  # Other osteoporosis with current pathological fracture, unspecified site, subsequent encounter for fracture with routine healing
        "M8080XG",  # Other osteoporosis with current pathological fracture, unspecified site, subsequent encounter for fracture with delayed healing
        "M8080XK",  # Other osteoporosis with current pathological fracture, unspecified site, subsequent encounter for fracture with nonunion
        "M8080XP",  # Other osteoporosis with current pathological fracture, unspecified site, subsequent encounter for fracture with malunion
        "M8080XS",  # Other osteoporosis with current pathological fracture, unspecified site, sequela
        "M80811A",  # Other osteoporosis with current pathological fracture, right shoulder, initial encounter for fracture
        "M80811D",  # Other osteoporosis with current pathological fracture, right shoulder, subsequent encounter for fracture with routine healing
        "M80811G",  # Other osteoporosis with current pathological fracture, right shoulder, subsequent encounter for fracture with delayed healing
        "M80811K",  # Other osteoporosis with current pathological fracture, right shoulder, subsequent encounter for fracture with nonunion
        "M80811P",  # Other osteoporosis with current pathological fracture, right shoulder, subsequent encounter for fracture with malunion
        "M80811S",  # Other osteoporosis with current pathological fracture, right shoulder, sequela
        "M80812A",  # Other osteoporosis with current pathological fracture, left shoulder, initial encounter for fracture
        "M80812D",  # Other osteoporosis with current pathological fracture, left shoulder, subsequent encounter for fracture with routine healing
        "M80812G",  # Other osteoporosis with current pathological fracture, left shoulder, subsequent encounter for fracture with delayed healing
        "M80812K",  # Other osteoporosis with current pathological fracture, left shoulder, subsequent encounter for fracture with nonunion
        "M80812P",  # Other osteoporosis with current pathological fracture, left shoulder, subsequent encounter for fracture with malunion
        "M80812S",  # Other osteoporosis with current pathological fracture, left shoulder, sequela
        "M80819A",  # Other osteoporosis with current pathological fracture, unspecified shoulder, initial encounter for fracture
        "M80819D",  # Other osteoporosis with current pathological fracture, unspecified shoulder, subsequent encounter for fracture with routine healing
        "M80819G",  # Other osteoporosis with current pathological fracture, unspecified shoulder, subsequent encounter for fracture with delayed healing
        "M80819K",  # Other osteoporosis with current pathological fracture, unspecified shoulder, subsequent encounter for fracture with nonunion
        "M80819P",  # Other osteoporosis with current pathological fracture, unspecified shoulder, subsequent encounter for fracture with malunion
        "M80819S",  # Other osteoporosis with current pathological fracture, unspecified shoulder, sequela
        "M80821A",  # Other osteoporosis with current pathological fracture, right humerus, initial encounter for fracture
        "M80821D",  # Other osteoporosis with current pathological fracture, right humerus, subsequent encounter for fracture with routine healing
        "M80821G",  # Other osteoporosis with current pathological fracture, right humerus, subsequent encounter for fracture with delayed healing
        "M80821K",  # Other osteoporosis with current pathological fracture, right humerus, subsequent encounter for fracture with nonunion
        "M80821P",  # Other osteoporosis with current pathological fracture, right humerus, subsequent encounter for fracture with malunion
        "M80821S",  # Other osteoporosis with current pathological fracture, right humerus, sequela
        "M80822A",  # Other osteoporosis with current pathological fracture, left humerus, initial encounter for fracture
        "M80822D",  # Other osteoporosis with current pathological fracture, left humerus, subsequent encounter for fracture with routine healing
        "M80822G",  # Other osteoporosis with current pathological fracture, left humerus, subsequent encounter for fracture with delayed healing
        "M80822K",  # Other osteoporosis with current pathological fracture, left humerus, subsequent encounter for fracture with nonunion
        "M80822P",  # Other osteoporosis with current pathological fracture, left humerus, subsequent encounter for fracture with malunion
        "M80822S",  # Other osteoporosis with current pathological fracture, left humerus, sequela
        "M80829A",  # Other osteoporosis with current pathological fracture, unspecified humerus, initial encounter for fracture
        "M80829D",  # Other osteoporosis with current pathological fracture, unspecified humerus, subsequent encounter for fracture with routine healing
        "M80829G",  # Other osteoporosis with current pathological fracture, unspecified humerus, subsequent encounter for fracture with delayed healing
        "M80829K",  # Other osteoporosis with current pathological fracture, unspecified humerus, subsequent encounter for fracture with nonunion
        "M80829P",  # Other osteoporosis with current pathological fracture, unspecified humerus, subsequent encounter for fracture with malunion
        "M80829S",  # Other osteoporosis with current pathological fracture, unspecified humerus, sequela
        "M80831A",  # Other osteoporosis with current pathological fracture, right forearm, initial encounter for fracture
        "M80831D",  # Other osteoporosis with current pathological fracture, right forearm, subsequent encounter for fracture with routine healing
        "M80831G",  # Other osteoporosis with current pathological fracture, right forearm, subsequent encounter for fracture with delayed healing
        "M80831K",  # Other osteoporosis with current pathological fracture, right forearm, subsequent encounter for fracture with nonunion
        "M80831P",  # Other osteoporosis with current pathological fracture, right forearm, subsequent encounter for fracture with malunion
        "M80831S",  # Other osteoporosis with current pathological fracture, right forearm, sequela
        "M80832A",  # Other osteoporosis with current pathological fracture, left forearm, initial encounter for fracture
        "M80832D",  # Other osteoporosis with current pathological fracture, left forearm, subsequent encounter for fracture with routine healing
        "M80832G",  # Other osteoporosis with current pathological fracture, left forearm, subsequent encounter for fracture with delayed healing
        "M80832K",  # Other osteoporosis with current pathological fracture, left forearm, subsequent encounter for fracture with nonunion
        "M80832P",  # Other osteoporosis with current pathological fracture, left forearm, subsequent encounter for fracture with malunion
        "M80832S",  # Other osteoporosis with current pathological fracture, left forearm, sequela
        "M80839A",  # Other osteoporosis with current pathological fracture, unspecified forearm, initial encounter for fracture
        "M80839D",  # Other osteoporosis with current pathological fracture, unspecified forearm, subsequent encounter for fracture with routine healing
        "M80839G",  # Other osteoporosis with current pathological fracture, unspecified forearm, subsequent encounter for fracture with delayed healing
        "M80839K",  # Other osteoporosis with current pathological fracture, unspecified forearm, subsequent encounter for fracture with nonunion
        "M80839P",  # Other osteoporosis with current pathological fracture, unspecified forearm, subsequent encounter for fracture with malunion
        "M80839S",  # Other osteoporosis with current pathological fracture, unspecified forearm, sequela
        "M80841A",  # Other osteoporosis with current pathological fracture, right hand, initial encounter for fracture
        "M80841D",  # Other osteoporosis with current pathological fracture, right hand, subsequent encounter for fracture with routine healing
        "M80841G",  # Other osteoporosis with current pathological fracture, right hand, subsequent encounter for fracture with delayed healing
        "M80841K",  # Other osteoporosis with current pathological fracture, right hand, subsequent encounter for fracture with nonunion
        "M80841P",  # Other osteoporosis with current pathological fracture, right hand, subsequent encounter for fracture with malunion
        "M80841S",  # Other osteoporosis with current pathological fracture, right hand, sequela
        "M80842A",  # Other osteoporosis with current pathological fracture, left hand, initial encounter for fracture
        "M80842D",  # Other osteoporosis with current pathological fracture, left hand, subsequent encounter for fracture with routine healing
        "M80842G",  # Other osteoporosis with current pathological fracture, left hand, subsequent encounter for fracture with delayed healing
        "M80842K",  # Other osteoporosis with current pathological fracture, left hand, subsequent encounter for fracture with nonunion
        "M80842P",  # Other osteoporosis with current pathological fracture, left hand, subsequent encounter for fracture with malunion
        "M80842S",  # Other osteoporosis with current pathological fracture, left hand, sequela
        "M80849A",  # Other osteoporosis with current pathological fracture, unspecified hand, initial encounter for fracture
        "M80849D",  # Other osteoporosis with current pathological fracture, unspecified hand, subsequent encounter for fracture with routine healing
        "M80849G",  # Other osteoporosis with current pathological fracture, unspecified hand, subsequent encounter for fracture with delayed healing
        "M80849K",  # Other osteoporosis with current pathological fracture, unspecified hand, subsequent encounter for fracture with nonunion
        "M80849P",  # Other osteoporosis with current pathological fracture, unspecified hand, subsequent encounter for fracture with malunion
        "M80849S",  # Other osteoporosis with current pathological fracture, unspecified hand, sequela
        "M80851A",  # Other osteoporosis with current pathological fracture, right femur, initial encounter for fracture
        "M80851D",  # Other osteoporosis with current pathological fracture, right femur, subsequent encounter for fracture with routine healing
        "M80851G",  # Other osteoporosis with current pathological fracture, right femur, subsequent encounter for fracture with delayed healing
        "M80851K",  # Other osteoporosis with current pathological fracture, right femur, subsequent encounter for fracture with nonunion
        "M80851P",  # Other osteoporosis with current pathological fracture, right femur, subsequent encounter for fracture with malunion
        "M80851S",  # Other osteoporosis with current pathological fracture, right femur, sequela
        "M80852A",  # Other osteoporosis with current pathological fracture, left femur, initial encounter for fracture
        "M80852D",  # Other osteoporosis with current pathological fracture, left femur, subsequent encounter for fracture with routine healing
        "M80852G",  # Other osteoporosis with current pathological fracture, left femur, subsequent encounter for fracture with delayed healing
        "M80852K",  # Other osteoporosis with current pathological fracture, left femur, subsequent encounter for fracture with nonunion
        "M80852P",  # Other osteoporosis with current pathological fracture, left femur, subsequent encounter for fracture with malunion
        "M80852S",  # Other osteoporosis with current pathological fracture, left femur, sequela
        "M80859A",  # Other osteoporosis with current pathological fracture, unspecified femur, initial encounter for fracture
        "M80859D",  # Other osteoporosis with current pathological fracture, unspecified femur, subsequent encounter for fracture with routine healing
        "M80859G",  # Other osteoporosis with current pathological fracture, unspecified femur, subsequent encounter for fracture with delayed healing
        "M80859K",  # Other osteoporosis with current pathological fracture, unspecified femur, subsequent encounter for fracture with nonunion
        "M80859P",  # Other osteoporosis with current pathological fracture, unspecified femur, subsequent encounter for fracture with malunion
        "M80859S",  # Other osteoporosis with current pathological fracture, unspecified femur, sequela
        "M80861A",  # Other osteoporosis with current pathological fracture, right lower leg, initial encounter for fracture
        "M80861D",  # Other osteoporosis with current pathological fracture, right lower leg, subsequent encounter for fracture with routine healing
        "M80861G",  # Other osteoporosis with current pathological fracture, right lower leg, subsequent encounter for fracture with delayed healing
        "M80861K",  # Other osteoporosis with current pathological fracture, right lower leg, subsequent encounter for fracture with nonunion
        "M80861P",  # Other osteoporosis with current pathological fracture, right lower leg, subsequent encounter for fracture with malunion
        "M80861S",  # Other osteoporosis with current pathological fracture, right lower leg, sequela
        "M80862A",  # Other osteoporosis with current pathological fracture, left lower leg, initial encounter for fracture
        "M80862D",  # Other osteoporosis with current pathological fracture, left lower leg, subsequent encounter for fracture with routine healing
        "M80862G",  # Other osteoporosis with current pathological fracture, left lower leg, subsequent encounter for fracture with delayed healing
        "M80862K",  # Other osteoporosis with current pathological fracture, left lower leg, subsequent encounter for fracture with nonunion
        "M80862P",  # Other osteoporosis with current pathological fracture, left lower leg, subsequent encounter for fracture with malunion
        "M80862S",  # Other osteoporosis with current pathological fracture, left lower leg, sequela
        "M80869A",  # Other osteoporosis with current pathological fracture, unspecified lower leg, initial encounter for fracture
        "M80869D",  # Other osteoporosis with current pathological fracture, unspecified lower leg, subsequent encounter for fracture with routine healing
        "M80869G",  # Other osteoporosis with current pathological fracture, unspecified lower leg, subsequent encounter for fracture with delayed healing
        "M80869K",  # Other osteoporosis with current pathological fracture, unspecified lower leg, subsequent encounter for fracture with nonunion
        "M80869P",  # Other osteoporosis with current pathological fracture, unspecified lower leg, subsequent encounter for fracture with malunion
        "M80869S",  # Other osteoporosis with current pathological fracture, unspecified lower leg, sequela
        "M80871A",  # Other osteoporosis with current pathological fracture, right ankle and foot, initial encounter for fracture
        "M80871D",  # Other osteoporosis with current pathological fracture, right ankle and foot, subsequent encounter for fracture with routine healing
        "M80871G",  # Other osteoporosis with current pathological fracture, right ankle and foot, subsequent encounter for fracture with delayed healing
        "M80871K",  # Other osteoporosis with current pathological fracture, right ankle and foot, subsequent encounter for fracture with nonunion
        "M80871P",  # Other osteoporosis with current pathological fracture, right ankle and foot, subsequent encounter for fracture with malunion
        "M80871S",  # Other osteoporosis with current pathological fracture, right ankle and foot, sequela
        "M80872A",  # Other osteoporosis with current pathological fracture, left ankle and foot, initial encounter for fracture
        "M80872D",  # Other osteoporosis with current pathological fracture, left ankle and foot, subsequent encounter for fracture with routine healing
        "M80872G",  # Other osteoporosis with current pathological fracture, left ankle and foot, subsequent encounter for fracture with delayed healing
        "M80872K",  # Other osteoporosis with current pathological fracture, left ankle and foot, subsequent encounter for fracture with nonunion
        "M80872P",  # Other osteoporosis with current pathological fracture, left ankle and foot, subsequent encounter for fracture with malunion
        "M80872S",  # Other osteoporosis with current pathological fracture, left ankle and foot, sequela
        "M80879A",  # Other osteoporosis with current pathological fracture, unspecified ankle and foot, initial encounter for fracture
        "M80879D",  # Other osteoporosis with current pathological fracture, unspecified ankle and foot, subsequent encounter for fracture with routine healing
        "M80879G",  # Other osteoporosis with current pathological fracture, unspecified ankle and foot, subsequent encounter for fracture with delayed healing
        "M80879K",  # Other osteoporosis with current pathological fracture, unspecified ankle and foot, subsequent encounter for fracture with nonunion
        "M80879P",  # Other osteoporosis with current pathological fracture, unspecified ankle and foot, subsequent encounter for fracture with malunion
        "M80879S",  # Other osteoporosis with current pathological fracture, unspecified ankle and foot, sequela
        "M8088XA",  # Other osteoporosis with current pathological fracture, vertebra(e), initial encounter for fracture
        "M8088XD",  # Other osteoporosis with current pathological fracture, vertebra(e), subsequent encounter for fracture with routine healing
        "M8088XG",  # Other osteoporosis with current pathological fracture, vertebra(e), subsequent encounter for fracture with delayed healing
        "M8088XK",  # Other osteoporosis with current pathological fracture, vertebra(e), subsequent encounter for fracture with nonunion
        "M8088XP",  # Other osteoporosis with current pathological fracture, vertebra(e), subsequent encounter for fracture with malunion
        "M8088XS",  # Other osteoporosis with current pathological fracture, vertebra(e), sequela
        "M808AXA",  # Other osteoporosis with current pathological fracture, other site, initial encounter for fracture
        "M808AXD",  # Other osteoporosis with current pathological fracture, other site, subsequent encounter for fracture with routine healing
        "M808AXG",  # Other osteoporosis with current pathological fracture, other site, subsequent encounter for fracture with delayed healing
        "M808AXK",  # Other osteoporosis with current pathological fracture, other site, subsequent encounter for fracture with nonunion
        "M808AXP",  # Other osteoporosis with current pathological fracture, other site, subsequent encounter for fracture with malunion
        "M808AXS",  # Other osteoporosis with current pathological fracture, other site, sequela
        "M808B1A",  # Other osteoporosis with current pathological fracture, right pelvis, initial encounter for fracture
        "M808B1D",  # Other osteoporosis with current pathological fracture, right pelvis, subsequent encounter for fracture with routine healing
        "M808B1G",  # Other osteoporosis with current pathological fracture, right pelvis, subsequent encounter for fracture with delayed healing
        "M808B1K",  # Other osteoporosis with current pathological fracture, right pelvis, subsequent encounter for fracture with nonunion
        "M808B1P",  # Other osteoporosis with current pathological fracture, right pelvis, subsequent encounter for fracture with malunion
        "M808B1S",  # Other osteoporosis with current pathological fracture, right pelvis, sequela
        "M808B2A",  # Other osteoporosis with current pathological fracture, left pelvis, initial encounter for fracture
        "M808B2D",  # Other osteoporosis with current pathological fracture, left pelvis, subsequent encounter for fracture with routine healing
        "M808B2G",  # Other osteoporosis with current pathological fracture, left pelvis, subsequent encounter for fracture with delayed healing
        "M808B2K",  # Other osteoporosis with current pathological fracture, left pelvis, subsequent encounter for fracture with nonunion
        "M808B2P",  # Other osteoporosis with current pathological fracture, left pelvis, subsequent encounter for fracture with malunion
        "M808B2S",  # Other osteoporosis with current pathological fracture, left pelvis, sequela
        "M808B9A",  # Other osteoporosis with current pathological fracture, unspecified pelvis, initial encounter for fracture
        "M808B9D",  # Other osteoporosis with current pathological fracture, unspecified pelvis, subsequent encounter for fracture with routine healing
        "M808B9G",  # Other osteoporosis with current pathological fracture, unspecified pelvis, subsequent encounter for fracture with delayed healing
        "M808B9K",  # Other osteoporosis with current pathological fracture, unspecified pelvis, subsequent encounter for fracture with nonunion
        "M808B9P",  # Other osteoporosis with current pathological fracture, unspecified pelvis, subsequent encounter for fracture with malunion
        "M808B9S",  # Other osteoporosis with current pathological fracture, unspecified pelvis, sequela
    }

class PeripheralNeuropathy(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for peripheral neuropathy

    **Data Element Scope:** This value set may use a model element related to Diagnosis

    **Inclusion Criteria:** Includes concepts representing peripheral neuropathy

    **Exclusion Criteria:** N/A
    """

    VALUE_SET_NAME = "Peripheral Neuropathy"
    OID = "2.16.840.1.113762.1.4.1248.175"
    DEFINITION_VERSION = "20221006"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "A5043",  # Late congenital syphilitic polyneuropathy
        "A5215",  # Late syphilitic neuropathy
        "B0223",  # Postherpetic polyneuropathy
        "B2684",  # Mumps polyneuropathy
        "B2701",  # Gammaherpesviral mononucleosis with polyneuropathy
        "B2711",  # Cytomegaloviral mononucleosis with polyneuropathy
        "B2781",  # Other infectious mononucleosis with polyneuropathy
        "B2791",  # Infectious mononucleosis, unspecified with polyneuropathy
        "E0840",  # Diabetes mellitus due to underlying condition with diabetic neuropathy, unspecified
        "E0841",  # Diabetes mellitus due to underlying condition with diabetic mononeuropathy
        "E0842",  # Diabetes mellitus due to underlying condition with diabetic polyneuropathy
        "E08610",  # Diabetes mellitus due to underlying condition with diabetic neuropathic arthropathy
        "E0940",  # Drug or chemical induced diabetes mellitus with neurological complications with diabetic neuropathy, unspecified
        "E0941",  # Drug or chemical induced diabetes mellitus with neurological complications with diabetic mononeuropathy
        "E0942",  # Drug or chemical induced diabetes mellitus with neurological complications with diabetic polyneuropathy
        "E09610",  # Drug or chemical induced diabetes mellitus with diabetic neuropathic arthropathy
        "E1040",  # Type 1 diabetes mellitus with diabetic neuropathy, unspecified
        "E1041",  # Type 1 diabetes mellitus with diabetic mononeuropathy
        "E1042",  # Type 1 diabetes mellitus with diabetic polyneuropathy
        "E10610",  # Type 1 diabetes mellitus with diabetic neuropathic arthropathy
        "E1140",  # Type 2 diabetes mellitus with diabetic neuropathy, unspecified
        "E1141",  # Type 2 diabetes mellitus with diabetic mononeuropathy
        "E1142",  # Type 2 diabetes mellitus with diabetic polyneuropathy
        "E11610",  # Type 2 diabetes mellitus with diabetic neuropathic arthropathy
        "E1340",  # Other specified diabetes mellitus with diabetic neuropathy, unspecified
        "E1341",  # Other specified diabetes mellitus with diabetic mononeuropathy
        "E1342",  # Other specified diabetes mellitus with diabetic polyneuropathy
        "E13610",  # Other specified diabetes mellitus with diabetic neuropathic arthropathy
        "E71522",  # Adrenomyeloneuropathy
        "E851",  # Neuropathic heredofamilial amyloidosis
        "G130",  # Paraneoplastic neuromyopathy and neuropathy
        "G5780",  # Other specified mononeuropathies of unspecified lower limb
        "G5781",  # Other specified mononeuropathies of right lower limb
        "G5782",  # Other specified mononeuropathies of left lower limb
        "G5783",  # Other specified mononeuropathies of bilateral lower limbs
        "G5790",  # Unspecified mononeuropathy of unspecified lower limb
        "G5791",  # Unspecified mononeuropathy of right lower limb
        "G5792",  # Unspecified mononeuropathy of left lower limb
        "G5793",  # Unspecified mononeuropathy of bilateral lower limbs
        "G588",  # Other specified mononeuropathies
        "G589",  # Mononeuropathy, unspecified
        "G59",  # Mononeuropathy in diseases classified elsewhere
        "G600",  # Hereditary motor and sensory neuropathy
        "G601",  # Refsum's disease
        "G602",  # Neuropathy in association with hereditary ataxia
        "G603",  # Idiopathic progressive neuropathy
        "G608",  # Other hereditary and idiopathic neuropathies
        "G609",  # Hereditary and idiopathic neuropathy, unspecified
        "G610",  # Guillain-Barre syndrome
        "G6181",  # Chronic inflammatory demyelinating polyneuritis
        "G6182",  # Multifocal motor neuropathy
        "G6189",  # Other inflammatory polyneuropathies
        "G619",  # Inflammatory polyneuropathy, unspecified
        "G620",  # Drug-induced polyneuropathy
        "G621",  # Alcoholic polyneuropathy
        "G622",  # Polyneuropathy due to other toxic agents
        "G6281",  # Critical illness polyneuropathy
        "G6282",  # Radiation-induced polyneuropathy
        "G6289",  # Other specified polyneuropathies
        "G629",  # Polyneuropathy, unspecified
        "G63",  # Polyneuropathy in diseases classified elsewhere
        "G651",  # Sequelae of other inflammatory polyneuropathy
        "G652",  # Sequelae of toxic polyneuropathy
        "M0550",  # Rheumatoid polyneuropathy with rheumatoid arthritis of unspecified site
        "M05551",  # Rheumatoid polyneuropathy with rheumatoid arthritis of right hip
        "M05552",  # Rheumatoid polyneuropathy with rheumatoid arthritis of left hip
        "M05559",  # Rheumatoid polyneuropathy with rheumatoid arthritis of unspecified hip
        "M05561",  # Rheumatoid polyneuropathy with rheumatoid arthritis of right knee
        "M05562",  # Rheumatoid polyneuropathy with rheumatoid arthritis of left knee
        "M05569",  # Rheumatoid polyneuropathy with rheumatoid arthritis of unspecified knee
        "M05571",  # Rheumatoid polyneuropathy with rheumatoid arthritis of right ankle and foot
        "M05572",  # Rheumatoid polyneuropathy with rheumatoid arthritis of left ankle and foot
        "M05579",  # Rheumatoid polyneuropathy with rheumatoid arthritis of unspecified ankle and foot
        "M0559",  # Rheumatoid polyneuropathy with rheumatoid arthritis of multiple sites
        "M3483",  # Systemic sclerosis with polyneuropathy
    }

class PresentOnAdmissionOrClinicallyUndetermined(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for indicating a diagnosis is present on admission (Y) or clinically undetermined on admission (W).

    **Data Element Scope:** This value set may use a model element related to Encounter diagnosis.

    **Inclusion Criteria:** Includes PresentOnAdmission concepts that represent diagnosis is present on admission (Y) or clinically undetermined (W)

    **Exclusion Criteria:** N/A
    """

    VALUE_SET_NAME = "Present on Admission or Clinically Undetermined"
    OID = "2.16.840.1.113762.1.4.1147.197"
    DEFINITION_VERSION = "20220415"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    PresentOnAdmission = {
        "W",  # Clinically undetermined
        "Y",  # Diagnosis was present at time of inpatient admission
    }

class Stroke(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for stroke

    **Data Element Scope:** This value set may use a model element related to Diagnosis

    **Inclusion Criteria:** Includes concepts representing ischemic and hemorrhagic (traumatic and non-traumatic) stroke and stroke sequela

    **Exclusion Criteria:** N/A
    """

    VALUE_SET_NAME = "Stroke"
    OID = "2.16.840.1.113762.1.4.1248.176"
    DEFINITION_VERSION = "20240112"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "G450",  # Vertebro-basilar artery syndrome
        "G451",  # Carotid artery syndrome (hemispheric)
        "G452",  # Multiple and bilateral precerebral artery syndromes
        "G460",  # Middle cerebral artery syndrome
        "G461",  # Anterior cerebral artery syndrome
        "G462",  # Posterior cerebral artery syndrome
        "G463",  # Brain stem stroke syndrome
        "G464",  # Cerebellar stroke syndrome
        "G465",  # Pure motor lacunar syndrome
        "G466",  # Pure sensory lacunar syndrome
        "G467",  # Other lacunar syndromes
        "G468",  # Other vascular syndromes of brain in cerebrovascular diseases
        "I6000",  # Nontraumatic subarachnoid hemorrhage from unspecified carotid siphon and bifurcation
        "I6001",  # Nontraumatic subarachnoid hemorrhage from right carotid siphon and bifurcation
        "I6002",  # Nontraumatic subarachnoid hemorrhage from left carotid siphon and bifurcation
        "I6010",  # Nontraumatic subarachnoid hemorrhage from unspecified middle cerebral artery
        "I6011",  # Nontraumatic subarachnoid hemorrhage from right middle cerebral artery
        "I6012",  # Nontraumatic subarachnoid hemorrhage from left middle cerebral artery
        "I602",  # Nontraumatic subarachnoid hemorrhage from anterior communicating artery
        "I6030",  # Nontraumatic subarachnoid hemorrhage from unspecified posterior communicating artery
        "I6031",  # Nontraumatic subarachnoid hemorrhage from right posterior communicating artery
        "I6032",  # Nontraumatic subarachnoid hemorrhage from left posterior communicating artery
        "I604",  # Nontraumatic subarachnoid hemorrhage from basilar artery
        "I6050",  # Nontraumatic subarachnoid hemorrhage from unspecified vertebral artery
        "I6051",  # Nontraumatic subarachnoid hemorrhage from right vertebral artery
        "I6052",  # Nontraumatic subarachnoid hemorrhage from left vertebral artery
        "I606",  # Nontraumatic subarachnoid hemorrhage from other intracranial arteries
        "I607",  # Nontraumatic subarachnoid hemorrhage from unspecified intracranial artery
        "I608",  # Other nontraumatic subarachnoid hemorrhage
        "I609",  # Nontraumatic subarachnoid hemorrhage, unspecified
        "I610",  # Nontraumatic intracerebral hemorrhage in hemisphere, subcortical
        "I611",  # Nontraumatic intracerebral hemorrhage in hemisphere, cortical
        "I612",  # Nontraumatic intracerebral hemorrhage in hemisphere, unspecified
        "I613",  # Nontraumatic intracerebral hemorrhage in brain stem
        "I614",  # Nontraumatic intracerebral hemorrhage in cerebellum
        "I615",  # Nontraumatic intracerebral hemorrhage, intraventricular
        "I616",  # Nontraumatic intracerebral hemorrhage, multiple localized
        "I618",  # Other nontraumatic intracerebral hemorrhage
        "I619",  # Nontraumatic intracerebral hemorrhage, unspecified
        "I6200",  # Nontraumatic subdural hemorrhage, unspecified
        "I6201",  # Nontraumatic acute subdural hemorrhage
        "I6202",  # Nontraumatic subacute subdural hemorrhage
        "I6203",  # Nontraumatic chronic subdural hemorrhage
        "I621",  # Nontraumatic extradural hemorrhage
        "I629",  # Nontraumatic intracranial hemorrhage, unspecified
        "I6300",  # Cerebral infarction due to thrombosis of unspecified precerebral artery
        "I63011",  # Cerebral infarction due to thrombosis of right vertebral artery
        "I63012",  # Cerebral infarction due to thrombosis of left vertebral artery
        "I63013",  # Cerebral infarction due to thrombosis of bilateral vertebral arteries
        "I63019",  # Cerebral infarction due to thrombosis of unspecified vertebral artery
        "I6302",  # Cerebral infarction due to thrombosis of basilar artery
        "I63031",  # Cerebral infarction due to thrombosis of right carotid artery
        "I63032",  # Cerebral infarction due to thrombosis of left carotid artery
        "I63033",  # Cerebral infarction due to thrombosis of bilateral carotid arteries
        "I63039",  # Cerebral infarction due to thrombosis of unspecified carotid artery
        "I6309",  # Cerebral infarction due to thrombosis of other precerebral artery
        "I6310",  # Cerebral infarction due to embolism of unspecified precerebral artery
        "I63111",  # Cerebral infarction due to embolism of right vertebral artery
        "I63112",  # Cerebral infarction due to embolism of left vertebral artery
        "I63113",  # Cerebral infarction due to embolism of bilateral vertebral arteries
        "I63119",  # Cerebral infarction due to embolism of unspecified vertebral artery
        "I6312",  # Cerebral infarction due to embolism of basilar artery
        "I63131",  # Cerebral infarction due to embolism of right carotid artery
        "I63132",  # Cerebral infarction due to embolism of left carotid artery
        "I63133",  # Cerebral infarction due to embolism of bilateral carotid arteries
        "I63139",  # Cerebral infarction due to embolism of unspecified carotid artery
        "I6319",  # Cerebral infarction due to embolism of other precerebral artery
        "I6320",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified precerebral arteries
        "I63211",  # Cerebral infarction due to unspecified occlusion or stenosis of right vertebral artery
        "I63212",  # Cerebral infarction due to unspecified occlusion or stenosis of left vertebral artery
        "I63213",  # Cerebral infarction due to unspecified occlusion or stenosis of bilateral vertebral arteries
        "I63219",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified vertebral artery
        "I6322",  # Cerebral infarction due to unspecified occlusion or stenosis of basilar artery
        "I63231",  # Cerebral infarction due to unspecified occlusion or stenosis of right carotid arteries
        "I63232",  # Cerebral infarction due to unspecified occlusion or stenosis of left carotid arteries
        "I63233",  # Cerebral infarction due to unspecified occlusion or stenosis of bilateral carotid arteries
        "I63239",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified carotid artery
        "I6329",  # Cerebral infarction due to unspecified occlusion or stenosis of other precerebral arteries
        "I6330",  # Cerebral infarction due to thrombosis of unspecified cerebral artery
        "I63311",  # Cerebral infarction due to thrombosis of right middle cerebral artery
        "I63312",  # Cerebral infarction due to thrombosis of left middle cerebral artery
        "I63313",  # Cerebral infarction due to thrombosis of bilateral middle cerebral arteries
        "I63319",  # Cerebral infarction due to thrombosis of unspecified middle cerebral artery
        "I63321",  # Cerebral infarction due to thrombosis of right anterior cerebral artery
        "I63322",  # Cerebral infarction due to thrombosis of left anterior cerebral artery
        "I63323",  # Cerebral infarction due to thrombosis of bilateral anterior cerebral arteries
        "I63329",  # Cerebral infarction due to thrombosis of unspecified anterior cerebral artery
        "I63331",  # Cerebral infarction due to thrombosis of right posterior cerebral artery
        "I63332",  # Cerebral infarction due to thrombosis of left posterior cerebral artery
        "I63333",  # Cerebral infarction due to thrombosis of bilateral posterior cerebral arteries
        "I63339",  # Cerebral infarction due to thrombosis of unspecified posterior cerebral artery
        "I63341",  # Cerebral infarction due to thrombosis of right cerebellar artery
        "I63342",  # Cerebral infarction due to thrombosis of left cerebellar artery
        "I63343",  # Cerebral infarction due to thrombosis of bilateral cerebellar arteries
        "I63349",  # Cerebral infarction due to thrombosis of unspecified cerebellar artery
        "I6339",  # Cerebral infarction due to thrombosis of other cerebral artery
        "I6340",  # Cerebral infarction due to embolism of unspecified cerebral artery
        "I63411",  # Cerebral infarction due to embolism of right middle cerebral artery
        "I63412",  # Cerebral infarction due to embolism of left middle cerebral artery
        "I63413",  # Cerebral infarction due to embolism of bilateral middle cerebral arteries
        "I63419",  # Cerebral infarction due to embolism of unspecified middle cerebral artery
        "I63421",  # Cerebral infarction due to embolism of right anterior cerebral artery
        "I63422",  # Cerebral infarction due to embolism of left anterior cerebral artery
        "I63423",  # Cerebral infarction due to embolism of bilateral anterior cerebral arteries
        "I63429",  # Cerebral infarction due to embolism of unspecified anterior cerebral artery
        "I63431",  # Cerebral infarction due to embolism of right posterior cerebral artery
        "I63432",  # Cerebral infarction due to embolism of left posterior cerebral artery
        "I63433",  # Cerebral infarction due to embolism of bilateral posterior cerebral arteries
        "I63439",  # Cerebral infarction due to embolism of unspecified posterior cerebral artery
        "I63441",  # Cerebral infarction due to embolism of right cerebellar artery
        "I63442",  # Cerebral infarction due to embolism of left cerebellar artery
        "I63443",  # Cerebral infarction due to embolism of bilateral cerebellar arteries
        "I63449",  # Cerebral infarction due to embolism of unspecified cerebellar artery
        "I6349",  # Cerebral infarction due to embolism of other cerebral artery
        "I6350",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified cerebral artery
        "I63511",  # Cerebral infarction due to unspecified occlusion or stenosis of right middle cerebral artery
        "I63512",  # Cerebral infarction due to unspecified occlusion or stenosis of left middle cerebral artery
        "I63513",  # Cerebral infarction due to unspecified occlusion or stenosis of bilateral middle cerebral arteries
        "I63519",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified middle cerebral artery
        "I63521",  # Cerebral infarction due to unspecified occlusion or stenosis of right anterior cerebral artery
        "I63522",  # Cerebral infarction due to unspecified occlusion or stenosis of left anterior cerebral artery
        "I63523",  # Cerebral infarction due to unspecified occlusion or stenosis of bilateral anterior cerebral arteries
        "I63529",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified anterior cerebral artery
        "I63531",  # Cerebral infarction due to unspecified occlusion or stenosis of right posterior cerebral artery
        "I63532",  # Cerebral infarction due to unspecified occlusion or stenosis of left posterior cerebral artery
        "I63533",  # Cerebral infarction due to unspecified occlusion or stenosis of bilateral posterior cerebral arteries
        "I63539",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified posterior cerebral artery
        "I63541",  # Cerebral infarction due to unspecified occlusion or stenosis of right cerebellar artery
        "I63542",  # Cerebral infarction due to unspecified occlusion or stenosis of left cerebellar artery
        "I63543",  # Cerebral infarction due to unspecified occlusion or stenosis of bilateral cerebellar arteries
        "I63549",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified cerebellar artery
        "I6359",  # Cerebral infarction due to unspecified occlusion or stenosis of other cerebral artery
        "I636",  # Cerebral infarction due to cerebral venous thrombosis, nonpyogenic
        "I6381",  # Other cerebral infarction due to occlusion or stenosis of small artery
        "I6389",  # Other cerebral infarction
        "I639",  # Cerebral infarction, unspecified
        "I6900",  # Unspecified sequelae of nontraumatic subarachnoid hemorrhage
        "I69010",  # Attention and concentration deficit following nontraumatic subarachnoid hemorrhage
        "I69012",  # Visuospatial deficit and spatial neglect following nontraumatic subarachnoid hemorrhage
        "I69013",  # Psychomotor deficit following nontraumatic subarachnoid hemorrhage
        "I69014",  # Frontal lobe and executive function deficit following nontraumatic subarachnoid hemorrhage
        "I69015",  # Cognitive social or emotional deficit following nontraumatic subarachnoid hemorrhage
        "I69018",  # Other symptoms and signs involving cognitive functions following nontraumatic subarachnoid hemorrhage
        "I69019",  # Unspecified symptoms and signs involving cognitive functions following nontraumatic subarachnoid hemorrhage
        "I69041",  # Monoplegia of lower limb following nontraumatic subarachnoid hemorrhage affecting right dominant side
        "I69042",  # Monoplegia of lower limb following nontraumatic subarachnoid hemorrhage affecting left dominant side
        "I69043",  # Monoplegia of lower limb following nontraumatic subarachnoid hemorrhage affecting right non-dominant side
        "I69044",  # Monoplegia of lower limb following nontraumatic subarachnoid hemorrhage affecting left non-dominant side
        "I69049",  # Monoplegia of lower limb following nontraumatic subarachnoid hemorrhage affecting unspecified side
        "I69051",  # Hemiplegia and hemiparesis following nontraumatic subarachnoid hemorrhage affecting right dominant side
        "I69052",  # Hemiplegia and hemiparesis following nontraumatic subarachnoid hemorrhage affecting left dominant side
        "I69053",  # Hemiplegia and hemiparesis following nontraumatic subarachnoid hemorrhage affecting right non-dominant side
        "I69054",  # Hemiplegia and hemiparesis following nontraumatic subarachnoid hemorrhage affecting left non-dominant side
        "I69059",  # Hemiplegia and hemiparesis following nontraumatic subarachnoid hemorrhage affecting unspecified side
        "I69061",  # Other paralytic syndrome following nontraumatic subarachnoid hemorrhage affecting right dominant side
        "I69062",  # Other paralytic syndrome following nontraumatic subarachnoid hemorrhage affecting left dominant side
        "I69063",  # Other paralytic syndrome following nontraumatic subarachnoid hemorrhage affecting right non-dominant side
        "I69064",  # Other paralytic syndrome following nontraumatic subarachnoid hemorrhage affecting left non-dominant side
        "I69065",  # Other paralytic syndrome following nontraumatic subarachnoid hemorrhage, bilateral
        "I69069",  # Other paralytic syndrome following nontraumatic subarachnoid hemorrhage affecting unspecified side
        "I69090",  # Apraxia following nontraumatic subarachnoid hemorrhage
        "I69093",  # Ataxia following nontraumatic subarachnoid hemorrhage
        "I69110",  # Attention and concentration deficit following nontraumatic intracerebral hemorrhage
        "I69111",  # Memory deficit following nontraumatic intracerebral hemorrhage
        "I69112",  # Visuospatial deficit and spatial neglect following nontraumatic intracerebral hemorrhage
        "I69113",  # Psychomotor deficit following nontraumatic intracerebral hemorrhage
        "I69114",  # Frontal lobe and executive function deficit following nontraumatic intracerebral hemorrhage
        "I69115",  # Cognitive social or emotional deficit following nontraumatic intracerebral hemorrhage
        "I69118",  # Other symptoms and signs involving cognitive functions following nontraumatic intracerebral hemorrhage
        "I69119",  # Unspecified symptoms and signs involving cognitive functions following nontraumatic intracerebral hemorrhage
        "I69141",  # Monoplegia of lower limb following nontraumatic intracerebral hemorrhage affecting right dominant side
        "I69142",  # Monoplegia of lower limb following nontraumatic intracerebral hemorrhage affecting left dominant side
        "I69143",  # Monoplegia of lower limb following nontraumatic intracerebral hemorrhage affecting right non-dominant side
        "I69144",  # Monoplegia of lower limb following nontraumatic intracerebral hemorrhage affecting left non-dominant side
        "I69149",  # Monoplegia of lower limb following nontraumatic intracerebral hemorrhage affecting unspecified side
        "I69151",  # Hemiplegia and hemiparesis following nontraumatic intracerebral hemorrhage affecting right dominant side
        "I69152",  # Hemiplegia and hemiparesis following nontraumatic intracerebral hemorrhage affecting left dominant side
        "I69153",  # Hemiplegia and hemiparesis following nontraumatic intracerebral hemorrhage affecting right non-dominant side
        "I69154",  # Hemiplegia and hemiparesis following nontraumatic intracerebral hemorrhage affecting left non-dominant side
        "I69159",  # Hemiplegia and hemiparesis following nontraumatic intracerebral hemorrhage affecting unspecified side
        "I69161",  # Other paralytic syndrome following nontraumatic intracerebral hemorrhage affecting right dominant side
        "I69162",  # Other paralytic syndrome following nontraumatic intracerebral hemorrhage affecting left dominant side
        "I69163",  # Other paralytic syndrome following nontraumatic intracerebral hemorrhage affecting right non-dominant side
        "I69164",  # Other paralytic syndrome following nontraumatic intracerebral hemorrhage affecting left non-dominant side
        "I69165",  # Other paralytic syndrome following nontraumatic intracerebral hemorrhage, bilateral
        "I69169",  # Other paralytic syndrome following nontraumatic intracerebral hemorrhage affecting unspecified side
        "I69190",  # Apraxia following nontraumatic intracerebral hemorrhage
        "I69193",  # Ataxia following nontraumatic intracerebral hemorrhage
        "I69198",  # Other sequelae of nontraumatic intracerebral hemorrhage
        "I6920",  # Unspecified sequelae of other nontraumatic intracranial hemorrhage
        "I69210",  # Attention and concentration deficit following other nontraumatic intracranial hemorrhage
        "I69211",  # Memory deficit following other nontraumatic intracranial hemorrhage
        "I69212",  # Visuospatial deficit and spatial neglect following other nontraumatic intracranial hemorrhage
        "I69213",  # Psychomotor deficit following other nontraumatic intracranial hemorrhage
        "I69214",  # Frontal lobe and executive function deficit following other nontraumatic intracranial hemorrhage
        "I69215",  # Cognitive social or emotional deficit following other nontraumatic intracranial hemorrhage
        "I69218",  # Other symptoms and signs involving cognitive functions following other nontraumatic intracranial hemorrhage
        "I69219",  # Unspecified symptoms and signs involving cognitive functions following other nontraumatic intracranial hemorrhage
        "I69241",  # Monoplegia of lower limb following other nontraumatic intracranial hemorrhage affecting right dominant side
        "I69242",  # Monoplegia of lower limb following other nontraumatic intracranial hemorrhage affecting left dominant side
        "I69243",  # Monoplegia of lower limb following other nontraumatic intracranial hemorrhage affecting right non-dominant side
        "I69244",  # Monoplegia of lower limb following other nontraumatic intracranial hemorrhage affecting left non-dominant side
        "I69249",  # Monoplegia of lower limb following other nontraumatic intracranial hemorrhage affecting unspecified side
        "I69251",  # Hemiplegia and hemiparesis following other nontraumatic intracranial hemorrhage affecting right dominant side
        "I69252",  # Hemiplegia and hemiparesis following other nontraumatic intracranial hemorrhage affecting left dominant side
        "I69253",  # Hemiplegia and hemiparesis following other nontraumatic intracranial hemorrhage affecting right non-dominant side
        "I69254",  # Hemiplegia and hemiparesis following other nontraumatic intracranial hemorrhage affecting left non-dominant side
        "I69259",  # Hemiplegia and hemiparesis following other nontraumatic intracranial hemorrhage affecting unspecified side
        "I69261",  # Other paralytic syndrome following other nontraumatic intracranial hemorrhage affecting right dominant side
        "I69262",  # Other paralytic syndrome following other nontraumatic intracranial hemorrhage affecting left dominant side
        "I69263",  # Other paralytic syndrome following other nontraumatic intracranial hemorrhage affecting right non-dominant side
        "I69264",  # Other paralytic syndrome following other nontraumatic intracranial hemorrhage affecting left non-dominant side
        "I69265",  # Other paralytic syndrome following other nontraumatic intracranial hemorrhage, bilateral
        "I69269",  # Other paralytic syndrome following other nontraumatic intracranial hemorrhage affecting unspecified side
        "I69290",  # Apraxia following other nontraumatic intracranial hemorrhage
        "I69293",  # Ataxia following other nontraumatic intracranial hemorrhage
        "I69310",  # Attention and concentration deficit following cerebral infarction
        "I69311",  # Memory deficit following cerebral infarction
        "I69312",  # Visuospatial deficit and spatial neglect following cerebral infarction
        "I69313",  # Psychomotor deficit following cerebral infarction
        "I69314",  # Frontal lobe and executive function deficit following cerebral infarction
        "I69315",  # Cognitive social or emotional deficit following cerebral infarction
        "I69318",  # Other symptoms and signs involving cognitive functions following cerebral infarction
        "I69319",  # Unspecified symptoms and signs involving cognitive functions following cerebral infarction
        "I69341",  # Monoplegia of lower limb following cerebral infarction affecting right dominant side
        "I69342",  # Monoplegia of lower limb following cerebral infarction affecting left dominant side
        "I69343",  # Monoplegia of lower limb following cerebral infarction affecting right non-dominant side
        "I69344",  # Monoplegia of lower limb following cerebral infarction affecting left non-dominant side
        "I69349",  # Monoplegia of lower limb following cerebral infarction affecting unspecified side
        "I69351",  # Hemiplegia and hemiparesis following cerebral infarction affecting right dominant side
        "I69352",  # Hemiplegia and hemiparesis following cerebral infarction affecting left dominant side
        "I69353",  # Hemiplegia and hemiparesis following cerebral infarction affecting right non-dominant side
        "I69354",  # Hemiplegia and hemiparesis following cerebral infarction affecting left non-dominant side
        "I69359",  # Hemiplegia and hemiparesis following cerebral infarction affecting unspecified side
        "I69361",  # Other paralytic syndrome following cerebral infarction affecting right dominant side
        "I69362",  # Other paralytic syndrome following cerebral infarction affecting left dominant side
        "I69363",  # Other paralytic syndrome following cerebral infarction affecting right non-dominant side
        "I69364",  # Other paralytic syndrome following cerebral infarction affecting left non-dominant side
        "I69365",  # Other paralytic syndrome following cerebral infarction, bilateral
        "I69369",  # Other paralytic syndrome following cerebral infarction affecting unspecified side
        "I69390",  # Apraxia following cerebral infarction
        "I69393",  # Ataxia following cerebral infarction
        "I69941",  # Monoplegia of lower limb following unspecified cerebrovascular disease affecting right dominant side
        "I69942",  # Monoplegia of lower limb following unspecified cerebrovascular disease affecting left dominant side
        "I69943",  # Monoplegia of lower limb following unspecified cerebrovascular disease affecting right non-dominant side
        "I69944",  # Monoplegia of lower limb following unspecified cerebrovascular disease affecting left non-dominant side
        "I69949",  # Monoplegia of lower limb following unspecified cerebrovascular disease affecting unspecified side
        "I69951",  # Hemiplegia and hemiparesis following unspecified cerebrovascular disease affecting right dominant side
        "I69952",  # Hemiplegia and hemiparesis following unspecified cerebrovascular disease affecting left dominant side
        "I69953",  # Hemiplegia and hemiparesis following unspecified cerebrovascular disease affecting right non-dominant side
        "I69954",  # Hemiplegia and hemiparesis following unspecified cerebrovascular disease affecting left non-dominant side
        "I69959",  # Hemiplegia and hemiparesis following unspecified cerebrovascular disease affecting unspecified side
        "I69961",  # Other paralytic syndrome following unspecified cerebrovascular disease affecting right dominant side
        "I69962",  # Other paralytic syndrome following unspecified cerebrovascular disease affecting left dominant side
        "I69963",  # Other paralytic syndrome following unspecified cerebrovascular disease affecting right non-dominant side
        "I69964",  # Other paralytic syndrome following unspecified cerebrovascular disease affecting left non-dominant side
        "I69965",  # Other paralytic syndrome following unspecified cerebrovascular disease, bilateral
        "I69969",  # Other paralytic syndrome following unspecified cerebrovascular disease affecting unspecified side
        "I69990",  # Apraxia following unspecified cerebrovascular disease
        "I69993",  # Ataxia following unspecified cerebrovascular disease
    }

class SuicideAttempt(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for stroke

    **Data Element Scope:** This value set may use a model element related to Diagnosis

    **Inclusion Criteria:** Includes concepts representing suicide attempt diagnoses

    **Exclusion Criteria:** N/A
    """

    VALUE_SET_NAME = "Suicide Attempt"
    OID = "2.16.840.1.113762.1.4.1248.130"
    DEFINITION_VERSION = "20230425"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "T1491XA",  # Suicide attempt, initial encounter
    }

class TwentyToFortyTwoPlusWeeksGestation(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of 20-42 weeks gestation.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of weeks gestation equal to 20-42 weeks.

    **Exclusion Criteria:** Excludes concepts that identify a diagnosis of weeks gestation less than 20 weeks.
    """

    VALUE_SET_NAME = "20 to 42 Plus Weeks Gestation"
    OID = "2.16.840.1.113762.1.4.1110.67"
    DEFINITION_VERSION = "20230217"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "Z3A20",  # 20 weeks gestation of pregnancy
        "Z3A21",  # 21 weeks gestation of pregnancy
        "Z3A22",  # 22 weeks gestation of pregnancy
        "Z3A23",  # 23 weeks gestation of pregnancy
        "Z3A24",  # 24 weeks gestation of pregnancy
        "Z3A25",  # 25 weeks gestation of pregnancy
        "Z3A26",  # 26 weeks gestation of pregnancy
        "Z3A27",  # 27 weeks gestation of pregnancy
        "Z3A28",  # 28 weeks gestation of pregnancy
        "Z3A29",  # 29 weeks gestation of pregnancy
        "Z3A30",  # 30 weeks gestation of pregnancy
        "Z3A31",  # 31 weeks gestation of pregnancy
        "Z3A32",  # 32 weeks gestation of pregnancy
        "Z3A33",  # 33 weeks gestation of pregnancy
        "Z3A34",  # 34 weeks gestation of pregnancy
        "Z3A35",  # 35 weeks gestation of pregnancy
        "Z3A36",  # 36 weeks gestation of pregnancy
        "Z3A37",  # 37 weeks gestation of pregnancy
        "Z3A38",  # 38 weeks gestation of pregnancy
        "Z3A39",  # 39 weeks gestation of pregnancy
        "Z3A40",  # 40 weeks gestation of pregnancy
        "Z3A41",  # 41 weeks gestation of pregnancy
        "Z3A42",  # 42 weeks gestation of pregnancy
        "Z3A49",  # Greater than 42 weeks gestation of pregnancy
    }

    SNOMEDCT = {
        "13763000",  # Gestation period, 34 weeks (finding)
        "13798002",  # Gestation period, 38 weeks (finding)
        "22281000119101",  # Post-term pregnancy of 40 to 42 weeks (finding)
        "23464008",  # Gestation period, 20 weeks (finding)
        "313179009",  # Gestation period, 24 weeks (finding)
        "313180007",  # Gestation greater than 24 weeks (finding)
        "36428009",  # Gestation period, 42 weeks (finding)
        "41438001",  # Gestation period, 21 weeks (finding)
        "429715006",  # Gestation greater than 20 weeks (finding)
        "433601000124106",  # Gestation period greater than or equal to 37 weeks (finding)
        "43697006",  # Gestation period, 37 weeks (finding)
        "45139008",  # Gestation period, 29 weeks (finding)
        "46230007",  # Gestation period, 40 weeks (finding)
        "46906003",  # Gestation period, 27 weeks (finding)
        "48688005",  # Gestation period, 26 weeks (finding)
        "57907009",  # Gestation period, 36 weeks (finding)
        "63503002",  # Gestation period, 41 weeks (finding)
        "64920003",  # Gestation period, 31 weeks (finding)
        "65035007",  # Gestation period, 22 weeks (finding)
        "71355009",  # Gestation period, 30 weeks (finding)
        "72544005",  # Gestation period, 25 weeks (finding)
        "7707000",  # Gestation period, 32 weeks (finding)
        "78395001",  # Gestation period, 33 weeks (finding)
        "80487005",  # Gestation period, 39 weeks (finding)
        "84132007",  # Gestation period, 35 weeks (finding)
        "86883006",  # Gestation period, 23 weeks (finding)
        "90797000",  # Gestation period, 28 weeks (finding)
    }

class AcuteHeartFailure(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to identify diagnoses of acute heart failure.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of acute heart failure.

    **Exclusion Criteria:** Excludes concepts that identify chronic conditions.
    """

    VALUE_SET_NAME = "Acute Heart Failure"
    OID = "2.16.840.1.113762.1.4.1029.233"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "I501",  # Left ventricular failure, unspecified
        "I5020",  # Unspecified systolic (congestive) heart failure
        "I5021",  # Acute systolic (congestive) heart failure
        "I5023",  # Acute on chronic systolic (congestive) heart failure
        "I5030",  # Unspecified diastolic (congestive) heart failure
        "I5031",  # Acute diastolic (congestive) heart failure
        "I5033",  # Acute on chronic diastolic (congestive) heart failure
        "I5040",  # Unspecified combined systolic (congestive) and diastolic (congestive) heart failure
        "I5041",  # Acute combined systolic (congestive) and diastolic (congestive) heart failure
        "I5043",  # Acute on chronic combined systolic (congestive) and diastolic (congestive) heart failure
        "I50810",  # Right heart failure, unspecified
        "I50811",  # Acute right heart failure
        "I50813",  # Acute on chronic right heart failure
        "I50814",  # Right heart failure due to left heart failure
        "I5082",  # Biventricular heart failure
        "I5083",  # High output heart failure
        "I5084",  # End stage heart failure
        "I5089",  # Other heart failure
        "I509",  # Heart failure, unspecified
    }

class AcuteMyocardialInfarction(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to identify diagnoses of acute myocardial infarction.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of an ST elevation myocardial infarction and Non ST elevation myocardial infarction.

    **Exclusion Criteria:** Excludes concepts that identify complications or chronic conditions.
    """

    VALUE_SET_NAME = "Acute Myocardial Infarction"
    OID = "2.16.840.1.113883.3.666.5.623"
    DEFINITION_VERSION = "20240210"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "I2101",  # ST elevation (STEMI) myocardial infarction involving left main coronary artery
        "I2102",  # ST elevation (STEMI) myocardial infarction involving left anterior descending coronary artery
        "I2109",  # ST elevation (STEMI) myocardial infarction involving other coronary artery of anterior wall
        "I2111",  # ST elevation (STEMI) myocardial infarction involving right coronary artery
        "I2119",  # ST elevation (STEMI) myocardial infarction involving other coronary artery of inferior wall
        "I2121",  # ST elevation (STEMI) myocardial infarction involving left circumflex coronary artery
        "I2129",  # ST elevation (STEMI) myocardial infarction involving other sites
        "I213",  # ST elevation (STEMI) myocardial infarction of unspecified site
        "I214",  # Non-ST elevation (NSTEMI) myocardial infarction
        "I219",  # Acute myocardial infarction, unspecified
        "I21A1",  # Myocardial infarction type 2
        "I21A9",  # Other myocardial infarction type
        "I21B",  # Myocardial infarction with coronary microvascular dysfunction
        "I220",  # Subsequent ST elevation (STEMI) myocardial infarction of anterior wall
        "I221",  # Subsequent ST elevation (STEMI) myocardial infarction of inferior wall
        "I222",  # Subsequent non-ST elevation (NSTEMI) myocardial infarction
        "I228",  # Subsequent ST elevation (STEMI) myocardial infarction of other sites
        "I229",  # Subsequent ST elevation (STEMI) myocardial infarction of unspecified site
    }

class AcuteRenalFailure(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to identify diagnoses of acute renal failure.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of an acute renal failure.

    **Exclusion Criteria:** Excludes concepts that identify chronic conditions.
    """

    VALUE_SET_NAME = "Acute Renal Failure"
    OID = "2.16.840.1.113762.1.4.1110.53"
    DEFINITION_VERSION = "20240210"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "N170",  # Acute kidney failure with tubular necrosis
        "N171",  # Acute kidney failure with acute cortical necrosis
        "N172",  # Acute kidney failure with medullary necrosis
        "N178",  # Other acute kidney failure
        "N179",  # Acute kidney failure, unspecified
        "O9041",  # Hepatorenal syndrome following labor and delivery
        "O9049",  # Other postpartum acute kidney failure
    }

class AcuteRespiratoryDistressSyndrome(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to identify diagnoses of acute respiratory distress syndrome.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of an acute respiratory distress syndrome.

    **Exclusion Criteria:** Excludes concepts that identify chronic conditions.
    """

    VALUE_SET_NAME = "Acute Respiratory Distress Syndrome"
    OID = "2.16.840.1.113762.1.4.1029.214"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "J80",  # Acute respiratory distress syndrome
        "J951",  # Acute pulmonary insufficiency following thoracic surgery
        "J952",  # Acute pulmonary insufficiency following nonthoracic surgery
        "J953",  # Chronic pulmonary insufficiency following surgery
        "J95821",  # Acute postprocedural respiratory failure
        "J95822",  # Acute and chronic postprocedural respiratory failure
        "J9600",  # Acute respiratory failure, unspecified whether with hypoxia or hypercapnia
        "J9601",  # Acute respiratory failure with hypoxia
        "J9602",  # Acute respiratory failure with hypercapnia
        "J9620",  # Acute and chronic respiratory failure, unspecified whether with hypoxia or hypercapnia
        "J9621",  # Acute and chronic respiratory failure with hypoxia
        "J9622",  # Acute and chronic respiratory failure with hypercapnia
        "J9690",  # Respiratory failure, unspecified, unspecified whether with hypoxia or hypercapnia
        "J9691",  # Respiratory failure, unspecified with hypoxia
        "J9692",  # Respiratory failure, unspecified with hypercapnia
        "R0603",  # Acute respiratory distress
        "R092",  # Respiratory arrest
    }

class AcuteOrPersistentAsthma(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to identify diagnoses of asthma with an indication of acute, persistent, and/or asthmaticus status.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of asthma.

    **Exclusion Criteria:** Excludes concepts of uncomplicated, mild or intermittent asthma.
    """

    VALUE_SET_NAME = "Acute or Persistent Asthma"
    OID = "2.16.840.1.113883.3.117.1.7.1.271"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "J4521",  # Mild intermittent asthma with (acute) exacerbation
        "J4522",  # Mild intermittent asthma with status asthmaticus
        "J4531",  # Mild persistent asthma with (acute) exacerbation
        "J4532",  # Mild persistent asthma with status asthmaticus
        "J4540",  # Moderate persistent asthma, uncomplicated
        "J4541",  # Moderate persistent asthma with (acute) exacerbation
        "J4542",  # Moderate persistent asthma with status asthmaticus
        "J4550",  # Severe persistent asthma, uncomplicated
        "J4551",  # Severe persistent asthma with (acute) exacerbation
        "J4552",  # Severe persistent asthma with status asthmaticus
        "J45901",  # Unspecified asthma with (acute) exacerbation
        "J45902",  # Unspecified asthma with status asthmaticus
        "O99511",  # Diseases of the respiratory system complicating pregnancy, first trimester
        "O99512",  # Diseases of the respiratory system complicating pregnancy, second trimester
        "O99513",  # Diseases of the respiratory system complicating pregnancy, third trimester
        "O99519",  # Diseases of the respiratory system complicating pregnancy, unspecified trimester
        "O9952",  # Diseases of the respiratory system complicating childbirth
        "O9953",  # Diseases of the respiratory system complicating the puerperium
    }

class AirAndThromboticEmbolism(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to identify diagnoses of air and thrombotic embolisms.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of an air and thrombotic embolism.

    **Exclusion Criteria:** Excludes concepts that identify chronic conditions.
    """

    VALUE_SET_NAME = "Air and Thrombotic Embolism"
    OID = "2.16.840.1.113762.1.4.1029.243"
    DEFINITION_VERSION = "20250207"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "I2601",  # Septic pulmonary embolism with acute cor pulmonale
        "I2602",  # Saddle embolus of pulmonary artery with acute cor pulmonale
        "I2604",  # Fat embolism of pulmonary artery with acute cor pulmonale
        "I2609",  # Other pulmonary embolism with acute cor pulmonale
        "I2690",  # Septic pulmonary embolism without acute cor pulmonale
        "I2692",  # Saddle embolus of pulmonary artery without acute cor pulmonale
        "I2693",  # Single subsegmental thrombotic pulmonary embolism without acute cor pulmonale
        "I2694",  # Multiple subsegmental thrombotic pulmonary emboli without acute cor pulmonale
        "I2696",  # Fat embolism of pulmonary artery without acute cor pulmonale
        "I2699",  # Other pulmonary embolism without acute cor pulmonale
        "O88012",  # Air embolism in pregnancy, second trimester
        "O88013",  # Air embolism in pregnancy, third trimester
        "O88019",  # Air embolism in pregnancy, unspecified trimester
        "O8802",  # Air embolism in childbirth
        "O8803",  # Air embolism in the puerperium
        "O88212",  # Thromboembolism in pregnancy, second trimester
        "O88213",  # Thromboembolism in pregnancy, third trimester
        "O88219",  # Thromboembolism in pregnancy, unspecified trimester
        "O8822",  # Thromboembolism in childbirth
        "O8823",  # Thromboembolism in the puerperium
        "O88312",  # Pyemic and septic embolism in pregnancy, second trimester
        "O88313",  # Pyemic and septic embolism in pregnancy, third trimester
        "O88319",  # Pyemic and septic embolism in pregnancy, unspecified trimester
        "O8832",  # Pyemic and septic embolism in childbirth
        "O8833",  # Pyemic and septic embolism in the puerperium
        "O88812",  # Other embolism in pregnancy, second trimester
        "O88813",  # Other embolism in pregnancy, third trimester
        "O88819",  # Other embolism in pregnancy, unspecified trimester
        "O8882",  # Other embolism in childbirth
        "O8883",  # Other embolism in the puerperium
        "T800XXA",  # Air embolism following infusion, transfusion and therapeutic injection, initial encounter
    }

class AmnioticFluidEmbolism(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to identify diagnoses of amniotic fluid embolisms.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of an amniotic fluid embolism.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Amniotic Fluid Embolism"
    OID = "2.16.840.1.113762.1.4.1029.217"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "O88112",  # Amniotic fluid embolism in pregnancy, second trimester
        "O88113",  # Amniotic fluid embolism in pregnancy, third trimester
        "O88119",  # Amniotic fluid embolism in pregnancy, unspecified trimester
        "O8812",  # Amniotic fluid embolism in childbirth
        "O8813",  # Amniotic fluid embolism in the puerperium
    }

class Anemia(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of anemia.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of an anemia.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Anemia"
    OID = "2.16.840.1.113762.1.4.1029.323"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "D500",  # Iron deficiency anemia secondary to blood loss (chronic)
        "D501",  # Sideropenic dysphagia
        "D508",  # Other iron deficiency anemias
        "D509",  # Iron deficiency anemia, unspecified
        "D550",  # Anemia due to glucose-6-phosphate dehydrogenase [G6PD] deficiency
        "D551",  # Anemia due to other disorders of glutathione metabolism
        "D5521",  # Anemia due to pyruvate kinase deficiency
        "D5529",  # Anemia due to other disorders of glycolytic enzymes
        "D553",  # Anemia due to disorders of nucleotide metabolism
        "D558",  # Other anemias due to enzyme disorders
        "D559",  # Anemia due to enzyme disorder, unspecified
        "D560",  # Alpha thalassemia
        "D561",  # Beta thalassemia
        "D562",  # Delta-beta thalassemia
        "D563",  # Thalassemia minor
        "D564",  # Hereditary persistence of fetal hemoglobin [HPFH]
        "D565",  # Hemoglobin E-beta thalassemia
        "D568",  # Other thalassemias
        "D569",  # Thalassemia, unspecified
        "D571",  # Sickle-cell disease without crisis
        "D5720",  # Sickle-cell/Hb-C disease without crisis
        "D573",  # Sickle-cell trait
        "D5740",  # Sickle-cell thalassemia without crisis
        "D5780",  # Other sickle-cell disorders without crisis
        "D580",  # Hereditary spherocytosis
        "D581",  # Hereditary elliptocytosis
        "D582",  # Other hemoglobinopathies
        "D588",  # Other specified hereditary hemolytic anemias
        "D589",  # Hereditary hemolytic anemia, unspecified
        "D590",  # Drug-induced autoimmune hemolytic anemia
        "D5910",  # Autoimmune hemolytic anemia, unspecified
        "D5911",  # Warm autoimmune hemolytic anemia
        "D5912",  # Cold autoimmune hemolytic anemia
        "D5913",  # Mixed type autoimmune hemolytic anemia
        "D5919",  # Other autoimmune hemolytic anemia
        "D592",  # Drug-induced nonautoimmune hemolytic anemia
        "D5930",  # Hemolytic-uremic syndrome, unspecified
        "D5931",  # Infection-associated hemolytic-uremic syndrome
        "D5932",  # Hereditary hemolytic-uremic syndrome
        "D5939",  # Other hemolytic-uremic syndrome
        "D594",  # Other nonautoimmune hemolytic anemias
        "D595",  # Paroxysmal nocturnal hemoglobinuria [Marchiafava-Micheli]
        "D596",  # Hemoglobinuria due to hemolysis from other external causes
        "D598",  # Other acquired hemolytic anemias
        "D599",  # Acquired hemolytic anemia, unspecified
        "D630",  # Anemia in neoplastic disease
        "D631",  # Anemia in chronic kidney disease
        "D638",  # Anemia in other chronic diseases classified elsewhere
        "O99011",  # Anemia complicating pregnancy, first trimester
        "O99012",  # Anemia complicating pregnancy, second trimester
        "O99013",  # Anemia complicating pregnancy, third trimester
        "O99019",  # Anemia complicating pregnancy, unspecified trimester
        "O9902",  # Anemia complicating childbirth
    }

class AorticAneurysm(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to identify diagnoses of aortic aneurysm.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of an aortic aneurysm.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Aortic Aneurysm"
    OID = "2.16.840.1.113762.1.4.1029.219"
    DEFINITION_VERSION = "20230217"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "I7100",  # Dissection of unspecified site of aorta
        "I71010",  # Dissection of ascending aorta
        "I71011",  # Dissection of aortic arch
        "I71012",  # Dissection of descending thoracic aorta
        "I71019",  # Dissection of thoracic aorta, unspecified
        "I7102",  # Dissection of abdominal aorta
        "I7103",  # Dissection of thoracoabdominal aorta
        "I7110",  # Thoracic aortic aneurysm, ruptured, unspecified
        "I7111",  # Aneurysm of the ascending aorta, ruptured
        "I7112",  # Aneurysm of the aortic arch, ruptured
        "I7113",  # Aneurysm of the descending thoracic aorta, ruptured
        "I7120",  # Thoracic aortic aneurysm, without rupture, unspecified
        "I7121",  # Aneurysm of the ascending aorta, without rupture
        "I7122",  # Aneurysm of the aortic arch, without rupture
        "I7123",  # Aneurysm of the descending thoracic aorta, without rupture
        "I7130",  # Abdominal aortic aneurysm, ruptured, unspecified
        "I7131",  # Pararenal abdominal aortic aneurysm, ruptured
        "I7132",  # Juxtarenal abdominal aortic aneurysm, ruptured
        "I7133",  # Infrarenal abdominal aortic aneurysm, ruptured
        "I7140",  # Abdominal aortic aneurysm, without rupture, unspecified
        "I7141",  # Pararenal abdominal aortic aneurysm, without rupture
        "I7142",  # Juxtarenal abdominal aortic aneurysm, without rupture
        "I7143",  # Infrarenal abdominal aortic aneurysm, without rupture
        "I7150",  # Thoracoabdominal aortic aneurysm, ruptured, unspecified
        "I7151",  # Supraceliac aneurysm of the thoracoabdominal aorta, ruptured
        "I7152",  # Paravisceral aneurysm of the thoracoabdominal aorta, ruptured
        "I7160",  # Thoracoabdominal aortic aneurysm, without rupture, unspecified
        "I7161",  # Supraceliac aneurysm of the thoracoabdominal aorta, without rupture
        "I7162",  # Paravisceral aneurysm of the thoracoabdominal aorta, without rupture
        "I718",  # Aortic aneurysm of unspecified site, ruptured
        "I719",  # Aortic aneurysm of unspecified site, without rupture
        "I790",  # Aneurysm of aorta in diseases classified elsewhere
    }

class AutoimmuneDisease(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of autoimmune disease.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of an autoimmune disease.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Autoimmune Disease"
    OID = "2.16.840.1.113762.1.4.1029.311"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "M300",  # Polyarteritis nodosa
        "M301",  # Polyarteritis with lung involvement [Churg-Strauss]
        "M302",  # Juvenile polyarteritis
        "M303",  # Mucocutaneous lymph node syndrome [Kawasaki]
        "M308",  # Other conditions related to polyarteritis nodosa
        "M310",  # Hypersensitivity angiitis
        "M3110",  # Thrombotic microangiopathy, unspecified
        "M3111",  # Hematopoietic stem cell transplantation-associated thrombotic microangiopathy [HSCT-TMA]
        "M3119",  # Other thrombotic microangiopathy
        "M312",  # Lethal midline granuloma
        "M3130",  # Wegener's granulomatosis without renal involvement
        "M3131",  # Wegener's granulomatosis with renal involvement
        "M314",  # Aortic arch syndrome [Takayasu]
        "M315",  # Giant cell arteritis with polymyalgia rheumatica
        "M316",  # Other giant cell arteritis
        "M317",  # Microscopic polyangiitis
        "M318",  # Other specified necrotizing vasculopathies
        "M319",  # Necrotizing vasculopathy, unspecified
        "M320",  # Drug-induced systemic lupus erythematosus
        "M3210",  # Systemic lupus erythematosus, organ or system involvement unspecified
        "M3211",  # Endocarditis in systemic lupus erythematosus
        "M3212",  # Pericarditis in systemic lupus erythematosus
        "M3213",  # Lung involvement in systemic lupus erythematosus
        "M3214",  # Glomerular disease in systemic lupus erythematosus
        "M3215",  # Tubulo-interstitial nephropathy in systemic lupus erythematosus
        "M3219",  # Other organ or system involvement in systemic lupus erythematosus
        "M328",  # Other forms of systemic lupus erythematosus
        "M329",  # Systemic lupus erythematosus, unspecified
        "M3300",  # Juvenile dermatomyositis, organ involvement unspecified
        "M3301",  # Juvenile dermatomyositis with respiratory involvement
        "M3302",  # Juvenile dermatomyositis with myopathy
        "M3303",  # Juvenile dermatomyositis without myopathy
        "M3309",  # Juvenile dermatomyositis with other organ involvement
        "M3310",  # Other dermatomyositis, organ involvement unspecified
        "M3311",  # Other dermatomyositis with respiratory involvement
        "M3312",  # Other dermatomyositis with myopathy
        "M3313",  # Other dermatomyositis without myopathy
        "M3319",  # Other dermatomyositis with other organ involvement
        "M3320",  # Polymyositis, organ involvement unspecified
        "M3321",  # Polymyositis with respiratory involvement
        "M3322",  # Polymyositis with myopathy
        "M3329",  # Polymyositis with other organ involvement
        "M3390",  # Dermatopolymyositis, unspecified, organ involvement unspecified
        "M3391",  # Dermatopolymyositis, unspecified with respiratory involvement
        "M3392",  # Dermatopolymyositis, unspecified with myopathy
        "M3393",  # Dermatopolymyositis, unspecified without myopathy
        "M3399",  # Dermatopolymyositis, unspecified with other organ involvement
        "M340",  # Progressive systemic sclerosis
        "M341",  # CR(E)ST syndrome
        "M342",  # Systemic sclerosis induced by drug and chemical
        "M3481",  # Systemic sclerosis with lung involvement
        "M3482",  # Systemic sclerosis with myopathy
        "M3483",  # Systemic sclerosis with polyneuropathy
        "M3489",  # Other systemic sclerosis
        "M349",  # Systemic sclerosis, unspecified
        "M3500",  # Sjogren syndrome, unspecified
        "M3501",  # Sjogren syndrome with keratoconjunctivitis
        "M3502",  # Sjogren syndrome with lung involvement
        "M3503",  # Sjogren syndrome with myopathy
        "M3504",  # Sjogren syndrome with tubulo-interstitial nephropathy
        "M3505",  # Sjogren syndrome with inflammatory arthritis
        "M3506",  # Sjogren syndrome with peripheral nervous system involvement
        "M3507",  # Sjogren syndrome with central nervous system involvement
        "M3508",  # Sjogren syndrome with gastrointestinal involvement
        "M3509",  # Sjogren syndrome with other organ involvement
        "M350A",  # Sjogren syndrome with glomerular disease
        "M350B",  # Sjogren syndrome with vasculitis
        "M350C",  # Sjogren syndrome with dental involvement
        "M351",  # Other overlap syndromes
        "M352",  # Behcet's disease
        "M353",  # Polymyalgia rheumatica
        "M354",  # Diffuse (eosinophilic) fasciitis
        "M355",  # Multifocal fibrosclerosis
        "M356",  # Relapsing panniculitis [Weber-Christian]
        "M357",  # Hypermobility syndrome
        "M3581",  # Multisystem inflammatory syndrome
        "M3589",  # Other specified systemic involvement of connective tissue
        "M359",  # Systemic involvement of connective tissue, unspecified
        "M360",  # Dermato(poly)myositis in neoplastic disease
        "M361",  # Arthropathy in neoplastic disease
        "M362",  # Hemophilic arthropathy
        "M363",  # Arthropathy in other blood disorders
        "M364",  # Arthropathy in hypersensitivity reactions classified elsewhere
        "M368",  # Systemic disorders of connective tissue in other diseases classified elsewhere
    }

class BariatricSurgery(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of bariatric surgery.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of a bariatric surgery.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Bariatric Surgery"
    OID = "2.16.840.1.113762.1.4.1029.317"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "O99840",  # Bariatric surgery status complicating pregnancy, unspecified trimester
        "O99842",  # Bariatric surgery status complicating pregnancy, second trimester
        "O99843",  # Bariatric surgery status complicating pregnancy, third trimester
        "O99844",  # Bariatric surgery status complicating childbirth
        "O99845",  # Bariatric surgery status complicating the puerperium
    }

class BleedingDisorder(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of a bleeding disorders.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of a bleeding disorder.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Bleeding Disorder"
    OID = "2.16.840.1.113762.1.4.1029.287"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "D66",  # Hereditary factor VIII deficiency
        "D67",  # Hereditary factor IX deficiency
        "D6800",  # Von Willebrand disease, unspecified
        "D6801",  # Von Willebrand disease, type 1
        "D68020",  # Von Willebrand disease, type 2A
        "D68021",  # Von Willebrand disease, type 2B
        "D68022",  # Von Willebrand disease, type 2M
        "D68023",  # Von Willebrand disease, type 2N
        "D68029",  # Von Willebrand disease, type 2, unspecified
        "D6803",  # Von Willebrand disease, type 3
        "D6804",  # Acquired von Willebrand disease
        "D6809",  # Other von Willebrand disease
        "D681",  # Hereditary factor XI deficiency
        "D682",  # Hereditary deficiency of other clotting factors
        "D68311",  # Acquired hemophilia
        "D68312",  # Antiphospholipid antibody with hemorrhagic disorder
        "D68318",  # Other hemorrhagic disorder due to intrinsic circulating anticoagulants, antibodies, or inhibitors
        "D6832",  # Hemorrhagic disorder due to extrinsic circulating anticoagulants
        "D684",  # Acquired coagulation factor deficiency
        "D6851",  # Activated protein C resistance
        "D6852",  # Prothrombin gene mutation
        "D6859",  # Other primary thrombophilia
        "D6861",  # Antiphospholipid syndrome
        "D6862",  # Lupus anticoagulant syndrome
        "D6869",  # Other thrombophilia
        "D690",  # Allergic purpura
        "D691",  # Qualitative platelet defects
        "D692",  # Other nonthrombocytopenic purpura
        "D693",  # Immune thrombocytopenic purpura
        "D6941",  # Evans syndrome
        "D6942",  # Congenital and hereditary thrombocytopenia purpura
        "D6949",  # Other primary thrombocytopenia
        "D6951",  # Posttransfusion purpura
        "D6959",  # Other secondary thrombocytopenia
        "D696",  # Thrombocytopenia, unspecified
        "D698",  # Other specified hemorrhagic conditions
        "D699",  # Hemorrhagic condition, unspecified
    }

class CardiacArrestVentricularFibrillation(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to identify diagnoses of cardiac arrest and ventricular fibrillation or flutter.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of a cardiac arrest and ventricular fibrillation or flutter.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Cardiac Arrest Ventricular Fibrillation"
    OID = "2.16.840.1.113762.1.4.1029.221"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "I462",  # Cardiac arrest due to underlying cardiac condition
        "I468",  # Cardiac arrest due to other underlying condition
        "I469",  # Cardiac arrest, cause unspecified
        "I4901",  # Ventricular fibrillation
        "I4902",  # Ventricular flutter
    }

class CardiacDisease(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of cardiac disease.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of cardiac disease.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Cardiac Disease"
    OID = "2.16.840.1.113762.1.4.1029.341"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "I050",  # Rheumatic mitral stenosis
        "I051",  # Rheumatic mitral insufficiency
        "I052",  # Rheumatic mitral stenosis with insufficiency
        "I058",  # Other rheumatic mitral valve diseases
        "I059",  # Rheumatic mitral valve disease, unspecified
        "I060",  # Rheumatic aortic stenosis
        "I061",  # Rheumatic aortic insufficiency
        "I062",  # Rheumatic aortic stenosis with insufficiency
        "I068",  # Other rheumatic aortic valve diseases
        "I069",  # Rheumatic aortic valve disease, unspecified
        "I070",  # Rheumatic tricuspid stenosis
        "I071",  # Rheumatic tricuspid insufficiency
        "I072",  # Rheumatic tricuspid stenosis and insufficiency
        "I078",  # Other rheumatic tricuspid valve diseases
        "I079",  # Rheumatic tricuspid valve disease, unspecified
        "I080",  # Rheumatic disorders of both mitral and aortic valves
        "I081",  # Rheumatic disorders of both mitral and tricuspid valves
        "I082",  # Rheumatic disorders of both aortic and tricuspid valves
        "I083",  # Combined rheumatic disorders of mitral, aortic and tricuspid valves
        "I088",  # Other rheumatic multiple valve diseases
        "I089",  # Rheumatic multiple valve disease, unspecified
        "I090",  # Rheumatic myocarditis
        "I091",  # Rheumatic diseases of endocardium, valve unspecified
        "I092",  # Chronic rheumatic pericarditis
        "I0981",  # Rheumatic heart failure
        "I0989",  # Other specified rheumatic heart diseases
        "I099",  # Rheumatic heart disease, unspecified
        "I110",  # Hypertensive heart disease with heart failure
        "I119",  # Hypertensive heart disease without heart failure
        "I150",  # Renovascular hypertension
        "I151",  # Hypertension secondary to other renal disorders
        "I152",  # Hypertension secondary to endocrine disorders
        "I158",  # Other secondary hypertension
        "I159",  # Secondary hypertension, unspecified
        "I160",  # Hypertensive urgency
        "I161",  # Hypertensive emergency
        "I169",  # Hypertensive crisis, unspecified
        "I1A0",  # Resistant hypertension
        "I200",  # Unstable angina
        "I201",  # Angina pectoris with documented spasm
        "I202",  # Refractory angina pectoris
        "I2081",  # Angina pectoris with coronary microvascular dysfunction
        "I2089",  # Other forms of angina pectoris
        "I209",  # Angina pectoris, unspecified
        "I2510",  # Atherosclerotic heart disease of native coronary artery without angina pectoris
        "I25110",  # Atherosclerotic heart disease of native coronary artery with unstable angina pectoris
        "I25111",  # Atherosclerotic heart disease of native coronary artery with angina pectoris with documented spasm
        "I25112",  # Atherosclerotic heart disease of native coronary artery with refractory angina pectoris
        "I25118",  # Atherosclerotic heart disease of native coronary artery with other forms of angina pectoris
        "I25119",  # Atherosclerotic heart disease of native coronary artery with unspecified angina pectoris
        "I252",  # Old myocardial infarction
        "I253",  # Aneurysm of heart
        "I2541",  # Coronary artery aneurysm
        "I2542",  # Coronary artery dissection
        "I255",  # Ischemic cardiomyopathy
        "I256",  # Silent myocardial ischemia
        "I25700",  # Atherosclerosis of coronary artery bypass graft(s), unspecified, with unstable angina pectoris
        "I25701",  # Atherosclerosis of coronary artery bypass graft(s), unspecified, with angina pectoris with documented spasm
        "I25702",  # Atherosclerosis of coronary artery bypass graft(s), unspecified, with refractory angina pectoris
        "I25708",  # Atherosclerosis of coronary artery bypass graft(s), unspecified, with other forms of angina pectoris
        "I25709",  # Atherosclerosis of coronary artery bypass graft(s), unspecified, with unspecified angina pectoris
        "I25710",  # Atherosclerosis of autologous vein coronary artery bypass graft(s) with unstable angina pectoris
        "I25711",  # Atherosclerosis of autologous vein coronary artery bypass graft(s) with angina pectoris with documented spasm
        "I25712",  # Atherosclerosis of autologous vein coronary artery bypass graft(s) with refractory angina pectoris
        "I25718",  # Atherosclerosis of autologous vein coronary artery bypass graft(s) with other forms of angina pectoris
        "I25719",  # Atherosclerosis of autologous vein coronary artery bypass graft(s) with unspecified angina pectoris
        "I25720",  # Atherosclerosis of autologous artery coronary artery bypass graft(s) with unstable angina pectoris
        "I25721",  # Atherosclerosis of autologous artery coronary artery bypass graft(s) with angina pectoris with documented spasm
        "I25722",  # Atherosclerosis of autologous artery coronary artery bypass graft(s) with refractory angina pectoris
        "I25728",  # Atherosclerosis of autologous artery coronary artery bypass graft(s) with other forms of angina pectoris
        "I25729",  # Atherosclerosis of autologous artery coronary artery bypass graft(s) with unspecified angina pectoris
        "I25730",  # Atherosclerosis of nonautologous biological coronary artery bypass graft(s) with unstable angina pectoris
        "I25731",  # Atherosclerosis of nonautologous biological coronary artery bypass graft(s) with angina pectoris with documented spasm
        "I25732",  # Atherosclerosis of nonautologous biological coronary artery bypass graft(s) with refractory angina pectoris
        "I25738",  # Atherosclerosis of nonautologous biological coronary artery bypass graft(s) with other forms of angina pectoris
        "I25739",  # Atherosclerosis of nonautologous biological coronary artery bypass graft(s) with unspecified angina pectoris
        "I25750",  # Atherosclerosis of native coronary artery of transplanted heart with unstable angina
        "I25751",  # Atherosclerosis of native coronary artery of transplanted heart with angina pectoris with documented spasm
        "I25752",  # Atherosclerosis of native coronary artery of transplanted heart with refractory angina pectoris
        "I25758",  # Atherosclerosis of native coronary artery of transplanted heart with other forms of angina pectoris
        "I25759",  # Atherosclerosis of native coronary artery of transplanted heart with unspecified angina pectoris
        "I25760",  # Atherosclerosis of bypass graft of coronary artery of transplanted heart with unstable angina
        "I25761",  # Atherosclerosis of bypass graft of coronary artery of transplanted heart with angina pectoris with documented spasm
        "I25762",  # Atherosclerosis of bypass graft of coronary artery of transplanted heart with refractory angina pectoris
        "I25768",  # Atherosclerosis of bypass graft of coronary artery of transplanted heart with other forms of angina pectoris
        "I25769",  # Atherosclerosis of bypass graft of coronary artery of transplanted heart with unspecified angina pectoris
        "I25790",  # Atherosclerosis of other coronary artery bypass graft(s) with unstable angina pectoris
        "I25791",  # Atherosclerosis of other coronary artery bypass graft(s) with angina pectoris with documented spasm
        "I25792",  # Atherosclerosis of other coronary artery bypass graft(s) with refractory angina pectoris
        "I25798",  # Atherosclerosis of other coronary artery bypass graft(s) with other forms of angina pectoris
        "I25799",  # Atherosclerosis of other coronary artery bypass graft(s) with unspecified angina pectoris
        "I25810",  # Atherosclerosis of coronary artery bypass graft(s) without angina pectoris
        "I25811",  # Atherosclerosis of native coronary artery of transplanted heart without angina pectoris
        "I25812",  # Atherosclerosis of bypass graft of coronary artery of transplanted heart without angina pectoris
        "I2582",  # Chronic total occlusion of coronary artery
        "I2583",  # Coronary atherosclerosis due to lipid rich plaque
        "I2584",  # Coronary atherosclerosis due to calcified coronary lesion
        "I2585",  # Chronic coronary microvascular dysfunction
        "I2589",  # Other forms of chronic ischemic heart disease
        "I259",  # Chronic ischemic heart disease, unspecified
        "I2781",  # Cor pulmonale (chronic)
        "I2782",  # Chronic pulmonary embolism
        "I2783",  # Eisenmenger's syndrome
        "I2789",  # Other specified pulmonary heart diseases
        "I300",  # Acute nonspecific idiopathic pericarditis
        "I301",  # Infective pericarditis
        "I308",  # Other forms of acute pericarditis
        "I309",  # Acute pericarditis, unspecified
        "I310",  # Chronic adhesive pericarditis
        "I311",  # Chronic constrictive pericarditis
        "I312",  # Hemopericardium, not elsewhere classified
        "I3131",  # Malignant pericardial effusion in diseases classified elsewhere
        "I3139",  # Other pericardial effusion (noninflammatory)
        "I314",  # Cardiac tamponade
        "I318",  # Other specified diseases of pericardium
        "I319",  # Disease of pericardium, unspecified
        "I32",  # Pericarditis in diseases classified elsewhere
        "I330",  # Acute and subacute infective endocarditis
        "I339",  # Acute and subacute endocarditis, unspecified
        "I340",  # Nonrheumatic mitral (valve) insufficiency
        "I341",  # Nonrheumatic mitral (valve) prolapse
        "I342",  # Nonrheumatic mitral (valve) stenosis
        "I3481",  # Nonrheumatic mitral (valve) annulus calcification
        "I3489",  # Other nonrheumatic mitral valve disorders
        "I349",  # Nonrheumatic mitral valve disorder, unspecified
        "I350",  # Nonrheumatic aortic (valve) stenosis
        "I351",  # Nonrheumatic aortic (valve) insufficiency
        "I352",  # Nonrheumatic aortic (valve) stenosis with insufficiency
        "I358",  # Other nonrheumatic aortic valve disorders
        "I359",  # Nonrheumatic aortic valve disorder, unspecified
        "I360",  # Nonrheumatic tricuspid (valve) stenosis
        "I361",  # Nonrheumatic tricuspid (valve) insufficiency
        "I362",  # Nonrheumatic tricuspid (valve) stenosis with insufficiency
        "I368",  # Other nonrheumatic tricuspid valve disorders
        "I369",  # Nonrheumatic tricuspid valve disorder, unspecified
        "I370",  # Nonrheumatic pulmonary valve stenosis
        "I371",  # Nonrheumatic pulmonary valve insufficiency
        "I372",  # Nonrheumatic pulmonary valve stenosis with insufficiency
        "I378",  # Other nonrheumatic pulmonary valve disorders
        "I379",  # Nonrheumatic pulmonary valve disorder, unspecified
        "I38",  # Endocarditis, valve unspecified
        "I39",  # Endocarditis and heart valve disorders in diseases classified elsewhere
        "I400",  # Infective myocarditis
        "I401",  # Isolated myocarditis
        "I408",  # Other acute myocarditis
        "I409",  # Acute myocarditis, unspecified
        "I41",  # Myocarditis in diseases classified elsewhere
        "I43",  # Cardiomyopathy in diseases classified elsewhere
        "I440",  # Atrioventricular block, first degree
        "I441",  # Atrioventricular block, second degree
        "I442",  # Atrioventricular block, complete
        "I4430",  # Unspecified atrioventricular block
        "I4439",  # Other atrioventricular block
        "I444",  # Left anterior fascicular block
        "I445",  # Left posterior fascicular block
        "I4460",  # Unspecified fascicular block
        "I4469",  # Other fascicular block
        "I447",  # Left bundle-branch block, unspecified
        "I450",  # Right fascicular block
        "I4510",  # Unspecified right bundle-branch block
        "I4519",  # Other right bundle-branch block
        "I452",  # Bifascicular block
        "I453",  # Trifascicular block
        "I454",  # Nonspecific intraventricular block
        "I455",  # Other specified heart block
        "I456",  # Pre-excitation syndrome
        "I4581",  # Long QT syndrome
        "I4589",  # Other specified conduction disorders
        "I459",  # Conduction disorder, unspecified
        "I462",  # Cardiac arrest due to underlying cardiac condition
        "I468",  # Cardiac arrest due to other underlying condition
        "I469",  # Cardiac arrest, cause unspecified
        "I470",  # Re-entry ventricular arrhythmia
        "I4710",  # Supraventricular tachycardia, unspecified
        "I4711",  # Inappropriate sinus tachycardia, so stated
        "I4719",  # Other supraventricular tachycardia
        "I4720",  # Ventricular tachycardia, unspecified
        "I4721",  # Torsades de pointes
        "I4729",  # Other ventricular tachycardia
        "I479",  # Paroxysmal tachycardia, unspecified
        "I480",  # Paroxysmal atrial fibrillation
        "I4811",  # Longstanding persistent atrial fibrillation
        "I4819",  # Other persistent atrial fibrillation
        "I4820",  # Chronic atrial fibrillation, unspecified
        "I4821",  # Permanent atrial fibrillation
        "I483",  # Typical atrial flutter
        "I484",  # Atypical atrial flutter
        "I4891",  # Unspecified atrial fibrillation
        "I4892",  # Unspecified atrial flutter
        "I4901",  # Ventricular fibrillation
        "I4902",  # Ventricular flutter
        "I491",  # Atrial premature depolarization
        "I492",  # Junctional premature depolarization
        "I493",  # Ventricular premature depolarization
        "I4940",  # Unspecified premature depolarization
        "I4949",  # Other premature depolarization
        "I495",  # Sick sinus syndrome
        "I498",  # Other specified cardiac arrhythmias
        "I499",  # Cardiac arrhythmia, unspecified
        "I5022",  # Chronic systolic (congestive) heart failure
        "I5023",  # Acute on chronic systolic (congestive) heart failure
        "I5032",  # Chronic diastolic (congestive) heart failure
        "I5033",  # Acute on chronic diastolic (congestive) heart failure
        "I5042",  # Chronic combined systolic (congestive) and diastolic (congestive) heart failure
        "I5043",  # Acute on chronic combined systolic (congestive) and diastolic (congestive) heart failure
        "I50812",  # Chronic right heart failure
        "I50813",  # Acute on chronic right heart failure
        "I50814",  # Right heart failure due to left heart failure
        "I5082",  # Biventricular heart failure
        "I5083",  # High output heart failure
        "I5084",  # End stage heart failure
        "I5089",  # Other heart failure
        "I509",  # Heart failure, unspecified
        "I52",  # Other heart disorders in diseases classified elsewhere
        "I5A",  # Non-ischemic myocardial injury (non-traumatic)
        "O99411",  # Diseases of the circulatory system complicating pregnancy, first trimester
        "O99412",  # Diseases of the circulatory system complicating pregnancy, second trimester
        "O99413",  # Diseases of the circulatory system complicating pregnancy, third trimester
        "O99419",  # Diseases of the circulatory system complicating pregnancy, unspecified trimester
        "O9942",  # Diseases of the circulatory system complicating childbirth
        "Q200",  # Common arterial trunk
        "Q201",  # Double outlet right ventricle
        "Q202",  # Double outlet left ventricle
        "Q203",  # Discordant ventriculoarterial connection
        "Q204",  # Double inlet ventricle
        "Q205",  # Discordant atrioventricular connection
        "Q206",  # Isomerism of atrial appendages
        "Q208",  # Other congenital malformations of cardiac chambers and connections
        "Q209",  # Congenital malformation of cardiac chambers and connections, unspecified
        "Q210",  # Ventricular septal defect
        "Q2110",  # Atrial septal defect, unspecified
        "Q2111",  # Secundum atrial septal defect
        "Q2112",  # Patent foramen ovale
        "Q2113",  # Coronary sinus atrial septal defect
        "Q2114",  # Superior sinus venosus atrial septal defect
        "Q2115",  # Inferior sinus venosus atrial septal defect
        "Q2116",  # Sinus venosus atrial septal defect, unspecified
        "Q2119",  # Other specified atrial septal defect
        "Q2120",  # Atrioventricular septal defect, unspecified as to partial or complete
        "Q2121",  # Partial atrioventricular septal defect
        "Q2122",  # Transitional atrioventricular septal defect
        "Q2123",  # Complete atrioventricular septal defect
        "Q213",  # Tetralogy of Fallot
        "Q214",  # Aortopulmonary septal defect
        "Q218",  # Other congenital malformations of cardiac septa
        "Q219",  # Congenital malformation of cardiac septum, unspecified
        "Q220",  # Pulmonary valve atresia
        "Q221",  # Congenital pulmonary valve stenosis
        "Q222",  # Congenital pulmonary valve insufficiency
        "Q223",  # Other congenital malformations of pulmonary valve
        "Q224",  # Congenital tricuspid stenosis
        "Q225",  # Ebstein's anomaly
        "Q226",  # Hypoplastic right heart syndrome
        "Q228",  # Other congenital malformations of tricuspid valve
        "Q229",  # Congenital malformation of tricuspid valve, unspecified
        "Q230",  # Congenital stenosis of aortic valve
        "Q231",  # Congenital insufficiency of aortic valve
        "Q232",  # Congenital mitral stenosis
        "Q233",  # Congenital mitral insufficiency
        "Q234",  # Hypoplastic left heart syndrome
        "Q2381",  # Bicuspid aortic valve
        "Q2382",  # Congenital mitral valve cleft leaflet
        "Q2388",  # Other congenital malformations of aortic and mitral valves
        "Q239",  # Congenital malformation of aortic and mitral valves, unspecified
        "Q240",  # Dextrocardia
        "Q241",  # Levocardia
        "Q242",  # Cor triatriatum
        "Q243",  # Pulmonary infundibular stenosis
        "Q244",  # Congenital subaortic stenosis
        "Q245",  # Malformation of coronary vessels
        "Q246",  # Congenital heart block
        "Q248",  # Other specified congenital malformations of heart
        "Q249",  # Congenital malformation of heart, unspecified
    }

class DisseminatedIntravascularCoagulation(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to identify diagnoses of disseminated intravascular coagulation (DIC).

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of disseminated intravascular coagulation (DIC).

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Disseminated Intravascular Coagulation"
    OID = "2.16.840.1.113762.1.4.1029.223"
    DEFINITION_VERSION = "20230217"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "D65",  # Disseminated intravascular coagulation [defibrination syndrome]
        "D688",  # Other specified coagulation defects
        "D689",  # Coagulation defect, unspecified
        "O45002",  # Premature separation of placenta with coagulation defect, unspecified, second trimester
        "O45003",  # Premature separation of placenta with coagulation defect, unspecified, third trimester
        "O45009",  # Premature separation of placenta with coagulation defect, unspecified, unspecified trimester
        "O45012",  # Premature separation of placenta with afibrinogenemia, second trimester
        "O45013",  # Premature separation of placenta with afibrinogenemia, third trimester
        "O45019",  # Premature separation of placenta with afibrinogenemia, unspecified trimester
        "O45022",  # Premature separation of placenta with disseminated intravascular coagulation, second trimester
        "O45023",  # Premature separation of placenta with disseminated intravascular coagulation, third trimester
        "O45029",  # Premature separation of placenta with disseminated intravascular coagulation, unspecified trimester
        "O45092",  # Premature separation of placenta with other coagulation defect, second trimester
        "O45093",  # Premature separation of placenta with other coagulation defect, third trimester
        "O45099",  # Premature separation of placenta with other coagulation defect, unspecified trimester
        "O46002",  # Antepartum hemorrhage with coagulation defect, unspecified, second trimester
        "O46003",  # Antepartum hemorrhage with coagulation defect, unspecified, third trimester
        "O46009",  # Antepartum hemorrhage with coagulation defect, unspecified, unspecified trimester
        "O46012",  # Antepartum hemorrhage with afibrinogenemia, second trimester
        "O46013",  # Antepartum hemorrhage with afibrinogenemia, third trimester
        "O46019",  # Antepartum hemorrhage with afibrinogenemia, unspecified trimester
        "O46022",  # Antepartum hemorrhage with disseminated intravascular coagulation, second trimester
        "O46023",  # Antepartum hemorrhage with disseminated intravascular coagulation, third trimester
        "O46029",  # Antepartum hemorrhage with disseminated intravascular coagulation, unspecified trimester
        "O46092",  # Antepartum hemorrhage with other coagulation defect, second trimester
        "O46093",  # Antepartum hemorrhage with other coagulation defect, third trimester
        "O46099",  # Antepartum hemorrhage with other coagulation defect, unspecified trimester
        "O670",  # Intrapartum hemorrhage with coagulation defect
    }

class Eclampsia(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to identify diagnoses of eclampsia.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of an eclampsia.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Eclampsia"
    OID = "2.16.840.1.113762.1.4.1029.225"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "O1500",  # Eclampsia complicating pregnancy, unspecified trimester
        "O1502",  # Eclampsia complicating pregnancy, second trimester
        "O1503",  # Eclampsia complicating pregnancy, third trimester
        "O151",  # Eclampsia complicating labor
        "O152",  # Eclampsia complicating the puerperium
        "O159",  # Eclampsia, unspecified as to time period
    }

class EconomicHousingInstability(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of economic housing instability.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of an economic housing instability.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Economic Housing Instability"
    OID = "2.16.840.1.113762.1.4.1029.292"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "Z5900",  # Homelessness unspecified
        "Z5901",  # Sheltered homelessness
        "Z5902",  # Unsheltered homelessness
        "Z5910",  # Inadequate housing, unspecified
        "Z5911",  # Inadequate housing environmental temperature
        "Z5912",  # Inadequate housing utilities
        "Z5919",  # Other inadequate housing
        "Z592",  # Discord with neighbors, lodgers and landlord
        "Z593",  # Problems related to living in residential institution
        "Z5941",  # Food insecurity
        "Z5948",  # Other specified lack of adequate food
        "Z595",  # Extreme poverty
        "Z596",  # Low income
        "Z5971",  # Insufficient health insurance coverage
        "Z5972",  # Insufficient welfare support
        "Z59811",  # Housing instability, housed, with risk of homelessness
        "Z59812",  # Housing instability, housed, homelessness in past 12 months
        "Z59819",  # Housing instability, housed unspecified
        "Z5982",  # Transportation insecurity
        "Z5986",  # Financial insecurity
        "Z5987",  # Material hardship due to limited financial resources, not elsewhere classified
        "Z5989",  # Other problems related to housing and economic circumstances
        "Z599",  # Problem related to housing and economic circumstances, unspecified
    }

class GastrointestinalDisease(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of gastrointestinal diseases.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of a gastrointestinal disease.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Gastrointestinal Disease"
    OID = "2.16.840.1.113762.1.4.1029.338"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "K5000",  # Crohn's disease of small intestine without complications
        "K50011",  # Crohn's disease of small intestine with rectal bleeding
        "K50012",  # Crohn's disease of small intestine with intestinal obstruction
        "K50013",  # Crohn's disease of small intestine with fistula
        "K50014",  # Crohn's disease of small intestine with abscess
        "K50018",  # Crohn's disease of small intestine with other complication
        "K50019",  # Crohn's disease of small intestine with unspecified complications
        "K5010",  # Crohn's disease of large intestine without complications
        "K50111",  # Crohn's disease of large intestine with rectal bleeding
        "K50112",  # Crohn's disease of large intestine with intestinal obstruction
        "K50113",  # Crohn's disease of large intestine with fistula
        "K50114",  # Crohn's disease of large intestine with abscess
        "K50118",  # Crohn's disease of large intestine with other complication
        "K50119",  # Crohn's disease of large intestine with unspecified complications
        "K5080",  # Crohn's disease of both small and large intestine without complications
        "K50811",  # Crohn's disease of both small and large intestine with rectal bleeding
        "K50812",  # Crohn's disease of both small and large intestine with intestinal obstruction
        "K50813",  # Crohn's disease of both small and large intestine with fistula
        "K50814",  # Crohn's disease of both small and large intestine with abscess
        "K50818",  # Crohn's disease of both small and large intestine with other complication
        "K50819",  # Crohn's disease of both small and large intestine with unspecified complications
        "K5090",  # Crohn's disease, unspecified, without complications
        "K50911",  # Crohn's disease, unspecified, with rectal bleeding
        "K50912",  # Crohn's disease, unspecified, with intestinal obstruction
        "K50913",  # Crohn's disease, unspecified, with fistula
        "K50914",  # Crohn's disease, unspecified, with abscess
        "K50918",  # Crohn's disease, unspecified, with other complication
        "K50919",  # Crohn's disease, unspecified, with unspecified complications
        "K5100",  # Ulcerative (chronic) pancolitis without complications
        "K51011",  # Ulcerative (chronic) pancolitis with rectal bleeding
        "K51012",  # Ulcerative (chronic) pancolitis with intestinal obstruction
        "K51013",  # Ulcerative (chronic) pancolitis with fistula
        "K51014",  # Ulcerative (chronic) pancolitis with abscess
        "K51018",  # Ulcerative (chronic) pancolitis with other complication
        "K51019",  # Ulcerative (chronic) pancolitis with unspecified complications
        "K5120",  # Ulcerative (chronic) proctitis without complications
        "K51211",  # Ulcerative (chronic) proctitis with rectal bleeding
        "K51212",  # Ulcerative (chronic) proctitis with intestinal obstruction
        "K51213",  # Ulcerative (chronic) proctitis with fistula
        "K51214",  # Ulcerative (chronic) proctitis with abscess
        "K51218",  # Ulcerative (chronic) proctitis with other complication
        "K51219",  # Ulcerative (chronic) proctitis with unspecified complications
        "K5130",  # Ulcerative (chronic) rectosigmoiditis without complications
        "K51311",  # Ulcerative (chronic) rectosigmoiditis with rectal bleeding
        "K51312",  # Ulcerative (chronic) rectosigmoiditis with intestinal obstruction
        "K51313",  # Ulcerative (chronic) rectosigmoiditis with fistula
        "K51314",  # Ulcerative (chronic) rectosigmoiditis with abscess
        "K51318",  # Ulcerative (chronic) rectosigmoiditis with other complication
        "K51319",  # Ulcerative (chronic) rectosigmoiditis with unspecified complications
        "K5140",  # Inflammatory polyps of colon without complications
        "K51411",  # Inflammatory polyps of colon with rectal bleeding
        "K51412",  # Inflammatory polyps of colon with intestinal obstruction
        "K51413",  # Inflammatory polyps of colon with fistula
        "K51414",  # Inflammatory polyps of colon with abscess
        "K51418",  # Inflammatory polyps of colon with other complication
        "K51419",  # Inflammatory polyps of colon with unspecified complications
        "K5150",  # Left sided colitis without complications
        "K51511",  # Left sided colitis with rectal bleeding
        "K51512",  # Left sided colitis with intestinal obstruction
        "K51513",  # Left sided colitis with fistula
        "K51514",  # Left sided colitis with abscess
        "K51518",  # Left sided colitis with other complication
        "K51519",  # Left sided colitis with unspecified complications
        "K5180",  # Other ulcerative colitis without complications
        "K51811",  # Other ulcerative colitis with rectal bleeding
        "K51812",  # Other ulcerative colitis with intestinal obstruction
        "K51813",  # Other ulcerative colitis with fistula
        "K51814",  # Other ulcerative colitis with abscess
        "K51818",  # Other ulcerative colitis with other complication
        "K51819",  # Other ulcerative colitis with unspecified complications
        "K5190",  # Ulcerative colitis, unspecified, without complications
        "K51911",  # Ulcerative colitis, unspecified with rectal bleeding
        "K51912",  # Ulcerative colitis, unspecified with intestinal obstruction
        "K51913",  # Ulcerative colitis, unspecified with fistula
        "K51914",  # Ulcerative colitis, unspecified with abscess
        "K51918",  # Ulcerative colitis, unspecified with other complication
        "K51919",  # Ulcerative colitis, unspecified with unspecified complications
        "K520",  # Gastroenteritis and colitis due to radiation
        "K521",  # Toxic gastroenteritis and colitis
        "K5221",  # Food protein-induced enterocolitis syndrome
        "K5222",  # Food protein-induced enteropathy
        "K5229",  # Other allergic and dietetic gastroenteritis and colitis
        "K523",  # Indeterminate colitis
        "K5281",  # Eosinophilic gastritis or gastroenteritis
        "K5282",  # Eosinophilic colitis
        "K52831",  # Collagenous colitis
        "K52832",  # Lymphocytic colitis
        "K52838",  # Other microscopic colitis
        "K52839",  # Microscopic colitis, unspecified
        "K5289",  # Other specified noninfective gastroenteritis and colitis
        "K529",  # Noninfective gastroenteritis and colitis, unspecified
        "K700",  # Alcoholic fatty liver
        "K7010",  # Alcoholic hepatitis without ascites
        "K7011",  # Alcoholic hepatitis with ascites
        "K702",  # Alcoholic fibrosis and sclerosis of liver
        "K7030",  # Alcoholic cirrhosis of liver without ascites
        "K7031",  # Alcoholic cirrhosis of liver with ascites
        "K7040",  # Alcoholic hepatic failure without coma
        "K7041",  # Alcoholic hepatic failure with coma
        "K709",  # Alcoholic liver disease, unspecified
        "K710",  # Toxic liver disease with cholestasis
        "K7110",  # Toxic liver disease with hepatic necrosis, without coma
        "K7111",  # Toxic liver disease with hepatic necrosis, with coma
        "K712",  # Toxic liver disease with acute hepatitis
        "K713",  # Toxic liver disease with chronic persistent hepatitis
        "K714",  # Toxic liver disease with chronic lobular hepatitis
        "K7150",  # Toxic liver disease with chronic active hepatitis without ascites
        "K7151",  # Toxic liver disease with chronic active hepatitis with ascites
        "K716",  # Toxic liver disease with hepatitis, not elsewhere classified
        "K717",  # Toxic liver disease with fibrosis and cirrhosis of liver
        "K718",  # Toxic liver disease with other disorders of liver
        "K719",  # Toxic liver disease, unspecified
        "K7200",  # Acute and subacute hepatic failure without coma
        "K7201",  # Acute and subacute hepatic failure with coma
        "K7210",  # Chronic hepatic failure without coma
        "K7211",  # Chronic hepatic failure with coma
        "K7290",  # Hepatic failure, unspecified without coma
        "K7291",  # Hepatic failure, unspecified with coma
        "K730",  # Chronic persistent hepatitis, not elsewhere classified
        "K731",  # Chronic lobular hepatitis, not elsewhere classified
        "K732",  # Chronic active hepatitis, not elsewhere classified
        "K738",  # Other chronic hepatitis, not elsewhere classified
        "K739",  # Chronic hepatitis, unspecified
        "K7400",  # Hepatic fibrosis, unspecified
        "K7401",  # Hepatic fibrosis, early fibrosis
        "K7402",  # Hepatic fibrosis, advanced fibrosis
        "K741",  # Hepatic sclerosis
        "K742",  # Hepatic fibrosis with hepatic sclerosis
        "K743",  # Primary biliary cirrhosis
        "K744",  # Secondary biliary cirrhosis
        "K745",  # Biliary cirrhosis, unspecified
        "K7460",  # Unspecified cirrhosis of liver
        "K7469",  # Other cirrhosis of liver
        "K750",  # Abscess of liver
        "K751",  # Phlebitis of portal vein
        "K752",  # Nonspecific reactive hepatitis
        "K753",  # Granulomatous hepatitis, not elsewhere classified
        "K754",  # Autoimmune hepatitis
        "K7581",  # Nonalcoholic steatohepatitis (NASH)
        "K7589",  # Other specified inflammatory liver diseases
        "K759",  # Inflammatory liver disease, unspecified
        "K760",  # Fatty (change of) liver, not elsewhere classified
        "K761",  # Chronic passive congestion of liver
        "K762",  # Central hemorrhagic necrosis of liver
        "K763",  # Infarction of liver
        "K764",  # Peliosis hepatis
        "K765",  # Hepatic veno-occlusive disease
        "K766",  # Portal hypertension
        "K767",  # Hepatorenal syndrome
        "K7681",  # Hepatopulmonary syndrome
        "K7682",  # Hepatic encephalopathy
        "K7689",  # Other specified diseases of liver
        "K769",  # Liver disease, unspecified
        "K77",  # Liver disorders in diseases classified elsewhere
        "K8000",  # Calculus of gallbladder with acute cholecystitis without obstruction
        "K8001",  # Calculus of gallbladder with acute cholecystitis with obstruction
        "K8010",  # Calculus of gallbladder with chronic cholecystitis without obstruction
        "K8011",  # Calculus of gallbladder with chronic cholecystitis with obstruction
        "K8012",  # Calculus of gallbladder with acute and chronic cholecystitis without obstruction
        "K8013",  # Calculus of gallbladder with acute and chronic cholecystitis with obstruction
        "K8018",  # Calculus of gallbladder with other cholecystitis without obstruction
        "K8019",  # Calculus of gallbladder with other cholecystitis with obstruction
        "K8020",  # Calculus of gallbladder without cholecystitis without obstruction
        "K8021",  # Calculus of gallbladder without cholecystitis with obstruction
        "K8030",  # Calculus of bile duct with cholangitis, unspecified, without obstruction
        "K8031",  # Calculus of bile duct with cholangitis, unspecified, with obstruction
        "K8032",  # Calculus of bile duct with acute cholangitis without obstruction
        "K8033",  # Calculus of bile duct with acute cholangitis with obstruction
        "K8034",  # Calculus of bile duct with chronic cholangitis without obstruction
        "K8035",  # Calculus of bile duct with chronic cholangitis with obstruction
        "K8036",  # Calculus of bile duct with acute and chronic cholangitis without obstruction
        "K8037",  # Calculus of bile duct with acute and chronic cholangitis with obstruction
        "K8040",  # Calculus of bile duct with cholecystitis, unspecified, without obstruction
        "K8041",  # Calculus of bile duct with cholecystitis, unspecified, with obstruction
        "K8042",  # Calculus of bile duct with acute cholecystitis without obstruction
        "K8043",  # Calculus of bile duct with acute cholecystitis with obstruction
        "K8044",  # Calculus of bile duct with chronic cholecystitis without obstruction
        "K8045",  # Calculus of bile duct with chronic cholecystitis with obstruction
        "K8046",  # Calculus of bile duct with acute and chronic cholecystitis without obstruction
        "K8047",  # Calculus of bile duct with acute and chronic cholecystitis with obstruction
        "K8050",  # Calculus of bile duct without cholangitis or cholecystitis without obstruction
        "K8051",  # Calculus of bile duct without cholangitis or cholecystitis with obstruction
        "K8060",  # Calculus of gallbladder and bile duct with cholecystitis, unspecified, without obstruction
        "K8061",  # Calculus of gallbladder and bile duct with cholecystitis, unspecified, with obstruction
        "K8062",  # Calculus of gallbladder and bile duct with acute cholecystitis without obstruction
        "K8063",  # Calculus of gallbladder and bile duct with acute cholecystitis with obstruction
        "K8064",  # Calculus of gallbladder and bile duct with chronic cholecystitis without obstruction
        "K8065",  # Calculus of gallbladder and bile duct with chronic cholecystitis with obstruction
        "K8066",  # Calculus of gallbladder and bile duct with acute and chronic cholecystitis without obstruction
        "K8067",  # Calculus of gallbladder and bile duct with acute and chronic cholecystitis with obstruction
        "K8070",  # Calculus of gallbladder and bile duct without cholecystitis without obstruction
        "K8071",  # Calculus of gallbladder and bile duct without cholecystitis with obstruction
        "K8080",  # Other cholelithiasis without obstruction
        "K8081",  # Other cholelithiasis with obstruction
        "K810",  # Acute cholecystitis
        "K811",  # Chronic cholecystitis
        "K812",  # Acute cholecystitis with chronic cholecystitis
        "K819",  # Cholecystitis, unspecified
        "K820",  # Obstruction of gallbladder
        "K821",  # Hydrops of gallbladder
        "K822",  # Perforation of gallbladder
        "K823",  # Fistula of gallbladder
        "K824",  # Cholesterolosis of gallbladder
        "K828",  # Other specified diseases of gallbladder
        "K829",  # Disease of gallbladder, unspecified
        "K82A1",  # Gangrene of gallbladder in cholecystitis
        "K82A2",  # Perforation of gallbladder in cholecystitis
        "K8301",  # Primary sclerosing cholangitis
        "K8309",  # Other cholangitis
        "K831",  # Obstruction of bile duct
        "K832",  # Perforation of bile duct
        "K833",  # Fistula of bile duct
        "K834",  # Spasm of sphincter of Oddi
        "K835",  # Biliary cyst
        "K838",  # Other specified diseases of biliary tract
        "K839",  # Disease of biliary tract, unspecified
        "K8500",  # Idiopathic acute pancreatitis without necrosis or infection
        "K8501",  # Idiopathic acute pancreatitis with uninfected necrosis
        "K8502",  # Idiopathic acute pancreatitis with infected necrosis
        "K8510",  # Biliary acute pancreatitis without necrosis or infection
        "K8511",  # Biliary acute pancreatitis with uninfected necrosis
        "K8512",  # Biliary acute pancreatitis with infected necrosis
        "K8520",  # Alcohol induced acute pancreatitis without necrosis or infection
        "K8521",  # Alcohol induced acute pancreatitis with uninfected necrosis
        "K8522",  # Alcohol induced acute pancreatitis with infected necrosis
        "K8530",  # Drug induced acute pancreatitis without necrosis or infection
        "K8531",  # Drug induced acute pancreatitis with uninfected necrosis
        "K8532",  # Drug induced acute pancreatitis with infected necrosis
        "K8580",  # Other acute pancreatitis without necrosis or infection
        "K8581",  # Other acute pancreatitis with uninfected necrosis
        "K8582",  # Other acute pancreatitis with infected necrosis
        "K8590",  # Acute pancreatitis without necrosis or infection, unspecified
        "K8591",  # Acute pancreatitis with uninfected necrosis, unspecified
        "K8592",  # Acute pancreatitis with infected necrosis, unspecified
        "K860",  # Alcohol-induced chronic pancreatitis
        "K861",  # Other chronic pancreatitis
        "K862",  # Cyst of pancreas
        "K863",  # Pseudocyst of pancreas
        "K8681",  # Exocrine pancreatic insufficiency
        "K8689",  # Other specified diseases of pancreas
        "K869",  # Disease of pancreas, unspecified
        "K87",  # Disorders of gallbladder, biliary tract and pancreas in diseases classified elsewhere
        "K9400",  # Colostomy complication, unspecified
        "K9401",  # Colostomy hemorrhage
        "K9402",  # Colostomy infection
        "K9403",  # Colostomy malfunction
        "K9409",  # Other complications of colostomy
        "K9410",  # Enterostomy complication, unspecified
        "K9411",  # Enterostomy hemorrhage
        "K9412",  # Enterostomy infection
        "K9413",  # Enterostomy malfunction
        "K9419",  # Other complications of enterostomy
        "K9420",  # Gastrostomy complication, unspecified
        "K9421",  # Gastrostomy hemorrhage
        "K9422",  # Gastrostomy infection
        "K9423",  # Gastrostomy malfunction
        "K9429",  # Other complications of gastrostomy
        "K9430",  # Esophagostomy complications, unspecified
        "K9431",  # Esophagostomy hemorrhage
        "K9432",  # Esophagostomy infection
        "K9433",  # Esophagostomy malfunction
        "K9439",  # Other complications of esophagostomy
        "K9501",  # Infection due to gastric band procedure
        "K9509",  # Other complications of gastric band procedure
        "K9581",  # Infection due to other bariatric procedure
        "K9589",  # Other complications of other bariatric procedure
        "O26611",  # Liver and biliary tract disorders in pregnancy, first trimester
        "O26612",  # Liver and biliary tract disorders in pregnancy, second trimester
        "O26613",  # Liver and biliary tract disorders in pregnancy, third trimester
        "O26619",  # Liver and biliary tract disorders in pregnancy, unspecified trimester
        "O2662",  # Liver and biliary tract disorders in childbirth
        "O2663",  # Liver and biliary tract disorders in the puerperium
        "O26641",  # Intrahepatic cholestasis of pregnancy, first trimester
        "O26642",  # Intrahepatic cholestasis of pregnancy, second trimester
        "O26643",  # Intrahepatic cholestasis of pregnancy, third trimester
        "O26649",  # Intrahepatic cholestasis of pregnancy, unspecified trimester
    }

class GestationalDiabetes(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of gestational diabetes.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of gestational diabetes.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Gestational Diabetes"
    OID = "2.16.840.1.113762.1.4.1029.269"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "O24410",  # Gestational diabetes mellitus in pregnancy, diet controlled
        "O24414",  # Gestational diabetes mellitus in pregnancy, insulin controlled
        "O24415",  # Gestational diabetes mellitus in pregnancy, controlled by oral hypoglycemic drugs
        "O24419",  # Gestational diabetes mellitus in pregnancy, unspecified control
        "O24420",  # Gestational diabetes mellitus in childbirth, diet controlled
        "O24424",  # Gestational diabetes mellitus in childbirth, insulin controlled
        "O24425",  # Gestational diabetes mellitus in childbirth, controlled by oral hypoglycemic drugs
        "O24429",  # Gestational diabetes mellitus in childbirth, unspecified control
        "O24430",  # Gestational diabetes mellitus in the puerperium, diet controlled
        "O24434",  # Gestational diabetes mellitus in the puerperium, insulin controlled
        "O24435",  # Gestational diabetes mellitus in puerperium, controlled by oral hypoglycemic drugs
        "O24439",  # Gestational diabetes mellitus in the puerperium, unspecified control
    }

class HivInPregnancyChildbirthAndPuerperium(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of human immunodeficiency virus (HIV) during pregnancy, childbirth, and puerperium.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of human immunodeficiency virus (HIV).

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "HIV in Pregnancy Childbirth and Puerperium"
    OID = "2.16.840.1.113762.1.4.1029.272"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "B20",  # Human immunodeficiency virus [HIV] disease
        "O98711",  # Human immunodeficiency virus [HIV] disease complicating pregnancy, first trimester
        "O98712",  # Human immunodeficiency virus [HIV] disease complicating pregnancy, second trimester
        "O98713",  # Human immunodeficiency virus [HIV] disease complicating pregnancy, third trimester
        "O98719",  # Human immunodeficiency virus [HIV] disease complicating pregnancy, unspecified trimester
        "O9872",  # Human immunodeficiency virus [HIV] disease complicating childbirth
        "O9873",  # Human immunodeficiency virus [HIV] disease complicating the puerperium
    }

class HeartFailureCardiacArrestRelatedToProcedureOrSurgery(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to identify diagnoses of heart failure and cardiac arrest occurring during or post procedure.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of heart failure and cardiac arrest occurring during or post procedure.

    **Exclusion Criteria:** Excludes concepts of a diagnosis of heart failure or cardiac arrest not occurring during or post procedure.
    """

    VALUE_SET_NAME = "Heart Failure Cardiac Arrest Related to Procedure or Surgery"
    OID = "2.16.840.1.113762.1.4.1029.227"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "I97120",  # Postprocedural cardiac arrest following cardiac surgery
        "I97121",  # Postprocedural cardiac arrest following other surgery
        "I97130",  # Postprocedural heart failure following cardiac surgery
        "I97131",  # Postprocedural heart failure following other surgery
        "I97710",  # Intraoperative cardiac arrest during cardiac surgery
        "I97711",  # Intraoperative cardiac arrest during other surgery
    }

class Hypertension(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of pre-existing hypertension.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of pre-existing hypertension.

    **Exclusion Criteria:** Excludes concepts of a diagnosis of acute hypertension.
    """

    VALUE_SET_NAME = "Hypertension"
    OID = "2.16.840.1.113762.1.4.1029.332"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "I10",  # Essential (primary) hypertension
        "O10011",  # Pre-existing essential hypertension complicating pregnancy, first trimester
        "O10012",  # Pre-existing essential hypertension complicating pregnancy, second trimester
        "O10013",  # Pre-existing essential hypertension complicating pregnancy, third trimester
        "O10019",  # Pre-existing essential hypertension complicating pregnancy, unspecified trimester
        "O1002",  # Pre-existing essential hypertension complicating childbirth
        "O1003",  # Pre-existing essential hypertension complicating the puerperium
        "O10111",  # Pre-existing hypertensive heart disease complicating pregnancy, first trimester
        "O10112",  # Pre-existing hypertensive heart disease complicating pregnancy, second trimester
        "O10113",  # Pre-existing hypertensive heart disease complicating pregnancy, third trimester
        "O10119",  # Pre-existing hypertensive heart disease complicating pregnancy, unspecified trimester
        "O1012",  # Pre-existing hypertensive heart disease complicating childbirth
        "O1013",  # Pre-existing hypertensive heart disease complicating the puerperium
        "O10211",  # Pre-existing hypertensive chronic kidney disease complicating pregnancy, first trimester
        "O10212",  # Pre-existing hypertensive chronic kidney disease complicating pregnancy, second trimester
        "O10213",  # Pre-existing hypertensive chronic kidney disease complicating pregnancy, third trimester
        "O10219",  # Pre-existing hypertensive chronic kidney disease complicating pregnancy, unspecified trimester
        "O1022",  # Pre-existing hypertensive chronic kidney disease complicating childbirth
        "O1023",  # Pre-existing hypertensive chronic kidney disease complicating the puerperium
        "O10311",  # Pre-existing hypertensive heart and chronic kidney disease complicating pregnancy, first trimester
        "O10312",  # Pre-existing hypertensive heart and chronic kidney disease complicating pregnancy, second trimester
        "O10313",  # Pre-existing hypertensive heart and chronic kidney disease complicating pregnancy, third trimester
        "O10319",  # Pre-existing hypertensive heart and chronic kidney disease complicating pregnancy, unspecified trimester
        "O1032",  # Pre-existing hypertensive heart and chronic kidney disease complicating childbirth
        "O1033",  # Pre-existing hypertensive heart and chronic kidney disease complicating the puerperium
        "O10411",  # Pre-existing secondary hypertension complicating pregnancy, first trimester
        "O10412",  # Pre-existing secondary hypertension complicating pregnancy, second trimester
        "O10413",  # Pre-existing secondary hypertension complicating pregnancy, third trimester
        "O10419",  # Pre-existing secondary hypertension complicating pregnancy, unspecified trimester
        "O1042",  # Pre-existing secondary hypertension complicating childbirth
        "O1043",  # Pre-existing secondary hypertension complicating the puerperium
        "O10911",  # Unspecified pre-existing hypertension complicating pregnancy, first trimester
        "O10912",  # Unspecified pre-existing hypertension complicating pregnancy, second trimester
        "O10913",  # Unspecified pre-existing hypertension complicating pregnancy, third trimester
        "O10919",  # Unspecified pre-existing hypertension complicating pregnancy, unspecified trimester
        "O1092",  # Unspecified pre-existing hypertension complicating childbirth
        "O1093",  # Unspecified pre-existing hypertension complicating the puerperium
    }

class LongTermAnticoagulantUse(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses for long term use of anticoagulants.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis for current long term use of anticoagulants.

    **Exclusion Criteria:** Excludes concepts of a diagnosis of short term use or history of anticoagulants.
    """

    VALUE_SET_NAME = "Long Term Anticoagulant Use"
    OID = "2.16.840.1.113762.1.4.1029.366"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "Z7901",  # Long term (current) use of anticoagulants
    }

class MentalHealthDisorder(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of mental health disorders.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of a mental health disorder related to psychotic, nonpsychotic, and mood disorders.

    **Exclusion Criteria:** Excludes concepts of a diagnosis of mental disorders due to substance abuse, developmental disorders, and intellectual disabilities.
    """

    VALUE_SET_NAME = "Mental Health Disorder"
    OID = "2.16.840.1.113762.1.4.1029.314"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "F060",  # Psychotic disorder with hallucinations due to known physiological condition
        "F061",  # Catatonic disorder due to known physiological condition
        "F062",  # Psychotic disorder with delusions due to known physiological condition
        "F0630",  # Mood disorder due to known physiological condition, unspecified
        "F0631",  # Mood disorder due to known physiological condition with depressive features
        "F0632",  # Mood disorder due to known physiological condition with major depressive-like episode
        "F0633",  # Mood disorder due to known physiological condition with manic features
        "F0634",  # Mood disorder due to known physiological condition with mixed features
        "F064",  # Anxiety disorder due to known physiological condition
        "F0670",  # Mild neurocognitive disorder due to known physiological condition without behavioral disturbance
        "F0671",  # Mild neurocognitive disorder due to known physiological condition with behavioral disturbance
        "F068",  # Other specified mental disorders due to known physiological condition
        "F200",  # Paranoid schizophrenia
        "F201",  # Disorganized schizophrenia
        "F202",  # Catatonic schizophrenia
        "F203",  # Undifferentiated schizophrenia
        "F205",  # Residual schizophrenia
        "F2081",  # Schizophreniform disorder
        "F2089",  # Other schizophrenia
        "F209",  # Schizophrenia, unspecified
        "F21",  # Schizotypal disorder
        "F22",  # Delusional disorders
        "F23",  # Brief psychotic disorder
        "F24",  # Shared psychotic disorder
        "F250",  # Schizoaffective disorder, bipolar type
        "F251",  # Schizoaffective disorder, depressive type
        "F258",  # Other schizoaffective disorders
        "F259",  # Schizoaffective disorder, unspecified
        "F28",  # Other psychotic disorder not due to a substance or known physiological condition
        "F29",  # Unspecified psychosis not due to a substance or known physiological condition
        "F3010",  # Manic episode without psychotic symptoms, unspecified
        "F3011",  # Manic episode without psychotic symptoms, mild
        "F3012",  # Manic episode without psychotic symptoms, moderate
        "F3013",  # Manic episode, severe, without psychotic symptoms
        "F302",  # Manic episode, severe with psychotic symptoms
        "F303",  # Manic episode in partial remission
        "F304",  # Manic episode in full remission
        "F308",  # Other manic episodes
        "F309",  # Manic episode, unspecified
        "F310",  # Bipolar disorder, current episode hypomanic
        "F3110",  # Bipolar disorder, current episode manic without psychotic features, unspecified
        "F3111",  # Bipolar disorder, current episode manic without psychotic features, mild
        "F3112",  # Bipolar disorder, current episode manic without psychotic features, moderate
        "F3113",  # Bipolar disorder, current episode manic without psychotic features, severe
        "F312",  # Bipolar disorder, current episode manic severe with psychotic features
        "F3130",  # Bipolar disorder, current episode depressed, mild or moderate severity, unspecified
        "F3131",  # Bipolar disorder, current episode depressed, mild
        "F3132",  # Bipolar disorder, current episode depressed, moderate
        "F314",  # Bipolar disorder, current episode depressed, severe, without psychotic features
        "F315",  # Bipolar disorder, current episode depressed, severe, with psychotic features
        "F3160",  # Bipolar disorder, current episode mixed, unspecified
        "F3161",  # Bipolar disorder, current episode mixed, mild
        "F3162",  # Bipolar disorder, current episode mixed, moderate
        "F3163",  # Bipolar disorder, current episode mixed, severe, without psychotic features
        "F3164",  # Bipolar disorder, current episode mixed, severe, with psychotic features
        "F3170",  # Bipolar disorder, currently in remission, most recent episode unspecified
        "F3171",  # Bipolar disorder, in partial remission, most recent episode hypomanic
        "F3172",  # Bipolar disorder, in full remission, most recent episode hypomanic
        "F3173",  # Bipolar disorder, in partial remission, most recent episode manic
        "F3174",  # Bipolar disorder, in full remission, most recent episode manic
        "F3175",  # Bipolar disorder, in partial remission, most recent episode depressed
        "F3176",  # Bipolar disorder, in full remission, most recent episode depressed
        "F3177",  # Bipolar disorder, in partial remission, most recent episode mixed
        "F3178",  # Bipolar disorder, in full remission, most recent episode mixed
        "F3181",  # Bipolar II disorder
        "F3189",  # Other bipolar disorder
        "F319",  # Bipolar disorder, unspecified
        "F320",  # Major depressive disorder, single episode, mild
        "F321",  # Major depressive disorder, single episode, moderate
        "F322",  # Major depressive disorder, single episode, severe without psychotic features
        "F323",  # Major depressive disorder, single episode, severe with psychotic features
        "F324",  # Major depressive disorder, single episode, in partial remission
        "F325",  # Major depressive disorder, single episode, in full remission
        "F3281",  # Premenstrual dysphoric disorder
        "F3289",  # Other specified depressive episodes
        "F329",  # Major depressive disorder, single episode, unspecified
        "F32A",  # Depression, unspecified
        "F330",  # Major depressive disorder, recurrent, mild
        "F331",  # Major depressive disorder, recurrent, moderate
        "F332",  # Major depressive disorder, recurrent severe without psychotic features
        "F333",  # Major depressive disorder, recurrent, severe with psychotic symptoms
        "F3340",  # Major depressive disorder, recurrent, in remission, unspecified
        "F3341",  # Major depressive disorder, recurrent, in partial remission
        "F3342",  # Major depressive disorder, recurrent, in full remission
        "F338",  # Other recurrent depressive disorders
        "F339",  # Major depressive disorder, recurrent, unspecified
        "F340",  # Cyclothymic disorder
        "F341",  # Dysthymic disorder
        "F3481",  # Disruptive mood dysregulation disorder
        "F3489",  # Other specified persistent mood disorders
        "F349",  # Persistent mood [affective] disorder, unspecified
        "F39",  # Unspecified mood [affective] disorder
        "F4000",  # Agoraphobia, unspecified
        "F4001",  # Agoraphobia with panic disorder
        "F4002",  # Agoraphobia without panic disorder
        "F410",  # Panic disorder [episodic paroxysmal anxiety]
        "F411",  # Generalized anxiety disorder
        "F413",  # Other mixed anxiety disorders
        "F418",  # Other specified anxiety disorders
        "F419",  # Anxiety disorder, unspecified
        "F430",  # Acute stress reaction
        "F4310",  # Post-traumatic stress disorder, unspecified
        "F4311",  # Post-traumatic stress disorder, acute
        "F4312",  # Post-traumatic stress disorder, chronic
        "F4320",  # Adjustment disorder, unspecified
        "F4321",  # Adjustment disorder with depressed mood
        "F4322",  # Adjustment disorder with anxiety
        "F4323",  # Adjustment disorder with mixed anxiety and depressed mood
        "F4324",  # Adjustment disorder with disturbance of conduct
        "F4325",  # Adjustment disorder with mixed disturbance of emotions and conduct
        "F4329",  # Adjustment disorder with other symptoms
        "F4381",  # Prolonged grief disorder
        "F4389",  # Other reactions to severe stress
        "F439",  # Reaction to severe stress, unspecified
        "F530",  # Postpartum depression
        "F531",  # Puerperal psychosis
        "F600",  # Paranoid personality disorder
        "F601",  # Schizoid personality disorder
        "F602",  # Antisocial personality disorder
        "F603",  # Borderline personality disorder
        "F604",  # Histrionic personality disorder
        "F605",  # Obsessive-compulsive personality disorder
        "F606",  # Avoidant personality disorder
        "F607",  # Dependent personality disorder
        "F6081",  # Narcissistic personality disorder
        "F6089",  # Other specific personality disorders
        "F609",  # Personality disorder, unspecified
    }

class MildOrModeratePreeclampsia(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of mild or moderate pre-eclampsia.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of mild or moderate pre-eclampsia.

    **Exclusion Criteria:** Excludes concepts that identify a diagnosis of severe pre-eclampsia.
    """

    VALUE_SET_NAME = "Mild or Moderate Preeclampsia"
    OID = "2.16.840.1.113762.1.4.1029.329"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "O131",  # Gestational [pregnancy-induced] hypertension without significant proteinuria, first trimester
        "O132",  # Gestational [pregnancy-induced] hypertension without significant proteinuria, second trimester
        "O133",  # Gestational [pregnancy-induced] hypertension without significant proteinuria, third trimester
        "O134",  # Gestational [pregnancy-induced] hypertension without significant proteinuria, complicating childbirth
        "O135",  # Gestational [pregnancy-induced] hypertension without significant proteinuria, complicating the puerperium
        "O139",  # Gestational [pregnancy-induced] hypertension without significant proteinuria, unspecified trimester
        "O1400",  # Mild to moderate pre-eclampsia, unspecified trimester
        "O1402",  # Mild to moderate pre-eclampsia, second trimester
        "O1403",  # Mild to moderate pre-eclampsia, third trimester
        "O1404",  # Mild to moderate pre-eclampsia, complicating childbirth
        "O1405",  # Mild to moderate pre-eclampsia, complicating the puerperium
        "O1490",  # Unspecified pre-eclampsia, unspecified trimester
        "O1492",  # Unspecified pre-eclampsia, second trimester
        "O1493",  # Unspecified pre-eclampsia, third trimester
        "O1494",  # Unspecified pre-eclampsia, complicating childbirth
        "O1495",  # Unspecified pre-eclampsia, complicating the puerperium
    }

class MorbidOrSevereObesity(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of morbid obesity.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of morbid obesity.

    **Exclusion Criteria:** Excludes concepts that identify a diagnosis of a body mass index less than 40.
    """

    VALUE_SET_NAME = "Morbid or Severe Obesity"
    OID = "2.16.840.1.113762.1.4.1029.290"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "E6601",  # Morbid (severe) obesity due to excess calories
        "E662",  # Morbid (severe) obesity with alveolar hypoventilation
        "E66813",  # Obesity, class 3
    }

class MultiplePregnancy(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of a multiple pregnancy.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of a multiple pregnancy.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Multiple Pregnancy"
    OID = "2.16.840.1.113762.1.4.1029.284"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "O30001",  # Twin pregnancy, unspecified number of placenta and unspecified number of amniotic sacs, first trimester
        "O30002",  # Twin pregnancy, unspecified number of placenta and unspecified number of amniotic sacs, second trimester
        "O30003",  # Twin pregnancy, unspecified number of placenta and unspecified number of amniotic sacs, third trimester
        "O30009",  # Twin pregnancy, unspecified number of placenta and unspecified number of amniotic sacs, unspecified trimester
        "O30011",  # Twin pregnancy, monochorionic/monoamniotic, first trimester
        "O30012",  # Twin pregnancy, monochorionic/monoamniotic, second trimester
        "O30013",  # Twin pregnancy, monochorionic/monoamniotic, third trimester
        "O30019",  # Twin pregnancy, monochorionic/monoamniotic, unspecified trimester
        "O30021",  # Conjoined twin pregnancy, first trimester
        "O30022",  # Conjoined twin pregnancy, second trimester
        "O30023",  # Conjoined twin pregnancy, third trimester
        "O30029",  # Conjoined twin pregnancy, unspecified trimester
        "O30031",  # Twin pregnancy, monochorionic/diamniotic, first trimester
        "O30032",  # Twin pregnancy, monochorionic/diamniotic, second trimester
        "O30033",  # Twin pregnancy, monochorionic/diamniotic, third trimester
        "O30039",  # Twin pregnancy, monochorionic/diamniotic, unspecified trimester
        "O30041",  # Twin pregnancy, dichorionic/diamniotic, first trimester
        "O30042",  # Twin pregnancy, dichorionic/diamniotic, second trimester
        "O30043",  # Twin pregnancy, dichorionic/diamniotic, third trimester
        "O30049",  # Twin pregnancy, dichorionic/diamniotic, unspecified trimester
        "O30091",  # Twin pregnancy, unable to determine number of placenta and number of amniotic sacs, first trimester
        "O30092",  # Twin pregnancy, unable to determine number of placenta and number of amniotic sacs, second trimester
        "O30093",  # Twin pregnancy, unable to determine number of placenta and number of amniotic sacs, third trimester
        "O30099",  # Twin pregnancy, unable to determine number of placenta and number of amniotic sacs, unspecified trimester
        "O30101",  # Triplet pregnancy, unspecified number of placenta and unspecified number of amniotic sacs, first trimester
        "O30102",  # Triplet pregnancy, unspecified number of placenta and unspecified number of amniotic sacs, second trimester
        "O30103",  # Triplet pregnancy, unspecified number of placenta and unspecified number of amniotic sacs, third trimester
        "O30109",  # Triplet pregnancy, unspecified number of placenta and unspecified number of amniotic sacs, unspecified trimester
        "O30111",  # Triplet pregnancy with two or more monochorionic fetuses, first trimester
        "O30112",  # Triplet pregnancy with two or more monochorionic fetuses, second trimester
        "O30113",  # Triplet pregnancy with two or more monochorionic fetuses, third trimester
        "O30119",  # Triplet pregnancy with two or more monochorionic fetuses, unspecified trimester
        "O30121",  # Triplet pregnancy with two or more monoamniotic fetuses, first trimester
        "O30122",  # Triplet pregnancy with two or more monoamniotic fetuses, second trimester
        "O30123",  # Triplet pregnancy with two or more monoamniotic fetuses, third trimester
        "O30129",  # Triplet pregnancy with two or more monoamniotic fetuses, unspecified trimester
        "O30131",  # Triplet pregnancy, trichorionic/triamniotic, first trimester
        "O30132",  # Triplet pregnancy, trichorionic/triamniotic, second trimester
        "O30133",  # Triplet pregnancy, trichorionic/triamniotic, third trimester
        "O30139",  # Triplet pregnancy, trichorionic/triamniotic, unspecified trimester
        "O30191",  # Triplet pregnancy, unable to determine number of placenta and number of amniotic sacs, first trimester
        "O30192",  # Triplet pregnancy, unable to determine number of placenta and number of amniotic sacs, second trimester
        "O30193",  # Triplet pregnancy, unable to determine number of placenta and number of amniotic sacs, third trimester
        "O30199",  # Triplet pregnancy, unable to determine number of placenta and number of amniotic sacs, unspecified trimester
        "O30201",  # Quadruplet pregnancy, unspecified number of placenta and unspecified number of amniotic sacs, first trimester
        "O30202",  # Quadruplet pregnancy, unspecified number of placenta and unspecified number of amniotic sacs, second trimester
        "O30203",  # Quadruplet pregnancy, unspecified number of placenta and unspecified number of amniotic sacs, third trimester
        "O30209",  # Quadruplet pregnancy, unspecified number of placenta and unspecified number of amniotic sacs, unspecified trimester
        "O30211",  # Quadruplet pregnancy with two or more monochorionic fetuses, first trimester
        "O30212",  # Quadruplet pregnancy with two or more monochorionic fetuses, second trimester
        "O30213",  # Quadruplet pregnancy with two or more monochorionic fetuses, third trimester
        "O30219",  # Quadruplet pregnancy with two or more monochorionic fetuses, unspecified trimester
        "O30221",  # Quadruplet pregnancy with two or more monoamniotic fetuses, first trimester
        "O30222",  # Quadruplet pregnancy with two or more monoamniotic fetuses, second trimester
        "O30223",  # Quadruplet pregnancy with two or more monoamniotic fetuses, third trimester
        "O30229",  # Quadruplet pregnancy with two or more monoamniotic fetuses, unspecified trimester
        "O30231",  # Quadruplet pregnancy, quadrachorionic/quadra-amniotic, first trimester
        "O30232",  # Quadruplet pregnancy, quadrachorionic/quadra-amniotic, second trimester
        "O30233",  # Quadruplet pregnancy, quadrachorionic/quadra-amniotic, third trimester
        "O30239",  # Quadruplet pregnancy, quadrachorionic/quadra-amniotic, unspecified trimester
        "O30291",  # Quadruplet pregnancy, unable to determine number of placenta and number of amniotic sacs, first trimester
        "O30292",  # Quadruplet pregnancy, unable to determine number of placenta and number of amniotic sacs, second trimester
        "O30293",  # Quadruplet pregnancy, unable to determine number of placenta and number of amniotic sacs, third trimester
        "O30299",  # Quadruplet pregnancy, unable to determine number of placenta and number of amniotic sacs, unspecified trimester
        "O30801",  # Other specified multiple gestation, unspecified number of placenta and unspecified number of amniotic sacs, first trimester
        "O30802",  # Other specified multiple gestation, unspecified number of placenta and unspecified number of amniotic sacs, second trimester
        "O30803",  # Other specified multiple gestation, unspecified number of placenta and unspecified number of amniotic sacs, third trimester
        "O30809",  # Other specified multiple gestation, unspecified number of placenta and unspecified number of amniotic sacs, unspecified trimester
        "O30811",  # Other specified multiple gestation with two or more monochorionic fetuses, first trimester
        "O30812",  # Other specified multiple gestation with two or more monochorionic fetuses, second trimester
        "O30813",  # Other specified multiple gestation with two or more monochorionic fetuses, third trimester
        "O30819",  # Other specified multiple gestation with two or more monochorionic fetuses, unspecified trimester
        "O30821",  # Other specified multiple gestation with two or more monoamniotic fetuses, first trimester
        "O30822",  # Other specified multiple gestation with two or more monoamniotic fetuses, second trimester
        "O30823",  # Other specified multiple gestation with two or more monoamniotic fetuses, third trimester
        "O30829",  # Other specified multiple gestation with two or more monoamniotic fetuses, unspecified trimester
        "O30831",  # Other specified multiple gestation, number of chorions and amnions are both equal to the number of fetuses, first trimester
        "O30832",  # Other specified multiple gestation, number of chorions and amnions are both equal to the number of fetuses, second trimester
        "O30833",  # Other specified multiple gestation, number of chorions and amnions are both equal to the number of fetuses, third trimester
        "O30839",  # Other specified multiple gestation, number of chorions and amnions are both equal to the number of fetuses, unspecified trimester
        "O30891",  # Other specified multiple gestation, unable to determine number of placenta and number of amniotic sacs, first trimester
        "O30892",  # Other specified multiple gestation, unable to determine number of placenta and number of amniotic sacs, second trimester
        "O30893",  # Other specified multiple gestation, unable to determine number of placenta and number of amniotic sacs, third trimester
        "O30899",  # Other specified multiple gestation, unable to determine number of placenta and number of amniotic sacs, unspecified trimester
        "O3090",  # Multiple gestation, unspecified, unspecified trimester
        "O3091",  # Multiple gestation, unspecified, first trimester
        "O3092",  # Multiple gestation, unspecified, second trimester
        "O3093",  # Multiple gestation, unspecified, third trimester
        "O3100X0",  # Papyraceous fetus, unspecified trimester, not applicable or unspecified
        "O3100X1",  # Papyraceous fetus, unspecified trimester, fetus 1
        "O3100X2",  # Papyraceous fetus, unspecified trimester, fetus 2
        "O3100X3",  # Papyraceous fetus, unspecified trimester, fetus 3
        "O3100X4",  # Papyraceous fetus, unspecified trimester, fetus 4
        "O3100X5",  # Papyraceous fetus, unspecified trimester, fetus 5
        "O3100X9",  # Papyraceous fetus, unspecified trimester, other fetus
        "O3101X0",  # Papyraceous fetus, first trimester, not applicable or unspecified
        "O3101X1",  # Papyraceous fetus, first trimester, fetus 1
        "O3101X2",  # Papyraceous fetus, first trimester, fetus 2
        "O3101X3",  # Papyraceous fetus, first trimester, fetus 3
        "O3101X4",  # Papyraceous fetus, first trimester, fetus 4
        "O3101X5",  # Papyraceous fetus, first trimester, fetus 5
        "O3101X9",  # Papyraceous fetus, first trimester, other fetus
        "O3102X0",  # Papyraceous fetus, second trimester, not applicable or unspecified
        "O3102X1",  # Papyraceous fetus, second trimester, fetus 1
        "O3102X2",  # Papyraceous fetus, second trimester, fetus 2
        "O3102X3",  # Papyraceous fetus, second trimester, fetus 3
        "O3102X4",  # Papyraceous fetus, second trimester, fetus 4
        "O3102X5",  # Papyraceous fetus, second trimester, fetus 5
        "O3102X9",  # Papyraceous fetus, second trimester, other fetus
        "O3103X0",  # Papyraceous fetus, third trimester, not applicable or unspecified
        "O3103X1",  # Papyraceous fetus, third trimester, fetus 1
        "O3103X2",  # Papyraceous fetus, third trimester, fetus 2
        "O3103X3",  # Papyraceous fetus, third trimester, fetus 3
        "O3103X4",  # Papyraceous fetus, third trimester, fetus 4
        "O3103X5",  # Papyraceous fetus, third trimester, fetus 5
        "O3103X9",  # Papyraceous fetus, third trimester, other fetus
        "O3110X0",  # Continuing pregnancy after spontaneous abortion of one fetus or more, unspecified trimester, not applicable or unspecified
        "O3110X1",  # Continuing pregnancy after spontaneous abortion of one fetus or more, unspecified trimester, fetus 1
        "O3110X2",  # Continuing pregnancy after spontaneous abortion of one fetus or more, unspecified trimester, fetus 2
        "O3110X3",  # Continuing pregnancy after spontaneous abortion of one fetus or more, unspecified trimester, fetus 3
        "O3110X4",  # Continuing pregnancy after spontaneous abortion of one fetus or more, unspecified trimester, fetus 4
        "O3110X5",  # Continuing pregnancy after spontaneous abortion of one fetus or more, unspecified trimester, fetus 5
        "O3110X9",  # Continuing pregnancy after spontaneous abortion of one fetus or more, unspecified trimester, other fetus
        "O3111X0",  # Continuing pregnancy after spontaneous abortion of one fetus or more, first trimester, not applicable or unspecified
        "O3111X1",  # Continuing pregnancy after spontaneous abortion of one fetus or more, first trimester, fetus 1
        "O3111X2",  # Continuing pregnancy after spontaneous abortion of one fetus or more, first trimester, fetus 2
        "O3111X3",  # Continuing pregnancy after spontaneous abortion of one fetus or more, first trimester, fetus 3
        "O3111X4",  # Continuing pregnancy after spontaneous abortion of one fetus or more, first trimester, fetus 4
        "O3111X5",  # Continuing pregnancy after spontaneous abortion of one fetus or more, first trimester, fetus 5
        "O3111X9",  # Continuing pregnancy after spontaneous abortion of one fetus or more, first trimester, other fetus
        "O3112X0",  # Continuing pregnancy after spontaneous abortion of one fetus or more, second trimester, not applicable or unspecified
        "O3112X1",  # Continuing pregnancy after spontaneous abortion of one fetus or more, second trimester, fetus 1
        "O3112X2",  # Continuing pregnancy after spontaneous abortion of one fetus or more, second trimester, fetus 2
        "O3112X3",  # Continuing pregnancy after spontaneous abortion of one fetus or more, second trimester, fetus 3
        "O3112X4",  # Continuing pregnancy after spontaneous abortion of one fetus or more, second trimester, fetus 4
        "O3112X5",  # Continuing pregnancy after spontaneous abortion of one fetus or more, second trimester, fetus 5
        "O3112X9",  # Continuing pregnancy after spontaneous abortion of one fetus or more, second trimester, other fetus
        "O3113X0",  # Continuing pregnancy after spontaneous abortion of one fetus or more, third trimester, not applicable or unspecified
        "O3113X1",  # Continuing pregnancy after spontaneous abortion of one fetus or more, third trimester, fetus 1
        "O3113X2",  # Continuing pregnancy after spontaneous abortion of one fetus or more, third trimester, fetus 2
        "O3113X3",  # Continuing pregnancy after spontaneous abortion of one fetus or more, third trimester, fetus 3
        "O3113X4",  # Continuing pregnancy after spontaneous abortion of one fetus or more, third trimester, fetus 4
        "O3113X5",  # Continuing pregnancy after spontaneous abortion of one fetus or more, third trimester, fetus 5
        "O3113X9",  # Continuing pregnancy after spontaneous abortion of one fetus or more, third trimester, other fetus
        "O3120X0",  # Continuing pregnancy after intrauterine death of one fetus or more, unspecified trimester, not applicable or unspecified
        "O3120X1",  # Continuing pregnancy after intrauterine death of one fetus or more, unspecified trimester, fetus 1
        "O3120X2",  # Continuing pregnancy after intrauterine death of one fetus or more, unspecified trimester, fetus 2
        "O3120X3",  # Continuing pregnancy after intrauterine death of one fetus or more, unspecified trimester, fetus 3
        "O3120X4",  # Continuing pregnancy after intrauterine death of one fetus or more, unspecified trimester, fetus 4
        "O3120X5",  # Continuing pregnancy after intrauterine death of one fetus or more, unspecified trimester, fetus 5
        "O3120X9",  # Continuing pregnancy after intrauterine death of one fetus or more, unspecified trimester, other fetus
        "O3121X0",  # Continuing pregnancy after intrauterine death of one fetus or more, first trimester, not applicable or unspecified
        "O3121X1",  # Continuing pregnancy after intrauterine death of one fetus or more, first trimester, fetus 1
        "O3121X2",  # Continuing pregnancy after intrauterine death of one fetus or more, first trimester, fetus 2
        "O3121X3",  # Continuing pregnancy after intrauterine death of one fetus or more, first trimester, fetus 3
        "O3121X4",  # Continuing pregnancy after intrauterine death of one fetus or more, first trimester, fetus 4
        "O3121X5",  # Continuing pregnancy after intrauterine death of one fetus or more, first trimester, fetus 5
        "O3121X9",  # Continuing pregnancy after intrauterine death of one fetus or more, first trimester, other fetus
        "O3122X0",  # Continuing pregnancy after intrauterine death of one fetus or more, second trimester, not applicable or unspecified
        "O3122X1",  # Continuing pregnancy after intrauterine death of one fetus or more, second trimester, fetus 1
        "O3122X2",  # Continuing pregnancy after intrauterine death of one fetus or more, second trimester, fetus 2
        "O3122X3",  # Continuing pregnancy after intrauterine death of one fetus or more, second trimester, fetus 3
        "O3122X4",  # Continuing pregnancy after intrauterine death of one fetus or more, second trimester, fetus 4
        "O3122X5",  # Continuing pregnancy after intrauterine death of one fetus or more, second trimester, fetus 5
        "O3122X9",  # Continuing pregnancy after intrauterine death of one fetus or more, second trimester, other fetus
        "O3123X0",  # Continuing pregnancy after intrauterine death of one fetus or more, third trimester, not applicable or unspecified
        "O3123X1",  # Continuing pregnancy after intrauterine death of one fetus or more, third trimester, fetus 1
        "O3123X2",  # Continuing pregnancy after intrauterine death of one fetus or more, third trimester, fetus 2
        "O3123X3",  # Continuing pregnancy after intrauterine death of one fetus or more, third trimester, fetus 3
        "O3123X4",  # Continuing pregnancy after intrauterine death of one fetus or more, third trimester, fetus 4
        "O3123X5",  # Continuing pregnancy after intrauterine death of one fetus or more, third trimester, fetus 5
        "O3123X9",  # Continuing pregnancy after intrauterine death of one fetus or more, third trimester, other fetus
        "O3130X0",  # Continuing pregnancy after elective fetal reduction of one fetus or more, unspecified trimester, not applicable or unspecified
        "O3130X1",  # Continuing pregnancy after elective fetal reduction of one fetus or more, unspecified trimester, fetus 1
        "O3130X2",  # Continuing pregnancy after elective fetal reduction of one fetus or more, unspecified trimester, fetus 2
        "O3130X3",  # Continuing pregnancy after elective fetal reduction of one fetus or more, unspecified trimester, fetus 3
        "O3130X4",  # Continuing pregnancy after elective fetal reduction of one fetus or more, unspecified trimester, fetus 4
        "O3130X5",  # Continuing pregnancy after elective fetal reduction of one fetus or more, unspecified trimester, fetus 5
        "O3130X9",  # Continuing pregnancy after elective fetal reduction of one fetus or more, unspecified trimester, other fetus
        "O3131X0",  # Continuing pregnancy after elective fetal reduction of one fetus or more, first trimester, not applicable or unspecified
        "O3131X1",  # Continuing pregnancy after elective fetal reduction of one fetus or more, first trimester, fetus 1
        "O3131X2",  # Continuing pregnancy after elective fetal reduction of one fetus or more, first trimester, fetus 2
        "O3131X3",  # Continuing pregnancy after elective fetal reduction of one fetus or more, first trimester, fetus 3
        "O3131X4",  # Continuing pregnancy after elective fetal reduction of one fetus or more, first trimester, fetus 4
        "O3131X5",  # Continuing pregnancy after elective fetal reduction of one fetus or more, first trimester, fetus 5
        "O3131X9",  # Continuing pregnancy after elective fetal reduction of one fetus or more, first trimester, other fetus
        "O3132X0",  # Continuing pregnancy after elective fetal reduction of one fetus or more, second trimester, not applicable or unspecified
        "O3132X1",  # Continuing pregnancy after elective fetal reduction of one fetus or more, second trimester, fetus 1
        "O3132X2",  # Continuing pregnancy after elective fetal reduction of one fetus or more, second trimester, fetus 2
        "O3132X3",  # Continuing pregnancy after elective fetal reduction of one fetus or more, second trimester, fetus 3
        "O3132X4",  # Continuing pregnancy after elective fetal reduction of one fetus or more, second trimester, fetus 4
        "O3132X5",  # Continuing pregnancy after elective fetal reduction of one fetus or more, second trimester, fetus 5
        "O3132X9",  # Continuing pregnancy after elective fetal reduction of one fetus or more, second trimester, other fetus
        "O3133X0",  # Continuing pregnancy after elective fetal reduction of one fetus or more, third trimester, not applicable or unspecified
        "O3133X1",  # Continuing pregnancy after elective fetal reduction of one fetus or more, third trimester, fetus 1
        "O3133X2",  # Continuing pregnancy after elective fetal reduction of one fetus or more, third trimester, fetus 2
        "O3133X3",  # Continuing pregnancy after elective fetal reduction of one fetus or more, third trimester, fetus 3
        "O3133X4",  # Continuing pregnancy after elective fetal reduction of one fetus or more, third trimester, fetus 4
        "O3133X5",  # Continuing pregnancy after elective fetal reduction of one fetus or more, third trimester, fetus 5
        "O3133X9",  # Continuing pregnancy after elective fetal reduction of one fetus or more, third trimester, other fetus
        "O318X10",  # Other complications specific to multiple gestation, first trimester, not applicable or unspecified
        "O318X11",  # Other complications specific to multiple gestation, first trimester, fetus 1
        "O318X12",  # Other complications specific to multiple gestation, first trimester, fetus 2
        "O318X13",  # Other complications specific to multiple gestation, first trimester, fetus 3
        "O318X14",  # Other complications specific to multiple gestation, first trimester, fetus 4
        "O318X15",  # Other complications specific to multiple gestation, first trimester, fetus 5
        "O318X19",  # Other complications specific to multiple gestation, first trimester, other fetus
        "O318X20",  # Other complications specific to multiple gestation, second trimester, not applicable or unspecified
        "O318X21",  # Other complications specific to multiple gestation, second trimester, fetus 1
        "O318X22",  # Other complications specific to multiple gestation, second trimester, fetus 2
        "O318X23",  # Other complications specific to multiple gestation, second trimester, fetus 3
        "O318X24",  # Other complications specific to multiple gestation, second trimester, fetus 4
        "O318X25",  # Other complications specific to multiple gestation, second trimester, fetus 5
        "O318X29",  # Other complications specific to multiple gestation, second trimester, other fetus
        "O318X30",  # Other complications specific to multiple gestation, third trimester, not applicable or unspecified
        "O318X31",  # Other complications specific to multiple gestation, third trimester, fetus 1
        "O318X32",  # Other complications specific to multiple gestation, third trimester, fetus 2
        "O318X33",  # Other complications specific to multiple gestation, third trimester, fetus 3
        "O318X34",  # Other complications specific to multiple gestation, third trimester, fetus 4
        "O318X35",  # Other complications specific to multiple gestation, third trimester, fetus 5
        "O318X39",  # Other complications specific to multiple gestation, third trimester, other fetus
        "O318X90",  # Other complications specific to multiple gestation, unspecified trimester, not applicable or unspecified
        "O318X91",  # Other complications specific to multiple gestation, unspecified trimester, fetus 1
        "O318X92",  # Other complications specific to multiple gestation, unspecified trimester, fetus 2
        "O318X93",  # Other complications specific to multiple gestation, unspecified trimester, fetus 3
        "O318X94",  # Other complications specific to multiple gestation, unspecified trimester, fetus 4
        "O318X95",  # Other complications specific to multiple gestation, unspecified trimester, fetus 5
        "O318X99",  # Other complications specific to multiple gestation, unspecified trimester, other fetus
        "Z372",  # Twins, both liveborn
        "Z373",  # Twins, one liveborn and one stillborn
        "Z374",  # Twins, both stillborn
        "Z3750",  # Multiple births, unspecified, all liveborn
        "Z3751",  # Triplets, all liveborn
        "Z3752",  # Quadruplets, all liveborn
        "Z3753",  # Quintuplets, all liveborn
        "Z3754",  # Sextuplets, all liveborn
        "Z3759",  # Other multiple births, all liveborn
        "Z3760",  # Multiple births, unspecified, some liveborn
        "Z3761",  # Triplets, some liveborn
        "Z3762",  # Quadruplets, some liveborn
        "Z3763",  # Quintuplets, some liveborn
        "Z3764",  # Sextuplets, some liveborn
        "Z3769",  # Other multiple births, some liveborn
        "Z377",  # Other multiple births, all stillborn
    }

class NeuromuscularDisease(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of neuromuscular disease.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of a neuromuscular disease.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Neuromuscular Disease"
    OID = "2.16.840.1.113762.1.4.1029.308"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "G40001",  # Localization-related (focal) (partial) idiopathic epilepsy and epileptic syndromes with seizures of localized onset, not intractable, with status epilepticus
        "G40009",  # Localization-related (focal) (partial) idiopathic epilepsy and epileptic syndromes with seizures of localized onset, not intractable, without status epilepticus
        "G40011",  # Localization-related (focal) (partial) idiopathic epilepsy and epileptic syndromes with seizures of localized onset, intractable, with status epilepticus
        "G40019",  # Localization-related (focal) (partial) idiopathic epilepsy and epileptic syndromes with seizures of localized onset, intractable, without status epilepticus
        "G40101",  # Localization-related (focal) (partial) symptomatic epilepsy and epileptic syndromes with simple partial seizures, not intractable, with status epilepticus
        "G40109",  # Localization-related (focal) (partial) symptomatic epilepsy and epileptic syndromes with simple partial seizures, not intractable, without status epilepticus
        "G40111",  # Localization-related (focal) (partial) symptomatic epilepsy and epileptic syndromes with simple partial seizures, intractable, with status epilepticus
        "G40119",  # Localization-related (focal) (partial) symptomatic epilepsy and epileptic syndromes with simple partial seizures, intractable, without status epilepticus
        "G40201",  # Localization-related (focal) (partial) symptomatic epilepsy and epileptic syndromes with complex partial seizures, not intractable, with status epilepticus
        "G40209",  # Localization-related (focal) (partial) symptomatic epilepsy and epileptic syndromes with complex partial seizures, not intractable, without status epilepticus
        "G40211",  # Localization-related (focal) (partial) symptomatic epilepsy and epileptic syndromes with complex partial seizures, intractable, with status epilepticus
        "G40219",  # Localization-related (focal) (partial) symptomatic epilepsy and epileptic syndromes with complex partial seizures, intractable, without status epilepticus
        "G40301",  # Generalized idiopathic epilepsy and epileptic syndromes, not intractable, with status epilepticus
        "G40309",  # Generalized idiopathic epilepsy and epileptic syndromes, not intractable, without status epilepticus
        "G40311",  # Generalized idiopathic epilepsy and epileptic syndromes, intractable, with status epilepticus
        "G40319",  # Generalized idiopathic epilepsy and epileptic syndromes, intractable, without status epilepticus
        "G40401",  # Other generalized epilepsy and epileptic syndromes, not intractable, with status epilepticus
        "G40409",  # Other generalized epilepsy and epileptic syndromes, not intractable, without status epilepticus
        "G40411",  # Other generalized epilepsy and epileptic syndromes, intractable, with status epilepticus
        "G40419",  # Other generalized epilepsy and epileptic syndromes, intractable, without status epilepticus
        "G4042",  # Cyclin-Dependent Kinase-Like 5 Deficiency Disorder
        "G40501",  # Epileptic seizures related to external causes, not intractable, with status epilepticus
        "G40509",  # Epileptic seizures related to external causes, not intractable, without status epilepticus
        "G40801",  # Other epilepsy, not intractable, with status epilepticus
        "G40802",  # Other epilepsy, not intractable, without status epilepticus
        "G40803",  # Other epilepsy, intractable, with status epilepticus
        "G40804",  # Other epilepsy, intractable, without status epilepticus
        "G40811",  # Lennox-Gastaut syndrome, not intractable, with status epilepticus
        "G40812",  # Lennox-Gastaut syndrome, not intractable, without status epilepticus
        "G40813",  # Lennox-Gastaut syndrome, intractable, with status epilepticus
        "G40814",  # Lennox-Gastaut syndrome, intractable, without status epilepticus
        "G40821",  # Epileptic spasms, not intractable, with status epilepticus
        "G40822",  # Epileptic spasms, not intractable, without status epilepticus
        "G40823",  # Epileptic spasms, intractable, with status epilepticus
        "G40824",  # Epileptic spasms, intractable, without status epilepticus
        "G40833",  # Dravet syndrome, intractable, with status epilepticus
        "G40834",  # Dravet syndrome, intractable, without status epilepticus
        "G40841",  # KCNQ2-related epilepsy, not intractable, with status epilepticus
        "G40842",  # KCNQ2-related epilepsy, not intractable, without status epilepticus
        "G40843",  # KCNQ2-related epilepsy, intractable, with status epilepticus
        "G40844",  # KCNQ2-related epilepsy, intractable, without status epilepticus
        "G4089",  # Other seizures
        "G40901",  # Epilepsy, unspecified, not intractable, with status epilepticus
        "G40909",  # Epilepsy, unspecified, not intractable, without status epilepticus
        "G40911",  # Epilepsy, unspecified, intractable, with status epilepticus
        "G40919",  # Epilepsy, unspecified, intractable, without status epilepticus
        "G40A01",  # Absence epileptic syndrome, not intractable, with status epilepticus
        "G40A09",  # Absence epileptic syndrome, not intractable, without status epilepticus
        "G40A11",  # Absence epileptic syndrome, intractable, with status epilepticus
        "G40A19",  # Absence epileptic syndrome, intractable, without status epilepticus
        "G40B01",  # Juvenile myoclonic epilepsy, not intractable, with status epilepticus
        "G40B09",  # Juvenile myoclonic epilepsy, not intractable, without status epilepticus
        "G40B11",  # Juvenile myoclonic epilepsy, intractable, with status epilepticus
        "G40B19",  # Juvenile myoclonic epilepsy, intractable, without status epilepticus
        "G40C01",  # Lafora progressive myoclonus epilepsy, not intractable, with status epilepticus
        "G40C09",  # Lafora progressive myoclonus epilepsy, not intractable, without status epilepticus
        "G40C11",  # Lafora progressive myoclonus epilepsy, intractable, with status epilepticus
        "G40C19",  # Lafora progressive myoclonus epilepsy, intractable, without status epilepticus
        "G7000",  # Myasthenia gravis without (acute) exacerbation
        "G7001",  # Myasthenia gravis with (acute) exacerbation
        "G701",  # Toxic myoneural disorders
        "G702",  # Congenital and developmental myasthenia
        "G7080",  # Lambert-Eaton syndrome, unspecified
        "G7081",  # Lambert-Eaton syndrome in disease classified elsewhere
        "G7089",  # Other specified myoneural disorders
        "G709",  # Myoneural disorder, unspecified
    }

class PatientExpired(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for an encounter with a discharge disposition of patient who has died in the hospital.

    **Data Element Scope:** This value set may use a model element related to Encounter.

    **Inclusion Criteria:** Includes concepts that identify an encounter with a discharge disposition of a patient who has died in the hospital.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Patient Expired"
    OID = "2.16.840.1.113883.3.117.1.7.1.309"
    DEFINITION_VERSION = "20210611"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "371828006",  # Patient deceased during stay (discharge status = dead) (finding)
    }

class PlacentaAccreta(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of a placenta accreta.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of a placenta accreta during the 2nd or 3rd trimester.

    **Exclusion Criteria:** Excludes concepts that represent a diagnosis of a placenta accreta during the 1st trimester.
    """

    VALUE_SET_NAME = "Placenta Accreta"
    OID = "2.16.840.1.113762.1.4.1029.302"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "O43212",  # Placenta accreta, second trimester
        "O43213",  # Placenta accreta, third trimester
        "O43219",  # Placenta accreta, unspecified trimester
    }

class PlacentaIncretaOrPercreta(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of a placenta increta or percreta.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of a placenta increta or percreta.

    **Exclusion Criteria:** Excludes concepts that represent diagnosis of a placenta increta or percreta in the 1st trimester.
    """

    VALUE_SET_NAME = "Placenta Increta or Percreta"
    OID = "2.16.840.1.113762.1.4.1029.388"
    DEFINITION_VERSION = "20240223"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "O43222",  # Placenta increta, second trimester
        "O43223",  # Placenta increta, third trimester
        "O43229",  # Placenta increta, unspecified trimester
        "O43232",  # Placenta percreta, second trimester
        "O43233",  # Placenta percreta, third trimester
        "O43239",  # Placenta percreta, unspecified trimester
    }

class PlacentaPrevia(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of a placenta previa.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of a complete or partial placenta previa during the 3rd trimester or when trimester is unspecified.

    **Exclusion Criteria:** Excludes concepts that represent placenta previa in 1st or 2nd trimester.
    """

    VALUE_SET_NAME = "Placenta Previa"
    OID = "2.16.840.1.113762.1.4.1110.78"
    DEFINITION_VERSION = "20231111"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "O4400",  # Complete placenta previa NOS or without hemorrhage, unspecified trimester
        "O4403",  # Complete placenta previa NOS or without hemorrhage, third trimester
        "O4410",  # Complete placenta previa with hemorrhage, unspecified trimester
        "O4413",  # Complete placenta previa with hemorrhage, third trimester
        "O4420",  # Partial placenta previa NOS or without hemorrhage, unspecified trimester
        "O4423",  # Partial placenta previa NOS or without hemorrhage, third trimester
        "O4430",  # Partial placenta previa with hemorrhage, unspecified trimester
        "O4433",  # Partial placenta previa with hemorrhage, third trimester
    }

class PlacentalAbruption(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of placental abruption.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of a placental abruption.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Placental Abruption"
    OID = "2.16.840.1.113762.1.4.1029.305"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "O45001",  # Premature separation of placenta with coagulation defect, unspecified, first trimester
        "O45002",  # Premature separation of placenta with coagulation defect, unspecified, second trimester
        "O45003",  # Premature separation of placenta with coagulation defect, unspecified, third trimester
        "O45009",  # Premature separation of placenta with coagulation defect, unspecified, unspecified trimester
        "O45011",  # Premature separation of placenta with afibrinogenemia, first trimester
        "O45012",  # Premature separation of placenta with afibrinogenemia, second trimester
        "O45013",  # Premature separation of placenta with afibrinogenemia, third trimester
        "O45019",  # Premature separation of placenta with afibrinogenemia, unspecified trimester
        "O45021",  # Premature separation of placenta with disseminated intravascular coagulation, first trimester
        "O45022",  # Premature separation of placenta with disseminated intravascular coagulation, second trimester
        "O45023",  # Premature separation of placenta with disseminated intravascular coagulation, third trimester
        "O45029",  # Premature separation of placenta with disseminated intravascular coagulation, unspecified trimester
        "O45091",  # Premature separation of placenta with other coagulation defect, first trimester
        "O45092",  # Premature separation of placenta with other coagulation defect, second trimester
        "O45093",  # Premature separation of placenta with other coagulation defect, third trimester
        "O45099",  # Premature separation of placenta with other coagulation defect, unspecified trimester
        "O458X1",  # Other premature separation of placenta, first trimester
        "O458X2",  # Other premature separation of placenta, second trimester
        "O458X3",  # Other premature separation of placenta, third trimester
        "O458X9",  # Other premature separation of placenta, unspecified trimester
        "O4590",  # Premature separation of placenta, unspecified, unspecified trimester
        "O4591",  # Premature separation of placenta, unspecified, first trimester
        "O4592",  # Premature separation of placenta, unspecified, second trimester
        "O4593",  # Premature separation of placenta, unspecified, third trimester
    }

class PreexistingDiabetes(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of pre-existing diabetes.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of pre-existing diabetes.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Preexisting Diabetes"
    OID = "2.16.840.1.113762.1.4.1029.275"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "E0800",  # Diabetes mellitus due to underlying condition with hyperosmolarity without nonketotic hyperglycemic-hyperosmolar coma (NKHHC)
        "E0801",  # Diabetes mellitus due to underlying condition with hyperosmolarity with coma
        "E0810",  # Diabetes mellitus due to underlying condition with ketoacidosis without coma
        "E0811",  # Diabetes mellitus due to underlying condition with ketoacidosis with coma
        "E0821",  # Diabetes mellitus due to underlying condition with diabetic nephropathy
        "E0822",  # Diabetes mellitus due to underlying condition with diabetic chronic kidney disease
        "E0829",  # Diabetes mellitus due to underlying condition with other diabetic kidney complication
        "E08311",  # Diabetes mellitus due to underlying condition with unspecified diabetic retinopathy with macular edema
        "E08319",  # Diabetes mellitus due to underlying condition with unspecified diabetic retinopathy without macular edema
        "E083211",  # Diabetes mellitus due to underlying condition with mild nonproliferative diabetic retinopathy with macular edema, right eye
        "E083212",  # Diabetes mellitus due to underlying condition with mild nonproliferative diabetic retinopathy with macular edema, left eye
        "E083213",  # Diabetes mellitus due to underlying condition with mild nonproliferative diabetic retinopathy with macular edema, bilateral
        "E083219",  # Diabetes mellitus due to underlying condition with mild nonproliferative diabetic retinopathy with macular edema, unspecified eye
        "E083291",  # Diabetes mellitus due to underlying condition with mild nonproliferative diabetic retinopathy without macular edema, right eye
        "E083292",  # Diabetes mellitus due to underlying condition with mild nonproliferative diabetic retinopathy without macular edema, left eye
        "E083293",  # Diabetes mellitus due to underlying condition with mild nonproliferative diabetic retinopathy without macular edema, bilateral
        "E083299",  # Diabetes mellitus due to underlying condition with mild nonproliferative diabetic retinopathy without macular edema, unspecified eye
        "E083311",  # Diabetes mellitus due to underlying condition with moderate nonproliferative diabetic retinopathy with macular edema, right eye
        "E083312",  # Diabetes mellitus due to underlying condition with moderate nonproliferative diabetic retinopathy with macular edema, left eye
        "E083313",  # Diabetes mellitus due to underlying condition with moderate nonproliferative diabetic retinopathy with macular edema, bilateral
        "E083319",  # Diabetes mellitus due to underlying condition with moderate nonproliferative diabetic retinopathy with macular edema, unspecified eye
        "E083391",  # Diabetes mellitus due to underlying condition with moderate nonproliferative diabetic retinopathy without macular edema, right eye
        "E083392",  # Diabetes mellitus due to underlying condition with moderate nonproliferative diabetic retinopathy without macular edema, left eye
        "E083393",  # Diabetes mellitus due to underlying condition with moderate nonproliferative diabetic retinopathy without macular edema, bilateral
        "E083399",  # Diabetes mellitus due to underlying condition with moderate nonproliferative diabetic retinopathy without macular edema, unspecified eye
        "E083411",  # Diabetes mellitus due to underlying condition with severe nonproliferative diabetic retinopathy with macular edema, right eye
        "E083412",  # Diabetes mellitus due to underlying condition with severe nonproliferative diabetic retinopathy with macular edema, left eye
        "E083413",  # Diabetes mellitus due to underlying condition with severe nonproliferative diabetic retinopathy with macular edema, bilateral
        "E083419",  # Diabetes mellitus due to underlying condition with severe nonproliferative diabetic retinopathy with macular edema, unspecified eye
        "E083491",  # Diabetes mellitus due to underlying condition with severe nonproliferative diabetic retinopathy without macular edema, right eye
        "E083492",  # Diabetes mellitus due to underlying condition with severe nonproliferative diabetic retinopathy without macular edema, left eye
        "E083493",  # Diabetes mellitus due to underlying condition with severe nonproliferative diabetic retinopathy without macular edema, bilateral
        "E083499",  # Diabetes mellitus due to underlying condition with severe nonproliferative diabetic retinopathy without macular edema, unspecified eye
        "E083511",  # Diabetes mellitus due to underlying condition with proliferative diabetic retinopathy with macular edema, right eye
        "E083512",  # Diabetes mellitus due to underlying condition with proliferative diabetic retinopathy with macular edema, left eye
        "E083513",  # Diabetes mellitus due to underlying condition with proliferative diabetic retinopathy with macular edema, bilateral
        "E083519",  # Diabetes mellitus due to underlying condition with proliferative diabetic retinopathy with macular edema, unspecified eye
        "E083521",  # Diabetes mellitus due to underlying condition with proliferative diabetic retinopathy with traction retinal detachment involving the macula, right eye
        "E083522",  # Diabetes mellitus due to underlying condition with proliferative diabetic retinopathy with traction retinal detachment involving the macula, left eye
        "E083523",  # Diabetes mellitus due to underlying condition with proliferative diabetic retinopathy with traction retinal detachment involving the macula, bilateral
        "E083529",  # Diabetes mellitus due to underlying condition with proliferative diabetic retinopathy with traction retinal detachment involving the macula, unspecified eye
        "E083531",  # Diabetes mellitus due to underlying condition with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, right eye
        "E083532",  # Diabetes mellitus due to underlying condition with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, left eye
        "E083533",  # Diabetes mellitus due to underlying condition with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, bilateral
        "E083539",  # Diabetes mellitus due to underlying condition with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, unspecified eye
        "E083541",  # Diabetes mellitus due to underlying condition with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, right eye
        "E083542",  # Diabetes mellitus due to underlying condition with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, left eye
        "E083543",  # Diabetes mellitus due to underlying condition with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, bilateral
        "E083549",  # Diabetes mellitus due to underlying condition with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, unspecified eye
        "E083551",  # Diabetes mellitus due to underlying condition with stable proliferative diabetic retinopathy, right eye
        "E083552",  # Diabetes mellitus due to underlying condition with stable proliferative diabetic retinopathy, left eye
        "E083553",  # Diabetes mellitus due to underlying condition with stable proliferative diabetic retinopathy, bilateral
        "E083559",  # Diabetes mellitus due to underlying condition with stable proliferative diabetic retinopathy, unspecified eye
        "E083591",  # Diabetes mellitus due to underlying condition with proliferative diabetic retinopathy without macular edema, right eye
        "E083592",  # Diabetes mellitus due to underlying condition with proliferative diabetic retinopathy without macular edema, left eye
        "E083593",  # Diabetes mellitus due to underlying condition with proliferative diabetic retinopathy without macular edema, bilateral
        "E083599",  # Diabetes mellitus due to underlying condition with proliferative diabetic retinopathy without macular edema, unspecified eye
        "E0836",  # Diabetes mellitus due to underlying condition with diabetic cataract
        "E0837X1",  # Diabetes mellitus due to underlying condition with diabetic macular edema, resolved following treatment, right eye
        "E0837X2",  # Diabetes mellitus due to underlying condition with diabetic macular edema, resolved following treatment, left eye
        "E0837X3",  # Diabetes mellitus due to underlying condition with diabetic macular edema, resolved following treatment, bilateral
        "E0837X9",  # Diabetes mellitus due to underlying condition with diabetic macular edema, resolved following treatment, unspecified eye
        "E0839",  # Diabetes mellitus due to underlying condition with other diabetic ophthalmic complication
        "E0840",  # Diabetes mellitus due to underlying condition with diabetic neuropathy, unspecified
        "E0841",  # Diabetes mellitus due to underlying condition with diabetic mononeuropathy
        "E0842",  # Diabetes mellitus due to underlying condition with diabetic polyneuropathy
        "E0843",  # Diabetes mellitus due to underlying condition with diabetic autonomic (poly)neuropathy
        "E0844",  # Diabetes mellitus due to underlying condition with diabetic amyotrophy
        "E0849",  # Diabetes mellitus due to underlying condition with other diabetic neurological complication
        "E0851",  # Diabetes mellitus due to underlying condition with diabetic peripheral angiopathy without gangrene
        "E0852",  # Diabetes mellitus due to underlying condition with diabetic peripheral angiopathy with gangrene
        "E0859",  # Diabetes mellitus due to underlying condition with other circulatory complications
        "E08610",  # Diabetes mellitus due to underlying condition with diabetic neuropathic arthropathy
        "E08618",  # Diabetes mellitus due to underlying condition with other diabetic arthropathy
        "E08620",  # Diabetes mellitus due to underlying condition with diabetic dermatitis
        "E08621",  # Diabetes mellitus due to underlying condition with foot ulcer
        "E08622",  # Diabetes mellitus due to underlying condition with other skin ulcer
        "E08628",  # Diabetes mellitus due to underlying condition with other skin complications
        "E08630",  # Diabetes mellitus due to underlying condition with periodontal disease
        "E08638",  # Diabetes mellitus due to underlying condition with other oral complications
        "E08641",  # Diabetes mellitus due to underlying condition with hypoglycemia with coma
        "E08649",  # Diabetes mellitus due to underlying condition with hypoglycemia without coma
        "E0865",  # Diabetes mellitus due to underlying condition with hyperglycemia
        "E0869",  # Diabetes mellitus due to underlying condition with other specified complication
        "E088",  # Diabetes mellitus due to underlying condition with unspecified complications
        "E089",  # Diabetes mellitus due to underlying condition without complications
        "E0900",  # Drug or chemical induced diabetes mellitus with hyperosmolarity without nonketotic hyperglycemic-hyperosmolar coma (NKHHC)
        "E0901",  # Drug or chemical induced diabetes mellitus with hyperosmolarity with coma
        "E0910",  # Drug or chemical induced diabetes mellitus with ketoacidosis without coma
        "E0911",  # Drug or chemical induced diabetes mellitus with ketoacidosis with coma
        "E0921",  # Drug or chemical induced diabetes mellitus with diabetic nephropathy
        "E0922",  # Drug or chemical induced diabetes mellitus with diabetic chronic kidney disease
        "E0929",  # Drug or chemical induced diabetes mellitus with other diabetic kidney complication
        "E09311",  # Drug or chemical induced diabetes mellitus with unspecified diabetic retinopathy with macular edema
        "E09319",  # Drug or chemical induced diabetes mellitus with unspecified diabetic retinopathy without macular edema
        "E093211",  # Drug or chemical induced diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, right eye
        "E093212",  # Drug or chemical induced diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, left eye
        "E093213",  # Drug or chemical induced diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, bilateral
        "E093219",  # Drug or chemical induced diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, unspecified eye
        "E093291",  # Drug or chemical induced diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, right eye
        "E093292",  # Drug or chemical induced diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, left eye
        "E093293",  # Drug or chemical induced diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, bilateral
        "E093299",  # Drug or chemical induced diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, unspecified eye
        "E093311",  # Drug or chemical induced diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, right eye
        "E093312",  # Drug or chemical induced diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, left eye
        "E093313",  # Drug or chemical induced diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, bilateral
        "E093319",  # Drug or chemical induced diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, unspecified eye
        "E093391",  # Drug or chemical induced diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, right eye
        "E093392",  # Drug or chemical induced diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, left eye
        "E093393",  # Drug or chemical induced diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, bilateral
        "E093399",  # Drug or chemical induced diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, unspecified eye
        "E093411",  # Drug or chemical induced diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, right eye
        "E093412",  # Drug or chemical induced diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, left eye
        "E093413",  # Drug or chemical induced diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, bilateral
        "E093419",  # Drug or chemical induced diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, unspecified eye
        "E093491",  # Drug or chemical induced diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, right eye
        "E093492",  # Drug or chemical induced diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, left eye
        "E093493",  # Drug or chemical induced diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, bilateral
        "E093499",  # Drug or chemical induced diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, unspecified eye
        "E093511",  # Drug or chemical induced diabetes mellitus with proliferative diabetic retinopathy with macular edema, right eye
        "E093512",  # Drug or chemical induced diabetes mellitus with proliferative diabetic retinopathy with macular edema, left eye
        "E093513",  # Drug or chemical induced diabetes mellitus with proliferative diabetic retinopathy with macular edema, bilateral
        "E093519",  # Drug or chemical induced diabetes mellitus with proliferative diabetic retinopathy with macular edema, unspecified eye
        "E093521",  # Drug or chemical induced diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, right eye
        "E093522",  # Drug or chemical induced diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, left eye
        "E093523",  # Drug or chemical induced diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, bilateral
        "E093529",  # Drug or chemical induced diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, unspecified eye
        "E093531",  # Drug or chemical induced diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, right eye
        "E093532",  # Drug or chemical induced diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, left eye
        "E093533",  # Drug or chemical induced diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, bilateral
        "E093539",  # Drug or chemical induced diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, unspecified eye
        "E093541",  # Drug or chemical induced diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, right eye
        "E093542",  # Drug or chemical induced diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, left eye
        "E093543",  # Drug or chemical induced diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, bilateral
        "E093549",  # Drug or chemical induced diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, unspecified eye
        "E093551",  # Drug or chemical induced diabetes mellitus with stable proliferative diabetic retinopathy, right eye
        "E093552",  # Drug or chemical induced diabetes mellitus with stable proliferative diabetic retinopathy, left eye
        "E093553",  # Drug or chemical induced diabetes mellitus with stable proliferative diabetic retinopathy, bilateral
        "E093559",  # Drug or chemical induced diabetes mellitus with stable proliferative diabetic retinopathy, unspecified eye
        "E093591",  # Drug or chemical induced diabetes mellitus with proliferative diabetic retinopathy without macular edema, right eye
        "E093592",  # Drug or chemical induced diabetes mellitus with proliferative diabetic retinopathy without macular edema, left eye
        "E093593",  # Drug or chemical induced diabetes mellitus with proliferative diabetic retinopathy without macular edema, bilateral
        "E093599",  # Drug or chemical induced diabetes mellitus with proliferative diabetic retinopathy without macular edema, unspecified eye
        "E0936",  # Drug or chemical induced diabetes mellitus with diabetic cataract
        "E0937X1",  # Drug or chemical induced diabetes mellitus with diabetic macular edema, resolved following treatment, right eye
        "E0937X2",  # Drug or chemical induced diabetes mellitus with diabetic macular edema, resolved following treatment, left eye
        "E0937X3",  # Drug or chemical induced diabetes mellitus with diabetic macular edema, resolved following treatment, bilateral
        "E0937X9",  # Drug or chemical induced diabetes mellitus with diabetic macular edema, resolved following treatment, unspecified eye
        "E0939",  # Drug or chemical induced diabetes mellitus with other diabetic ophthalmic complication
        "E0940",  # Drug or chemical induced diabetes mellitus with neurological complications with diabetic neuropathy, unspecified
        "E0941",  # Drug or chemical induced diabetes mellitus with neurological complications with diabetic mononeuropathy
        "E0942",  # Drug or chemical induced diabetes mellitus with neurological complications with diabetic polyneuropathy
        "E0943",  # Drug or chemical induced diabetes mellitus with neurological complications with diabetic autonomic (poly)neuropathy
        "E0944",  # Drug or chemical induced diabetes mellitus with neurological complications with diabetic amyotrophy
        "E0949",  # Drug or chemical induced diabetes mellitus with neurological complications with other diabetic neurological complication
        "E0951",  # Drug or chemical induced diabetes mellitus with diabetic peripheral angiopathy without gangrene
        "E0952",  # Drug or chemical induced diabetes mellitus with diabetic peripheral angiopathy with gangrene
        "E0959",  # Drug or chemical induced diabetes mellitus with other circulatory complications
        "E09610",  # Drug or chemical induced diabetes mellitus with diabetic neuropathic arthropathy
        "E09618",  # Drug or chemical induced diabetes mellitus with other diabetic arthropathy
        "E09620",  # Drug or chemical induced diabetes mellitus with diabetic dermatitis
        "E09621",  # Drug or chemical induced diabetes mellitus with foot ulcer
        "E09622",  # Drug or chemical induced diabetes mellitus with other skin ulcer
        "E09628",  # Drug or chemical induced diabetes mellitus with other skin complications
        "E09630",  # Drug or chemical induced diabetes mellitus with periodontal disease
        "E09638",  # Drug or chemical induced diabetes mellitus with other oral complications
        "E09641",  # Drug or chemical induced diabetes mellitus with hypoglycemia with coma
        "E09649",  # Drug or chemical induced diabetes mellitus with hypoglycemia without coma
        "E0965",  # Drug or chemical induced diabetes mellitus with hyperglycemia
        "E0969",  # Drug or chemical induced diabetes mellitus with other specified complication
        "E098",  # Drug or chemical induced diabetes mellitus with unspecified complications
        "E099",  # Drug or chemical induced diabetes mellitus without complications
        "E1010",  # Type 1 diabetes mellitus with ketoacidosis without coma
        "E1011",  # Type 1 diabetes mellitus with ketoacidosis with coma
        "E1021",  # Type 1 diabetes mellitus with diabetic nephropathy
        "E1022",  # Type 1 diabetes mellitus with diabetic chronic kidney disease
        "E1029",  # Type 1 diabetes mellitus with other diabetic kidney complication
        "E10311",  # Type 1 diabetes mellitus with unspecified diabetic retinopathy with macular edema
        "E10319",  # Type 1 diabetes mellitus with unspecified diabetic retinopathy without macular edema
        "E103211",  # Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, right eye
        "E103212",  # Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, left eye
        "E103213",  # Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, bilateral
        "E103219",  # Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, unspecified eye
        "E103291",  # Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, right eye
        "E103292",  # Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, left eye
        "E103293",  # Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, bilateral
        "E103299",  # Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, unspecified eye
        "E103311",  # Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, right eye
        "E103312",  # Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, left eye
        "E103313",  # Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, bilateral
        "E103319",  # Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, unspecified eye
        "E103391",  # Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, right eye
        "E103392",  # Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, left eye
        "E103393",  # Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, bilateral
        "E103399",  # Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, unspecified eye
        "E103411",  # Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, right eye
        "E103412",  # Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, left eye
        "E103413",  # Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, bilateral
        "E103419",  # Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, unspecified eye
        "E103491",  # Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, right eye
        "E103492",  # Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, left eye
        "E103493",  # Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, bilateral
        "E103499",  # Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, unspecified eye
        "E103511",  # Type 1 diabetes mellitus with proliferative diabetic retinopathy with macular edema, right eye
        "E103512",  # Type 1 diabetes mellitus with proliferative diabetic retinopathy with macular edema, left eye
        "E103513",  # Type 1 diabetes mellitus with proliferative diabetic retinopathy with macular edema, bilateral
        "E103519",  # Type 1 diabetes mellitus with proliferative diabetic retinopathy with macular edema, unspecified eye
        "E103521",  # Type 1 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, right eye
        "E103522",  # Type 1 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, left eye
        "E103523",  # Type 1 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, bilateral
        "E103529",  # Type 1 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, unspecified eye
        "E103531",  # Type 1 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, right eye
        "E103532",  # Type 1 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, left eye
        "E103533",  # Type 1 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, bilateral
        "E103539",  # Type 1 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, unspecified eye
        "E103541",  # Type 1 diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, right eye
        "E103542",  # Type 1 diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, left eye
        "E103543",  # Type 1 diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, bilateral
        "E103549",  # Type 1 diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, unspecified eye
        "E103551",  # Type 1 diabetes mellitus with stable proliferative diabetic retinopathy, right eye
        "E103552",  # Type 1 diabetes mellitus with stable proliferative diabetic retinopathy, left eye
        "E103553",  # Type 1 diabetes mellitus with stable proliferative diabetic retinopathy, bilateral
        "E103559",  # Type 1 diabetes mellitus with stable proliferative diabetic retinopathy, unspecified eye
        "E103591",  # Type 1 diabetes mellitus with proliferative diabetic retinopathy without macular edema, right eye
        "E103592",  # Type 1 diabetes mellitus with proliferative diabetic retinopathy without macular edema, left eye
        "E103593",  # Type 1 diabetes mellitus with proliferative diabetic retinopathy without macular edema, bilateral
        "E103599",  # Type 1 diabetes mellitus with proliferative diabetic retinopathy without macular edema, unspecified eye
        "E1036",  # Type 1 diabetes mellitus with diabetic cataract
        "E1037X1",  # Type 1 diabetes mellitus with diabetic macular edema, resolved following treatment, right eye
        "E1037X2",  # Type 1 diabetes mellitus with diabetic macular edema, resolved following treatment, left eye
        "E1037X3",  # Type 1 diabetes mellitus with diabetic macular edema, resolved following treatment, bilateral
        "E1037X9",  # Type 1 diabetes mellitus with diabetic macular edema, resolved following treatment, unspecified eye
        "E1039",  # Type 1 diabetes mellitus with other diabetic ophthalmic complication
        "E1040",  # Type 1 diabetes mellitus with diabetic neuropathy, unspecified
        "E1041",  # Type 1 diabetes mellitus with diabetic mononeuropathy
        "E1042",  # Type 1 diabetes mellitus with diabetic polyneuropathy
        "E1043",  # Type 1 diabetes mellitus with diabetic autonomic (poly)neuropathy
        "E1044",  # Type 1 diabetes mellitus with diabetic amyotrophy
        "E1049",  # Type 1 diabetes mellitus with other diabetic neurological complication
        "E1051",  # Type 1 diabetes mellitus with diabetic peripheral angiopathy without gangrene
        "E1052",  # Type 1 diabetes mellitus with diabetic peripheral angiopathy with gangrene
        "E1059",  # Type 1 diabetes mellitus with other circulatory complications
        "E10610",  # Type 1 diabetes mellitus with diabetic neuropathic arthropathy
        "E10618",  # Type 1 diabetes mellitus with other diabetic arthropathy
        "E10620",  # Type 1 diabetes mellitus with diabetic dermatitis
        "E10621",  # Type 1 diabetes mellitus with foot ulcer
        "E10622",  # Type 1 diabetes mellitus with other skin ulcer
        "E10628",  # Type 1 diabetes mellitus with other skin complications
        "E10630",  # Type 1 diabetes mellitus with periodontal disease
        "E10638",  # Type 1 diabetes mellitus with other oral complications
        "E10641",  # Type 1 diabetes mellitus with hypoglycemia with coma
        "E10649",  # Type 1 diabetes mellitus with hypoglycemia without coma
        "E1065",  # Type 1 diabetes mellitus with hyperglycemia
        "E1069",  # Type 1 diabetes mellitus with other specified complication
        "E108",  # Type 1 diabetes mellitus with unspecified complications
        "E109",  # Type 1 diabetes mellitus without complications
        "E10A0",  # Type 1 diabetes mellitus, presymptomatic, unspecified
        "E10A1",  # Type 1 diabetes mellitus, presymptomatic, Stage 1
        "E10A2",  # Type 1 diabetes mellitus, presymptomatic, Stage 2
        "E1100",  # Type 2 diabetes mellitus with hyperosmolarity without nonketotic hyperglycemic-hyperosmolar coma (NKHHC)
        "E1101",  # Type 2 diabetes mellitus with hyperosmolarity with coma
        "E1110",  # Type 2 diabetes mellitus with ketoacidosis without coma
        "E1111",  # Type 2 diabetes mellitus with ketoacidosis with coma
        "E1121",  # Type 2 diabetes mellitus with diabetic nephropathy
        "E1122",  # Type 2 diabetes mellitus with diabetic chronic kidney disease
        "E1129",  # Type 2 diabetes mellitus with other diabetic kidney complication
        "E11311",  # Type 2 diabetes mellitus with unspecified diabetic retinopathy with macular edema
        "E11319",  # Type 2 diabetes mellitus with unspecified diabetic retinopathy without macular edema
        "E113211",  # Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, right eye
        "E113212",  # Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, left eye
        "E113213",  # Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, bilateral
        "E113219",  # Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, unspecified eye
        "E113291",  # Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, right eye
        "E113292",  # Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, left eye
        "E113293",  # Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, bilateral
        "E113299",  # Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, unspecified eye
        "E113311",  # Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, right eye
        "E113312",  # Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, left eye
        "E113313",  # Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, bilateral
        "E113319",  # Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, unspecified eye
        "E113391",  # Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, right eye
        "E113392",  # Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, left eye
        "E113393",  # Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, bilateral
        "E113399",  # Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, unspecified eye
        "E113411",  # Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, right eye
        "E113412",  # Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, left eye
        "E113413",  # Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, bilateral
        "E113419",  # Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, unspecified eye
        "E113491",  # Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, right eye
        "E113492",  # Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, left eye
        "E113493",  # Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, bilateral
        "E113499",  # Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, unspecified eye
        "E113511",  # Type 2 diabetes mellitus with proliferative diabetic retinopathy with macular edema, right eye
        "E113512",  # Type 2 diabetes mellitus with proliferative diabetic retinopathy with macular edema, left eye
        "E113513",  # Type 2 diabetes mellitus with proliferative diabetic retinopathy with macular edema, bilateral
        "E113519",  # Type 2 diabetes mellitus with proliferative diabetic retinopathy with macular edema, unspecified eye
        "E113521",  # Type 2 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, right eye
        "E113522",  # Type 2 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, left eye
        "E113523",  # Type 2 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, bilateral
        "E113529",  # Type 2 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, unspecified eye
        "E113531",  # Type 2 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, right eye
        "E113532",  # Type 2 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, left eye
        "E113533",  # Type 2 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, bilateral
        "E113539",  # Type 2 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, unspecified eye
        "E113541",  # Type 2 diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, right eye
        "E113542",  # Type 2 diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, left eye
        "E113543",  # Type 2 diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, bilateral
        "E113549",  # Type 2 diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, unspecified eye
        "E113551",  # Type 2 diabetes mellitus with stable proliferative diabetic retinopathy, right eye
        "E113552",  # Type 2 diabetes mellitus with stable proliferative diabetic retinopathy, left eye
        "E113553",  # Type 2 diabetes mellitus with stable proliferative diabetic retinopathy, bilateral
        "E113559",  # Type 2 diabetes mellitus with stable proliferative diabetic retinopathy, unspecified eye
        "E113591",  # Type 2 diabetes mellitus with proliferative diabetic retinopathy without macular edema, right eye
        "E113592",  # Type 2 diabetes mellitus with proliferative diabetic retinopathy without macular edema, left eye
        "E113593",  # Type 2 diabetes mellitus with proliferative diabetic retinopathy without macular edema, bilateral
        "E113599",  # Type 2 diabetes mellitus with proliferative diabetic retinopathy without macular edema, unspecified eye
        "E1136",  # Type 2 diabetes mellitus with diabetic cataract
        "E1137X1",  # Type 2 diabetes mellitus with diabetic macular edema, resolved following treatment, right eye
        "E1137X2",  # Type 2 diabetes mellitus with diabetic macular edema, resolved following treatment, left eye
        "E1137X3",  # Type 2 diabetes mellitus with diabetic macular edema, resolved following treatment, bilateral
        "E1137X9",  # Type 2 diabetes mellitus with diabetic macular edema, resolved following treatment, unspecified eye
        "E1139",  # Type 2 diabetes mellitus with other diabetic ophthalmic complication
        "E1140",  # Type 2 diabetes mellitus with diabetic neuropathy, unspecified
        "E1141",  # Type 2 diabetes mellitus with diabetic mononeuropathy
        "E1142",  # Type 2 diabetes mellitus with diabetic polyneuropathy
        "E1143",  # Type 2 diabetes mellitus with diabetic autonomic (poly)neuropathy
        "E1144",  # Type 2 diabetes mellitus with diabetic amyotrophy
        "E1149",  # Type 2 diabetes mellitus with other diabetic neurological complication
        "E1151",  # Type 2 diabetes mellitus with diabetic peripheral angiopathy without gangrene
        "E1152",  # Type 2 diabetes mellitus with diabetic peripheral angiopathy with gangrene
        "E1159",  # Type 2 diabetes mellitus with other circulatory complications
        "E11610",  # Type 2 diabetes mellitus with diabetic neuropathic arthropathy
        "E11618",  # Type 2 diabetes mellitus with other diabetic arthropathy
        "E11620",  # Type 2 diabetes mellitus with diabetic dermatitis
        "E11621",  # Type 2 diabetes mellitus with foot ulcer
        "E11622",  # Type 2 diabetes mellitus with other skin ulcer
        "E11628",  # Type 2 diabetes mellitus with other skin complications
        "E11630",  # Type 2 diabetes mellitus with periodontal disease
        "E11638",  # Type 2 diabetes mellitus with other oral complications
        "E11641",  # Type 2 diabetes mellitus with hypoglycemia with coma
        "E11649",  # Type 2 diabetes mellitus with hypoglycemia without coma
        "E1165",  # Type 2 diabetes mellitus with hyperglycemia
        "E1169",  # Type 2 diabetes mellitus with other specified complication
        "E118",  # Type 2 diabetes mellitus with unspecified complications
        "E119",  # Type 2 diabetes mellitus without complications
        "E1300",  # Other specified diabetes mellitus with hyperosmolarity without nonketotic hyperglycemic-hyperosmolar coma (NKHHC)
        "E1301",  # Other specified diabetes mellitus with hyperosmolarity with coma
        "E1310",  # Other specified diabetes mellitus with ketoacidosis without coma
        "E1311",  # Other specified diabetes mellitus with ketoacidosis with coma
        "E1321",  # Other specified diabetes mellitus with diabetic nephropathy
        "E1322",  # Other specified diabetes mellitus with diabetic chronic kidney disease
        "E1329",  # Other specified diabetes mellitus with other diabetic kidney complication
        "E13311",  # Other specified diabetes mellitus with unspecified diabetic retinopathy with macular edema
        "E13319",  # Other specified diabetes mellitus with unspecified diabetic retinopathy without macular edema
        "E133211",  # Other specified diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, right eye
        "E133212",  # Other specified diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, left eye
        "E133213",  # Other specified diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, bilateral
        "E133219",  # Other specified diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, unspecified eye
        "E133291",  # Other specified diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, right eye
        "E133292",  # Other specified diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, left eye
        "E133293",  # Other specified diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, bilateral
        "E133299",  # Other specified diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, unspecified eye
        "E133311",  # Other specified diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, right eye
        "E133312",  # Other specified diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, left eye
        "E133313",  # Other specified diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, bilateral
        "E133319",  # Other specified diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, unspecified eye
        "E133391",  # Other specified diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, right eye
        "E133392",  # Other specified diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, left eye
        "E133393",  # Other specified diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, bilateral
        "E133399",  # Other specified diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, unspecified eye
        "E133411",  # Other specified diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, right eye
        "E133412",  # Other specified diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, left eye
        "E133413",  # Other specified diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, bilateral
        "E133419",  # Other specified diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, unspecified eye
        "E133491",  # Other specified diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, right eye
        "E133492",  # Other specified diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, left eye
        "E133493",  # Other specified diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, bilateral
        "E133499",  # Other specified diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, unspecified eye
        "E133511",  # Other specified diabetes mellitus with proliferative diabetic retinopathy with macular edema, right eye
        "E133512",  # Other specified diabetes mellitus with proliferative diabetic retinopathy with macular edema, left eye
        "E133513",  # Other specified diabetes mellitus with proliferative diabetic retinopathy with macular edema, bilateral
        "E133519",  # Other specified diabetes mellitus with proliferative diabetic retinopathy with macular edema, unspecified eye
        "E133521",  # Other specified diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, right eye
        "E133522",  # Other specified diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, left eye
        "E133523",  # Other specified diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, bilateral
        "E133529",  # Other specified diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, unspecified eye
        "E133531",  # Other specified diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, right eye
        "E133532",  # Other specified diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, left eye
        "E133533",  # Other specified diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, bilateral
        "E133539",  # Other specified diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, unspecified eye
        "E133541",  # Other specified diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, right eye
        "E133542",  # Other specified diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, left eye
        "E133543",  # Other specified diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, bilateral
        "E133549",  # Other specified diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, unspecified eye
        "E133551",  # Other specified diabetes mellitus with stable proliferative diabetic retinopathy, right eye
        "E133552",  # Other specified diabetes mellitus with stable proliferative diabetic retinopathy, left eye
        "E133553",  # Other specified diabetes mellitus with stable proliferative diabetic retinopathy, bilateral
        "E133559",  # Other specified diabetes mellitus with stable proliferative diabetic retinopathy, unspecified eye
        "E133591",  # Other specified diabetes mellitus with proliferative diabetic retinopathy without macular edema, right eye
        "E133592",  # Other specified diabetes mellitus with proliferative diabetic retinopathy without macular edema, left eye
        "E133593",  # Other specified diabetes mellitus with proliferative diabetic retinopathy without macular edema, bilateral
        "E133599",  # Other specified diabetes mellitus with proliferative diabetic retinopathy without macular edema, unspecified eye
        "E1336",  # Other specified diabetes mellitus with diabetic cataract
        "E1337X1",  # Other specified diabetes mellitus with diabetic macular edema, resolved following treatment, right eye
        "E1337X2",  # Other specified diabetes mellitus with diabetic macular edema, resolved following treatment, left eye
        "E1337X3",  # Other specified diabetes mellitus with diabetic macular edema, resolved following treatment, bilateral
        "E1337X9",  # Other specified diabetes mellitus with diabetic macular edema, resolved following treatment, unspecified eye
        "E1339",  # Other specified diabetes mellitus with other diabetic ophthalmic complication
        "E1340",  # Other specified diabetes mellitus with diabetic neuropathy, unspecified
        "E1341",  # Other specified diabetes mellitus with diabetic mononeuropathy
        "E1342",  # Other specified diabetes mellitus with diabetic polyneuropathy
        "E1343",  # Other specified diabetes mellitus with diabetic autonomic (poly)neuropathy
        "E1344",  # Other specified diabetes mellitus with diabetic amyotrophy
        "E1349",  # Other specified diabetes mellitus with other diabetic neurological complication
        "E1351",  # Other specified diabetes mellitus with diabetic peripheral angiopathy without gangrene
        "E1352",  # Other specified diabetes mellitus with diabetic peripheral angiopathy with gangrene
        "E1359",  # Other specified diabetes mellitus with other circulatory complications
        "E13610",  # Other specified diabetes mellitus with diabetic neuropathic arthropathy
        "E13618",  # Other specified diabetes mellitus with other diabetic arthropathy
        "E13620",  # Other specified diabetes mellitus with diabetic dermatitis
        "E13621",  # Other specified diabetes mellitus with foot ulcer
        "E13622",  # Other specified diabetes mellitus with other skin ulcer
        "E13628",  # Other specified diabetes mellitus with other skin complications
        "E13630",  # Other specified diabetes mellitus with periodontal disease
        "E13638",  # Other specified diabetes mellitus with other oral complications
        "E13641",  # Other specified diabetes mellitus with hypoglycemia with coma
        "E13649",  # Other specified diabetes mellitus with hypoglycemia without coma
        "E1365",  # Other specified diabetes mellitus with hyperglycemia
        "E1369",  # Other specified diabetes mellitus with other specified complication
        "E138",  # Other specified diabetes mellitus with unspecified complications
        "E139",  # Other specified diabetes mellitus without complications
        "O24011",  # Pre-existing type 1 diabetes mellitus, in pregnancy, first trimester
        "O24012",  # Pre-existing type 1 diabetes mellitus, in pregnancy, second trimester
        "O24013",  # Pre-existing type 1 diabetes mellitus, in pregnancy, third trimester
        "O24019",  # Pre-existing type 1 diabetes mellitus, in pregnancy, unspecified trimester
        "O2402",  # Pre-existing type 1 diabetes mellitus, in childbirth
        "O2403",  # Pre-existing type 1 diabetes mellitus, in the puerperium
        "O24111",  # Pre-existing type 2 diabetes mellitus, in pregnancy, first trimester
        "O24112",  # Pre-existing type 2 diabetes mellitus, in pregnancy, second trimester
        "O24113",  # Pre-existing type 2 diabetes mellitus, in pregnancy, third trimester
        "O24119",  # Pre-existing type 2 diabetes mellitus, in pregnancy, unspecified trimester
        "O2412",  # Pre-existing type 2 diabetes mellitus, in childbirth
        "O2413",  # Pre-existing type 2 diabetes mellitus, in the puerperium
        "O24311",  # Unspecified pre-existing diabetes mellitus in pregnancy, first trimester
        "O24312",  # Unspecified pre-existing diabetes mellitus in pregnancy, second trimester
        "O24313",  # Unspecified pre-existing diabetes mellitus in pregnancy, third trimester
        "O24319",  # Unspecified pre-existing diabetes mellitus in pregnancy, unspecified trimester
        "O2432",  # Unspecified pre-existing diabetes mellitus in childbirth
        "O2433",  # Unspecified pre-existing diabetes mellitus in the puerperium
        "O24811",  # Other pre-existing diabetes mellitus in pregnancy, first trimester
        "O24812",  # Other pre-existing diabetes mellitus in pregnancy, second trimester
        "O24813",  # Other pre-existing diabetes mellitus in pregnancy, third trimester
        "O24819",  # Other pre-existing diabetes mellitus in pregnancy, unspecified trimester
        "O2482",  # Other pre-existing diabetes mellitus in childbirth
        "O2483",  # Other pre-existing diabetes mellitus in the puerperium
        "O24911",  # Unspecified diabetes mellitus in pregnancy, first trimester
        "O24912",  # Unspecified diabetes mellitus in pregnancy, second trimester
        "O24913",  # Unspecified diabetes mellitus in pregnancy, third trimester
        "O24919",  # Unspecified diabetes mellitus in pregnancy, unspecified trimester
        "O2492",  # Unspecified diabetes mellitus in childbirth
        "O2493",  # Unspecified diabetes mellitus in the puerperium
        "Z794",  # Long term (current) use of insulin
    }

class PresentOnAdmissionIsYesOrExempt(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to identify that diagnosis is present on admission or exempt from POA status.

    **Data Element Scope:** This value set may use a model element related to encounter diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis indicator of being present on admission or exempt from POA status.

    **Exclusion Criteria:** Excludes concepts that represent a diagnosis indicator of not being present on admission or unable to determine.
    """

    VALUE_SET_NAME = "Present On Admission is Yes or Exempt"
    OID = "2.16.840.1.113762.1.4.1110.63"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    PresentOnAdmission = {
        "1",  # Unreported/Not used. Exempt from POA reporting
        "Y",  # Diagnosis was present at time of inpatient admission
    }

class PresentOnAdmissionIsNoOrUnableToDetermine(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to identify that diagnosis is not present on admission or unable to determine.

    **Data Element Scope:** This value set may use a model element related to encounter diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis indicator of not being present on admission.

    **Exclusion Criteria:** Excludes concepts that represent a diagnosis indicator being present on admission.
    """

    VALUE_SET_NAME = "Present on Admission is No or Unable To Determine"
    OID = "2.16.840.1.113762.1.4.1029.370"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    PresentOnAdmission = {
        "N",  # Diagnosis was not present at time of inpatient admission
        "U",  # Documentation insufficient to determine if the condition was present at the time of inpatient admission
        "W",  # Clinically undetermined
    }

class PretermBirth(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of a preterm birth.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of a gestation <=36 weeks.

    **Exclusion Criteria:** Excludes concepts that represent a diagnosis of a gestation >=37 weeks.
    """

    VALUE_SET_NAME = "Preterm Birth"
    OID = "2.16.840.1.113762.1.4.1029.299"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "Z3A20",  # 20 weeks gestation of pregnancy
        "Z3A21",  # 21 weeks gestation of pregnancy
        "Z3A22",  # 22 weeks gestation of pregnancy
        "Z3A23",  # 23 weeks gestation of pregnancy
        "Z3A24",  # 24 weeks gestation of pregnancy
        "Z3A25",  # 25 weeks gestation of pregnancy
        "Z3A26",  # 26 weeks gestation of pregnancy
        "Z3A27",  # 27 weeks gestation of pregnancy
        "Z3A28",  # 28 weeks gestation of pregnancy
        "Z3A29",  # 29 weeks gestation of pregnancy
        "Z3A30",  # 30 weeks gestation of pregnancy
        "Z3A31",  # 31 weeks gestation of pregnancy
        "Z3A32",  # 32 weeks gestation of pregnancy
        "Z3A33",  # 33 weeks gestation of pregnancy
        "Z3A34",  # 34 weeks gestation of pregnancy
        "Z3A35",  # 35 weeks gestation of pregnancy
        "Z3A36",  # 36 weeks gestation of pregnancy
    }

class PreviousCesarean(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of a previous cesarean section.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of a previous cesarean section.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Previous Cesarean"
    OID = "2.16.840.1.113762.1.4.1029.278"
    DEFINITION_VERSION = "20220316"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "O34211",  # Maternal care for low transverse scar from previous cesarean delivery
        "O34212",  # Maternal care for vertical scar from previous cesarean delivery
        "O34218",  # Maternal care for other type scar from previous cesarean delivery
        "O34219",  # Maternal care for unspecified type scar from previous cesarean delivery
    }

class PuerperalCerebrovascularDisorder(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to identify diagnoses of a puerperal cerebrovascular disorder.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of a puerperal cerebrovascular disorder.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Puerperal Cerebrovascular Disorder"
    OID = "2.16.840.1.113762.1.4.1029.229"
    DEFINITION_VERSION = "20250207"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "A812",  # Progressive multifocal leukoencephalopathy
        "G450",  # Vertebro-basilar artery syndrome
        "G451",  # Carotid artery syndrome (hemispheric)
        "G452",  # Multiple and bilateral precerebral artery syndromes
        "G453",  # Amaurosis fugax
        "G454",  # Transient global amnesia
        "G458",  # Other transient cerebral ischemic attacks and related syndromes
        "G459",  # Transient cerebral ischemic attack, unspecified
        "G460",  # Middle cerebral artery syndrome
        "G461",  # Anterior cerebral artery syndrome
        "G462",  # Posterior cerebral artery syndrome
        "G463",  # Brain stem stroke syndrome
        "G464",  # Cerebellar stroke syndrome
        "G465",  # Pure motor lacunar syndrome
        "G466",  # Pure sensory lacunar syndrome
        "G467",  # Other lacunar syndromes
        "G468",  # Other vascular syndromes of brain in cerebrovascular diseases
        "G9345",  # Developmental and epileptic encephalopathy
        "G9349",  # Other encephalopathy
        "H3400",  # Transient retinal artery occlusion, unspecified eye
        "H3401",  # Transient retinal artery occlusion, right eye
        "H3402",  # Transient retinal artery occlusion, left eye
        "H3403",  # Transient retinal artery occlusion, bilateral
        "I6000",  # Nontraumatic subarachnoid hemorrhage from unspecified carotid siphon and bifurcation
        "I6001",  # Nontraumatic subarachnoid hemorrhage from right carotid siphon and bifurcation
        "I6002",  # Nontraumatic subarachnoid hemorrhage from left carotid siphon and bifurcation
        "I6010",  # Nontraumatic subarachnoid hemorrhage from unspecified middle cerebral artery
        "I6011",  # Nontraumatic subarachnoid hemorrhage from right middle cerebral artery
        "I6012",  # Nontraumatic subarachnoid hemorrhage from left middle cerebral artery
        "I602",  # Nontraumatic subarachnoid hemorrhage from anterior communicating artery
        "I6030",  # Nontraumatic subarachnoid hemorrhage from unspecified posterior communicating artery
        "I6031",  # Nontraumatic subarachnoid hemorrhage from right posterior communicating artery
        "I6032",  # Nontraumatic subarachnoid hemorrhage from left posterior communicating artery
        "I604",  # Nontraumatic subarachnoid hemorrhage from basilar artery
        "I6050",  # Nontraumatic subarachnoid hemorrhage from unspecified vertebral artery
        "I6051",  # Nontraumatic subarachnoid hemorrhage from right vertebral artery
        "I6052",  # Nontraumatic subarachnoid hemorrhage from left vertebral artery
        "I606",  # Nontraumatic subarachnoid hemorrhage from other intracranial arteries
        "I607",  # Nontraumatic subarachnoid hemorrhage from unspecified intracranial artery
        "I608",  # Other nontraumatic subarachnoid hemorrhage
        "I609",  # Nontraumatic subarachnoid hemorrhage, unspecified
        "I610",  # Nontraumatic intracerebral hemorrhage in hemisphere, subcortical
        "I611",  # Nontraumatic intracerebral hemorrhage in hemisphere, cortical
        "I612",  # Nontraumatic intracerebral hemorrhage in hemisphere, unspecified
        "I613",  # Nontraumatic intracerebral hemorrhage in brain stem
        "I614",  # Nontraumatic intracerebral hemorrhage in cerebellum
        "I615",  # Nontraumatic intracerebral hemorrhage, intraventricular
        "I616",  # Nontraumatic intracerebral hemorrhage, multiple localized
        "I618",  # Other nontraumatic intracerebral hemorrhage
        "I619",  # Nontraumatic intracerebral hemorrhage, unspecified
        "I6200",  # Nontraumatic subdural hemorrhage, unspecified
        "I6201",  # Nontraumatic acute subdural hemorrhage
        "I6202",  # Nontraumatic subacute subdural hemorrhage
        "I6203",  # Nontraumatic chronic subdural hemorrhage
        "I621",  # Nontraumatic extradural hemorrhage
        "I629",  # Nontraumatic intracranial hemorrhage, unspecified
        "I6300",  # Cerebral infarction due to thrombosis of unspecified precerebral artery
        "I63011",  # Cerebral infarction due to thrombosis of right vertebral artery
        "I63012",  # Cerebral infarction due to thrombosis of left vertebral artery
        "I63013",  # Cerebral infarction due to thrombosis of bilateral vertebral arteries
        "I63019",  # Cerebral infarction due to thrombosis of unspecified vertebral artery
        "I6302",  # Cerebral infarction due to thrombosis of basilar artery
        "I63031",  # Cerebral infarction due to thrombosis of right carotid artery
        "I63032",  # Cerebral infarction due to thrombosis of left carotid artery
        "I63033",  # Cerebral infarction due to thrombosis of bilateral carotid arteries
        "I63039",  # Cerebral infarction due to thrombosis of unspecified carotid artery
        "I6309",  # Cerebral infarction due to thrombosis of other precerebral artery
        "I6310",  # Cerebral infarction due to embolism of unspecified precerebral artery
        "I63111",  # Cerebral infarction due to embolism of right vertebral artery
        "I63112",  # Cerebral infarction due to embolism of left vertebral artery
        "I63113",  # Cerebral infarction due to embolism of bilateral vertebral arteries
        "I63119",  # Cerebral infarction due to embolism of unspecified vertebral artery
        "I6312",  # Cerebral infarction due to embolism of basilar artery
        "I63131",  # Cerebral infarction due to embolism of right carotid artery
        "I63132",  # Cerebral infarction due to embolism of left carotid artery
        "I63133",  # Cerebral infarction due to embolism of bilateral carotid arteries
        "I63139",  # Cerebral infarction due to embolism of unspecified carotid artery
        "I6319",  # Cerebral infarction due to embolism of other precerebral artery
        "I6320",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified precerebral arteries
        "I63211",  # Cerebral infarction due to unspecified occlusion or stenosis of right vertebral artery
        "I63212",  # Cerebral infarction due to unspecified occlusion or stenosis of left vertebral artery
        "I63213",  # Cerebral infarction due to unspecified occlusion or stenosis of bilateral vertebral arteries
        "I63219",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified vertebral artery
        "I6322",  # Cerebral infarction due to unspecified occlusion or stenosis of basilar artery
        "I63231",  # Cerebral infarction due to unspecified occlusion or stenosis of right carotid arteries
        "I63232",  # Cerebral infarction due to unspecified occlusion or stenosis of left carotid arteries
        "I63233",  # Cerebral infarction due to unspecified occlusion or stenosis of bilateral carotid arteries
        "I63239",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified carotid artery
        "I6329",  # Cerebral infarction due to unspecified occlusion or stenosis of other precerebral arteries
        "I6330",  # Cerebral infarction due to thrombosis of unspecified cerebral artery
        "I63311",  # Cerebral infarction due to thrombosis of right middle cerebral artery
        "I63312",  # Cerebral infarction due to thrombosis of left middle cerebral artery
        "I63313",  # Cerebral infarction due to thrombosis of bilateral middle cerebral arteries
        "I63319",  # Cerebral infarction due to thrombosis of unspecified middle cerebral artery
        "I63321",  # Cerebral infarction due to thrombosis of right anterior cerebral artery
        "I63322",  # Cerebral infarction due to thrombosis of left anterior cerebral artery
        "I63323",  # Cerebral infarction due to thrombosis of bilateral anterior cerebral arteries
        "I63329",  # Cerebral infarction due to thrombosis of unspecified anterior cerebral artery
        "I63331",  # Cerebral infarction due to thrombosis of right posterior cerebral artery
        "I63332",  # Cerebral infarction due to thrombosis of left posterior cerebral artery
        "I63333",  # Cerebral infarction due to thrombosis of bilateral posterior cerebral arteries
        "I63339",  # Cerebral infarction due to thrombosis of unspecified posterior cerebral artery
        "I63341",  # Cerebral infarction due to thrombosis of right cerebellar artery
        "I63342",  # Cerebral infarction due to thrombosis of left cerebellar artery
        "I63343",  # Cerebral infarction due to thrombosis of bilateral cerebellar arteries
        "I63349",  # Cerebral infarction due to thrombosis of unspecified cerebellar artery
        "I6339",  # Cerebral infarction due to thrombosis of other cerebral artery
        "I6340",  # Cerebral infarction due to embolism of unspecified cerebral artery
        "I63411",  # Cerebral infarction due to embolism of right middle cerebral artery
        "I63412",  # Cerebral infarction due to embolism of left middle cerebral artery
        "I63413",  # Cerebral infarction due to embolism of bilateral middle cerebral arteries
        "I63419",  # Cerebral infarction due to embolism of unspecified middle cerebral artery
        "I63421",  # Cerebral infarction due to embolism of right anterior cerebral artery
        "I63422",  # Cerebral infarction due to embolism of left anterior cerebral artery
        "I63423",  # Cerebral infarction due to embolism of bilateral anterior cerebral arteries
        "I63429",  # Cerebral infarction due to embolism of unspecified anterior cerebral artery
        "I63431",  # Cerebral infarction due to embolism of right posterior cerebral artery
        "I63432",  # Cerebral infarction due to embolism of left posterior cerebral artery
        "I63433",  # Cerebral infarction due to embolism of bilateral posterior cerebral arteries
        "I63439",  # Cerebral infarction due to embolism of unspecified posterior cerebral artery
        "I63441",  # Cerebral infarction due to embolism of right cerebellar artery
        "I63442",  # Cerebral infarction due to embolism of left cerebellar artery
        "I63443",  # Cerebral infarction due to embolism of bilateral cerebellar arteries
        "I63449",  # Cerebral infarction due to embolism of unspecified cerebellar artery
        "I6349",  # Cerebral infarction due to embolism of other cerebral artery
        "I6350",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified cerebral artery
        "I63511",  # Cerebral infarction due to unspecified occlusion or stenosis of right middle cerebral artery
        "I63512",  # Cerebral infarction due to unspecified occlusion or stenosis of left middle cerebral artery
        "I63513",  # Cerebral infarction due to unspecified occlusion or stenosis of bilateral middle cerebral arteries
        "I63519",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified middle cerebral artery
        "I63521",  # Cerebral infarction due to unspecified occlusion or stenosis of right anterior cerebral artery
        "I63522",  # Cerebral infarction due to unspecified occlusion or stenosis of left anterior cerebral artery
        "I63523",  # Cerebral infarction due to unspecified occlusion or stenosis of bilateral anterior cerebral arteries
        "I63529",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified anterior cerebral artery
        "I63531",  # Cerebral infarction due to unspecified occlusion or stenosis of right posterior cerebral artery
        "I63532",  # Cerebral infarction due to unspecified occlusion or stenosis of left posterior cerebral artery
        "I63533",  # Cerebral infarction due to unspecified occlusion or stenosis of bilateral posterior cerebral arteries
        "I63539",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified posterior cerebral artery
        "I63541",  # Cerebral infarction due to unspecified occlusion or stenosis of right cerebellar artery
        "I63542",  # Cerebral infarction due to unspecified occlusion or stenosis of left cerebellar artery
        "I63543",  # Cerebral infarction due to unspecified occlusion or stenosis of bilateral cerebellar arteries
        "I63549",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified cerebellar artery
        "I6359",  # Cerebral infarction due to unspecified occlusion or stenosis of other cerebral artery
        "I636",  # Cerebral infarction due to cerebral venous thrombosis, nonpyogenic
        "I6381",  # Other cerebral infarction due to occlusion or stenosis of small artery
        "I6389",  # Other cerebral infarction
        "I639",  # Cerebral infarction, unspecified
        "I6501",  # Occlusion and stenosis of right vertebral artery
        "I6502",  # Occlusion and stenosis of left vertebral artery
        "I6503",  # Occlusion and stenosis of bilateral vertebral arteries
        "I6509",  # Occlusion and stenosis of unspecified vertebral artery
        "I651",  # Occlusion and stenosis of basilar artery
        "I6521",  # Occlusion and stenosis of right carotid artery
        "I6522",  # Occlusion and stenosis of left carotid artery
        "I6523",  # Occlusion and stenosis of bilateral carotid arteries
        "I6529",  # Occlusion and stenosis of unspecified carotid artery
        "I658",  # Occlusion and stenosis of other precerebral arteries
        "I659",  # Occlusion and stenosis of unspecified precerebral artery
        "I6601",  # Occlusion and stenosis of right middle cerebral artery
        "I6602",  # Occlusion and stenosis of left middle cerebral artery
        "I6603",  # Occlusion and stenosis of bilateral middle cerebral arteries
        "I6609",  # Occlusion and stenosis of unspecified middle cerebral artery
        "I6611",  # Occlusion and stenosis of right anterior cerebral artery
        "I6612",  # Occlusion and stenosis of left anterior cerebral artery
        "I6613",  # Occlusion and stenosis of bilateral anterior cerebral arteries
        "I6619",  # Occlusion and stenosis of unspecified anterior cerebral artery
        "I6621",  # Occlusion and stenosis of right posterior cerebral artery
        "I6622",  # Occlusion and stenosis of left posterior cerebral artery
        "I6623",  # Occlusion and stenosis of bilateral posterior cerebral arteries
        "I6629",  # Occlusion and stenosis of unspecified posterior cerebral artery
        "I663",  # Occlusion and stenosis of cerebellar arteries
        "I668",  # Occlusion and stenosis of other cerebral arteries
        "I669",  # Occlusion and stenosis of unspecified cerebral artery
        "I670",  # Dissection of cerebral arteries, nonruptured
        "I671",  # Cerebral aneurysm, nonruptured
        "I672",  # Cerebral atherosclerosis
        "I673",  # Progressive vascular leukoencephalopathy
        "I674",  # Hypertensive encephalopathy
        "I675",  # Moyamoya disease
        "I676",  # Nonpyogenic thrombosis of intracranial venous system
        "I677",  # Cerebral arteritis, not elsewhere classified
        "I6781",  # Acute cerebrovascular insufficiency
        "I6782",  # Cerebral ischemia
        "I6783",  # Posterior reversible encephalopathy syndrome
        "I67841",  # Reversible cerebrovascular vasoconstriction syndrome
        "I67848",  # Other cerebrovascular vasospasm and vasoconstriction
        "I6789",  # Other cerebrovascular disease
        "I679",  # Cerebrovascular disease, unspecified
        "I680",  # Cerebral amyloid angiopathy
        "I682",  # Cerebral arteritis in other diseases classified elsewhere
        "I688",  # Other cerebrovascular disorders in diseases classified elsewhere
        "I97810",  # Intraoperative cerebrovascular infarction during cardiac surgery
        "I97811",  # Intraoperative cerebrovascular infarction during other surgery
        "I97820",  # Postprocedural cerebrovascular infarction following cardiac surgery
        "I97821",  # Postprocedural cerebrovascular infarction following other surgery
        "O2250",  # Cerebral venous thrombosis in pregnancy, unspecified trimester
        "O2252",  # Cerebral venous thrombosis in pregnancy, second trimester
        "O2253",  # Cerebral venous thrombosis in pregnancy, third trimester
        "O873",  # Cerebral venous thrombosis in the puerperium
    }

class PulmonaryEdema(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to identify diagnoses of a pulmonary edema.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of an acute pulmonary edema.

    **Exclusion Criteria:** Excludes concepts that represent a diagnosis of a chronic pulmonary edema.
    """

    VALUE_SET_NAME = "Pulmonary Edema"
    OID = "2.16.840.1.113762.1.4.1029.231"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "J810",  # Acute pulmonary edema
    }

class PulmonaryHypertension(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of pulmonary hypertension.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of a pulmonary hypertension.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Pulmonary Hypertension"
    OID = "2.16.840.1.113762.1.4.1029.281"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "I270",  # Primary pulmonary hypertension
        "I2720",  # Pulmonary hypertension, unspecified
        "I2721",  # Secondary pulmonary arterial hypertension
        "I2722",  # Pulmonary hypertension due to left heart disease
        "I2723",  # Pulmonary hypertension due to lung diseases and hypoxia
        "I2724",  # Chronic thromboembolic pulmonary hypertension
        "I2729",  # Other secondary pulmonary hypertension
    }

class RenalDisease(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of renal disease.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of renal disease.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Renal Disease"
    OID = "2.16.840.1.113762.1.4.1029.335"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "I120",  # Hypertensive chronic kidney disease with stage 5 chronic kidney disease or end stage renal disease
        "I129",  # Hypertensive chronic kidney disease with stage 1 through stage 4 chronic kidney disease, or unspecified chronic kidney disease
        "I130",  # Hypertensive heart and chronic kidney disease with heart failure and stage 1 through stage 4 chronic kidney disease, or unspecified chronic kidney disease
        "I1310",  # Hypertensive heart and chronic kidney disease without heart failure, with stage 1 through stage 4 chronic kidney disease, or unspecified chronic kidney disease
        "I1311",  # Hypertensive heart and chronic kidney disease without heart failure, with stage 5 chronic kidney disease, or end stage renal disease
        "I132",  # Hypertensive heart and chronic kidney disease with heart failure and with stage 5 chronic kidney disease, or end stage renal disease
        "N030",  # Chronic nephritic syndrome with minor glomerular abnormality
        "N031",  # Chronic nephritic syndrome with focal and segmental glomerular lesions
        "N032",  # Chronic nephritic syndrome with diffuse membranous glomerulonephritis
        "N033",  # Chronic nephritic syndrome with diffuse mesangial proliferative glomerulonephritis
        "N034",  # Chronic nephritic syndrome with diffuse endocapillary proliferative glomerulonephritis
        "N035",  # Chronic nephritic syndrome with diffuse mesangiocapillary glomerulonephritis
        "N036",  # Chronic nephritic syndrome with dense deposit disease
        "N037",  # Chronic nephritic syndrome with diffuse crescentic glomerulonephritis
        "N038",  # Chronic nephritic syndrome with other morphologic changes
        "N039",  # Chronic nephritic syndrome with unspecified morphologic changes
        "N03A",  # Chronic nephritic syndrome with C3 glomerulonephritis
        "N040",  # Nephrotic syndrome with minor glomerular abnormality
        "N041",  # Nephrotic syndrome with focal and segmental glomerular lesions
        "N0420",  # Nephrotic syndrome with diffuse membranous glomerulonephritis, unspecified
        "N0421",  # Primary membranous nephropathy with nephrotic syndrome
        "N0422",  # Secondary membranous nephropathy with nephrotic syndrome
        "N0429",  # Other nephrotic syndrome with diffuse membranous glomerulonephritis
        "N043",  # Nephrotic syndrome with diffuse mesangial proliferative glomerulonephritis
        "N044",  # Nephrotic syndrome with diffuse endocapillary proliferative glomerulonephritis
        "N045",  # Nephrotic syndrome with diffuse mesangiocapillary glomerulonephritis
        "N046",  # Nephrotic syndrome with dense deposit disease
        "N047",  # Nephrotic syndrome with diffuse crescentic glomerulonephritis
        "N048",  # Nephrotic syndrome with other morphologic changes
        "N049",  # Nephrotic syndrome with unspecified morphologic changes
        "N04A",  # Nephrotic syndrome with C3 glomerulonephritis
        "N050",  # Unspecified nephritic syndrome with minor glomerular abnormality
        "N051",  # Unspecified nephritic syndrome with focal and segmental glomerular lesions
        "N052",  # Unspecified nephritic syndrome with diffuse membranous glomerulonephritis
        "N053",  # Unspecified nephritic syndrome with diffuse mesangial proliferative glomerulonephritis
        "N054",  # Unspecified nephritic syndrome with diffuse endocapillary proliferative glomerulonephritis
        "N055",  # Unspecified nephritic syndrome with diffuse mesangiocapillary glomerulonephritis
        "N056",  # Unspecified nephritic syndrome with dense deposit disease
        "N057",  # Unspecified nephritic syndrome with diffuse crescentic glomerulonephritis
        "N058",  # Unspecified nephritic syndrome with other morphologic changes
        "N059",  # Unspecified nephritic syndrome with unspecified morphologic changes
        "N05A",  # Unspecified nephritic syndrome with C3 glomerulonephritis
        "N070",  # Hereditary nephropathy, not elsewhere classified with minor glomerular abnormality
        "N071",  # Hereditary nephropathy, not elsewhere classified with focal and segmental glomerular lesions
        "N072",  # Hereditary nephropathy, not elsewhere classified with diffuse membranous glomerulonephritis
        "N073",  # Hereditary nephropathy, not elsewhere classified with diffuse mesangial proliferative glomerulonephritis
        "N074",  # Hereditary nephropathy, not elsewhere classified with diffuse endocapillary proliferative glomerulonephritis
        "N075",  # Hereditary nephropathy, not elsewhere classified with diffuse mesangiocapillary glomerulonephritis
        "N076",  # Hereditary nephropathy, not elsewhere classified with dense deposit disease
        "N077",  # Hereditary nephropathy, not elsewhere classified with diffuse crescentic glomerulonephritis
        "N078",  # Hereditary nephropathy, not elsewhere classified with other morphologic lesions
        "N079",  # Hereditary nephropathy, not elsewhere classified with unspecified morphologic lesions
        "N07A",  # Hereditary nephropathy, not elsewhere classified with C3 glomerulonephritis
        "N08",  # Glomerular disorders in diseases classified elsewhere
        "N111",  # Chronic obstructive pyelonephritis
        "N118",  # Other chronic tubulo-interstitial nephritis
        "N119",  # Chronic tubulo-interstitial nephritis, unspecified
        "N181",  # Chronic kidney disease, stage 1
        "N182",  # Chronic kidney disease, stage 2 (mild)
        "N1830",  # Chronic kidney disease, stage 3 unspecified
        "N1831",  # Chronic kidney disease, stage 3a
        "N1832",  # Chronic kidney disease, stage 3b
        "N184",  # Chronic kidney disease, stage 4 (severe)
        "N185",  # Chronic kidney disease, stage 5
        "N186",  # End stage renal disease
        "N189",  # Chronic kidney disease, unspecified
        "N250",  # Renal osteodystrophy
        "N251",  # Nephrogenic diabetes insipidus
        "N2581",  # Secondary hyperparathyroidism of renal origin
        "N2589",  # Other disorders resulting from impaired renal tubular function
        "N259",  # Disorder resulting from impaired renal tubular function, unspecified
        "N269",  # Renal sclerosis, unspecified
        "O26831",  # Pregnancy related renal disease, first trimester
        "O26832",  # Pregnancy related renal disease, second trimester
        "O26833",  # Pregnancy related renal disease, third trimester
        "O26839",  # Pregnancy related renal disease, unspecified trimester
    }

class Sepsis(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to identify diagnoses of sepsis.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of sepsis.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Sepsis"
    OID = "2.16.840.1.113762.1.4.1029.237"
    DEFINITION_VERSION = "20240210"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "A327",  # Listerial sepsis
        "A400",  # Sepsis due to streptococcus, group A
        "A401",  # Sepsis due to streptococcus, group B
        "A403",  # Sepsis due to Streptococcus pneumoniae
        "A408",  # Other streptococcal sepsis
        "A409",  # Streptococcal sepsis, unspecified
        "A4101",  # Sepsis due to Methicillin susceptible Staphylococcus aureus
        "A4102",  # Sepsis due to Methicillin resistant Staphylococcus aureus
        "A411",  # Sepsis due to other specified staphylococcus
        "A412",  # Sepsis due to unspecified staphylococcus
        "A413",  # Sepsis due to Hemophilus influenzae
        "A414",  # Sepsis due to anaerobes
        "A4150",  # Gram-negative sepsis, unspecified
        "A4151",  # Sepsis due to Escherichia coli [E. coli]
        "A4152",  # Sepsis due to Pseudomonas
        "A4153",  # Sepsis due to Serratia
        "A4154",  # Sepsis due to Acinetobacter baumannii
        "A4159",  # Other Gram-negative sepsis
        "A4181",  # Sepsis due to Enterococcus
        "A4189",  # Other specified sepsis
        "A419",  # Sepsis, unspecified organism
        "I76",  # Septic arterial embolism
        "O85",  # Puerperal sepsis
        "O8604",  # Sepsis following an obstetrical procedure
        "R6520",  # Severe sepsis without septic shock
        "R6521",  # Severe sepsis with septic shock
        "T8112XA",  # Postprocedural septic shock, initial encounter
        "T8144XA",  # Sepsis following a procedure, initial encounter
    }

class SevereAnesthesiaComplications(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to identify diagnoses of severe anesthesia complications.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of a severe anesthesia complications.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Severe Anesthesia Complications"
    OID = "2.16.840.1.113762.1.4.1029.235"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "O29112",  # Cardiac arrest due to anesthesia during pregnancy, second trimester
        "O29113",  # Cardiac arrest due to anesthesia during pregnancy, third trimester
        "O29119",  # Cardiac arrest due to anesthesia during pregnancy, unspecified trimester
        "O29122",  # Cardiac failure due to anesthesia during pregnancy, second trimester
        "O29123",  # Cardiac failure due to anesthesia during pregnancy, third trimester
        "O29129",  # Cardiac failure due to anesthesia during pregnancy, unspecified trimester
        "O29192",  # Other cardiac complications of anesthesia during pregnancy, second trimester
        "O29193",  # Other cardiac complications of anesthesia during pregnancy, third trimester
        "O29199",  # Other cardiac complications of anesthesia during pregnancy, unspecified trimester
        "O29212",  # Cerebral anoxia due to anesthesia during pregnancy, second trimester
        "O29213",  # Cerebral anoxia due to anesthesia during pregnancy, third trimester
        "O29219",  # Cerebral anoxia due to anesthesia during pregnancy, unspecified trimester
        "O29292",  # Other central nervous system complications of anesthesia during pregnancy, second trimester
        "O29293",  # Other central nervous system complications of anesthesia during pregnancy, third trimester
        "O29299",  # Other central nervous system complications of anesthesia during pregnancy, unspecified trimester
        "O740",  # Aspiration pneumonitis due to anesthesia during labor and delivery
        "O741",  # Other pulmonary complications of anesthesia during labor and delivery
        "O742",  # Cardiac complications of anesthesia during labor and delivery
        "O743",  # Central nervous system complications of anesthesia during labor and delivery
        "O8901",  # Aspiration pneumonitis due to anesthesia during the puerperium
        "O8909",  # Other pulmonary complications of anesthesia during the puerperium
        "O891",  # Cardiac complications of anesthesia during the puerperium
        "O892",  # Central nervous system complications of anesthesia during the puerperium
        "T882XXA",  # Shock due to anesthesia, initial encounter
        "T883XXA",  # Malignant hyperthermia due to anesthesia, initial encounter
    }

class SevereMaternalMorbidityDiagnoses(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of severe maternal morbidities.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of a severe maternal morbidity.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Severe Maternal Morbidity Diagnoses"
    OID = "2.16.840.1.113762.1.4.1029.255"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "A327",  # Listerial sepsis
        "A400",  # Sepsis due to streptococcus, group A
        "A401",  # Sepsis due to streptococcus, group B
        "A403",  # Sepsis due to Streptococcus pneumoniae
        "A408",  # Other streptococcal sepsis
        "A409",  # Streptococcal sepsis, unspecified
        "A4101",  # Sepsis due to Methicillin susceptible Staphylococcus aureus
        "A4102",  # Sepsis due to Methicillin resistant Staphylococcus aureus
        "A411",  # Sepsis due to other specified staphylococcus
        "A412",  # Sepsis due to unspecified staphylococcus
        "A413",  # Sepsis due to Hemophilus influenzae
        "A414",  # Sepsis due to anaerobes
        "A4150",  # Gram-negative sepsis, unspecified
        "A4151",  # Sepsis due to Escherichia coli [E. coli]
        "A4152",  # Sepsis due to Pseudomonas
        "A4153",  # Sepsis due to Serratia
        "A4154",  # Sepsis due to Acinetobacter baumannii
        "A4159",  # Other Gram-negative sepsis
        "A4181",  # Sepsis due to Enterococcus
        "A4189",  # Other specified sepsis
        "A419",  # Sepsis, unspecified organism
        "A812",  # Progressive multifocal leukoencephalopathy
        "D5700",  # Hb-SS disease with crisis, unspecified
        "D5701",  # Hb-SS disease with acute chest syndrome
        "D5702",  # Hb-SS disease with splenic sequestration
        "D5703",  # Hb-SS disease with cerebral vascular involvement
        "D5704",  # Hb-SS disease with dactylitis
        "D5709",  # Hb-SS disease with crisis with other specified complication
        "D57211",  # Sickle-cell/Hb-C disease with acute chest syndrome
        "D57212",  # Sickle-cell/Hb-C disease with splenic sequestration
        "D57213",  # Sickle-cell/Hb-C disease with cerebral vascular involvement
        "D57214",  # Sickle-cell/Hb-C disease with dactylitis
        "D57218",  # Sickle-cell/Hb-C disease with crisis with other specified complication
        "D57219",  # Sickle-cell/Hb-C disease with crisis, unspecified
        "D57411",  # Sickle-cell thalassemia, unspecified, with acute chest syndrome
        "D57412",  # Sickle-cell thalassemia, unspecified, with splenic sequestration
        "D57413",  # Sickle-cell thalassemia, unspecified, with cerebral vascular involvement
        "D57414",  # Sickle-cell thalassemia, unspecified, with dactylitis
        "D57418",  # Sickle-cell thalassemia, unspecified, with crisis with other specified complication
        "D57419",  # Sickle-cell thalassemia, unspecified, with crisis
        "D57431",  # Sickle-cell thalassemia beta zero with acute chest syndrome
        "D57432",  # Sickle-cell thalassemia beta zero with splenic sequestration
        "D57433",  # Sickle-cell thalassemia beta zero with cerebral vascular involvement
        "D57434",  # Sickle-cell thalassemia beta zero with dactylitis
        "D57438",  # Sickle-cell thalassemia beta zero with crisis with other specified complication
        "D57439",  # Sickle-cell thalassemia beta zero with crisis, unspecified
        "D57451",  # Sickle-cell thalassemia beta plus with acute chest syndrome
        "D57452",  # Sickle-cell thalassemia beta plus with splenic sequestration
        "D57453",  # Sickle-cell thalassemia beta plus with cerebral vascular involvement
        "D57454",  # Sickle-cell thalassemia beta plus with dactylitis
        "D57458",  # Sickle-cell thalassemia beta plus with crisis with other specified complication
        "D57459",  # Sickle-cell thalassemia beta plus with crisis, unspecified
        "D57811",  # Other sickle-cell disorders with acute chest syndrome
        "D57812",  # Other sickle-cell disorders with splenic sequestration
        "D57813",  # Other sickle-cell disorders with cerebral vascular involvement
        "D57814",  # Other sickle-cell disorders with dactylitis
        "D57818",  # Other sickle-cell disorders with crisis with other specified complication
        "D57819",  # Other sickle-cell disorders with crisis, unspecified
        "D65",  # Disseminated intravascular coagulation [defibrination syndrome]
        "D688",  # Other specified coagulation defects
        "D689",  # Coagulation defect, unspecified
        "G450",  # Vertebro-basilar artery syndrome
        "G451",  # Carotid artery syndrome (hemispheric)
        "G452",  # Multiple and bilateral precerebral artery syndromes
        "G453",  # Amaurosis fugax
        "G454",  # Transient global amnesia
        "G458",  # Other transient cerebral ischemic attacks and related syndromes
        "G459",  # Transient cerebral ischemic attack, unspecified
        "G460",  # Middle cerebral artery syndrome
        "G461",  # Anterior cerebral artery syndrome
        "G462",  # Posterior cerebral artery syndrome
        "G463",  # Brain stem stroke syndrome
        "G464",  # Cerebellar stroke syndrome
        "G465",  # Pure motor lacunar syndrome
        "G466",  # Pure sensory lacunar syndrome
        "G467",  # Other lacunar syndromes
        "G468",  # Other vascular syndromes of brain in cerebrovascular diseases
        "G9345",  # Developmental and epileptic encephalopathy
        "G9349",  # Other encephalopathy
        "H3400",  # Transient retinal artery occlusion, unspecified eye
        "H3401",  # Transient retinal artery occlusion, right eye
        "H3402",  # Transient retinal artery occlusion, left eye
        "H3403",  # Transient retinal artery occlusion, bilateral
        "I2101",  # ST elevation (STEMI) myocardial infarction involving left main coronary artery
        "I2102",  # ST elevation (STEMI) myocardial infarction involving left anterior descending coronary artery
        "I2109",  # ST elevation (STEMI) myocardial infarction involving other coronary artery of anterior wall
        "I2111",  # ST elevation (STEMI) myocardial infarction involving right coronary artery
        "I2119",  # ST elevation (STEMI) myocardial infarction involving other coronary artery of inferior wall
        "I2121",  # ST elevation (STEMI) myocardial infarction involving left circumflex coronary artery
        "I2129",  # ST elevation (STEMI) myocardial infarction involving other sites
        "I213",  # ST elevation (STEMI) myocardial infarction of unspecified site
        "I214",  # Non-ST elevation (NSTEMI) myocardial infarction
        "I219",  # Acute myocardial infarction, unspecified
        "I21A1",  # Myocardial infarction type 2
        "I21A9",  # Other myocardial infarction type
        "I21B",  # Myocardial infarction with coronary microvascular dysfunction
        "I220",  # Subsequent ST elevation (STEMI) myocardial infarction of anterior wall
        "I221",  # Subsequent ST elevation (STEMI) myocardial infarction of inferior wall
        "I222",  # Subsequent non-ST elevation (NSTEMI) myocardial infarction
        "I228",  # Subsequent ST elevation (STEMI) myocardial infarction of other sites
        "I229",  # Subsequent ST elevation (STEMI) myocardial infarction of unspecified site
        "I2601",  # Septic pulmonary embolism with acute cor pulmonale
        "I2602",  # Saddle embolus of pulmonary artery with acute cor pulmonale
        "I2604",  # Fat embolism of pulmonary artery with acute cor pulmonale
        "I2609",  # Other pulmonary embolism with acute cor pulmonale
        "I2690",  # Septic pulmonary embolism without acute cor pulmonale
        "I2692",  # Saddle embolus of pulmonary artery without acute cor pulmonale
        "I2693",  # Single subsegmental thrombotic pulmonary embolism without acute cor pulmonale
        "I2694",  # Multiple subsegmental thrombotic pulmonary emboli without acute cor pulmonale
        "I2696",  # Fat embolism of pulmonary artery without acute cor pulmonale
        "I2699",  # Other pulmonary embolism without acute cor pulmonale
        "I462",  # Cardiac arrest due to underlying cardiac condition
        "I468",  # Cardiac arrest due to other underlying condition
        "I469",  # Cardiac arrest, cause unspecified
        "I4901",  # Ventricular fibrillation
        "I4902",  # Ventricular flutter
        "I501",  # Left ventricular failure, unspecified
        "I5020",  # Unspecified systolic (congestive) heart failure
        "I5021",  # Acute systolic (congestive) heart failure
        "I5023",  # Acute on chronic systolic (congestive) heart failure
        "I5030",  # Unspecified diastolic (congestive) heart failure
        "I5031",  # Acute diastolic (congestive) heart failure
        "I5033",  # Acute on chronic diastolic (congestive) heart failure
        "I5040",  # Unspecified combined systolic (congestive) and diastolic (congestive) heart failure
        "I5041",  # Acute combined systolic (congestive) and diastolic (congestive) heart failure
        "I5043",  # Acute on chronic combined systolic (congestive) and diastolic (congestive) heart failure
        "I50810",  # Right heart failure, unspecified
        "I50811",  # Acute right heart failure
        "I50813",  # Acute on chronic right heart failure
        "I50814",  # Right heart failure due to left heart failure
        "I5082",  # Biventricular heart failure
        "I5083",  # High output heart failure
        "I5084",  # End stage heart failure
        "I5089",  # Other heart failure
        "I509",  # Heart failure, unspecified
        "I6000",  # Nontraumatic subarachnoid hemorrhage from unspecified carotid siphon and bifurcation
        "I6001",  # Nontraumatic subarachnoid hemorrhage from right carotid siphon and bifurcation
        "I6002",  # Nontraumatic subarachnoid hemorrhage from left carotid siphon and bifurcation
        "I6010",  # Nontraumatic subarachnoid hemorrhage from unspecified middle cerebral artery
        "I6011",  # Nontraumatic subarachnoid hemorrhage from right middle cerebral artery
        "I6012",  # Nontraumatic subarachnoid hemorrhage from left middle cerebral artery
        "I602",  # Nontraumatic subarachnoid hemorrhage from anterior communicating artery
        "I6030",  # Nontraumatic subarachnoid hemorrhage from unspecified posterior communicating artery
        "I6031",  # Nontraumatic subarachnoid hemorrhage from right posterior communicating artery
        "I6032",  # Nontraumatic subarachnoid hemorrhage from left posterior communicating artery
        "I604",  # Nontraumatic subarachnoid hemorrhage from basilar artery
        "I6050",  # Nontraumatic subarachnoid hemorrhage from unspecified vertebral artery
        "I6051",  # Nontraumatic subarachnoid hemorrhage from right vertebral artery
        "I6052",  # Nontraumatic subarachnoid hemorrhage from left vertebral artery
        "I606",  # Nontraumatic subarachnoid hemorrhage from other intracranial arteries
        "I607",  # Nontraumatic subarachnoid hemorrhage from unspecified intracranial artery
        "I608",  # Other nontraumatic subarachnoid hemorrhage
        "I609",  # Nontraumatic subarachnoid hemorrhage, unspecified
        "I610",  # Nontraumatic intracerebral hemorrhage in hemisphere, subcortical
        "I611",  # Nontraumatic intracerebral hemorrhage in hemisphere, cortical
        "I612",  # Nontraumatic intracerebral hemorrhage in hemisphere, unspecified
        "I613",  # Nontraumatic intracerebral hemorrhage in brain stem
        "I614",  # Nontraumatic intracerebral hemorrhage in cerebellum
        "I615",  # Nontraumatic intracerebral hemorrhage, intraventricular
        "I616",  # Nontraumatic intracerebral hemorrhage, multiple localized
        "I618",  # Other nontraumatic intracerebral hemorrhage
        "I619",  # Nontraumatic intracerebral hemorrhage, unspecified
        "I6200",  # Nontraumatic subdural hemorrhage, unspecified
        "I6201",  # Nontraumatic acute subdural hemorrhage
        "I6202",  # Nontraumatic subacute subdural hemorrhage
        "I6203",  # Nontraumatic chronic subdural hemorrhage
        "I621",  # Nontraumatic extradural hemorrhage
        "I629",  # Nontraumatic intracranial hemorrhage, unspecified
        "I6300",  # Cerebral infarction due to thrombosis of unspecified precerebral artery
        "I63011",  # Cerebral infarction due to thrombosis of right vertebral artery
        "I63012",  # Cerebral infarction due to thrombosis of left vertebral artery
        "I63013",  # Cerebral infarction due to thrombosis of bilateral vertebral arteries
        "I63019",  # Cerebral infarction due to thrombosis of unspecified vertebral artery
        "I6302",  # Cerebral infarction due to thrombosis of basilar artery
        "I63031",  # Cerebral infarction due to thrombosis of right carotid artery
        "I63032",  # Cerebral infarction due to thrombosis of left carotid artery
        "I63033",  # Cerebral infarction due to thrombosis of bilateral carotid arteries
        "I63039",  # Cerebral infarction due to thrombosis of unspecified carotid artery
        "I6309",  # Cerebral infarction due to thrombosis of other precerebral artery
        "I6310",  # Cerebral infarction due to embolism of unspecified precerebral artery
        "I63111",  # Cerebral infarction due to embolism of right vertebral artery
        "I63112",  # Cerebral infarction due to embolism of left vertebral artery
        "I63113",  # Cerebral infarction due to embolism of bilateral vertebral arteries
        "I63119",  # Cerebral infarction due to embolism of unspecified vertebral artery
        "I6312",  # Cerebral infarction due to embolism of basilar artery
        "I63131",  # Cerebral infarction due to embolism of right carotid artery
        "I63132",  # Cerebral infarction due to embolism of left carotid artery
        "I63133",  # Cerebral infarction due to embolism of bilateral carotid arteries
        "I63139",  # Cerebral infarction due to embolism of unspecified carotid artery
        "I6319",  # Cerebral infarction due to embolism of other precerebral artery
        "I6320",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified precerebral arteries
        "I63211",  # Cerebral infarction due to unspecified occlusion or stenosis of right vertebral artery
        "I63212",  # Cerebral infarction due to unspecified occlusion or stenosis of left vertebral artery
        "I63213",  # Cerebral infarction due to unspecified occlusion or stenosis of bilateral vertebral arteries
        "I63219",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified vertebral artery
        "I6322",  # Cerebral infarction due to unspecified occlusion or stenosis of basilar artery
        "I63231",  # Cerebral infarction due to unspecified occlusion or stenosis of right carotid arteries
        "I63232",  # Cerebral infarction due to unspecified occlusion or stenosis of left carotid arteries
        "I63233",  # Cerebral infarction due to unspecified occlusion or stenosis of bilateral carotid arteries
        "I63239",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified carotid artery
        "I6329",  # Cerebral infarction due to unspecified occlusion or stenosis of other precerebral arteries
        "I6330",  # Cerebral infarction due to thrombosis of unspecified cerebral artery
        "I63311",  # Cerebral infarction due to thrombosis of right middle cerebral artery
        "I63312",  # Cerebral infarction due to thrombosis of left middle cerebral artery
        "I63313",  # Cerebral infarction due to thrombosis of bilateral middle cerebral arteries
        "I63319",  # Cerebral infarction due to thrombosis of unspecified middle cerebral artery
        "I63321",  # Cerebral infarction due to thrombosis of right anterior cerebral artery
        "I63322",  # Cerebral infarction due to thrombosis of left anterior cerebral artery
        "I63323",  # Cerebral infarction due to thrombosis of bilateral anterior cerebral arteries
        "I63329",  # Cerebral infarction due to thrombosis of unspecified anterior cerebral artery
        "I63331",  # Cerebral infarction due to thrombosis of right posterior cerebral artery
        "I63332",  # Cerebral infarction due to thrombosis of left posterior cerebral artery
        "I63333",  # Cerebral infarction due to thrombosis of bilateral posterior cerebral arteries
        "I63339",  # Cerebral infarction due to thrombosis of unspecified posterior cerebral artery
        "I63341",  # Cerebral infarction due to thrombosis of right cerebellar artery
        "I63342",  # Cerebral infarction due to thrombosis of left cerebellar artery
        "I63343",  # Cerebral infarction due to thrombosis of bilateral cerebellar arteries
        "I63349",  # Cerebral infarction due to thrombosis of unspecified cerebellar artery
        "I6339",  # Cerebral infarction due to thrombosis of other cerebral artery
        "I6340",  # Cerebral infarction due to embolism of unspecified cerebral artery
        "I63411",  # Cerebral infarction due to embolism of right middle cerebral artery
        "I63412",  # Cerebral infarction due to embolism of left middle cerebral artery
        "I63413",  # Cerebral infarction due to embolism of bilateral middle cerebral arteries
        "I63419",  # Cerebral infarction due to embolism of unspecified middle cerebral artery
        "I63421",  # Cerebral infarction due to embolism of right anterior cerebral artery
        "I63422",  # Cerebral infarction due to embolism of left anterior cerebral artery
        "I63423",  # Cerebral infarction due to embolism of bilateral anterior cerebral arteries
        "I63429",  # Cerebral infarction due to embolism of unspecified anterior cerebral artery
        "I63431",  # Cerebral infarction due to embolism of right posterior cerebral artery
        "I63432",  # Cerebral infarction due to embolism of left posterior cerebral artery
        "I63433",  # Cerebral infarction due to embolism of bilateral posterior cerebral arteries
        "I63439",  # Cerebral infarction due to embolism of unspecified posterior cerebral artery
        "I63441",  # Cerebral infarction due to embolism of right cerebellar artery
        "I63442",  # Cerebral infarction due to embolism of left cerebellar artery
        "I63443",  # Cerebral infarction due to embolism of bilateral cerebellar arteries
        "I63449",  # Cerebral infarction due to embolism of unspecified cerebellar artery
        "I6349",  # Cerebral infarction due to embolism of other cerebral artery
        "I6350",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified cerebral artery
        "I63511",  # Cerebral infarction due to unspecified occlusion or stenosis of right middle cerebral artery
        "I63512",  # Cerebral infarction due to unspecified occlusion or stenosis of left middle cerebral artery
        "I63513",  # Cerebral infarction due to unspecified occlusion or stenosis of bilateral middle cerebral arteries
        "I63519",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified middle cerebral artery
        "I63521",  # Cerebral infarction due to unspecified occlusion or stenosis of right anterior cerebral artery
        "I63522",  # Cerebral infarction due to unspecified occlusion or stenosis of left anterior cerebral artery
        "I63523",  # Cerebral infarction due to unspecified occlusion or stenosis of bilateral anterior cerebral arteries
        "I63529",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified anterior cerebral artery
        "I63531",  # Cerebral infarction due to unspecified occlusion or stenosis of right posterior cerebral artery
        "I63532",  # Cerebral infarction due to unspecified occlusion or stenosis of left posterior cerebral artery
        "I63533",  # Cerebral infarction due to unspecified occlusion or stenosis of bilateral posterior cerebral arteries
        "I63539",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified posterior cerebral artery
        "I63541",  # Cerebral infarction due to unspecified occlusion or stenosis of right cerebellar artery
        "I63542",  # Cerebral infarction due to unspecified occlusion or stenosis of left cerebellar artery
        "I63543",  # Cerebral infarction due to unspecified occlusion or stenosis of bilateral cerebellar arteries
        "I63549",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified cerebellar artery
        "I6359",  # Cerebral infarction due to unspecified occlusion or stenosis of other cerebral artery
        "I636",  # Cerebral infarction due to cerebral venous thrombosis, nonpyogenic
        "I6381",  # Other cerebral infarction due to occlusion or stenosis of small artery
        "I6389",  # Other cerebral infarction
        "I639",  # Cerebral infarction, unspecified
        "I6501",  # Occlusion and stenosis of right vertebral artery
        "I6502",  # Occlusion and stenosis of left vertebral artery
        "I6503",  # Occlusion and stenosis of bilateral vertebral arteries
        "I6509",  # Occlusion and stenosis of unspecified vertebral artery
        "I651",  # Occlusion and stenosis of basilar artery
        "I6521",  # Occlusion and stenosis of right carotid artery
        "I6522",  # Occlusion and stenosis of left carotid artery
        "I6523",  # Occlusion and stenosis of bilateral carotid arteries
        "I6529",  # Occlusion and stenosis of unspecified carotid artery
        "I658",  # Occlusion and stenosis of other precerebral arteries
        "I659",  # Occlusion and stenosis of unspecified precerebral artery
        "I6601",  # Occlusion and stenosis of right middle cerebral artery
        "I6602",  # Occlusion and stenosis of left middle cerebral artery
        "I6603",  # Occlusion and stenosis of bilateral middle cerebral arteries
        "I6609",  # Occlusion and stenosis of unspecified middle cerebral artery
        "I6611",  # Occlusion and stenosis of right anterior cerebral artery
        "I6612",  # Occlusion and stenosis of left anterior cerebral artery
        "I6613",  # Occlusion and stenosis of bilateral anterior cerebral arteries
        "I6619",  # Occlusion and stenosis of unspecified anterior cerebral artery
        "I6621",  # Occlusion and stenosis of right posterior cerebral artery
        "I6622",  # Occlusion and stenosis of left posterior cerebral artery
        "I6623",  # Occlusion and stenosis of bilateral posterior cerebral arteries
        "I6629",  # Occlusion and stenosis of unspecified posterior cerebral artery
        "I663",  # Occlusion and stenosis of cerebellar arteries
        "I668",  # Occlusion and stenosis of other cerebral arteries
        "I669",  # Occlusion and stenosis of unspecified cerebral artery
        "I670",  # Dissection of cerebral arteries, nonruptured
        "I671",  # Cerebral aneurysm, nonruptured
        "I672",  # Cerebral atherosclerosis
        "I673",  # Progressive vascular leukoencephalopathy
        "I674",  # Hypertensive encephalopathy
        "I675",  # Moyamoya disease
        "I676",  # Nonpyogenic thrombosis of intracranial venous system
        "I677",  # Cerebral arteritis, not elsewhere classified
        "I6781",  # Acute cerebrovascular insufficiency
        "I6782",  # Cerebral ischemia
        "I6783",  # Posterior reversible encephalopathy syndrome
        "I67841",  # Reversible cerebrovascular vasoconstriction syndrome
        "I67848",  # Other cerebrovascular vasospasm and vasoconstriction
        "I6789",  # Other cerebrovascular disease
        "I679",  # Cerebrovascular disease, unspecified
        "I680",  # Cerebral amyloid angiopathy
        "I682",  # Cerebral arteritis in other diseases classified elsewhere
        "I688",  # Other cerebrovascular disorders in diseases classified elsewhere
        "I7100",  # Dissection of unspecified site of aorta
        "I71010",  # Dissection of ascending aorta
        "I71011",  # Dissection of aortic arch
        "I71012",  # Dissection of descending thoracic aorta
        "I71019",  # Dissection of thoracic aorta, unspecified
        "I7102",  # Dissection of abdominal aorta
        "I7103",  # Dissection of thoracoabdominal aorta
        "I7110",  # Thoracic aortic aneurysm, ruptured, unspecified
        "I7111",  # Aneurysm of the ascending aorta, ruptured
        "I7112",  # Aneurysm of the aortic arch, ruptured
        "I7113",  # Aneurysm of the descending thoracic aorta, ruptured
        "I7120",  # Thoracic aortic aneurysm, without rupture, unspecified
        "I7121",  # Aneurysm of the ascending aorta, without rupture
        "I7122",  # Aneurysm of the aortic arch, without rupture
        "I7123",  # Aneurysm of the descending thoracic aorta, without rupture
        "I7130",  # Abdominal aortic aneurysm, ruptured, unspecified
        "I7131",  # Pararenal abdominal aortic aneurysm, ruptured
        "I7132",  # Juxtarenal abdominal aortic aneurysm, ruptured
        "I7133",  # Infrarenal abdominal aortic aneurysm, ruptured
        "I7140",  # Abdominal aortic aneurysm, without rupture, unspecified
        "I7141",  # Pararenal abdominal aortic aneurysm, without rupture
        "I7142",  # Juxtarenal abdominal aortic aneurysm, without rupture
        "I7143",  # Infrarenal abdominal aortic aneurysm, without rupture
        "I7150",  # Thoracoabdominal aortic aneurysm, ruptured, unspecified
        "I7151",  # Supraceliac aneurysm of the thoracoabdominal aorta, ruptured
        "I7152",  # Paravisceral aneurysm of the thoracoabdominal aorta, ruptured
        "I7160",  # Thoracoabdominal aortic aneurysm, without rupture, unspecified
        "I7161",  # Supraceliac aneurysm of the thoracoabdominal aorta, without rupture
        "I7162",  # Paravisceral aneurysm of the thoracoabdominal aorta, without rupture
        "I718",  # Aortic aneurysm of unspecified site, ruptured
        "I719",  # Aortic aneurysm of unspecified site, without rupture
        "I76",  # Septic arterial embolism
        "I790",  # Aneurysm of aorta in diseases classified elsewhere
        "I97120",  # Postprocedural cardiac arrest following cardiac surgery
        "I97121",  # Postprocedural cardiac arrest following other surgery
        "I97130",  # Postprocedural heart failure following cardiac surgery
        "I97131",  # Postprocedural heart failure following other surgery
        "I97710",  # Intraoperative cardiac arrest during cardiac surgery
        "I97711",  # Intraoperative cardiac arrest during other surgery
        "I97810",  # Intraoperative cerebrovascular infarction during cardiac surgery
        "I97811",  # Intraoperative cerebrovascular infarction during other surgery
        "I97820",  # Postprocedural cerebrovascular infarction following cardiac surgery
        "I97821",  # Postprocedural cerebrovascular infarction following other surgery
        "J80",  # Acute respiratory distress syndrome
        "J810",  # Acute pulmonary edema
        "J951",  # Acute pulmonary insufficiency following thoracic surgery
        "J952",  # Acute pulmonary insufficiency following nonthoracic surgery
        "J953",  # Chronic pulmonary insufficiency following surgery
        "J95821",  # Acute postprocedural respiratory failure
        "J95822",  # Acute and chronic postprocedural respiratory failure
        "J9600",  # Acute respiratory failure, unspecified whether with hypoxia or hypercapnia
        "J9601",  # Acute respiratory failure with hypoxia
        "J9602",  # Acute respiratory failure with hypercapnia
        "J9620",  # Acute and chronic respiratory failure, unspecified whether with hypoxia or hypercapnia
        "J9621",  # Acute and chronic respiratory failure with hypoxia
        "J9622",  # Acute and chronic respiratory failure with hypercapnia
        "J9690",  # Respiratory failure, unspecified, unspecified whether with hypoxia or hypercapnia
        "J9691",  # Respiratory failure, unspecified with hypoxia
        "J9692",  # Respiratory failure, unspecified with hypercapnia
        "N170",  # Acute kidney failure with tubular necrosis
        "N171",  # Acute kidney failure with acute cortical necrosis
        "N172",  # Acute kidney failure with medullary necrosis
        "N178",  # Other acute kidney failure
        "N179",  # Acute kidney failure, unspecified
        "O1500",  # Eclampsia complicating pregnancy, unspecified trimester
        "O1502",  # Eclampsia complicating pregnancy, second trimester
        "O1503",  # Eclampsia complicating pregnancy, third trimester
        "O151",  # Eclampsia complicating labor
        "O152",  # Eclampsia complicating the puerperium
        "O159",  # Eclampsia, unspecified as to time period
        "O2250",  # Cerebral venous thrombosis in pregnancy, unspecified trimester
        "O2252",  # Cerebral venous thrombosis in pregnancy, second trimester
        "O2253",  # Cerebral venous thrombosis in pregnancy, third trimester
        "O29112",  # Cardiac arrest due to anesthesia during pregnancy, second trimester
        "O29113",  # Cardiac arrest due to anesthesia during pregnancy, third trimester
        "O29119",  # Cardiac arrest due to anesthesia during pregnancy, unspecified trimester
        "O29122",  # Cardiac failure due to anesthesia during pregnancy, second trimester
        "O29123",  # Cardiac failure due to anesthesia during pregnancy, third trimester
        "O29129",  # Cardiac failure due to anesthesia during pregnancy, unspecified trimester
        "O29192",  # Other cardiac complications of anesthesia during pregnancy, second trimester
        "O29193",  # Other cardiac complications of anesthesia during pregnancy, third trimester
        "O29199",  # Other cardiac complications of anesthesia during pregnancy, unspecified trimester
        "O29212",  # Cerebral anoxia due to anesthesia during pregnancy, second trimester
        "O29213",  # Cerebral anoxia due to anesthesia during pregnancy, third trimester
        "O29219",  # Cerebral anoxia due to anesthesia during pregnancy, unspecified trimester
        "O29292",  # Other central nervous system complications of anesthesia during pregnancy, second trimester
        "O29293",  # Other central nervous system complications of anesthesia during pregnancy, third trimester
        "O29299",  # Other central nervous system complications of anesthesia during pregnancy, unspecified trimester
        "O45002",  # Premature separation of placenta with coagulation defect, unspecified, second trimester
        "O45003",  # Premature separation of placenta with coagulation defect, unspecified, third trimester
        "O45009",  # Premature separation of placenta with coagulation defect, unspecified, unspecified trimester
        "O45012",  # Premature separation of placenta with afibrinogenemia, second trimester
        "O45013",  # Premature separation of placenta with afibrinogenemia, third trimester
        "O45019",  # Premature separation of placenta with afibrinogenemia, unspecified trimester
        "O45022",  # Premature separation of placenta with disseminated intravascular coagulation, second trimester
        "O45023",  # Premature separation of placenta with disseminated intravascular coagulation, third trimester
        "O45029",  # Premature separation of placenta with disseminated intravascular coagulation, unspecified trimester
        "O45092",  # Premature separation of placenta with other coagulation defect, second trimester
        "O45093",  # Premature separation of placenta with other coagulation defect, third trimester
        "O45099",  # Premature separation of placenta with other coagulation defect, unspecified trimester
        "O46002",  # Antepartum hemorrhage with coagulation defect, unspecified, second trimester
        "O46003",  # Antepartum hemorrhage with coagulation defect, unspecified, third trimester
        "O46009",  # Antepartum hemorrhage with coagulation defect, unspecified, unspecified trimester
        "O46012",  # Antepartum hemorrhage with afibrinogenemia, second trimester
        "O46013",  # Antepartum hemorrhage with afibrinogenemia, third trimester
        "O46019",  # Antepartum hemorrhage with afibrinogenemia, unspecified trimester
        "O46022",  # Antepartum hemorrhage with disseminated intravascular coagulation, second trimester
        "O46023",  # Antepartum hemorrhage with disseminated intravascular coagulation, third trimester
        "O46029",  # Antepartum hemorrhage with disseminated intravascular coagulation, unspecified trimester
        "O46092",  # Antepartum hemorrhage with other coagulation defect, second trimester
        "O46093",  # Antepartum hemorrhage with other coagulation defect, third trimester
        "O46099",  # Antepartum hemorrhage with other coagulation defect, unspecified trimester
        "O670",  # Intrapartum hemorrhage with coagulation defect
        "O740",  # Aspiration pneumonitis due to anesthesia during labor and delivery
        "O741",  # Other pulmonary complications of anesthesia during labor and delivery
        "O742",  # Cardiac complications of anesthesia during labor and delivery
        "O743",  # Central nervous system complications of anesthesia during labor and delivery
        "O751",  # Shock during or following labor and delivery
        "O85",  # Puerperal sepsis
        "O8604",  # Sepsis following an obstetrical procedure
        "O873",  # Cerebral venous thrombosis in the puerperium
        "O88012",  # Air embolism in pregnancy, second trimester
        "O88013",  # Air embolism in pregnancy, third trimester
        "O88019",  # Air embolism in pregnancy, unspecified trimester
        "O8802",  # Air embolism in childbirth
        "O8803",  # Air embolism in the puerperium
        "O88112",  # Amniotic fluid embolism in pregnancy, second trimester
        "O88113",  # Amniotic fluid embolism in pregnancy, third trimester
        "O88119",  # Amniotic fluid embolism in pregnancy, unspecified trimester
        "O8812",  # Amniotic fluid embolism in childbirth
        "O8813",  # Amniotic fluid embolism in the puerperium
        "O88212",  # Thromboembolism in pregnancy, second trimester
        "O88213",  # Thromboembolism in pregnancy, third trimester
        "O88219",  # Thromboembolism in pregnancy, unspecified trimester
        "O8822",  # Thromboembolism in childbirth
        "O8823",  # Thromboembolism in the puerperium
        "O88312",  # Pyemic and septic embolism in pregnancy, second trimester
        "O88313",  # Pyemic and septic embolism in pregnancy, third trimester
        "O88319",  # Pyemic and septic embolism in pregnancy, unspecified trimester
        "O8832",  # Pyemic and septic embolism in childbirth
        "O8833",  # Pyemic and septic embolism in the puerperium
        "O88812",  # Other embolism in pregnancy, second trimester
        "O88813",  # Other embolism in pregnancy, third trimester
        "O88819",  # Other embolism in pregnancy, unspecified trimester
        "O8882",  # Other embolism in childbirth
        "O8883",  # Other embolism in the puerperium
        "O8901",  # Aspiration pneumonitis due to anesthesia during the puerperium
        "O8909",  # Other pulmonary complications of anesthesia during the puerperium
        "O891",  # Cardiac complications of anesthesia during the puerperium
        "O892",  # Central nervous system complications of anesthesia during the puerperium
        "O9041",  # Hepatorenal syndrome following labor and delivery
        "O9049",  # Other postpartum acute kidney failure
        "R0603",  # Acute respiratory distress
        "R092",  # Respiratory arrest
        "R570",  # Cardiogenic shock
        "R571",  # Hypovolemic shock
        "R578",  # Other shock
        "R579",  # Shock, unspecified
        "R6520",  # Severe sepsis without septic shock
        "R6521",  # Severe sepsis with septic shock
        "T782XXA",  # Anaphylactic shock, unspecified, initial encounter
        "T800XXA",  # Air embolism following infusion, transfusion and therapeutic injection, initial encounter
        "T8110XA",  # Postprocedural shock unspecified, initial encounter
        "T8111XA",  # Postprocedural cardiogenic shock, initial encounter
        "T8112XA",  # Postprocedural septic shock, initial encounter
        "T8119XA",  # Other postprocedural shock, initial encounter
        "T8144XA",  # Sepsis following a procedure, initial encounter
        "T882XXA",  # Shock due to anesthesia, initial encounter
        "T883XXA",  # Malignant hyperthermia due to anesthesia, initial encounter
        "T886XXA",  # Anaphylactic reaction due to adverse effect of correct drug or medicament properly administered, initial encounter
    }

class SeverePreeclampsia(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of severe pre-eclampsia.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of a severe pre-eclampsia.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Severe Preeclampsia"
    OID = "2.16.840.1.113762.1.4.1029.327"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "O111",  # Pre-existing hypertension with pre-eclampsia, first trimester
        "O112",  # Pre-existing hypertension with pre-eclampsia, second trimester
        "O113",  # Pre-existing hypertension with pre-eclampsia, third trimester
        "O114",  # Pre-existing hypertension with pre-eclampsia, complicating childbirth
        "O115",  # Pre-existing hypertension with pre-eclampsia, complicating the puerperium
        "O119",  # Pre-existing hypertension with pre-eclampsia, unspecified trimester
        "O1410",  # Severe pre-eclampsia, unspecified trimester
        "O1412",  # Severe pre-eclampsia, second trimester
        "O1413",  # Severe pre-eclampsia, third trimester
        "O1414",  # Severe pre-eclampsia complicating childbirth
        "O1415",  # Severe pre-eclampsia, complicating the puerperium
        "O1420",  # HELLP syndrome (HELLP), unspecified trimester
        "O1422",  # HELLP syndrome (HELLP), second trimester
        "O1423",  # HELLP syndrome (HELLP), third trimester
        "O1424",  # HELLP syndrome, complicating childbirth
        "O1425",  # HELLP syndrome, complicating the puerperium
    }

class Shock(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to identify diagnoses of shock.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of shock.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Shock"
    OID = "2.16.840.1.113762.1.4.1029.239"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "O751",  # Shock during or following labor and delivery
        "R570",  # Cardiogenic shock
        "R571",  # Hypovolemic shock
        "R578",  # Other shock
        "R579",  # Shock, unspecified
        "T782XXA",  # Anaphylactic shock, unspecified, initial encounter
        "T8110XA",  # Postprocedural shock unspecified, initial encounter
        "T8111XA",  # Postprocedural cardiogenic shock, initial encounter
        "T8119XA",  # Other postprocedural shock, initial encounter
        "T886XXA",  # Anaphylactic reaction due to adverse effect of correct drug or medicament properly administered, initial encounter
    }

class SickleCellDiseaseWithCrisis(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to identify diagnoses of sickle cell disease with crisis.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of sickle cell disease with crisis.

    **Exclusion Criteria:** Excludes concepts that identify a diagnosis of sickle cell disease without crisis.
    """

    VALUE_SET_NAME = "Sickle Cell Disease with Crisis"
    OID = "2.16.840.1.113762.1.4.1029.241"
    DEFINITION_VERSION = "20240210"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "D5700",  # Hb-SS disease with crisis, unspecified
        "D5701",  # Hb-SS disease with acute chest syndrome
        "D5702",  # Hb-SS disease with splenic sequestration
        "D5703",  # Hb-SS disease with cerebral vascular involvement
        "D5704",  # Hb-SS disease with dactylitis
        "D5709",  # Hb-SS disease with crisis with other specified complication
        "D57211",  # Sickle-cell/Hb-C disease with acute chest syndrome
        "D57212",  # Sickle-cell/Hb-C disease with splenic sequestration
        "D57213",  # Sickle-cell/Hb-C disease with cerebral vascular involvement
        "D57214",  # Sickle-cell/Hb-C disease with dactylitis
        "D57218",  # Sickle-cell/Hb-C disease with crisis with other specified complication
        "D57219",  # Sickle-cell/Hb-C disease with crisis, unspecified
        "D57411",  # Sickle-cell thalassemia, unspecified, with acute chest syndrome
        "D57412",  # Sickle-cell thalassemia, unspecified, with splenic sequestration
        "D57413",  # Sickle-cell thalassemia, unspecified, with cerebral vascular involvement
        "D57414",  # Sickle-cell thalassemia, unspecified, with dactylitis
        "D57418",  # Sickle-cell thalassemia, unspecified, with crisis with other specified complication
        "D57419",  # Sickle-cell thalassemia, unspecified, with crisis
        "D57431",  # Sickle-cell thalassemia beta zero with acute chest syndrome
        "D57432",  # Sickle-cell thalassemia beta zero with splenic sequestration
        "D57433",  # Sickle-cell thalassemia beta zero with cerebral vascular involvement
        "D57434",  # Sickle-cell thalassemia beta zero with dactylitis
        "D57438",  # Sickle-cell thalassemia beta zero with crisis with other specified complication
        "D57439",  # Sickle-cell thalassemia beta zero with crisis, unspecified
        "D57451",  # Sickle-cell thalassemia beta plus with acute chest syndrome
        "D57452",  # Sickle-cell thalassemia beta plus with splenic sequestration
        "D57453",  # Sickle-cell thalassemia beta plus with cerebral vascular involvement
        "D57454",  # Sickle-cell thalassemia beta plus with dactylitis
        "D57458",  # Sickle-cell thalassemia beta plus with crisis with other specified complication
        "D57459",  # Sickle-cell thalassemia beta plus with crisis, unspecified
        "D57811",  # Other sickle-cell disorders with acute chest syndrome
        "D57812",  # Other sickle-cell disorders with splenic sequestration
        "D57813",  # Other sickle-cell disorders with cerebral vascular involvement
        "D57814",  # Other sickle-cell disorders with dactylitis
        "D57818",  # Other sickle-cell disorders with crisis with other specified complication
        "D57819",  # Other sickle-cell disorders with crisis, unspecified
    }

class SubstanceAbuse(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of substance abuse.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of substance abuse.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Substance Abuse"
    OID = "2.16.840.1.113762.1.4.1029.320"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "F1010",  # Alcohol abuse, uncomplicated
        "F1011",  # Alcohol abuse, in remission
        "F10120",  # Alcohol abuse with intoxication, uncomplicated
        "F10121",  # Alcohol abuse with intoxication delirium
        "F10129",  # Alcohol abuse with intoxication, unspecified
        "F10130",  # Alcohol abuse with withdrawal, uncomplicated
        "F10131",  # Alcohol abuse with withdrawal delirium
        "F10132",  # Alcohol abuse with withdrawal with perceptual disturbance
        "F10139",  # Alcohol abuse with withdrawal, unspecified
        "F1014",  # Alcohol abuse with alcohol-induced mood disorder
        "F10150",  # Alcohol abuse with alcohol-induced psychotic disorder with delusions
        "F10151",  # Alcohol abuse with alcohol-induced psychotic disorder with hallucinations
        "F10159",  # Alcohol abuse with alcohol-induced psychotic disorder, unspecified
        "F10180",  # Alcohol abuse with alcohol-induced anxiety disorder
        "F10181",  # Alcohol abuse with alcohol-induced sexual dysfunction
        "F10182",  # Alcohol abuse with alcohol-induced sleep disorder
        "F10188",  # Alcohol abuse with other alcohol-induced disorder
        "F1019",  # Alcohol abuse with unspecified alcohol-induced disorder
        "F1020",  # Alcohol dependence, uncomplicated
        "F1021",  # Alcohol dependence, in remission
        "F10220",  # Alcohol dependence with intoxication, uncomplicated
        "F10221",  # Alcohol dependence with intoxication delirium
        "F10229",  # Alcohol dependence with intoxication, unspecified
        "F10230",  # Alcohol dependence with withdrawal, uncomplicated
        "F10231",  # Alcohol dependence with withdrawal delirium
        "F10232",  # Alcohol dependence with withdrawal with perceptual disturbance
        "F10239",  # Alcohol dependence with withdrawal, unspecified
        "F1024",  # Alcohol dependence with alcohol-induced mood disorder
        "F10250",  # Alcohol dependence with alcohol-induced psychotic disorder with delusions
        "F10251",  # Alcohol dependence with alcohol-induced psychotic disorder with hallucinations
        "F10259",  # Alcohol dependence with alcohol-induced psychotic disorder, unspecified
        "F1026",  # Alcohol dependence with alcohol-induced persisting amnestic disorder
        "F1027",  # Alcohol dependence with alcohol-induced persisting dementia
        "F10280",  # Alcohol dependence with alcohol-induced anxiety disorder
        "F10281",  # Alcohol dependence with alcohol-induced sexual dysfunction
        "F10282",  # Alcohol dependence with alcohol-induced sleep disorder
        "F10288",  # Alcohol dependence with other alcohol-induced disorder
        "F1029",  # Alcohol dependence with unspecified alcohol-induced disorder
        "F1091",  # Alcohol use, unspecified, in remission
        "F10920",  # Alcohol use, unspecified with intoxication, uncomplicated
        "F10921",  # Alcohol use, unspecified with intoxication delirium
        "F10929",  # Alcohol use, unspecified with intoxication, unspecified
        "F10930",  # Alcohol use, unspecified with withdrawal, uncomplicated
        "F10931",  # Alcohol use, unspecified with withdrawal delirium
        "F10932",  # Alcohol use, unspecified with withdrawal with perceptual disturbance
        "F10939",  # Alcohol use, unspecified with withdrawal, unspecified
        "F1094",  # Alcohol use, unspecified with alcohol-induced mood disorder
        "F10950",  # Alcohol use, unspecified with alcohol-induced psychotic disorder with delusions
        "F10951",  # Alcohol use, unspecified with alcohol-induced psychotic disorder with hallucinations
        "F10959",  # Alcohol use, unspecified with alcohol-induced psychotic disorder, unspecified
        "F1096",  # Alcohol use, unspecified with alcohol-induced persisting amnestic disorder
        "F1097",  # Alcohol use, unspecified with alcohol-induced persisting dementia
        "F10980",  # Alcohol use, unspecified with alcohol-induced anxiety disorder
        "F10981",  # Alcohol use, unspecified with alcohol-induced sexual dysfunction
        "F10982",  # Alcohol use, unspecified with alcohol-induced sleep disorder
        "F10988",  # Alcohol use, unspecified with other alcohol-induced disorder
        "F1099",  # Alcohol use, unspecified with unspecified alcohol-induced disorder
        "F1110",  # Opioid abuse, uncomplicated
        "F1111",  # Opioid abuse, in remission
        "F11120",  # Opioid abuse with intoxication, uncomplicated
        "F11121",  # Opioid abuse with intoxication delirium
        "F11122",  # Opioid abuse with intoxication with perceptual disturbance
        "F11129",  # Opioid abuse with intoxication, unspecified
        "F1113",  # Opioid abuse with withdrawal
        "F1114",  # Opioid abuse with opioid-induced mood disorder
        "F11150",  # Opioid abuse with opioid-induced psychotic disorder with delusions
        "F11151",  # Opioid abuse with opioid-induced psychotic disorder with hallucinations
        "F11159",  # Opioid abuse with opioid-induced psychotic disorder, unspecified
        "F11181",  # Opioid abuse with opioid-induced sexual dysfunction
        "F11182",  # Opioid abuse with opioid-induced sleep disorder
        "F11188",  # Opioid abuse with other opioid-induced disorder
        "F1119",  # Opioid abuse with unspecified opioid-induced disorder
        "F1120",  # Opioid dependence, uncomplicated
        "F1121",  # Opioid dependence, in remission
        "F11220",  # Opioid dependence with intoxication, uncomplicated
        "F11221",  # Opioid dependence with intoxication delirium
        "F11222",  # Opioid dependence with intoxication with perceptual disturbance
        "F11229",  # Opioid dependence with intoxication, unspecified
        "F1123",  # Opioid dependence with withdrawal
        "F1124",  # Opioid dependence with opioid-induced mood disorder
        "F11250",  # Opioid dependence with opioid-induced psychotic disorder with delusions
        "F11251",  # Opioid dependence with opioid-induced psychotic disorder with hallucinations
        "F11259",  # Opioid dependence with opioid-induced psychotic disorder, unspecified
        "F11281",  # Opioid dependence with opioid-induced sexual dysfunction
        "F11282",  # Opioid dependence with opioid-induced sleep disorder
        "F11288",  # Opioid dependence with other opioid-induced disorder
        "F1129",  # Opioid dependence with unspecified opioid-induced disorder
        "F1190",  # Opioid use, unspecified, uncomplicated
        "F1191",  # Opioid use, unspecified, in remission
        "F11920",  # Opioid use, unspecified with intoxication, uncomplicated
        "F11921",  # Opioid use, unspecified with intoxication delirium
        "F11922",  # Opioid use, unspecified with intoxication with perceptual disturbance
        "F11929",  # Opioid use, unspecified with intoxication, unspecified
        "F1193",  # Opioid use, unspecified with withdrawal
        "F1194",  # Opioid use, unspecified with opioid-induced mood disorder
        "F11950",  # Opioid use, unspecified with opioid-induced psychotic disorder with delusions
        "F11951",  # Opioid use, unspecified with opioid-induced psychotic disorder with hallucinations
        "F11959",  # Opioid use, unspecified with opioid-induced psychotic disorder, unspecified
        "F11981",  # Opioid use, unspecified with opioid-induced sexual dysfunction
        "F11982",  # Opioid use, unspecified with opioid-induced sleep disorder
        "F11988",  # Opioid use, unspecified with other opioid-induced disorder
        "F1199",  # Opioid use, unspecified with unspecified opioid-induced disorder
        "F1210",  # Cannabis abuse, uncomplicated
        "F1211",  # Cannabis abuse, in remission
        "F12120",  # Cannabis abuse with intoxication, uncomplicated
        "F12121",  # Cannabis abuse with intoxication delirium
        "F12122",  # Cannabis abuse with intoxication with perceptual disturbance
        "F12129",  # Cannabis abuse with intoxication, unspecified
        "F1213",  # Cannabis abuse with withdrawal
        "F12150",  # Cannabis abuse with psychotic disorder with delusions
        "F12151",  # Cannabis abuse with psychotic disorder with hallucinations
        "F12159",  # Cannabis abuse with psychotic disorder, unspecified
        "F12180",  # Cannabis abuse with cannabis-induced anxiety disorder
        "F12188",  # Cannabis abuse with other cannabis-induced disorder
        "F1219",  # Cannabis abuse with unspecified cannabis-induced disorder
        "F1220",  # Cannabis dependence, uncomplicated
        "F1221",  # Cannabis dependence, in remission
        "F12220",  # Cannabis dependence with intoxication, uncomplicated
        "F12221",  # Cannabis dependence with intoxication delirium
        "F12222",  # Cannabis dependence with intoxication with perceptual disturbance
        "F12229",  # Cannabis dependence with intoxication, unspecified
        "F1223",  # Cannabis dependence with withdrawal
        "F12250",  # Cannabis dependence with psychotic disorder with delusions
        "F12251",  # Cannabis dependence with psychotic disorder with hallucinations
        "F12259",  # Cannabis dependence with psychotic disorder, unspecified
        "F12280",  # Cannabis dependence with cannabis-induced anxiety disorder
        "F12288",  # Cannabis dependence with other cannabis-induced disorder
        "F1229",  # Cannabis dependence with unspecified cannabis-induced disorder
        "F1290",  # Cannabis use, unspecified, uncomplicated
        "F1291",  # Cannabis use, unspecified, in remission
        "F12920",  # Cannabis use, unspecified with intoxication, uncomplicated
        "F12921",  # Cannabis use, unspecified with intoxication delirium
        "F12922",  # Cannabis use, unspecified with intoxication with perceptual disturbance
        "F12929",  # Cannabis use, unspecified with intoxication, unspecified
        "F1293",  # Cannabis use, unspecified with withdrawal
        "F12950",  # Cannabis use, unspecified with psychotic disorder with delusions
        "F12951",  # Cannabis use, unspecified with psychotic disorder with hallucinations
        "F12959",  # Cannabis use, unspecified with psychotic disorder, unspecified
        "F12980",  # Cannabis use, unspecified with anxiety disorder
        "F12988",  # Cannabis use, unspecified with other cannabis-induced disorder
        "F1299",  # Cannabis use, unspecified with unspecified cannabis-induced disorder
        "F1310",  # Sedative, hypnotic or anxiolytic abuse, uncomplicated
        "F1311",  # Sedative, hypnotic or anxiolytic abuse, in remission
        "F13120",  # Sedative, hypnotic or anxiolytic abuse with intoxication, uncomplicated
        "F13121",  # Sedative, hypnotic or anxiolytic abuse with intoxication delirium
        "F13129",  # Sedative, hypnotic or anxiolytic abuse with intoxication, unspecified
        "F13130",  # Sedative, hypnotic or anxiolytic abuse with withdrawal, uncomplicated
        "F13131",  # Sedative, hypnotic or anxiolytic abuse with withdrawal delirium
        "F13132",  # Sedative, hypnotic or anxiolytic abuse with withdrawal with perceptual disturbance
        "F13139",  # Sedative, hypnotic or anxiolytic abuse with withdrawal, unspecified
        "F1314",  # Sedative, hypnotic or anxiolytic abuse with sedative, hypnotic or anxiolytic-induced mood disorder
        "F13150",  # Sedative, hypnotic or anxiolytic abuse with sedative, hypnotic or anxiolytic-induced psychotic disorder with delusions
        "F13151",  # Sedative, hypnotic or anxiolytic abuse with sedative, hypnotic or anxiolytic-induced psychotic disorder with hallucinations
        "F13159",  # Sedative, hypnotic or anxiolytic abuse with sedative, hypnotic or anxiolytic-induced psychotic disorder, unspecified
        "F13180",  # Sedative, hypnotic or anxiolytic abuse with sedative, hypnotic or anxiolytic-induced anxiety disorder
        "F13181",  # Sedative, hypnotic or anxiolytic abuse with sedative, hypnotic or anxiolytic-induced sexual dysfunction
        "F13182",  # Sedative, hypnotic or anxiolytic abuse with sedative, hypnotic or anxiolytic-induced sleep disorder
        "F13188",  # Sedative, hypnotic or anxiolytic abuse with other sedative, hypnotic or anxiolytic-induced disorder
        "F1319",  # Sedative, hypnotic or anxiolytic abuse with unspecified sedative, hypnotic or anxiolytic-induced disorder
        "F1320",  # Sedative, hypnotic or anxiolytic dependence, uncomplicated
        "F1321",  # Sedative, hypnotic or anxiolytic dependence, in remission
        "F13220",  # Sedative, hypnotic or anxiolytic dependence with intoxication, uncomplicated
        "F13221",  # Sedative, hypnotic or anxiolytic dependence with intoxication delirium
        "F13229",  # Sedative, hypnotic or anxiolytic dependence with intoxication, unspecified
        "F13230",  # Sedative, hypnotic or anxiolytic dependence with withdrawal, uncomplicated
        "F13231",  # Sedative, hypnotic or anxiolytic dependence with withdrawal delirium
        "F13232",  # Sedative, hypnotic or anxiolytic dependence with withdrawal with perceptual disturbance
        "F13239",  # Sedative, hypnotic or anxiolytic dependence with withdrawal, unspecified
        "F1324",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced mood disorder
        "F13250",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced psychotic disorder with delusions
        "F13251",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced psychotic disorder with hallucinations
        "F13259",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced psychotic disorder, unspecified
        "F1326",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced persisting amnestic disorder
        "F1327",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced persisting dementia
        "F13280",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced anxiety disorder
        "F13281",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced sexual dysfunction
        "F13282",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced sleep disorder
        "F13288",  # Sedative, hypnotic or anxiolytic dependence with other sedative, hypnotic or anxiolytic-induced disorder
        "F1329",  # Sedative, hypnotic or anxiolytic dependence with unspecified sedative, hypnotic or anxiolytic-induced disorder
        "F1390",  # Sedative, hypnotic, or anxiolytic use, unspecified, uncomplicated
        "F1391",  # Sedative, hypnotic or anxiolytic use, unspecified, in remission
        "F13920",  # Sedative, hypnotic or anxiolytic use, unspecified with intoxication, uncomplicated
        "F13921",  # Sedative, hypnotic or anxiolytic use, unspecified with intoxication delirium
        "F13929",  # Sedative, hypnotic or anxiolytic use, unspecified with intoxication, unspecified
        "F13930",  # Sedative, hypnotic or anxiolytic use, unspecified with withdrawal, uncomplicated
        "F13931",  # Sedative, hypnotic or anxiolytic use, unspecified with withdrawal delirium
        "F13932",  # Sedative, hypnotic or anxiolytic use, unspecified with withdrawal with perceptual disturbances
        "F13939",  # Sedative, hypnotic or anxiolytic use, unspecified with withdrawal, unspecified
        "F1394",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced mood disorder
        "F13950",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced psychotic disorder with delusions
        "F13951",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced psychotic disorder with hallucinations
        "F13959",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced psychotic disorder, unspecified
        "F1396",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced persisting amnestic disorder
        "F1397",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced persisting dementia
        "F13980",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced anxiety disorder
        "F13981",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced sexual dysfunction
        "F13982",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced sleep disorder
        "F13988",  # Sedative, hypnotic or anxiolytic use, unspecified with other sedative, hypnotic or anxiolytic-induced disorder
        "F1399",  # Sedative, hypnotic or anxiolytic use, unspecified with unspecified sedative, hypnotic or anxiolytic-induced disorder
        "F1410",  # Cocaine abuse, uncomplicated
        "F1411",  # Cocaine abuse, in remission
        "F14120",  # Cocaine abuse with intoxication, uncomplicated
        "F14121",  # Cocaine abuse with intoxication with delirium
        "F14122",  # Cocaine abuse with intoxication with perceptual disturbance
        "F14129",  # Cocaine abuse with intoxication, unspecified
        "F1413",  # Cocaine abuse, unspecified with withdrawal
        "F1414",  # Cocaine abuse with cocaine-induced mood disorder
        "F14150",  # Cocaine abuse with cocaine-induced psychotic disorder with delusions
        "F14151",  # Cocaine abuse with cocaine-induced psychotic disorder with hallucinations
        "F14159",  # Cocaine abuse with cocaine-induced psychotic disorder, unspecified
        "F14180",  # Cocaine abuse with cocaine-induced anxiety disorder
        "F14181",  # Cocaine abuse with cocaine-induced sexual dysfunction
        "F14182",  # Cocaine abuse with cocaine-induced sleep disorder
        "F14188",  # Cocaine abuse with other cocaine-induced disorder
        "F1419",  # Cocaine abuse with unspecified cocaine-induced disorder
        "F1420",  # Cocaine dependence, uncomplicated
        "F1421",  # Cocaine dependence, in remission
        "F14220",  # Cocaine dependence with intoxication, uncomplicated
        "F14221",  # Cocaine dependence with intoxication delirium
        "F14222",  # Cocaine dependence with intoxication with perceptual disturbance
        "F14229",  # Cocaine dependence with intoxication, unspecified
        "F1423",  # Cocaine dependence with withdrawal
        "F1424",  # Cocaine dependence with cocaine-induced mood disorder
        "F14250",  # Cocaine dependence with cocaine-induced psychotic disorder with delusions
        "F14251",  # Cocaine dependence with cocaine-induced psychotic disorder with hallucinations
        "F14259",  # Cocaine dependence with cocaine-induced psychotic disorder, unspecified
        "F14280",  # Cocaine dependence with cocaine-induced anxiety disorder
        "F14281",  # Cocaine dependence with cocaine-induced sexual dysfunction
        "F14282",  # Cocaine dependence with cocaine-induced sleep disorder
        "F14288",  # Cocaine dependence with other cocaine-induced disorder
        "F1429",  # Cocaine dependence with unspecified cocaine-induced disorder
        "F1490",  # Cocaine use, unspecified, uncomplicated
        "F1491",  # Cocaine use, unspecified, in remission
        "F14920",  # Cocaine use, unspecified with intoxication, uncomplicated
        "F14921",  # Cocaine use, unspecified with intoxication delirium
        "F14922",  # Cocaine use, unspecified with intoxication with perceptual disturbance
        "F14929",  # Cocaine use, unspecified with intoxication, unspecified
        "F1493",  # Cocaine use, unspecified with withdrawal
        "F1494",  # Cocaine use, unspecified with cocaine-induced mood disorder
        "F14950",  # Cocaine use, unspecified with cocaine-induced psychotic disorder with delusions
        "F14951",  # Cocaine use, unspecified with cocaine-induced psychotic disorder with hallucinations
        "F14959",  # Cocaine use, unspecified with cocaine-induced psychotic disorder, unspecified
        "F14980",  # Cocaine use, unspecified with cocaine-induced anxiety disorder
        "F14981",  # Cocaine use, unspecified with cocaine-induced sexual dysfunction
        "F14982",  # Cocaine use, unspecified with cocaine-induced sleep disorder
        "F14988",  # Cocaine use, unspecified with other cocaine-induced disorder
        "F1499",  # Cocaine use, unspecified with unspecified cocaine-induced disorder
        "F1510",  # Other stimulant abuse, uncomplicated
        "F1511",  # Other stimulant abuse, in remission
        "F15120",  # Other stimulant abuse with intoxication, uncomplicated
        "F15121",  # Other stimulant abuse with intoxication delirium
        "F15122",  # Other stimulant abuse with intoxication with perceptual disturbance
        "F15129",  # Other stimulant abuse with intoxication, unspecified
        "F1513",  # Other stimulant abuse with withdrawal
        "F1514",  # Other stimulant abuse with stimulant-induced mood disorder
        "F15150",  # Other stimulant abuse with stimulant-induced psychotic disorder with delusions
        "F15151",  # Other stimulant abuse with stimulant-induced psychotic disorder with hallucinations
        "F15159",  # Other stimulant abuse with stimulant-induced psychotic disorder, unspecified
        "F15180",  # Other stimulant abuse with stimulant-induced anxiety disorder
        "F15181",  # Other stimulant abuse with stimulant-induced sexual dysfunction
        "F15182",  # Other stimulant abuse with stimulant-induced sleep disorder
        "F15188",  # Other stimulant abuse with other stimulant-induced disorder
        "F1519",  # Other stimulant abuse with unspecified stimulant-induced disorder
        "F1520",  # Other stimulant dependence, uncomplicated
        "F1521",  # Other stimulant dependence, in remission
        "F15220",  # Other stimulant dependence with intoxication, uncomplicated
        "F15221",  # Other stimulant dependence with intoxication delirium
        "F15222",  # Other stimulant dependence with intoxication with perceptual disturbance
        "F15229",  # Other stimulant dependence with intoxication, unspecified
        "F1523",  # Other stimulant dependence with withdrawal
        "F1524",  # Other stimulant dependence with stimulant-induced mood disorder
        "F15250",  # Other stimulant dependence with stimulant-induced psychotic disorder with delusions
        "F15251",  # Other stimulant dependence with stimulant-induced psychotic disorder with hallucinations
        "F15259",  # Other stimulant dependence with stimulant-induced psychotic disorder, unspecified
        "F15280",  # Other stimulant dependence with stimulant-induced anxiety disorder
        "F15281",  # Other stimulant dependence with stimulant-induced sexual dysfunction
        "F15282",  # Other stimulant dependence with stimulant-induced sleep disorder
        "F15288",  # Other stimulant dependence with other stimulant-induced disorder
        "F1529",  # Other stimulant dependence with unspecified stimulant-induced disorder
        "F1590",  # Other stimulant use, unspecified, uncomplicated
        "F1591",  # Other stimulant use, unspecified, in remission
        "F15920",  # Other stimulant use, unspecified with intoxication, uncomplicated
        "F15921",  # Other stimulant use, unspecified with intoxication delirium
        "F15922",  # Other stimulant use, unspecified with intoxication with perceptual disturbance
        "F15929",  # Other stimulant use, unspecified with intoxication, unspecified
        "F1593",  # Other stimulant use, unspecified with withdrawal
        "F1594",  # Other stimulant use, unspecified with stimulant-induced mood disorder
        "F15950",  # Other stimulant use, unspecified with stimulant-induced psychotic disorder with delusions
        "F15951",  # Other stimulant use, unspecified with stimulant-induced psychotic disorder with hallucinations
        "F15959",  # Other stimulant use, unspecified with stimulant-induced psychotic disorder, unspecified
        "F15980",  # Other stimulant use, unspecified with stimulant-induced anxiety disorder
        "F15981",  # Other stimulant use, unspecified with stimulant-induced sexual dysfunction
        "F15982",  # Other stimulant use, unspecified with stimulant-induced sleep disorder
        "F15988",  # Other stimulant use, unspecified with other stimulant-induced disorder
        "F1599",  # Other stimulant use, unspecified with unspecified stimulant-induced disorder
        "F1610",  # Hallucinogen abuse, uncomplicated
        "F1611",  # Hallucinogen abuse, in remission
        "F16120",  # Hallucinogen abuse with intoxication, uncomplicated
        "F16121",  # Hallucinogen abuse with intoxication with delirium
        "F16122",  # Hallucinogen abuse with intoxication with perceptual disturbance
        "F16129",  # Hallucinogen abuse with intoxication, unspecified
        "F1614",  # Hallucinogen abuse with hallucinogen-induced mood disorder
        "F16150",  # Hallucinogen abuse with hallucinogen-induced psychotic disorder with delusions
        "F16151",  # Hallucinogen abuse with hallucinogen-induced psychotic disorder with hallucinations
        "F16159",  # Hallucinogen abuse with hallucinogen-induced psychotic disorder, unspecified
        "F16180",  # Hallucinogen abuse with hallucinogen-induced anxiety disorder
        "F16183",  # Hallucinogen abuse with hallucinogen persisting perception disorder (flashbacks)
        "F16188",  # Hallucinogen abuse with other hallucinogen-induced disorder
        "F1619",  # Hallucinogen abuse with unspecified hallucinogen-induced disorder
        "F1620",  # Hallucinogen dependence, uncomplicated
        "F1621",  # Hallucinogen dependence, in remission
        "F16220",  # Hallucinogen dependence with intoxication, uncomplicated
        "F16221",  # Hallucinogen dependence with intoxication with delirium
        "F16229",  # Hallucinogen dependence with intoxication, unspecified
        "F1624",  # Hallucinogen dependence with hallucinogen-induced mood disorder
        "F16250",  # Hallucinogen dependence with hallucinogen-induced psychotic disorder with delusions
        "F16251",  # Hallucinogen dependence with hallucinogen-induced psychotic disorder with hallucinations
        "F16259",  # Hallucinogen dependence with hallucinogen-induced psychotic disorder, unspecified
        "F16280",  # Hallucinogen dependence with hallucinogen-induced anxiety disorder
        "F16283",  # Hallucinogen dependence with hallucinogen persisting perception disorder (flashbacks)
        "F16288",  # Hallucinogen dependence with other hallucinogen-induced disorder
        "F1629",  # Hallucinogen dependence with unspecified hallucinogen-induced disorder
        "F1690",  # Hallucinogen use, unspecified, uncomplicated
        "F1691",  # Hallucinogen use, unspecified, in remission
        "F16920",  # Hallucinogen use, unspecified with intoxication, uncomplicated
        "F16921",  # Hallucinogen use, unspecified with intoxication with delirium
        "F16929",  # Hallucinogen use, unspecified with intoxication, unspecified
        "F1694",  # Hallucinogen use, unspecified with hallucinogen-induced mood disorder
        "F16950",  # Hallucinogen use, unspecified with hallucinogen-induced psychotic disorder with delusions
        "F16951",  # Hallucinogen use, unspecified with hallucinogen-induced psychotic disorder with hallucinations
        "F16959",  # Hallucinogen use, unspecified with hallucinogen-induced psychotic disorder, unspecified
        "F16980",  # Hallucinogen use, unspecified with hallucinogen-induced anxiety disorder
        "F16983",  # Hallucinogen use, unspecified with hallucinogen persisting perception disorder (flashbacks)
        "F16988",  # Hallucinogen use, unspecified with other hallucinogen-induced disorder
        "F1699",  # Hallucinogen use, unspecified with unspecified hallucinogen-induced disorder
        "F17200",  # Nicotine dependence, unspecified, uncomplicated
        "F17201",  # Nicotine dependence, unspecified, in remission
        "F17203",  # Nicotine dependence unspecified, with withdrawal
        "F17208",  # Nicotine dependence, unspecified, with other nicotine-induced disorders
        "F17209",  # Nicotine dependence, unspecified, with unspecified nicotine-induced disorders
        "F17210",  # Nicotine dependence, cigarettes, uncomplicated
        "F17211",  # Nicotine dependence, cigarettes, in remission
        "F17213",  # Nicotine dependence, cigarettes, with withdrawal
        "F17218",  # Nicotine dependence, cigarettes, with other nicotine-induced disorders
        "F17219",  # Nicotine dependence, cigarettes, with unspecified nicotine-induced disorders
        "F17220",  # Nicotine dependence, chewing tobacco, uncomplicated
        "F17221",  # Nicotine dependence, chewing tobacco, in remission
        "F17223",  # Nicotine dependence, chewing tobacco, with withdrawal
        "F17228",  # Nicotine dependence, chewing tobacco, with other nicotine-induced disorders
        "F17229",  # Nicotine dependence, chewing tobacco, with unspecified nicotine-induced disorders
        "F17290",  # Nicotine dependence, other tobacco product, uncomplicated
        "F17291",  # Nicotine dependence, other tobacco product, in remission
        "F17293",  # Nicotine dependence, other tobacco product, with withdrawal
        "F17298",  # Nicotine dependence, other tobacco product, with other nicotine-induced disorders
        "F17299",  # Nicotine dependence, other tobacco product, with unspecified nicotine-induced disorders
        "F1810",  # Inhalant abuse, uncomplicated
        "F1811",  # Inhalant abuse, in remission
        "F18120",  # Inhalant abuse with intoxication, uncomplicated
        "F18121",  # Inhalant abuse with intoxication delirium
        "F18129",  # Inhalant abuse with intoxication, unspecified
        "F1814",  # Inhalant abuse with inhalant-induced mood disorder
        "F18150",  # Inhalant abuse with inhalant-induced psychotic disorder with delusions
        "F18151",  # Inhalant abuse with inhalant-induced psychotic disorder with hallucinations
        "F18159",  # Inhalant abuse with inhalant-induced psychotic disorder, unspecified
        "F1817",  # Inhalant abuse with inhalant-induced dementia
        "F18180",  # Inhalant abuse with inhalant-induced anxiety disorder
        "F18188",  # Inhalant abuse with other inhalant-induced disorder
        "F1819",  # Inhalant abuse with unspecified inhalant-induced disorder
        "F1820",  # Inhalant dependence, uncomplicated
        "F1821",  # Inhalant dependence, in remission
        "F18220",  # Inhalant dependence with intoxication, uncomplicated
        "F18221",  # Inhalant dependence with intoxication delirium
        "F18229",  # Inhalant dependence with intoxication, unspecified
        "F1824",  # Inhalant dependence with inhalant-induced mood disorder
        "F18250",  # Inhalant dependence with inhalant-induced psychotic disorder with delusions
        "F18251",  # Inhalant dependence with inhalant-induced psychotic disorder with hallucinations
        "F18259",  # Inhalant dependence with inhalant-induced psychotic disorder, unspecified
        "F1827",  # Inhalant dependence with inhalant-induced dementia
        "F18280",  # Inhalant dependence with inhalant-induced anxiety disorder
        "F18288",  # Inhalant dependence with other inhalant-induced disorder
        "F1829",  # Inhalant dependence with unspecified inhalant-induced disorder
        "F1890",  # Inhalant use, unspecified, uncomplicated
        "F1891",  # Inhalant use, unspecified, in remission
        "F18920",  # Inhalant use, unspecified with intoxication, uncomplicated
        "F18921",  # Inhalant use, unspecified with intoxication with delirium
        "F18929",  # Inhalant use, unspecified with intoxication, unspecified
        "F1894",  # Inhalant use, unspecified with inhalant-induced mood disorder
        "F18950",  # Inhalant use, unspecified with inhalant-induced psychotic disorder with delusions
        "F18951",  # Inhalant use, unspecified with inhalant-induced psychotic disorder with hallucinations
        "F18959",  # Inhalant use, unspecified with inhalant-induced psychotic disorder, unspecified
        "F1897",  # Inhalant use, unspecified with inhalant-induced persisting dementia
        "F18980",  # Inhalant use, unspecified with inhalant-induced anxiety disorder
        "F18988",  # Inhalant use, unspecified with other inhalant-induced disorder
        "F1899",  # Inhalant use, unspecified with unspecified inhalant-induced disorder
        "F1910",  # Other psychoactive substance abuse, uncomplicated
        "F1911",  # Other psychoactive substance abuse, in remission
        "F19120",  # Other psychoactive substance abuse with intoxication, uncomplicated
        "F19121",  # Other psychoactive substance abuse with intoxication delirium
        "F19122",  # Other psychoactive substance abuse with intoxication with perceptual disturbances
        "F19129",  # Other psychoactive substance abuse with intoxication, unspecified
        "F19130",  # Other psychoactive substance abuse with withdrawal, uncomplicated
        "F19131",  # Other psychoactive substance abuse with withdrawal delirium
        "F19132",  # Other psychoactive substance abuse with withdrawal with perceptual disturbance
        "F19139",  # Other psychoactive substance abuse with withdrawal, unspecified
        "F1914",  # Other psychoactive substance abuse with psychoactive substance-induced mood disorder
        "F19150",  # Other psychoactive substance abuse with psychoactive substance-induced psychotic disorder with delusions
        "F19151",  # Other psychoactive substance abuse with psychoactive substance-induced psychotic disorder with hallucinations
        "F19159",  # Other psychoactive substance abuse with psychoactive substance-induced psychotic disorder, unspecified
        "F1916",  # Other psychoactive substance abuse with psychoactive substance-induced persisting amnestic disorder
        "F1917",  # Other psychoactive substance abuse with psychoactive substance-induced persisting dementia
        "F19180",  # Other psychoactive substance abuse with psychoactive substance-induced anxiety disorder
        "F19181",  # Other psychoactive substance abuse with psychoactive substance-induced sexual dysfunction
        "F19182",  # Other psychoactive substance abuse with psychoactive substance-induced sleep disorder
        "F19188",  # Other psychoactive substance abuse with other psychoactive substance-induced disorder
        "F1919",  # Other psychoactive substance abuse with unspecified psychoactive substance-induced disorder
        "F1920",  # Other psychoactive substance dependence, uncomplicated
        "F1921",  # Other psychoactive substance dependence, in remission
        "F19220",  # Other psychoactive substance dependence with intoxication, uncomplicated
        "F19221",  # Other psychoactive substance dependence with intoxication delirium
        "F19222",  # Other psychoactive substance dependence with intoxication with perceptual disturbance
        "F19229",  # Other psychoactive substance dependence with intoxication, unspecified
        "F19230",  # Other psychoactive substance dependence with withdrawal, uncomplicated
        "F19231",  # Other psychoactive substance dependence with withdrawal delirium
        "F19232",  # Other psychoactive substance dependence with withdrawal with perceptual disturbance
        "F19239",  # Other psychoactive substance dependence with withdrawal, unspecified
        "F1924",  # Other psychoactive substance dependence with psychoactive substance-induced mood disorder
        "F19250",  # Other psychoactive substance dependence with psychoactive substance-induced psychotic disorder with delusions
        "F19251",  # Other psychoactive substance dependence with psychoactive substance-induced psychotic disorder with hallucinations
        "F19259",  # Other psychoactive substance dependence with psychoactive substance-induced psychotic disorder, unspecified
        "F1926",  # Other psychoactive substance dependence with psychoactive substance-induced persisting amnestic disorder
        "F1927",  # Other psychoactive substance dependence with psychoactive substance-induced persisting dementia
        "F19280",  # Other psychoactive substance dependence with psychoactive substance-induced anxiety disorder
        "F19281",  # Other psychoactive substance dependence with psychoactive substance-induced sexual dysfunction
        "F19282",  # Other psychoactive substance dependence with psychoactive substance-induced sleep disorder
        "F19288",  # Other psychoactive substance dependence with other psychoactive substance-induced disorder
        "F1929",  # Other psychoactive substance dependence with unspecified psychoactive substance-induced disorder
        "F1990",  # Other psychoactive substance use, unspecified, uncomplicated
        "F1991",  # Other psychoactive substance use, unspecified, in remission
        "F19920",  # Other psychoactive substance use, unspecified with intoxication, uncomplicated
        "F19921",  # Other psychoactive substance use, unspecified with intoxication with delirium
        "F19922",  # Other psychoactive substance use, unspecified with intoxication with perceptual disturbance
        "F19929",  # Other psychoactive substance use, unspecified with intoxication, unspecified
        "F19930",  # Other psychoactive substance use, unspecified with withdrawal, uncomplicated
        "F19931",  # Other psychoactive substance use, unspecified with withdrawal delirium
        "F19932",  # Other psychoactive substance use, unspecified with withdrawal with perceptual disturbance
        "F19939",  # Other psychoactive substance use, unspecified with withdrawal, unspecified
        "F1994",  # Other psychoactive substance use, unspecified with psychoactive substance-induced mood disorder
        "F19950",  # Other psychoactive substance use, unspecified with psychoactive substance-induced psychotic disorder with delusions
        "F19951",  # Other psychoactive substance use, unspecified with psychoactive substance-induced psychotic disorder with hallucinations
        "F19959",  # Other psychoactive substance use, unspecified with psychoactive substance-induced psychotic disorder, unspecified
        "F1996",  # Other psychoactive substance use, unspecified with psychoactive substance-induced persisting amnestic disorder
        "F1997",  # Other psychoactive substance use, unspecified with psychoactive substance-induced persisting dementia
        "F19980",  # Other psychoactive substance use, unspecified with psychoactive substance-induced anxiety disorder
        "F19981",  # Other psychoactive substance use, unspecified with psychoactive substance-induced sexual dysfunction
        "F19982",  # Other psychoactive substance use, unspecified with psychoactive substance-induced sleep disorder
        "F19988",  # Other psychoactive substance use, unspecified with other psychoactive substance-induced disorder
        "F1999",  # Other psychoactive substance use, unspecified with unspecified psychoactive substance-induced disorder
        "O99310",  # Alcohol use complicating pregnancy, unspecified trimester
        "O99311",  # Alcohol use complicating pregnancy, first trimester
        "O99312",  # Alcohol use complicating pregnancy, second trimester
        "O99313",  # Alcohol use complicating pregnancy, third trimester
        "O99314",  # Alcohol use complicating childbirth
        "O99315",  # Alcohol use complicating the puerperium
        "O99320",  # Drug use complicating pregnancy, unspecified trimester
        "O99321",  # Drug use complicating pregnancy, first trimester
        "O99322",  # Drug use complicating pregnancy, second trimester
        "O99323",  # Drug use complicating pregnancy, third trimester
        "O99324",  # Drug use complicating childbirth
        "O99325",  # Drug use complicating the puerperium
    }

class Thyrotoxicosis(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of thyrotoxicosis.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of thyrotoxicosis.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Thyrotoxicosis"
    OID = "2.16.840.1.113762.1.4.1029.296"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "E0500",  # Thyrotoxicosis with diffuse goiter without thyrotoxic crisis or storm
        "E0501",  # Thyrotoxicosis with diffuse goiter with thyrotoxic crisis or storm
        "E0510",  # Thyrotoxicosis with toxic single thyroid nodule without thyrotoxic crisis or storm
        "E0511",  # Thyrotoxicosis with toxic single thyroid nodule with thyrotoxic crisis or storm
        "E0520",  # Thyrotoxicosis with toxic multinodular goiter without thyrotoxic crisis or storm
        "E0521",  # Thyrotoxicosis with toxic multinodular goiter with thyrotoxic crisis or storm
        "E0530",  # Thyrotoxicosis from ectopic thyroid tissue without thyrotoxic crisis or storm
        "E0531",  # Thyrotoxicosis from ectopic thyroid tissue with thyrotoxic crisis or storm
        "E0540",  # Thyrotoxicosis factitia without thyrotoxic crisis or storm
        "E0541",  # Thyrotoxicosis factitia with thyrotoxic crisis or storm
        "E0580",  # Other thyrotoxicosis without thyrotoxic crisis or storm
        "E0581",  # Other thyrotoxicosis with thyrotoxic crisis or storm
        "E0590",  # Thyrotoxicosis, unspecified without thyrotoxic crisis or storm
        "E0591",  # Thyrotoxicosis, unspecified with thyrotoxic crisis or storm
    }

class VenousThromboembolismInPregnancy(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of an obstetrical venous thromboembolism (VTE) in pregnancy.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of an obstetrical venous thromboembolism (VTE) in pregnancy.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Venous Thromboembolism in Pregnancy"
    OID = "2.16.840.1.113762.1.4.1029.363"
    DEFINITION_VERSION = "20220127"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "O2230",  # Deep phlebothrombosis in pregnancy, unspecified trimester
        "O2231",  # Deep phlebothrombosis in pregnancy, first trimester
        "O2232",  # Deep phlebothrombosis in pregnancy, second trimester
        "O2233",  # Deep phlebothrombosis in pregnancy, third trimester
        "O2250",  # Cerebral venous thrombosis in pregnancy, unspecified trimester
        "O2251",  # Cerebral venous thrombosis in pregnancy, first trimester
        "O2252",  # Cerebral venous thrombosis in pregnancy, second trimester
        "O2253",  # Cerebral venous thrombosis in pregnancy, third trimester
        "O228X1",  # Other venous complications in pregnancy, first trimester
        "O228X2",  # Other venous complications in pregnancy, second trimester
        "O228X3",  # Other venous complications in pregnancy, third trimester
        "O228X9",  # Other venous complications in pregnancy, unspecified trimester
        "O2290",  # Venous complication in pregnancy, unspecified, unspecified trimester
        "O2291",  # Venous complication in pregnancy, unspecified, first trimester
        "O2292",  # Venous complication in pregnancy, unspecified, second trimester
        "O2293",  # Venous complication in pregnancy, unspecified, third trimester
    }

class DischargeToAcuteCareFacility(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for an encounter with the discharge of a patient to an acute care facility.

    **Data Element Scope:** This value set may use a model element related to Encounter.

    **Inclusion Criteria:** Includes concepts that represent an encounter with a discharge to a short-term acute care hospital, including a specialty hospital.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Discharge To Acute Care Facility"
    OID = "2.16.840.1.113883.3.117.1.7.1.87"
    DEFINITION_VERSION = "20210611"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "306701001",  # Discharge to community hospital (procedure)
        "306703003",  # Discharge to tertiary referral hospital (procedure)
        "434781000124105",  # Discharge to acute care hospital (procedure)
    }

class DischargedToHealthCareFacilityForHospiceCare(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for an encounter with a discharge disposition of a patient to a health care facility for hospice care.

    **Data Element Scope:** This value set may use a model element related to Encounter.

    **Inclusion Criteria:** Includes concepts that represent an encounter with a discharge disposition to a health care facility.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Discharged to Health Care Facility for Hospice Care"
    OID = "2.16.840.1.113883.3.117.1.7.1.207"
    DEFINITION_VERSION = "20210611"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "428371000124100",  # Discharge to healthcare facility for hospice care (procedure)
    }

class DischargedToHomeForHospiceCare(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for an encounter with the discharge of a patient to home for hospice care.

    **Data Element Scope:** This value set may use a model element related to Encounter.

    **Inclusion Criteria:** Includes concepts that represent an encounter with a discharge disposition to home for hospice care.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Discharged to Home for Hospice Care"
    OID = "2.16.840.1.113883.3.117.1.7.1.209"
    DEFINITION_VERSION = "20210220"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "428361000124107",  # Discharge to home for hospice care (procedure)
    }

class IschemicStroke(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for diagnoses of ischemic strokes.

    **Data Element Scope:** This value set may use a model element related to Diagnosis.

    **Inclusion Criteria:** Includes concepts that represent a diagnosis of ischemic stroke.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Ischemic Stroke"
    OID = "2.16.840.1.113883.3.117.1.7.1.247"
    DEFINITION_VERSION = "20210220"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "I6300",  # Cerebral infarction due to thrombosis of unspecified precerebral artery
        "I63011",  # Cerebral infarction due to thrombosis of right vertebral artery
        "I63012",  # Cerebral infarction due to thrombosis of left vertebral artery
        "I63013",  # Cerebral infarction due to thrombosis of bilateral vertebral arteries
        "I63019",  # Cerebral infarction due to thrombosis of unspecified vertebral artery
        "I6302",  # Cerebral infarction due to thrombosis of basilar artery
        "I63031",  # Cerebral infarction due to thrombosis of right carotid artery
        "I63032",  # Cerebral infarction due to thrombosis of left carotid artery
        "I63033",  # Cerebral infarction due to thrombosis of bilateral carotid arteries
        "I63039",  # Cerebral infarction due to thrombosis of unspecified carotid artery
        "I6309",  # Cerebral infarction due to thrombosis of other precerebral artery
        "I6310",  # Cerebral infarction due to embolism of unspecified precerebral artery
        "I63111",  # Cerebral infarction due to embolism of right vertebral artery
        "I63112",  # Cerebral infarction due to embolism of left vertebral artery
        "I63113",  # Cerebral infarction due to embolism of bilateral vertebral arteries
        "I63119",  # Cerebral infarction due to embolism of unspecified vertebral artery
        "I6312",  # Cerebral infarction due to embolism of basilar artery
        "I63131",  # Cerebral infarction due to embolism of right carotid artery
        "I63132",  # Cerebral infarction due to embolism of left carotid artery
        "I63133",  # Cerebral infarction due to embolism of bilateral carotid arteries
        "I63139",  # Cerebral infarction due to embolism of unspecified carotid artery
        "I6319",  # Cerebral infarction due to embolism of other precerebral artery
        "I6320",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified precerebral arteries
        "I63211",  # Cerebral infarction due to unspecified occlusion or stenosis of right vertebral artery
        "I63212",  # Cerebral infarction due to unspecified occlusion or stenosis of left vertebral artery
        "I63213",  # Cerebral infarction due to unspecified occlusion or stenosis of bilateral vertebral arteries
        "I63219",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified vertebral artery
        "I6322",  # Cerebral infarction due to unspecified occlusion or stenosis of basilar artery
        "I63231",  # Cerebral infarction due to unspecified occlusion or stenosis of right carotid arteries
        "I63232",  # Cerebral infarction due to unspecified occlusion or stenosis of left carotid arteries
        "I63233",  # Cerebral infarction due to unspecified occlusion or stenosis of bilateral carotid arteries
        "I63239",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified carotid artery
        "I6329",  # Cerebral infarction due to unspecified occlusion or stenosis of other precerebral arteries
        "I6330",  # Cerebral infarction due to thrombosis of unspecified cerebral artery
        "I63311",  # Cerebral infarction due to thrombosis of right middle cerebral artery
        "I63312",  # Cerebral infarction due to thrombosis of left middle cerebral artery
        "I63313",  # Cerebral infarction due to thrombosis of bilateral middle cerebral arteries
        "I63319",  # Cerebral infarction due to thrombosis of unspecified middle cerebral artery
        "I63321",  # Cerebral infarction due to thrombosis of right anterior cerebral artery
        "I63322",  # Cerebral infarction due to thrombosis of left anterior cerebral artery
        "I63323",  # Cerebral infarction due to thrombosis of bilateral anterior cerebral arteries
        "I63329",  # Cerebral infarction due to thrombosis of unspecified anterior cerebral artery
        "I63331",  # Cerebral infarction due to thrombosis of right posterior cerebral artery
        "I63332",  # Cerebral infarction due to thrombosis of left posterior cerebral artery
        "I63333",  # Cerebral infarction due to thrombosis of bilateral posterior cerebral arteries
        "I63339",  # Cerebral infarction due to thrombosis of unspecified posterior cerebral artery
        "I63341",  # Cerebral infarction due to thrombosis of right cerebellar artery
        "I63342",  # Cerebral infarction due to thrombosis of left cerebellar artery
        "I63343",  # Cerebral infarction due to thrombosis of bilateral cerebellar arteries
        "I63349",  # Cerebral infarction due to thrombosis of unspecified cerebellar artery
        "I6339",  # Cerebral infarction due to thrombosis of other cerebral artery
        "I6340",  # Cerebral infarction due to embolism of unspecified cerebral artery
        "I63411",  # Cerebral infarction due to embolism of right middle cerebral artery
        "I63412",  # Cerebral infarction due to embolism of left middle cerebral artery
        "I63413",  # Cerebral infarction due to embolism of bilateral middle cerebral arteries
        "I63419",  # Cerebral infarction due to embolism of unspecified middle cerebral artery
        "I63421",  # Cerebral infarction due to embolism of right anterior cerebral artery
        "I63422",  # Cerebral infarction due to embolism of left anterior cerebral artery
        "I63423",  # Cerebral infarction due to embolism of bilateral anterior cerebral arteries
        "I63429",  # Cerebral infarction due to embolism of unspecified anterior cerebral artery
        "I63431",  # Cerebral infarction due to embolism of right posterior cerebral artery
        "I63432",  # Cerebral infarction due to embolism of left posterior cerebral artery
        "I63433",  # Cerebral infarction due to embolism of bilateral posterior cerebral arteries
        "I63439",  # Cerebral infarction due to embolism of unspecified posterior cerebral artery
        "I63441",  # Cerebral infarction due to embolism of right cerebellar artery
        "I63442",  # Cerebral infarction due to embolism of left cerebellar artery
        "I63443",  # Cerebral infarction due to embolism of bilateral cerebellar arteries
        "I63449",  # Cerebral infarction due to embolism of unspecified cerebellar artery
        "I6349",  # Cerebral infarction due to embolism of other cerebral artery
        "I6350",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified cerebral artery
        "I63511",  # Cerebral infarction due to unspecified occlusion or stenosis of right middle cerebral artery
        "I63512",  # Cerebral infarction due to unspecified occlusion or stenosis of left middle cerebral artery
        "I63513",  # Cerebral infarction due to unspecified occlusion or stenosis of bilateral middle cerebral arteries
        "I63519",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified middle cerebral artery
        "I63521",  # Cerebral infarction due to unspecified occlusion or stenosis of right anterior cerebral artery
        "I63522",  # Cerebral infarction due to unspecified occlusion or stenosis of left anterior cerebral artery
        "I63523",  # Cerebral infarction due to unspecified occlusion or stenosis of bilateral anterior cerebral arteries
        "I63529",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified anterior cerebral artery
        "I63531",  # Cerebral infarction due to unspecified occlusion or stenosis of right posterior cerebral artery
        "I63532",  # Cerebral infarction due to unspecified occlusion or stenosis of left posterior cerebral artery
        "I63533",  # Cerebral infarction due to unspecified occlusion or stenosis of bilateral posterior cerebral arteries
        "I63539",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified posterior cerebral artery
        "I63541",  # Cerebral infarction due to unspecified occlusion or stenosis of right cerebellar artery
        "I63542",  # Cerebral infarction due to unspecified occlusion or stenosis of left cerebellar artery
        "I63543",  # Cerebral infarction due to unspecified occlusion or stenosis of bilateral cerebellar arteries
        "I63549",  # Cerebral infarction due to unspecified occlusion or stenosis of unspecified cerebellar artery
        "I6359",  # Cerebral infarction due to unspecified occlusion or stenosis of other cerebral artery
        "I636",  # Cerebral infarction due to cerebral venous thrombosis, nonpyogenic
        "I6381",  # Other cerebral infarction due to occlusion or stenosis of small artery
        "I6389",  # Other cerebral infarction
        "I639",  # Cerebral infarction, unspecified
    }

    SNOMEDCT = {
        "111297002",  # Nonparalytic stroke (disorder)
        "116288000",  # Paralytic stroke (disorder)
        "195185009",  # Cerebral infarct due to thrombosis of precerebral arteries (disorder)
        "195186005",  # Cerebral infarction due to embolism of precerebral arteries (disorder)
        "195189003",  # Cerebral infarction due to thrombosis of cerebral arteries (disorder)
        "195190007",  # Cerebral infarction due to embolism of cerebral arteries (disorder)
        "195212005",  # Brainstem stroke syndrome (disorder)
        "195213000",  # Cerebellar stroke syndrome (disorder)
        "195216008",  # Left sided cerebral hemisphere cerebrovascular accident (disorder)
        "195217004",  # Right sided cerebral hemisphere cerebrovascular accident (disorder)
        "195230003",  # Cerebral infarction due to cerebral venous thrombosis, non-pyogenic (disorder)
        "230690007",  # Cerebrovascular accident (disorder)
        "230691006",  # Cerebrovascular accident due to occlusion of cerebral artery (disorder)
        "230692004",  # Infarction - precerebral (disorder)
        "230693009",  # Anterior cerebral circulation infarction (disorder)
        "230694003",  # Total anterior cerebral circulation infarction (disorder)
        "230695002",  # Partial anterior cerebral circulation infarction (disorder)
        "230696001",  # Posterior cerebral circulation infarction (disorder)
        "230698000",  # Lacunar infarction (disorder)
        "230699008",  # Pure motor hemiparesis due to and following lacunar infarction (disorder)
        "230700009",  # Pure sensory stroke due to and following lacunar infarction (disorder)
        "230701008",  # Pure sensorimotor motor hemiparesis due to and following lacunar infarction (disorder)
        "307363008",  # Multiple lacunar infarcts (disorder)
        "422504002",  # Ischemic stroke (disorder)
        "426107000",  # Acute lacunar infarction (disorder)
    }

class LeftAgainstMedicalAdvice(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for an encounter with a patient discharge of leaving against medical advice.

    **Data Element Scope:** This value set may use a model element related to Encounter.

    **Inclusion Criteria:** Includes concepts that represent an encounter with a discharge disposition of leaving against medical advice.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Left Against Medical Advice"
    OID = "2.16.840.1.113883.3.117.1.7.1.308"
    DEFINITION_VERSION = "20210220"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "445060000",  # Left against medical advice (finding)
    }

class MedicalReasonForNotProvidingTreatment(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts of negation rationale for medical reasons for not providing treatment.

    **Data Element Scope:** This value set may use a model element related to Negation Rationale.

    **Inclusion Criteria:** Includes concepts that represent a negation rationale or reason for not providing treatment.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Medical Reason For Not Providing Treatment"
    OID = "2.16.840.1.113883.3.117.1.7.1.473"
    DEFINITION_VERSION = "20220212"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "183932001",  # Procedure contraindicated (situation)
        "183964008",  # Treatment not indicated (situation)
        "183966005",  # Drug treatment not indicated (situation)
        "266721009",  # Absent response to treatment (situation)
        "31438003",  # Drug resistance (disorder)
        "35688006",  # Complication of medical care (disorder)
        "407563006",  # Treatment not tolerated (situation)
        "410529002",  # Not needed (qualifier value)
        "410534003",  # Not indicated (qualifier value)
        "410536001",  # Contraindicated (qualifier value)
        "416098002",  # Allergy to drug (finding)
        "419511003",  # Propensity to adverse reactions to drug (finding)
        "428024001",  # Clinical trial participant (person)
        "428119001",  # Procedure not indicated (situation)
        "59037007",  # Intolerance to drug (finding)
        "62014003",  # Adverse reaction caused by drug (disorder)
        "79899007",  # Drug interaction (finding)
    }

class PatientRefusal(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts of negation rationale for a patient's refusal of treatment.

    **Data Element Scope:** This value set may use a model element related to Negation Rationale.

    **Inclusion Criteria:** Includes concepts that identify a negation rationale for refusal of any intervention.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Patient Refusal"
    OID = "2.16.840.1.113883.3.117.1.7.1.93"
    DEFINITION_VERSION = "20250206"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "1162745003",  # Refused by parent of subject (qualifier value)
        "1296859006",  # Procedure declined (situation)
        "182890002",  # Patient requests alternative treatment (finding)
        "182895007",  # Drug declined by patient (situation)
        "182896008",  # Drug declined by patient - dislikes taste (situation)
        "182897004",  # Drug declined by patient - side effects (situation)
        "182898009",  # Drug declined by patient - inconvenient (situation)
        "182900006",  # Drug declined by patient - patient beliefs (situation)
        "182901005",  # Drug declined by patient - alternative therapy (situation)
        "182903008",  # Drug declined by patient - reason unknown (situation)
        "183945002",  # Procedure declined for religious reason (situation)
        "183946001",  # Procedure declined - uncooperative (situation)
        "183948000",  # Procedure declined by parent (situation)
        "275936005",  # Patient noncompliance - general (situation)
        "406149000",  # Medication declined (situation)
        "416432009",  # Procedure not wanted (situation)
        "443390004",  # Refused (qualifier value)
        "895451009",  # Referral to service declined by subject (situation)
    }

class HemorrhagicStroke(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to identify concepts for diagnoses of hemorrhagic stroke.

    **Data Element Scope:** This value set may use a model element related to Diagnosis.

    **Inclusion Criteria:** Includes concepts that represent a diagnosis of hemorrhagic stroke.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Hemorrhagic Stroke"
    OID = "2.16.840.1.113883.3.117.1.7.1.212"
    DEFINITION_VERSION = "20210220"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "I6000",  # Nontraumatic subarachnoid hemorrhage from unspecified carotid siphon and bifurcation
        "I6001",  # Nontraumatic subarachnoid hemorrhage from right carotid siphon and bifurcation
        "I6002",  # Nontraumatic subarachnoid hemorrhage from left carotid siphon and bifurcation
        "I6010",  # Nontraumatic subarachnoid hemorrhage from unspecified middle cerebral artery
        "I6011",  # Nontraumatic subarachnoid hemorrhage from right middle cerebral artery
        "I6012",  # Nontraumatic subarachnoid hemorrhage from left middle cerebral artery
        "I602",  # Nontraumatic subarachnoid hemorrhage from anterior communicating artery
        "I6030",  # Nontraumatic subarachnoid hemorrhage from unspecified posterior communicating artery
        "I6031",  # Nontraumatic subarachnoid hemorrhage from right posterior communicating artery
        "I6032",  # Nontraumatic subarachnoid hemorrhage from left posterior communicating artery
        "I604",  # Nontraumatic subarachnoid hemorrhage from basilar artery
        "I6050",  # Nontraumatic subarachnoid hemorrhage from unspecified vertebral artery
        "I6051",  # Nontraumatic subarachnoid hemorrhage from right vertebral artery
        "I6052",  # Nontraumatic subarachnoid hemorrhage from left vertebral artery
        "I606",  # Nontraumatic subarachnoid hemorrhage from other intracranial arteries
        "I607",  # Nontraumatic subarachnoid hemorrhage from unspecified intracranial artery
        "I608",  # Other nontraumatic subarachnoid hemorrhage
        "I609",  # Nontraumatic subarachnoid hemorrhage, unspecified
        "I610",  # Nontraumatic intracerebral hemorrhage in hemisphere, subcortical
        "I611",  # Nontraumatic intracerebral hemorrhage in hemisphere, cortical
        "I612",  # Nontraumatic intracerebral hemorrhage in hemisphere, unspecified
        "I613",  # Nontraumatic intracerebral hemorrhage in brain stem
        "I614",  # Nontraumatic intracerebral hemorrhage in cerebellum
        "I615",  # Nontraumatic intracerebral hemorrhage, intraventricular
        "I616",  # Nontraumatic intracerebral hemorrhage, multiple localized
        "I618",  # Other nontraumatic intracerebral hemorrhage
        "I619",  # Nontraumatic intracerebral hemorrhage, unspecified
    }

    SNOMEDCT = {
        "195155004",  # Subarachnoid hemorrhage from carotid siphon and bifurcation (disorder)
        "195160000",  # Intracranial subarachnoid hemorrhage from vertebral artery (disorder)
        "195165005",  # Basal ganglia hemorrhage (disorder)
        "195167002",  # External capsule hemorrhage (disorder)
        "195168007",  # Intracerebral hemorrhage with intraventricular hemorrhage (disorder)
        "195169004",  # Intracerebral hemorrhage, multiple localized (disorder)
        "20908003",  # Subcortical cerebral hemorrhage (disorder)
        "230706003",  # Hemorrhagic cerebral infarction (disorder)
        "230707007",  # Anterior cerebral circulation hemorrhagic infarction (disorder)
        "230708002",  # Posterior cerebral circulation hemorrhagic infarction (disorder)
        "230709005",  # Massive supratentorial cerebral hemorrhage (disorder)
        "230710000",  # Lobar cerebral hemorrhage (disorder)
        "230711001",  # Thalamic hemorrhage (disorder)
        "230712008",  # Lacunar hemorrhage (disorder)
        "23276006",  # Ventricular hemorrhage (disorder)
        "270907008",  # Spontaneous intracranial subarachnoid hemorrhage (disorder)
        "274100004",  # Cerebral hemorrhage (disorder)
        "276277008",  # Subarachnoid hemorrhage from multiple aneurysms (disorder)
        "276278003",  # Subarachnoid hemorrhage from anterior cerebral artery aneurysm (disorder)
        "276280009",  # Subarachnoid hemorrhage from middle cerebral artery aneurysm (disorder)
        "276281008",  # Subarachnoid hemorrhage from posterior cerebral artery aneurysm (disorder)
        "276282001",  # Subarachnoid hemorrhage from anterior communicating artery aneurysm (disorder)
        "276283006",  # Subarachnoid hemorrhage from posterior communicating artery aneurysm (disorder)
        "276284000",  # Subarachnoid hemorrhage from basilar artery aneurysm (disorder)
        "276285004",  # Subarachnoid hemorrhage from posterior inferior cerebellar artery aneurysm (disorder)
        "276286003",  # Subarachnoid hemorrhage from carotid artery aneurysm (disorder)
        "276722003",  # Intracerebellar and posterior fossa hemorrhage (disorder)
        "28318001",  # Basilar hemorrhage (disorder)
        "42429001",  # Cerebromeningeal hemorrhage (disorder)
        "425957003",  # Non-traumatic intracerebral ventricular hemorrhage (disorder)
        "449020009",  # Intraparenchymal hemorrhage of brain (disorder)
        "49422009",  # Cortical hemorrhage (disorder)
        "52201006",  # Internal capsule hemorrhage (disorder)
        "73020009",  # Cerebral hemisphere hemorrhage (disorder)
        "75038005",  # Cerebellar hemorrhage (disorder)
        "7713009",  # Intrapontine hemorrhage (disorder)
        "95454007",  # Brain stem hemorrhage (disorder)
    }

class IntensiveCareUnit(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts of locations of adult or pediatric intensive care units (ICUs).

    **Data Element Scope:** This value set may use a model element related to Encounter.

    **Inclusion Criteria:** Includes concepts that represent a location for an adult or pediatric intensive care unit (ICU).

    **Exclusion Criteria:** Excludes concepts that represent neonatal intensive care units (NICU).
    """

    VALUE_SET_NAME = "Intensive Care Unit"
    OID = "2.16.840.1.113762.1.4.1029.206"
    DEFINITION_VERSION = "20210220"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    HSLOC = {
        "1025-6",  # Trauma Critical Care
        "1026-4",  # Burn Critical Care
        "1027-2",  # Medical Critical Care
        "1028-0",  # Medical Cardiac Critical Care
        "1029-8",  # Medical-Surgical Critical Care
        "1030-6",  # Surgical Critical Care
        "1031-4",  # Neurosurgical Critical Care
        "1032-2",  # Surgical Cardiothoracic Critical Care
        "1033-0",  # Respiratory Critical Care
        "1034-8",  # Prenatal Critical Care
        "1035-5",  # Neurologic Critical Care
        "1042-1",  # Pediatric Burn Critical Care
        "1043-9",  # Pediatric Surgical Cardiothoracic Critical Care
        "1044-7",  # Pediatric Medical Critical Care
        "1045-4",  # Pediatric Medical-Surgical Critical Care
        "1046-2",  # Pediatric Neurosurgical Critical Care
        "1047-0",  # Pediatric Respiratory Critical Care
        "1048-8",  # Pediatric Surgical Critical Care
        "1049-6",  # Pediatric Trauma Critical Care
        "1220-3",  # Long Term Acute Care Intensive Care Unit
        "1222-9",  # Long Term Acute Care Pediatric Intensive Care Unit
        "1223-7",  # Oncology Medical Critical Care
        "1224-5",  # Oncology Surgical Critical Care
        "1225-2",  # Oncology Medical-Surgical Critical Care
        "1233-6",  # Oncology Pediatric Critical Care
    }

    SNOMEDCT = {
        "309904001",  # Intensive care unit (environment)
        "309905000",  # Adult intensive care unit (environment)
        "309907008",  # Cardiac intensive care unit (environment)
        "309908003",  # Metabolic intensive care unit (environment)
        "309909006",  # Neurological intensive care unit (environment)
        "309910001",  # Pediatric intensive care unit (environment)
        "309911002",  # Respiratory intensive care unit (environment)
        "418433008",  # Surgical intensive care unit (environment)
        "426439001",  # Burns intensive care unit (environment)
        "441994008",  # Medical intensive care unit (environment)
        "448391000124102",  # Trauma intensive care unit (environment)
    }

class IntravenousRoute(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to identify concepts of a procedure of medication administered intravenously.

    **Data Element Scope:** This value set may use a model element related to Procedure.

    **Inclusion Criteria:** Includes concepts that identify a procedure of a medication given intravenously.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Intravenous route"
    OID = "2.16.840.1.113883.3.117.1.7.1.222"
    DEFINITION_VERSION = "20210220"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "418114005",  # Intravenous central route (qualifier value)
        "419993007",  # Intravenous peripheral route (qualifier value)
        "47625008",  # Intravenous route (qualifier value)
    }

class LowRisk(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to describe concepts for an assessment with a measurement containing results of "low."

    **Data Element Scope:** This value set may use a model element related to Assessment.

    **Inclusion Criteria:** Includes concepts that represent an assessment with results of "low".

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Low Risk"
    OID = "2.16.840.1.113883.3.117.1.7.1.400"
    DEFINITION_VERSION = "20240203"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "260362008",  # Very low (qualifier value)
        "62482003",  # Low (qualifier value)
        "723505004",  # Low risk (qualifier value)
    }

class MentalHealthDiagnoses(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for a diagnosis of mental health disorders.

    **Data Element Scope:** This value set may use a model element related to Diagnosis.

    **Inclusion Criteria:** Includes concepts that represent a diagnosis for mental health disorders.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Mental Health Diagnoses"
    OID = "2.16.840.1.113883.3.464.1003.105.12.1004"
    DEFINITION_VERSION = "20210220"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "F0390",  # Unspecified dementia, unspecified severity, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F03911",  # Unspecified dementia, unspecified severity, with agitation
        "F03918",  # Unspecified dementia, unspecified severity, with other behavioral disturbance
        "F0392",  # Unspecified dementia, unspecified severity, with psychotic disturbance
        "F0393",  # Unspecified dementia, unspecified severity, with mood disturbance
        "F0394",  # Unspecified dementia, unspecified severity, with anxiety
        "F03A0",  # Unspecified dementia, mild, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F03A11",  # Unspecified dementia, mild, with agitation
        "F03A18",  # Unspecified dementia, mild, with other behavioral disturbance
        "F03A2",  # Unspecified dementia, mild, with psychotic disturbance
        "F03A3",  # Unspecified dementia, mild, with mood disturbance
        "F03A4",  # Unspecified dementia, mild, with anxiety
        "F03B0",  # Unspecified dementia, moderate, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F03B11",  # Unspecified dementia, moderate, with agitation
        "F03B18",  # Unspecified dementia, moderate, with other behavioral disturbance
        "F03B2",  # Unspecified dementia, moderate, with psychotic disturbance
        "F03B3",  # Unspecified dementia, moderate, with mood disturbance
        "F03B4",  # Unspecified dementia, moderate, with anxiety
        "F03C0",  # Unspecified dementia, severe, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F03C11",  # Unspecified dementia, severe, with agitation
        "F03C18",  # Unspecified dementia, severe, with other behavioral disturbance
        "F03C2",  # Unspecified dementia, severe, with psychotic disturbance
        "F03C3",  # Unspecified dementia, severe, with mood disturbance
        "F03C4",  # Unspecified dementia, severe, with anxiety
        "F1010",  # Alcohol abuse, uncomplicated
        "F1011",  # Alcohol abuse, in remission
        "F10120",  # Alcohol abuse with intoxication, uncomplicated
        "F10121",  # Alcohol abuse with intoxication delirium
        "F10129",  # Alcohol abuse with intoxication, unspecified
        "F10130",  # Alcohol abuse with withdrawal, uncomplicated
        "F10131",  # Alcohol abuse with withdrawal delirium
        "F10132",  # Alcohol abuse with withdrawal with perceptual disturbance
        "F10139",  # Alcohol abuse with withdrawal, unspecified
        "F1014",  # Alcohol abuse with alcohol-induced mood disorder
        "F10150",  # Alcohol abuse with alcohol-induced psychotic disorder with delusions
        "F10151",  # Alcohol abuse with alcohol-induced psychotic disorder with hallucinations
        "F10159",  # Alcohol abuse with alcohol-induced psychotic disorder, unspecified
        "F10180",  # Alcohol abuse with alcohol-induced anxiety disorder
        "F10181",  # Alcohol abuse with alcohol-induced sexual dysfunction
        "F10182",  # Alcohol abuse with alcohol-induced sleep disorder
        "F10188",  # Alcohol abuse with other alcohol-induced disorder
        "F1019",  # Alcohol abuse with unspecified alcohol-induced disorder
        "F1020",  # Alcohol dependence, uncomplicated
        "F1021",  # Alcohol dependence, in remission
        "F10220",  # Alcohol dependence with intoxication, uncomplicated
        "F10221",  # Alcohol dependence with intoxication delirium
        "F10229",  # Alcohol dependence with intoxication, unspecified
        "F10230",  # Alcohol dependence with withdrawal, uncomplicated
        "F10231",  # Alcohol dependence with withdrawal delirium
        "F10232",  # Alcohol dependence with withdrawal with perceptual disturbance
        "F10239",  # Alcohol dependence with withdrawal, unspecified
        "F1024",  # Alcohol dependence with alcohol-induced mood disorder
        "F10250",  # Alcohol dependence with alcohol-induced psychotic disorder with delusions
        "F10251",  # Alcohol dependence with alcohol-induced psychotic disorder with hallucinations
        "F10259",  # Alcohol dependence with alcohol-induced psychotic disorder, unspecified
        "F1026",  # Alcohol dependence with alcohol-induced persisting amnestic disorder
        "F1027",  # Alcohol dependence with alcohol-induced persisting dementia
        "F10280",  # Alcohol dependence with alcohol-induced anxiety disorder
        "F10281",  # Alcohol dependence with alcohol-induced sexual dysfunction
        "F10282",  # Alcohol dependence with alcohol-induced sleep disorder
        "F10288",  # Alcohol dependence with other alcohol-induced disorder
        "F1029",  # Alcohol dependence with unspecified alcohol-induced disorder
        "F1090",  # Alcohol use, unspecified, uncomplicated
        "F1091",  # Alcohol use, unspecified, in remission
        "F10920",  # Alcohol use, unspecified with intoxication, uncomplicated
        "F10921",  # Alcohol use, unspecified with intoxication delirium
        "F10929",  # Alcohol use, unspecified with intoxication, unspecified
        "F10930",  # Alcohol use, unspecified with withdrawal, uncomplicated
        "F10931",  # Alcohol use, unspecified with withdrawal delirium
        "F10932",  # Alcohol use, unspecified with withdrawal with perceptual disturbance
        "F10939",  # Alcohol use, unspecified with withdrawal, unspecified
        "F1094",  # Alcohol use, unspecified with alcohol-induced mood disorder
        "F10950",  # Alcohol use, unspecified with alcohol-induced psychotic disorder with delusions
        "F10951",  # Alcohol use, unspecified with alcohol-induced psychotic disorder with hallucinations
        "F10959",  # Alcohol use, unspecified with alcohol-induced psychotic disorder, unspecified
        "F1096",  # Alcohol use, unspecified with alcohol-induced persisting amnestic disorder
        "F1097",  # Alcohol use, unspecified with alcohol-induced persisting dementia
        "F10980",  # Alcohol use, unspecified with alcohol-induced anxiety disorder
        "F10981",  # Alcohol use, unspecified with alcohol-induced sexual dysfunction
        "F10982",  # Alcohol use, unspecified with alcohol-induced sleep disorder
        "F10988",  # Alcohol use, unspecified with other alcohol-induced disorder
        "F1099",  # Alcohol use, unspecified with unspecified alcohol-induced disorder
        "F1110",  # Opioid abuse, uncomplicated
        "F1111",  # Opioid abuse, in remission
        "F11120",  # Opioid abuse with intoxication, uncomplicated
        "F11121",  # Opioid abuse with intoxication delirium
        "F11122",  # Opioid abuse with intoxication with perceptual disturbance
        "F11129",  # Opioid abuse with intoxication, unspecified
        "F1113",  # Opioid abuse with withdrawal
        "F1114",  # Opioid abuse with opioid-induced mood disorder
        "F11150",  # Opioid abuse with opioid-induced psychotic disorder with delusions
        "F11151",  # Opioid abuse with opioid-induced psychotic disorder with hallucinations
        "F11159",  # Opioid abuse with opioid-induced psychotic disorder, unspecified
        "F11181",  # Opioid abuse with opioid-induced sexual dysfunction
        "F11182",  # Opioid abuse with opioid-induced sleep disorder
        "F11188",  # Opioid abuse with other opioid-induced disorder
        "F1119",  # Opioid abuse with unspecified opioid-induced disorder
        "F1120",  # Opioid dependence, uncomplicated
        "F1121",  # Opioid dependence, in remission
        "F11220",  # Opioid dependence with intoxication, uncomplicated
        "F11221",  # Opioid dependence with intoxication delirium
        "F11222",  # Opioid dependence with intoxication with perceptual disturbance
        "F11229",  # Opioid dependence with intoxication, unspecified
        "F1123",  # Opioid dependence with withdrawal
        "F1124",  # Opioid dependence with opioid-induced mood disorder
        "F11250",  # Opioid dependence with opioid-induced psychotic disorder with delusions
        "F11251",  # Opioid dependence with opioid-induced psychotic disorder with hallucinations
        "F11259",  # Opioid dependence with opioid-induced psychotic disorder, unspecified
        "F11281",  # Opioid dependence with opioid-induced sexual dysfunction
        "F11282",  # Opioid dependence with opioid-induced sleep disorder
        "F11288",  # Opioid dependence with other opioid-induced disorder
        "F1129",  # Opioid dependence with unspecified opioid-induced disorder
        "F1190",  # Opioid use, unspecified, uncomplicated
        "F1191",  # Opioid use, unspecified, in remission
        "F11920",  # Opioid use, unspecified with intoxication, uncomplicated
        "F11921",  # Opioid use, unspecified with intoxication delirium
        "F11922",  # Opioid use, unspecified with intoxication with perceptual disturbance
        "F11929",  # Opioid use, unspecified with intoxication, unspecified
        "F1193",  # Opioid use, unspecified with withdrawal
        "F1194",  # Opioid use, unspecified with opioid-induced mood disorder
        "F11950",  # Opioid use, unspecified with opioid-induced psychotic disorder with delusions
        "F11951",  # Opioid use, unspecified with opioid-induced psychotic disorder with hallucinations
        "F11959",  # Opioid use, unspecified with opioid-induced psychotic disorder, unspecified
        "F11981",  # Opioid use, unspecified with opioid-induced sexual dysfunction
        "F11982",  # Opioid use, unspecified with opioid-induced sleep disorder
        "F11988",  # Opioid use, unspecified with other opioid-induced disorder
        "F1199",  # Opioid use, unspecified with unspecified opioid-induced disorder
        "F1210",  # Cannabis abuse, uncomplicated
        "F1211",  # Cannabis abuse, in remission
        "F12120",  # Cannabis abuse with intoxication, uncomplicated
        "F12121",  # Cannabis abuse with intoxication delirium
        "F12122",  # Cannabis abuse with intoxication with perceptual disturbance
        "F12129",  # Cannabis abuse with intoxication, unspecified
        "F1213",  # Cannabis abuse with withdrawal
        "F12150",  # Cannabis abuse with psychotic disorder with delusions
        "F12151",  # Cannabis abuse with psychotic disorder with hallucinations
        "F12159",  # Cannabis abuse with psychotic disorder, unspecified
        "F12180",  # Cannabis abuse with cannabis-induced anxiety disorder
        "F12188",  # Cannabis abuse with other cannabis-induced disorder
        "F1219",  # Cannabis abuse with unspecified cannabis-induced disorder
        "F1220",  # Cannabis dependence, uncomplicated
        "F1221",  # Cannabis dependence, in remission
        "F12220",  # Cannabis dependence with intoxication, uncomplicated
        "F12221",  # Cannabis dependence with intoxication delirium
        "F12222",  # Cannabis dependence with intoxication with perceptual disturbance
        "F12229",  # Cannabis dependence with intoxication, unspecified
        "F1223",  # Cannabis dependence with withdrawal
        "F12250",  # Cannabis dependence with psychotic disorder with delusions
        "F12251",  # Cannabis dependence with psychotic disorder with hallucinations
        "F12259",  # Cannabis dependence with psychotic disorder, unspecified
        "F12280",  # Cannabis dependence with cannabis-induced anxiety disorder
        "F12288",  # Cannabis dependence with other cannabis-induced disorder
        "F1229",  # Cannabis dependence with unspecified cannabis-induced disorder
        "F1290",  # Cannabis use, unspecified, uncomplicated
        "F1291",  # Cannabis use, unspecified, in remission
        "F12920",  # Cannabis use, unspecified with intoxication, uncomplicated
        "F12921",  # Cannabis use, unspecified with intoxication delirium
        "F12922",  # Cannabis use, unspecified with intoxication with perceptual disturbance
        "F12929",  # Cannabis use, unspecified with intoxication, unspecified
        "F1293",  # Cannabis use, unspecified with withdrawal
        "F12950",  # Cannabis use, unspecified with psychotic disorder with delusions
        "F12951",  # Cannabis use, unspecified with psychotic disorder with hallucinations
        "F12959",  # Cannabis use, unspecified with psychotic disorder, unspecified
        "F12980",  # Cannabis use, unspecified with anxiety disorder
        "F12988",  # Cannabis use, unspecified with other cannabis-induced disorder
        "F1299",  # Cannabis use, unspecified with unspecified cannabis-induced disorder
        "F1310",  # Sedative, hypnotic or anxiolytic abuse, uncomplicated
        "F1311",  # Sedative, hypnotic or anxiolytic abuse, in remission
        "F13120",  # Sedative, hypnotic or anxiolytic abuse with intoxication, uncomplicated
        "F13121",  # Sedative, hypnotic or anxiolytic abuse with intoxication delirium
        "F13129",  # Sedative, hypnotic or anxiolytic abuse with intoxication, unspecified
        "F13130",  # Sedative, hypnotic or anxiolytic abuse with withdrawal, uncomplicated
        "F13131",  # Sedative, hypnotic or anxiolytic abuse with withdrawal delirium
        "F13132",  # Sedative, hypnotic or anxiolytic abuse with withdrawal with perceptual disturbance
        "F13139",  # Sedative, hypnotic or anxiolytic abuse with withdrawal, unspecified
        "F1314",  # Sedative, hypnotic or anxiolytic abuse with sedative, hypnotic or anxiolytic-induced mood disorder
        "F13150",  # Sedative, hypnotic or anxiolytic abuse with sedative, hypnotic or anxiolytic-induced psychotic disorder with delusions
        "F13151",  # Sedative, hypnotic or anxiolytic abuse with sedative, hypnotic or anxiolytic-induced psychotic disorder with hallucinations
        "F13159",  # Sedative, hypnotic or anxiolytic abuse with sedative, hypnotic or anxiolytic-induced psychotic disorder, unspecified
        "F13180",  # Sedative, hypnotic or anxiolytic abuse with sedative, hypnotic or anxiolytic-induced anxiety disorder
        "F13181",  # Sedative, hypnotic or anxiolytic abuse with sedative, hypnotic or anxiolytic-induced sexual dysfunction
        "F13182",  # Sedative, hypnotic or anxiolytic abuse with sedative, hypnotic or anxiolytic-induced sleep disorder
        "F13188",  # Sedative, hypnotic or anxiolytic abuse with other sedative, hypnotic or anxiolytic-induced disorder
        "F1319",  # Sedative, hypnotic or anxiolytic abuse with unspecified sedative, hypnotic or anxiolytic-induced disorder
        "F1320",  # Sedative, hypnotic or anxiolytic dependence, uncomplicated
        "F1321",  # Sedative, hypnotic or anxiolytic dependence, in remission
        "F13220",  # Sedative, hypnotic or anxiolytic dependence with intoxication, uncomplicated
        "F13221",  # Sedative, hypnotic or anxiolytic dependence with intoxication delirium
        "F13229",  # Sedative, hypnotic or anxiolytic dependence with intoxication, unspecified
        "F13230",  # Sedative, hypnotic or anxiolytic dependence with withdrawal, uncomplicated
        "F13231",  # Sedative, hypnotic or anxiolytic dependence with withdrawal delirium
        "F13232",  # Sedative, hypnotic or anxiolytic dependence with withdrawal with perceptual disturbance
        "F13239",  # Sedative, hypnotic or anxiolytic dependence with withdrawal, unspecified
        "F1324",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced mood disorder
        "F13250",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced psychotic disorder with delusions
        "F13251",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced psychotic disorder with hallucinations
        "F13259",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced psychotic disorder, unspecified
        "F1326",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced persisting amnestic disorder
        "F1327",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced persisting dementia
        "F13280",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced anxiety disorder
        "F13281",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced sexual dysfunction
        "F13282",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced sleep disorder
        "F13288",  # Sedative, hypnotic or anxiolytic dependence with other sedative, hypnotic or anxiolytic-induced disorder
        "F1329",  # Sedative, hypnotic or anxiolytic dependence with unspecified sedative, hypnotic or anxiolytic-induced disorder
        "F1390",  # Sedative, hypnotic, or anxiolytic use, unspecified, uncomplicated
        "F1391",  # Sedative, hypnotic or anxiolytic use, unspecified, in remission
        "F13920",  # Sedative, hypnotic or anxiolytic use, unspecified with intoxication, uncomplicated
        "F13921",  # Sedative, hypnotic or anxiolytic use, unspecified with intoxication delirium
        "F13929",  # Sedative, hypnotic or anxiolytic use, unspecified with intoxication, unspecified
        "F13930",  # Sedative, hypnotic or anxiolytic use, unspecified with withdrawal, uncomplicated
        "F13931",  # Sedative, hypnotic or anxiolytic use, unspecified with withdrawal delirium
        "F13932",  # Sedative, hypnotic or anxiolytic use, unspecified with withdrawal with perceptual disturbances
        "F13939",  # Sedative, hypnotic or anxiolytic use, unspecified with withdrawal, unspecified
        "F1394",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced mood disorder
        "F13950",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced psychotic disorder with delusions
        "F13951",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced psychotic disorder with hallucinations
        "F13959",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced psychotic disorder, unspecified
        "F1396",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced persisting amnestic disorder
        "F1397",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced persisting dementia
        "F13980",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced anxiety disorder
        "F13981",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced sexual dysfunction
        "F13982",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced sleep disorder
        "F13988",  # Sedative, hypnotic or anxiolytic use, unspecified with other sedative, hypnotic or anxiolytic-induced disorder
        "F1399",  # Sedative, hypnotic or anxiolytic use, unspecified with unspecified sedative, hypnotic or anxiolytic-induced disorder
        "F1410",  # Cocaine abuse, uncomplicated
        "F1411",  # Cocaine abuse, in remission
        "F14120",  # Cocaine abuse with intoxication, uncomplicated
        "F14121",  # Cocaine abuse with intoxication with delirium
        "F14122",  # Cocaine abuse with intoxication with perceptual disturbance
        "F14129",  # Cocaine abuse with intoxication, unspecified
        "F1413",  # Cocaine abuse, unspecified with withdrawal
        "F1414",  # Cocaine abuse with cocaine-induced mood disorder
        "F14150",  # Cocaine abuse with cocaine-induced psychotic disorder with delusions
        "F14151",  # Cocaine abuse with cocaine-induced psychotic disorder with hallucinations
        "F14159",  # Cocaine abuse with cocaine-induced psychotic disorder, unspecified
        "F14180",  # Cocaine abuse with cocaine-induced anxiety disorder
        "F14181",  # Cocaine abuse with cocaine-induced sexual dysfunction
        "F14182",  # Cocaine abuse with cocaine-induced sleep disorder
        "F14188",  # Cocaine abuse with other cocaine-induced disorder
        "F1419",  # Cocaine abuse with unspecified cocaine-induced disorder
        "F1420",  # Cocaine dependence, uncomplicated
        "F1421",  # Cocaine dependence, in remission
        "F14220",  # Cocaine dependence with intoxication, uncomplicated
        "F14221",  # Cocaine dependence with intoxication delirium
        "F14222",  # Cocaine dependence with intoxication with perceptual disturbance
        "F14229",  # Cocaine dependence with intoxication, unspecified
        "F1423",  # Cocaine dependence with withdrawal
        "F1424",  # Cocaine dependence with cocaine-induced mood disorder
        "F14250",  # Cocaine dependence with cocaine-induced psychotic disorder with delusions
        "F14251",  # Cocaine dependence with cocaine-induced psychotic disorder with hallucinations
        "F14259",  # Cocaine dependence with cocaine-induced psychotic disorder, unspecified
        "F14280",  # Cocaine dependence with cocaine-induced anxiety disorder
        "F14281",  # Cocaine dependence with cocaine-induced sexual dysfunction
        "F14282",  # Cocaine dependence with cocaine-induced sleep disorder
        "F14288",  # Cocaine dependence with other cocaine-induced disorder
        "F1429",  # Cocaine dependence with unspecified cocaine-induced disorder
        "F1490",  # Cocaine use, unspecified, uncomplicated
        "F1491",  # Cocaine use, unspecified, in remission
        "F14920",  # Cocaine use, unspecified with intoxication, uncomplicated
        "F14921",  # Cocaine use, unspecified with intoxication delirium
        "F14922",  # Cocaine use, unspecified with intoxication with perceptual disturbance
        "F14929",  # Cocaine use, unspecified with intoxication, unspecified
        "F1493",  # Cocaine use, unspecified with withdrawal
        "F1494",  # Cocaine use, unspecified with cocaine-induced mood disorder
        "F14950",  # Cocaine use, unspecified with cocaine-induced psychotic disorder with delusions
        "F14951",  # Cocaine use, unspecified with cocaine-induced psychotic disorder with hallucinations
        "F14959",  # Cocaine use, unspecified with cocaine-induced psychotic disorder, unspecified
        "F14980",  # Cocaine use, unspecified with cocaine-induced anxiety disorder
        "F14981",  # Cocaine use, unspecified with cocaine-induced sexual dysfunction
        "F14982",  # Cocaine use, unspecified with cocaine-induced sleep disorder
        "F14988",  # Cocaine use, unspecified with other cocaine-induced disorder
        "F1499",  # Cocaine use, unspecified with unspecified cocaine-induced disorder
        "F1510",  # Other stimulant abuse, uncomplicated
        "F1511",  # Other stimulant abuse, in remission
        "F15120",  # Other stimulant abuse with intoxication, uncomplicated
        "F15121",  # Other stimulant abuse with intoxication delirium
        "F15122",  # Other stimulant abuse with intoxication with perceptual disturbance
        "F15129",  # Other stimulant abuse with intoxication, unspecified
        "F1513",  # Other stimulant abuse with withdrawal
        "F1514",  # Other stimulant abuse with stimulant-induced mood disorder
        "F15150",  # Other stimulant abuse with stimulant-induced psychotic disorder with delusions
        "F15151",  # Other stimulant abuse with stimulant-induced psychotic disorder with hallucinations
        "F15159",  # Other stimulant abuse with stimulant-induced psychotic disorder, unspecified
        "F15180",  # Other stimulant abuse with stimulant-induced anxiety disorder
        "F15181",  # Other stimulant abuse with stimulant-induced sexual dysfunction
        "F15182",  # Other stimulant abuse with stimulant-induced sleep disorder
        "F15188",  # Other stimulant abuse with other stimulant-induced disorder
        "F1519",  # Other stimulant abuse with unspecified stimulant-induced disorder
        "F1520",  # Other stimulant dependence, uncomplicated
        "F1521",  # Other stimulant dependence, in remission
        "F15220",  # Other stimulant dependence with intoxication, uncomplicated
        "F15221",  # Other stimulant dependence with intoxication delirium
        "F15222",  # Other stimulant dependence with intoxication with perceptual disturbance
        "F15229",  # Other stimulant dependence with intoxication, unspecified
        "F1523",  # Other stimulant dependence with withdrawal
        "F1524",  # Other stimulant dependence with stimulant-induced mood disorder
        "F15250",  # Other stimulant dependence with stimulant-induced psychotic disorder with delusions
        "F15251",  # Other stimulant dependence with stimulant-induced psychotic disorder with hallucinations
        "F15259",  # Other stimulant dependence with stimulant-induced psychotic disorder, unspecified
        "F15280",  # Other stimulant dependence with stimulant-induced anxiety disorder
        "F15281",  # Other stimulant dependence with stimulant-induced sexual dysfunction
        "F15282",  # Other stimulant dependence with stimulant-induced sleep disorder
        "F15288",  # Other stimulant dependence with other stimulant-induced disorder
        "F1529",  # Other stimulant dependence with unspecified stimulant-induced disorder
        "F1590",  # Other stimulant use, unspecified, uncomplicated
        "F1591",  # Other stimulant use, unspecified, in remission
        "F15920",  # Other stimulant use, unspecified with intoxication, uncomplicated
        "F15921",  # Other stimulant use, unspecified with intoxication delirium
        "F15922",  # Other stimulant use, unspecified with intoxication with perceptual disturbance
        "F15929",  # Other stimulant use, unspecified with intoxication, unspecified
        "F1593",  # Other stimulant use, unspecified with withdrawal
        "F1594",  # Other stimulant use, unspecified with stimulant-induced mood disorder
        "F15950",  # Other stimulant use, unspecified with stimulant-induced psychotic disorder with delusions
        "F15951",  # Other stimulant use, unspecified with stimulant-induced psychotic disorder with hallucinations
        "F15959",  # Other stimulant use, unspecified with stimulant-induced psychotic disorder, unspecified
        "F15980",  # Other stimulant use, unspecified with stimulant-induced anxiety disorder
        "F15981",  # Other stimulant use, unspecified with stimulant-induced sexual dysfunction
        "F15982",  # Other stimulant use, unspecified with stimulant-induced sleep disorder
        "F15988",  # Other stimulant use, unspecified with other stimulant-induced disorder
        "F1599",  # Other stimulant use, unspecified with unspecified stimulant-induced disorder
        "F1610",  # Hallucinogen abuse, uncomplicated
        "F1611",  # Hallucinogen abuse, in remission
        "F16120",  # Hallucinogen abuse with intoxication, uncomplicated
        "F16121",  # Hallucinogen abuse with intoxication with delirium
        "F16122",  # Hallucinogen abuse with intoxication with perceptual disturbance
        "F16129",  # Hallucinogen abuse with intoxication, unspecified
        "F1614",  # Hallucinogen abuse with hallucinogen-induced mood disorder
        "F16150",  # Hallucinogen abuse with hallucinogen-induced psychotic disorder with delusions
        "F16151",  # Hallucinogen abuse with hallucinogen-induced psychotic disorder with hallucinations
        "F16159",  # Hallucinogen abuse with hallucinogen-induced psychotic disorder, unspecified
        "F16180",  # Hallucinogen abuse with hallucinogen-induced anxiety disorder
        "F16183",  # Hallucinogen abuse with hallucinogen persisting perception disorder (flashbacks)
        "F16188",  # Hallucinogen abuse with other hallucinogen-induced disorder
        "F1619",  # Hallucinogen abuse with unspecified hallucinogen-induced disorder
        "F1620",  # Hallucinogen dependence, uncomplicated
        "F1621",  # Hallucinogen dependence, in remission
        "F16220",  # Hallucinogen dependence with intoxication, uncomplicated
        "F16221",  # Hallucinogen dependence with intoxication with delirium
        "F16229",  # Hallucinogen dependence with intoxication, unspecified
        "F1624",  # Hallucinogen dependence with hallucinogen-induced mood disorder
        "F16250",  # Hallucinogen dependence with hallucinogen-induced psychotic disorder with delusions
        "F16251",  # Hallucinogen dependence with hallucinogen-induced psychotic disorder with hallucinations
        "F16259",  # Hallucinogen dependence with hallucinogen-induced psychotic disorder, unspecified
        "F16280",  # Hallucinogen dependence with hallucinogen-induced anxiety disorder
        "F16283",  # Hallucinogen dependence with hallucinogen persisting perception disorder (flashbacks)
        "F16288",  # Hallucinogen dependence with other hallucinogen-induced disorder
        "F1629",  # Hallucinogen dependence with unspecified hallucinogen-induced disorder
        "F1690",  # Hallucinogen use, unspecified, uncomplicated
        "F1691",  # Hallucinogen use, unspecified, in remission
        "F16920",  # Hallucinogen use, unspecified with intoxication, uncomplicated
        "F16921",  # Hallucinogen use, unspecified with intoxication with delirium
        "F16929",  # Hallucinogen use, unspecified with intoxication, unspecified
        "F1694",  # Hallucinogen use, unspecified with hallucinogen-induced mood disorder
        "F16950",  # Hallucinogen use, unspecified with hallucinogen-induced psychotic disorder with delusions
        "F16951",  # Hallucinogen use, unspecified with hallucinogen-induced psychotic disorder with hallucinations
        "F16959",  # Hallucinogen use, unspecified with hallucinogen-induced psychotic disorder, unspecified
        "F16980",  # Hallucinogen use, unspecified with hallucinogen-induced anxiety disorder
        "F16983",  # Hallucinogen use, unspecified with hallucinogen persisting perception disorder (flashbacks)
        "F16988",  # Hallucinogen use, unspecified with other hallucinogen-induced disorder
        "F1699",  # Hallucinogen use, unspecified with unspecified hallucinogen-induced disorder
        "F1810",  # Inhalant abuse, uncomplicated
        "F1811",  # Inhalant abuse, in remission
        "F18120",  # Inhalant abuse with intoxication, uncomplicated
        "F18121",  # Inhalant abuse with intoxication delirium
        "F18129",  # Inhalant abuse with intoxication, unspecified
        "F1814",  # Inhalant abuse with inhalant-induced mood disorder
        "F18150",  # Inhalant abuse with inhalant-induced psychotic disorder with delusions
        "F18151",  # Inhalant abuse with inhalant-induced psychotic disorder with hallucinations
        "F18159",  # Inhalant abuse with inhalant-induced psychotic disorder, unspecified
        "F1817",  # Inhalant abuse with inhalant-induced dementia
        "F18180",  # Inhalant abuse with inhalant-induced anxiety disorder
        "F18188",  # Inhalant abuse with other inhalant-induced disorder
        "F1819",  # Inhalant abuse with unspecified inhalant-induced disorder
        "F1820",  # Inhalant dependence, uncomplicated
        "F1821",  # Inhalant dependence, in remission
        "F18220",  # Inhalant dependence with intoxication, uncomplicated
        "F18221",  # Inhalant dependence with intoxication delirium
        "F18229",  # Inhalant dependence with intoxication, unspecified
        "F1824",  # Inhalant dependence with inhalant-induced mood disorder
        "F18250",  # Inhalant dependence with inhalant-induced psychotic disorder with delusions
        "F18251",  # Inhalant dependence with inhalant-induced psychotic disorder with hallucinations
        "F18259",  # Inhalant dependence with inhalant-induced psychotic disorder, unspecified
        "F1827",  # Inhalant dependence with inhalant-induced dementia
        "F18280",  # Inhalant dependence with inhalant-induced anxiety disorder
        "F18288",  # Inhalant dependence with other inhalant-induced disorder
        "F1829",  # Inhalant dependence with unspecified inhalant-induced disorder
        "F1890",  # Inhalant use, unspecified, uncomplicated
        "F1891",  # Inhalant use, unspecified, in remission
        "F18920",  # Inhalant use, unspecified with intoxication, uncomplicated
        "F18921",  # Inhalant use, unspecified with intoxication with delirium
        "F18929",  # Inhalant use, unspecified with intoxication, unspecified
        "F1894",  # Inhalant use, unspecified with inhalant-induced mood disorder
        "F18950",  # Inhalant use, unspecified with inhalant-induced psychotic disorder with delusions
        "F18951",  # Inhalant use, unspecified with inhalant-induced psychotic disorder with hallucinations
        "F18959",  # Inhalant use, unspecified with inhalant-induced psychotic disorder, unspecified
        "F1897",  # Inhalant use, unspecified with inhalant-induced persisting dementia
        "F18980",  # Inhalant use, unspecified with inhalant-induced anxiety disorder
        "F18988",  # Inhalant use, unspecified with other inhalant-induced disorder
        "F1899",  # Inhalant use, unspecified with unspecified inhalant-induced disorder
        "F1910",  # Other psychoactive substance abuse, uncomplicated
        "F1911",  # Other psychoactive substance abuse, in remission
        "F19120",  # Other psychoactive substance abuse with intoxication, uncomplicated
        "F19121",  # Other psychoactive substance abuse with intoxication delirium
        "F19122",  # Other psychoactive substance abuse with intoxication with perceptual disturbances
        "F19129",  # Other psychoactive substance abuse with intoxication, unspecified
        "F19130",  # Other psychoactive substance abuse with withdrawal, uncomplicated
        "F19131",  # Other psychoactive substance abuse with withdrawal delirium
        "F19132",  # Other psychoactive substance abuse with withdrawal with perceptual disturbance
        "F19139",  # Other psychoactive substance abuse with withdrawal, unspecified
        "F1914",  # Other psychoactive substance abuse with psychoactive substance-induced mood disorder
        "F19150",  # Other psychoactive substance abuse with psychoactive substance-induced psychotic disorder with delusions
        "F19151",  # Other psychoactive substance abuse with psychoactive substance-induced psychotic disorder with hallucinations
        "F19159",  # Other psychoactive substance abuse with psychoactive substance-induced psychotic disorder, unspecified
        "F1916",  # Other psychoactive substance abuse with psychoactive substance-induced persisting amnestic disorder
        "F1917",  # Other psychoactive substance abuse with psychoactive substance-induced persisting dementia
        "F19180",  # Other psychoactive substance abuse with psychoactive substance-induced anxiety disorder
        "F19181",  # Other psychoactive substance abuse with psychoactive substance-induced sexual dysfunction
        "F19182",  # Other psychoactive substance abuse with psychoactive substance-induced sleep disorder
        "F19188",  # Other psychoactive substance abuse with other psychoactive substance-induced disorder
        "F1919",  # Other psychoactive substance abuse with unspecified psychoactive substance-induced disorder
        "F1920",  # Other psychoactive substance dependence, uncomplicated
        "F1921",  # Other psychoactive substance dependence, in remission
        "F19220",  # Other psychoactive substance dependence with intoxication, uncomplicated
        "F19221",  # Other psychoactive substance dependence with intoxication delirium
        "F19222",  # Other psychoactive substance dependence with intoxication with perceptual disturbance
        "F19229",  # Other psychoactive substance dependence with intoxication, unspecified
        "F19230",  # Other psychoactive substance dependence with withdrawal, uncomplicated
        "F19231",  # Other psychoactive substance dependence with withdrawal delirium
        "F19232",  # Other psychoactive substance dependence with withdrawal with perceptual disturbance
        "F19239",  # Other psychoactive substance dependence with withdrawal, unspecified
        "F1924",  # Other psychoactive substance dependence with psychoactive substance-induced mood disorder
        "F19250",  # Other psychoactive substance dependence with psychoactive substance-induced psychotic disorder with delusions
        "F19251",  # Other psychoactive substance dependence with psychoactive substance-induced psychotic disorder with hallucinations
        "F19259",  # Other psychoactive substance dependence with psychoactive substance-induced psychotic disorder, unspecified
        "F1926",  # Other psychoactive substance dependence with psychoactive substance-induced persisting amnestic disorder
        "F1927",  # Other psychoactive substance dependence with psychoactive substance-induced persisting dementia
        "F19280",  # Other psychoactive substance dependence with psychoactive substance-induced anxiety disorder
        "F19281",  # Other psychoactive substance dependence with psychoactive substance-induced sexual dysfunction
        "F19282",  # Other psychoactive substance dependence with psychoactive substance-induced sleep disorder
        "F19288",  # Other psychoactive substance dependence with other psychoactive substance-induced disorder
        "F1929",  # Other psychoactive substance dependence with unspecified psychoactive substance-induced disorder
        "F1990",  # Other psychoactive substance use, unspecified, uncomplicated
        "F1991",  # Other psychoactive substance use, unspecified, in remission
        "F19920",  # Other psychoactive substance use, unspecified with intoxication, uncomplicated
        "F19921",  # Other psychoactive substance use, unspecified with intoxication with delirium
        "F19922",  # Other psychoactive substance use, unspecified with intoxication with perceptual disturbance
        "F19929",  # Other psychoactive substance use, unspecified with intoxication, unspecified
        "F19930",  # Other psychoactive substance use, unspecified with withdrawal, uncomplicated
        "F19931",  # Other psychoactive substance use, unspecified with withdrawal delirium
        "F19932",  # Other psychoactive substance use, unspecified with withdrawal with perceptual disturbance
        "F19939",  # Other psychoactive substance use, unspecified with withdrawal, unspecified
        "F1994",  # Other psychoactive substance use, unspecified with psychoactive substance-induced mood disorder
        "F19950",  # Other psychoactive substance use, unspecified with psychoactive substance-induced psychotic disorder with delusions
        "F19951",  # Other psychoactive substance use, unspecified with psychoactive substance-induced psychotic disorder with hallucinations
        "F19959",  # Other psychoactive substance use, unspecified with psychoactive substance-induced psychotic disorder, unspecified
        "F1996",  # Other psychoactive substance use, unspecified with psychoactive substance-induced persisting amnestic disorder
        "F1997",  # Other psychoactive substance use, unspecified with psychoactive substance-induced persisting dementia
        "F19980",  # Other psychoactive substance use, unspecified with psychoactive substance-induced anxiety disorder
        "F19981",  # Other psychoactive substance use, unspecified with psychoactive substance-induced sexual dysfunction
        "F19982",  # Other psychoactive substance use, unspecified with psychoactive substance-induced sleep disorder
        "F19988",  # Other psychoactive substance use, unspecified with other psychoactive substance-induced disorder
        "F1999",  # Other psychoactive substance use, unspecified with unspecified psychoactive substance-induced disorder
        "F200",  # Paranoid schizophrenia
        "F201",  # Disorganized schizophrenia
        "F202",  # Catatonic schizophrenia
        "F203",  # Undifferentiated schizophrenia
        "F205",  # Residual schizophrenia
        "F2081",  # Schizophreniform disorder
        "F2089",  # Other schizophrenia
        "F209",  # Schizophrenia, unspecified
        "F21",  # Schizotypal disorder
        "F22",  # Delusional disorders
        "F23",  # Brief psychotic disorder
        "F24",  # Shared psychotic disorder
        "F250",  # Schizoaffective disorder, bipolar type
        "F251",  # Schizoaffective disorder, depressive type
        "F258",  # Other schizoaffective disorders
        "F259",  # Schizoaffective disorder, unspecified
        "F28",  # Other psychotic disorder not due to a substance or known physiological condition
        "F29",  # Unspecified psychosis not due to a substance or known physiological condition
        "F3010",  # Manic episode without psychotic symptoms, unspecified
        "F3011",  # Manic episode without psychotic symptoms, mild
        "F3012",  # Manic episode without psychotic symptoms, moderate
        "F3013",  # Manic episode, severe, without psychotic symptoms
        "F302",  # Manic episode, severe with psychotic symptoms
        "F303",  # Manic episode in partial remission
        "F304",  # Manic episode in full remission
        "F308",  # Other manic episodes
        "F309",  # Manic episode, unspecified
        "F310",  # Bipolar disorder, current episode hypomanic
        "F3110",  # Bipolar disorder, current episode manic without psychotic features, unspecified
        "F3111",  # Bipolar disorder, current episode manic without psychotic features, mild
        "F3112",  # Bipolar disorder, current episode manic without psychotic features, moderate
        "F3113",  # Bipolar disorder, current episode manic without psychotic features, severe
        "F312",  # Bipolar disorder, current episode manic severe with psychotic features
        "F3130",  # Bipolar disorder, current episode depressed, mild or moderate severity, unspecified
        "F3131",  # Bipolar disorder, current episode depressed, mild
        "F3132",  # Bipolar disorder, current episode depressed, moderate
        "F314",  # Bipolar disorder, current episode depressed, severe, without psychotic features
        "F315",  # Bipolar disorder, current episode depressed, severe, with psychotic features
        "F3160",  # Bipolar disorder, current episode mixed, unspecified
        "F3161",  # Bipolar disorder, current episode mixed, mild
        "F3162",  # Bipolar disorder, current episode mixed, moderate
        "F3163",  # Bipolar disorder, current episode mixed, severe, without psychotic features
        "F3164",  # Bipolar disorder, current episode mixed, severe, with psychotic features
        "F3170",  # Bipolar disorder, currently in remission, most recent episode unspecified
        "F3171",  # Bipolar disorder, in partial remission, most recent episode hypomanic
        "F3172",  # Bipolar disorder, in full remission, most recent episode hypomanic
        "F3173",  # Bipolar disorder, in partial remission, most recent episode manic
        "F3174",  # Bipolar disorder, in full remission, most recent episode manic
        "F3175",  # Bipolar disorder, in partial remission, most recent episode depressed
        "F3176",  # Bipolar disorder, in full remission, most recent episode depressed
        "F3177",  # Bipolar disorder, in partial remission, most recent episode mixed
        "F3178",  # Bipolar disorder, in full remission, most recent episode mixed
        "F3181",  # Bipolar II disorder
        "F3189",  # Other bipolar disorder
        "F319",  # Bipolar disorder, unspecified
        "F320",  # Major depressive disorder, single episode, mild
        "F321",  # Major depressive disorder, single episode, moderate
        "F322",  # Major depressive disorder, single episode, severe without psychotic features
        "F323",  # Major depressive disorder, single episode, severe with psychotic features
        "F324",  # Major depressive disorder, single episode, in partial remission
        "F325",  # Major depressive disorder, single episode, in full remission
        "F3281",  # Premenstrual dysphoric disorder
        "F3289",  # Other specified depressive episodes
        "F329",  # Major depressive disorder, single episode, unspecified
        "F32A",  # Depression, unspecified
        "F330",  # Major depressive disorder, recurrent, mild
        "F331",  # Major depressive disorder, recurrent, moderate
        "F332",  # Major depressive disorder, recurrent severe without psychotic features
        "F333",  # Major depressive disorder, recurrent, severe with psychotic symptoms
        "F3340",  # Major depressive disorder, recurrent, in remission, unspecified
        "F3341",  # Major depressive disorder, recurrent, in partial remission
        "F3342",  # Major depressive disorder, recurrent, in full remission
        "F338",  # Other recurrent depressive disorders
        "F339",  # Major depressive disorder, recurrent, unspecified
        "F340",  # Cyclothymic disorder
        "F341",  # Dysthymic disorder
        "F3481",  # Disruptive mood dysregulation disorder
        "F3489",  # Other specified persistent mood disorders
        "F349",  # Persistent mood [affective] disorder, unspecified
        "F39",  # Unspecified mood [affective] disorder
        "F4000",  # Agoraphobia, unspecified
        "F4001",  # Agoraphobia with panic disorder
        "F4002",  # Agoraphobia without panic disorder
        "F4010",  # Social phobia, unspecified
        "F4011",  # Social phobia, generalized
        "F40210",  # Arachnophobia
        "F40218",  # Other animal type phobia
        "F40220",  # Fear of thunderstorms
        "F40228",  # Other natural environment type phobia
        "F40230",  # Fear of blood
        "F40231",  # Fear of injections and transfusions
        "F40232",  # Fear of other medical care
        "F40233",  # Fear of injury
        "F40240",  # Claustrophobia
        "F40241",  # Acrophobia
        "F40242",  # Fear of bridges
        "F40243",  # Fear of flying
        "F40248",  # Other situational type phobia
        "F40290",  # Androphobia
        "F40291",  # Gynephobia
        "F40298",  # Other specified phobia
        "F408",  # Other phobic anxiety disorders
        "F409",  # Phobic anxiety disorder, unspecified
        "F410",  # Panic disorder [episodic paroxysmal anxiety]
        "F411",  # Generalized anxiety disorder
        "F413",  # Other mixed anxiety disorders
        "F418",  # Other specified anxiety disorders
        "F419",  # Anxiety disorder, unspecified
        "F422",  # Mixed obsessional thoughts and acts
        "F423",  # Hoarding disorder
        "F424",  # Excoriation (skin-picking) disorder
        "F428",  # Other obsessive-compulsive disorder
        "F429",  # Obsessive-compulsive disorder, unspecified
        "F430",  # Acute stress reaction
        "F4310",  # Post-traumatic stress disorder, unspecified
        "F4311",  # Post-traumatic stress disorder, acute
        "F4312",  # Post-traumatic stress disorder, chronic
        "F4320",  # Adjustment disorder, unspecified
        "F4321",  # Adjustment disorder with depressed mood
        "F4322",  # Adjustment disorder with anxiety
        "F4323",  # Adjustment disorder with mixed anxiety and depressed mood
        "F4324",  # Adjustment disorder with disturbance of conduct
        "F4325",  # Adjustment disorder with mixed disturbance of emotions and conduct
        "F4329",  # Adjustment disorder with other symptoms
        "F4381",  # Prolonged grief disorder
        "F4389",  # Other reactions to severe stress
        "F439",  # Reaction to severe stress, unspecified
        "F440",  # Dissociative amnesia
        "F441",  # Dissociative fugue
        "F442",  # Dissociative stupor
        "F444",  # Conversion disorder with motor symptom or deficit
        "F445",  # Conversion disorder with seizures or convulsions
        "F446",  # Conversion disorder with sensory symptom or deficit
        "F447",  # Conversion disorder with mixed symptom presentation
        "F4481",  # Dissociative identity disorder
        "F4489",  # Other dissociative and conversion disorders
        "F449",  # Dissociative and conversion disorder, unspecified
        "F450",  # Somatization disorder
        "F451",  # Undifferentiated somatoform disorder
        "F4520",  # Hypochondriacal disorder, unspecified
        "F4521",  # Hypochondriasis
        "F4522",  # Body dysmorphic disorder
        "F4529",  # Other hypochondriacal disorders
        "F4541",  # Pain disorder exclusively related to psychological factors
        "F4542",  # Pain disorder with related psychological factors
        "F458",  # Other somatoform disorders
        "F459",  # Somatoform disorder, unspecified
        "F481",  # Depersonalization-derealization syndrome
        "F482",  # Pseudobulbar affect
        "F488",  # Other specified nonpsychotic mental disorders
        "F489",  # Nonpsychotic mental disorder, unspecified
        "F5000",  # Anorexia nervosa, unspecified
        "F5001",  # Anorexia nervosa, restricting type
        "F50010",  # Anorexia nervosa, restricting type, mild
        "F50011",  # Anorexia nervosa, restricting type, moderate
        "F50012",  # Anorexia nervosa, restricting type, severe
        "F50013",  # Anorexia nervosa, restricting type, extreme
        "F50014",  # Anorexia nervosa, restricting type, in remission
        "F50019",  # Anorexia nervosa, restricting type, unspecified
        "F5002",  # Anorexia nervosa, binge eating/purging type
        "F50020",  # Anorexia nervosa, binge eating/purging type, mild
        "F50021",  # Anorexia nervosa, binge eating/purging type, moderate
        "F50022",  # Anorexia nervosa, binge eating/purging type, severe
        "F50023",  # Anorexia nervosa, binge eating/purging type, extreme
        "F50024",  # Anorexia nervosa, binge eating/purging type, in remission
        "F50029",  # Anorexia nervosa, binge eating/purging type, unspecified
        "F502",  # Bulimia nervosa
        "F5020",  # Bulimia nervosa, unspecified
        "F5021",  # Bulimia nervosa, mild
        "F5022",  # Bulimia nervosa, moderate
        "F5023",  # Bulimia nervosa, severe
        "F5024",  # Bulimia nervosa, extreme
        "F5025",  # Bulimia nervosa, in remission
        "F5081",  # Binge eating disorder
        "F50810",  # Binge eating disorder, mild
        "F50811",  # Binge eating disorder, moderate
        "F50812",  # Binge eating disorder, severe
        "F50813",  # Binge eating disorder, extreme
        "F50814",  # Binge eating disorder, in remission
        "F50819",  # Binge eating disorder, unspecified
        "F5082",  # Avoidant/restrictive food intake disorder
        "F5083",  # Pica in adults
        "F5084",  # Rumination disorder in adults
        "F5089",  # Other specified eating disorder
        "F509",  # Eating disorder, unspecified
        "F5101",  # Primary insomnia
        "F5102",  # Adjustment insomnia
        "F5103",  # Paradoxical insomnia
        "F5104",  # Psychophysiologic insomnia
        "F5105",  # Insomnia due to other mental disorder
        "F5109",  # Other insomnia not due to a substance or known physiological condition
        "F5111",  # Primary hypersomnia
        "F5112",  # Insufficient sleep syndrome
        "F5113",  # Hypersomnia due to other mental disorder
        "F5119",  # Other hypersomnia not due to a substance or known physiological condition
        "F513",  # Sleepwalking [somnambulism]
        "F514",  # Sleep terrors [night terrors]
        "F515",  # Nightmare disorder
        "F518",  # Other sleep disorders not due to a substance or known physiological condition
        "F519",  # Sleep disorder not due to a substance or known physiological condition, unspecified
        "F520",  # Hypoactive sexual desire disorder
        "F521",  # Sexual aversion disorder
        "F5221",  # Male erectile disorder
        "F5222",  # Female sexual arousal disorder
        "F5231",  # Female orgasmic disorder
        "F5232",  # Male orgasmic disorder
        "F524",  # Premature ejaculation
        "F525",  # Vaginismus not due to a substance or known physiological condition
        "F526",  # Dyspareunia not due to a substance or known physiological condition
        "F528",  # Other sexual dysfunction not due to a substance or known physiological condition
        "F529",  # Unspecified sexual dysfunction not due to a substance or known physiological condition
        "F530",  # Postpartum depression
        "F531",  # Puerperal psychosis
        "F59",  # Unspecified behavioral syndromes associated with physiological disturbances and physical factors
        "F600",  # Paranoid personality disorder
        "F601",  # Schizoid personality disorder
        "F602",  # Antisocial personality disorder
        "F603",  # Borderline personality disorder
        "F604",  # Histrionic personality disorder
        "F605",  # Obsessive-compulsive personality disorder
        "F606",  # Avoidant personality disorder
        "F607",  # Dependent personality disorder
        "F6081",  # Narcissistic personality disorder
        "F6089",  # Other specific personality disorders
        "F609",  # Personality disorder, unspecified
        "F630",  # Pathological gambling
        "F631",  # Pyromania
        "F632",  # Kleptomania
        "F633",  # Trichotillomania
        "F6381",  # Intermittent explosive disorder
        "F6389",  # Other impulse disorders
        "F639",  # Impulse disorder, unspecified
        "F640",  # Transsexualism
        "F641",  # Dual role transvestism
        "F642",  # Gender identity disorder of childhood
        "F648",  # Other gender identity disorders
        "F649",  # Gender identity disorder, unspecified
        "F650",  # Fetishism
        "F651",  # Transvestic fetishism
        "F652",  # Exhibitionism
        "F653",  # Voyeurism
        "F654",  # Pedophilia
        "F6550",  # Sadomasochism, unspecified
        "F6551",  # Sexual masochism
        "F6552",  # Sexual sadism
        "F6581",  # Frotteurism
        "F6589",  # Other paraphilias
        "F659",  # Paraphilia, unspecified
        "F66",  # Other sexual disorders
        "F6810",  # Factitious disorder imposed on self, unspecified
        "F6811",  # Factitious disorder imposed on self, with predominantly psychological signs and symptoms
        "F6812",  # Factitious disorder imposed on self, with predominantly physical signs and symptoms
        "F6813",  # Factitious disorder imposed on self, with combined psychological and physical signs and symptoms
        "F688",  # Other specified disorders of adult personality and behavior
        "F68A",  # Factitious disorder imposed on another
        "F69",  # Unspecified disorder of adult personality and behavior
        "F800",  # Phonological disorder
        "F801",  # Expressive language disorder
        "F802",  # Mixed receptive-expressive language disorder
        "F804",  # Speech and language development delay due to hearing loss
        "F8081",  # Childhood onset fluency disorder
        "F8082",  # Social pragmatic communication disorder
        "F8089",  # Other developmental disorders of speech and language
        "F809",  # Developmental disorder of speech and language, unspecified
        "F810",  # Specific reading disorder
        "F812",  # Mathematics disorder
        "F8181",  # Disorder of written expression
        "F8189",  # Other developmental disorders of scholastic skills
        "F819",  # Developmental disorder of scholastic skills, unspecified
        "F82",  # Specific developmental disorder of motor function
        "F840",  # Autistic disorder
        "F842",  # Rett's syndrome
        "F843",  # Other childhood disintegrative disorder
        "F845",  # Asperger's syndrome
        "F848",  # Other pervasive developmental disorders
        "F849",  # Pervasive developmental disorder, unspecified
        "F88",  # Other disorders of psychological development
        "F89",  # Unspecified disorder of psychological development
        "F900",  # Attention-deficit hyperactivity disorder, predominantly inattentive type
        "F901",  # Attention-deficit hyperactivity disorder, predominantly hyperactive type
        "F902",  # Attention-deficit hyperactivity disorder, combined type
        "F908",  # Attention-deficit hyperactivity disorder, other type
        "F909",  # Attention-deficit hyperactivity disorder, unspecified type
        "F910",  # Conduct disorder confined to family context
        "F911",  # Conduct disorder, childhood-onset type
        "F912",  # Conduct disorder, adolescent-onset type
        "F913",  # Oppositional defiant disorder
        "F918",  # Other conduct disorders
        "F919",  # Conduct disorder, unspecified
        "F930",  # Separation anxiety disorder of childhood
        "F938",  # Other childhood emotional disorders
        "F939",  # Childhood emotional disorder, unspecified
        "F940",  # Selective mutism
        "F941",  # Reactive attachment disorder of childhood
        "F942",  # Disinhibited attachment disorder of childhood
        "F948",  # Other childhood disorders of social functioning
        "F949",  # Childhood disorder of social functioning, unspecified
        "F950",  # Transient tic disorder
        "F951",  # Chronic motor or vocal tic disorder
        "F952",  # Tourette's disorder
        "F958",  # Other tic disorders
        "F959",  # Tic disorder, unspecified
        "F980",  # Enuresis not due to a substance or known physiological condition
        "F981",  # Encopresis not due to a substance or known physiological condition
        "F9821",  # Rumination disorder of infancy and childhood
        "F9829",  # Other feeding disorders of infancy and early childhood
        "F983",  # Pica of infancy and childhood
        "F984",  # Stereotyped movement disorders
        "F985",  # Adult onset fluency disorder
        "F988",  # Other specified behavioral and emotional disorders with onset usually occurring in childhood and adolescence
        "F989",  # Unspecified behavioral and emotional disorders with onset usually occurring in childhood and adolescence
        "F99",  # Mental disorder, not otherwise specified
        "T1491XA",  # Suicide attempt, initial encounter
        "T360X2A",  # Poisoning by penicillins, intentional self-harm, initial encounter
        "T361X2A",  # Poisoning by cephalosporins and other beta-lactam antibiotics, intentional self-harm, initial encounter
        "T362X2A",  # Poisoning by chloramphenicol group, intentional self-harm, initial encounter
        "T363X2A",  # Poisoning by macrolides, intentional self-harm, initial encounter
        "T364X2A",  # Poisoning by tetracyclines, intentional self-harm, initial encounter
        "T365X2A",  # Poisoning by aminoglycosides, intentional self-harm, initial encounter
        "T366X2A",  # Poisoning by rifampicins, intentional self-harm, initial encounter
        "T367X2A",  # Poisoning by antifungal antibiotics, systemically used, intentional self-harm, initial encounter
        "T368X2A",  # Poisoning by other systemic antibiotics, intentional self-harm, initial encounter
        "T3692XA",  # Poisoning by unspecified systemic antibiotic, intentional self-harm, initial encounter
        "T370X2A",  # Poisoning by sulfonamides, intentional self-harm, initial encounter
        "T371X2A",  # Poisoning by antimycobacterial drugs, intentional self-harm, initial encounter
        "T372X2A",  # Poisoning by antimalarials and drugs acting on other blood protozoa, intentional self-harm, initial encounter
        "T373X2A",  # Poisoning by other antiprotozoal drugs, intentional self-harm, initial encounter
        "T374X2A",  # Poisoning by anthelminthics, intentional self-harm, initial encounter
        "T375X2A",  # Poisoning by antiviral drugs, intentional self-harm, initial encounter
        "T378X2A",  # Poisoning by other specified systemic anti-infectives and antiparasitics, intentional self-harm, initial encounter
        "T3792XA",  # Poisoning by unspecified systemic anti-infective and antiparasitics, intentional self-harm, initial encounter
        "T380X2A",  # Poisoning by glucocorticoids and synthetic analogues, intentional self-harm, initial encounter
        "T381X2A",  # Poisoning by thyroid hormones and substitutes, intentional self-harm, initial encounter
        "T382X2A",  # Poisoning by antithyroid drugs, intentional self-harm, initial encounter
        "T383X2A",  # Poisoning by insulin and oral hypoglycemic [antidiabetic] drugs, intentional self-harm, initial encounter
        "T384X2A",  # Poisoning by oral contraceptives, intentional self-harm, initial encounter
        "T385X2A",  # Poisoning by other estrogens and progestogens, intentional self-harm, initial encounter
        "T386X2A",  # Poisoning by antigonadotrophins, antiestrogens, antiandrogens, not elsewhere classified, intentional self-harm, initial encounter
        "T387X2A",  # Poisoning by androgens and anabolic congeners, intentional self-harm, initial encounter
        "T38802A",  # Poisoning by unspecified hormones and synthetic substitutes, intentional self-harm, initial encounter
        "T38812A",  # Poisoning by anterior pituitary [adenohypophyseal] hormones, intentional self-harm, initial encounter
        "T38892A",  # Poisoning by other hormones and synthetic substitutes, intentional self-harm, initial encounter
        "T38902A",  # Poisoning by unspecified hormone antagonists, intentional self-harm, initial encounter
        "T38992A",  # Poisoning by other hormone antagonists, intentional self-harm, initial encounter
        "T39012A",  # Poisoning by aspirin, intentional self-harm, initial encounter
        "T39092A",  # Poisoning by salicylates, intentional self-harm, initial encounter
        "T391X2A",  # Poisoning by 4-Aminophenol derivatives, intentional self-harm, initial encounter
        "T392X2A",  # Poisoning by pyrazolone derivatives, intentional self-harm, initial encounter
        "T39312A",  # Poisoning by propionic acid derivatives, intentional self-harm, initial encounter
        "T39392A",  # Poisoning by other nonsteroidal anti-inflammatory drugs [NSAID], intentional self-harm, initial encounter
        "T394X2A",  # Poisoning by antirheumatics, not elsewhere classified, intentional self-harm, initial encounter
        "T398X2A",  # Poisoning by other nonopioid analgesics and antipyretics, not elsewhere classified, intentional self-harm, initial encounter
        "T3992XA",  # Poisoning by unspecified nonopioid analgesic, antipyretic and antirheumatic, intentional self-harm, initial encounter
        "T400X2A",  # Poisoning by opium, intentional self-harm, initial encounter
        "T401X2A",  # Poisoning by heroin, intentional self-harm, initial encounter
        "T402X2A",  # Poisoning by other opioids, intentional self-harm, initial encounter
        "T403X2A",  # Poisoning by methadone, intentional self-harm, initial encounter
        "T40412A",  # Poisoning by fentanyl or fentanyl analogs, intentional self-harm, initial encounter
        "T40422A",  # Poisoning by tramadol, intentional self-harm, initial encounter
        "T40492A",  # Poisoning by other synthetic narcotics, intentional self-harm, initial encounter
        "T405X2A",  # Poisoning by cocaine, intentional self-harm, initial encounter
        "T40602A",  # Poisoning by unspecified narcotics, intentional self-harm, initial encounter
        "T40692A",  # Poisoning by other narcotics, intentional self-harm, initial encounter
        "T40712A",  # Poisoning by cannabis, intentional self-harm, initial encounter
        "T40722A",  # Poisoning by synthetic cannabinoids, intentional self-harm, initial encounter
        "T408X2A",  # Poisoning by lysergide [LSD], intentional self-harm, initial encounter
        "T40902A",  # Poisoning by unspecified psychodysleptics [hallucinogens], intentional self-harm, initial encounter
        "T40992A",  # Poisoning by other psychodysleptics [hallucinogens], intentional self-harm, initial encounter
        "T410X2A",  # Poisoning by inhaled anesthetics, intentional self-harm, initial encounter
        "T411X2A",  # Poisoning by intravenous anesthetics, intentional self-harm, initial encounter
        "T41202A",  # Poisoning by unspecified general anesthetics, intentional self-harm, initial encounter
        "T41292A",  # Poisoning by other general anesthetics, intentional self-harm, initial encounter
        "T413X2A",  # Poisoning by local anesthetics, intentional self-harm, initial encounter
        "T4142XA",  # Poisoning by unspecified anesthetic, intentional self-harm, initial encounter
        "T415X2A",  # Poisoning by therapeutic gases, intentional self-harm, initial encounter
        "T420X2A",  # Poisoning by hydantoin derivatives, intentional self-harm, initial encounter
        "T421X2A",  # Poisoning by iminostilbenes, intentional self-harm, initial encounter
        "T422X2A",  # Poisoning by succinimides and oxazolidinediones, intentional self-harm, initial encounter
        "T423X2A",  # Poisoning by barbiturates, intentional self-harm, initial encounter
        "T424X2A",  # Poisoning by benzodiazepines, intentional self-harm, initial encounter
        "T425X2A",  # Poisoning by mixed antiepileptics, intentional self-harm, initial encounter
        "T426X2A",  # Poisoning by other antiepileptic and sedative-hypnotic drugs, intentional self-harm, initial encounter
        "T4272XA",  # Poisoning by unspecified antiepileptic and sedative-hypnotic drugs, intentional self-harm, initial encounter
        "T428X2A",  # Poisoning by antiparkinsonism drugs and other central muscle-tone depressants, intentional self-harm, initial encounter
        "T43012A",  # Poisoning by tricyclic antidepressants, intentional self-harm, initial encounter
        "T43022A",  # Poisoning by tetracyclic antidepressants, intentional self-harm, initial encounter
        "T431X2A",  # Poisoning by monoamine-oxidase-inhibitor antidepressants, intentional self-harm, initial encounter
        "T43202A",  # Poisoning by unspecified antidepressants, intentional self-harm, initial encounter
        "T43212A",  # Poisoning by selective serotonin and norepinephrine reuptake inhibitors, intentional self-harm, initial encounter
        "T43222A",  # Poisoning by selective serotonin reuptake inhibitors, intentional self-harm, initial encounter
        "T43292A",  # Poisoning by other antidepressants, intentional self-harm, initial encounter
        "T433X2A",  # Poisoning by phenothiazine antipsychotics and neuroleptics, intentional self-harm, initial encounter
        "T434X2A",  # Poisoning by butyrophenone and thiothixene neuroleptics, intentional self-harm, initial encounter
        "T43502A",  # Poisoning by unspecified antipsychotics and neuroleptics, intentional self-harm, initial encounter
        "T43592A",  # Poisoning by other antipsychotics and neuroleptics, intentional self-harm, initial encounter
        "T43602A",  # Poisoning by unspecified psychostimulants, intentional self-harm, initial encounter
        "T43612A",  # Poisoning by caffeine, intentional self-harm, initial encounter
        "T43622A",  # Poisoning by amphetamines, intentional self-harm, initial encounter
        "T43632A",  # Poisoning by methylphenidate, intentional self-harm, initial encounter
        "T43642A",  # Poisoning by ecstasy, intentional self-harm, initial encounter
        "T43652A",  # Poisoning by methamphetamines intentional self-harm, initial encounter
        "T43692A",  # Poisoning by other psychostimulants, intentional self-harm, initial encounter
        "T438X2A",  # Poisoning by other psychotropic drugs, intentional self-harm, initial encounter
        "T4392XA",  # Poisoning by unspecified psychotropic drug, intentional self-harm, initial encounter
        "T440X2A",  # Poisoning by anticholinesterase agents, intentional self-harm, initial encounter
        "T441X2A",  # Poisoning by other parasympathomimetics [cholinergics], intentional self-harm, initial encounter
        "T442X2A",  # Poisoning by ganglionic blocking drugs, intentional self-harm, initial encounter
        "T443X2A",  # Poisoning by other parasympatholytics [anticholinergics and antimuscarinics] and spasmolytics, intentional self-harm, initial encounter
        "T444X2A",  # Poisoning by predominantly alpha-adrenoreceptor agonists, intentional self-harm, initial encounter
        "T445X2A",  # Poisoning by predominantly beta-adrenoreceptor agonists, intentional self-harm, initial encounter
        "T446X2A",  # Poisoning by alpha-adrenoreceptor antagonists, intentional self-harm, initial encounter
        "T447X2A",  # Poisoning by beta-adrenoreceptor antagonists, intentional self-harm, initial encounter
        "T448X2A",  # Poisoning by centrally-acting and adrenergic-neuron-blocking agents, intentional self-harm, initial encounter
        "T44902A",  # Poisoning by unspecified drugs primarily affecting the autonomic nervous system, intentional self-harm, initial encounter
        "T44992A",  # Poisoning by other drug primarily affecting the autonomic nervous system, intentional self-harm, initial encounter
        "T450X2A",  # Poisoning by antiallergic and antiemetic drugs, intentional self-harm, initial encounter
        "T451X2A",  # Poisoning by antineoplastic and immunosuppressive drugs, intentional self-harm, initial encounter
        "T452X2A",  # Poisoning by vitamins, intentional self-harm, initial encounter
        "T453X2A",  # Poisoning by enzymes, intentional self-harm, initial encounter
        "T454X2A",  # Poisoning by iron and its compounds, intentional self-harm, initial encounter
        "T45512A",  # Poisoning by anticoagulants, intentional self-harm, initial encounter
        "T45522A",  # Poisoning by antithrombotic drugs, intentional self-harm, initial encounter
        "T45602A",  # Poisoning by unspecified fibrinolysis-affecting drugs, intentional self-harm, initial encounter
        "T45612A",  # Poisoning by thrombolytic drug, intentional self-harm, initial encounter
        "T45622A",  # Poisoning by hemostatic drug, intentional self-harm, initial encounter
        "T45692A",  # Poisoning by other fibrinolysis-affecting drugs, intentional self-harm, initial encounter
        "T457X2A",  # Poisoning by anticoagulant antagonists, vitamin K and other coagulants, intentional self-harm, initial encounter
        "T458X2A",  # Poisoning by other primarily systemic and hematological agents, intentional self-harm, initial encounter
        "T4592XA",  # Poisoning by unspecified primarily systemic and hematological agent, intentional self-harm, initial encounter
        "T45AX2A",  # Poisoning by immune checkpoint inhibitors and immunostimulant drugs, intentional self-harm, initial encounter
        "T460X2A",  # Poisoning by cardiac-stimulant glycosides and drugs of similar action, intentional self-harm, initial encounter
        "T461X2A",  # Poisoning by calcium-channel blockers, intentional self-harm, initial encounter
        "T462X2A",  # Poisoning by other antidysrhythmic drugs, intentional self-harm, initial encounter
        "T463X2A",  # Poisoning by coronary vasodilators, intentional self-harm, initial encounter
        "T464X2A",  # Poisoning by angiotensin-converting-enzyme inhibitors, intentional self-harm, initial encounter
        "T465X2A",  # Poisoning by other antihypertensive drugs, intentional self-harm, initial encounter
        "T466X2A",  # Poisoning by antihyperlipidemic and antiarteriosclerotic drugs, intentional self-harm, initial encounter
        "T467X2A",  # Poisoning by peripheral vasodilators, intentional self-harm, initial encounter
        "T468X2A",  # Poisoning by antivaricose drugs, including sclerosing agents, intentional self-harm, initial encounter
        "T46902A",  # Poisoning by unspecified agents primarily affecting the cardiovascular system, intentional self-harm, initial encounter
        "T46992A",  # Poisoning by other agents primarily affecting the cardiovascular system, intentional self-harm, initial encounter
        "T470X2A",  # Poisoning by histamine H2-receptor blockers, intentional self-harm, initial encounter
        "T471X2A",  # Poisoning by other antacids and anti-gastric-secretion drugs, intentional self-harm, initial encounter
        "T472X2A",  # Poisoning by stimulant laxatives, intentional self-harm, initial encounter
        "T473X2A",  # Poisoning by saline and osmotic laxatives, intentional self-harm, initial encounter
        "T474X2A",  # Poisoning by other laxatives, intentional self-harm, initial encounter
        "T475X2A",  # Poisoning by digestants, intentional self-harm, initial encounter
        "T476X2A",  # Poisoning by antidiarrheal drugs, intentional self-harm, initial encounter
        "T477X2A",  # Poisoning by emetics, intentional self-harm, initial encounter
        "T478X2A",  # Poisoning by other agents primarily affecting gastrointestinal system, intentional self-harm, initial encounter
        "T4792XA",  # Poisoning by unspecified agents primarily affecting the gastrointestinal system, intentional self-harm, initial encounter
        "T480X2A",  # Poisoning by oxytocic drugs, intentional self-harm, initial encounter
        "T481X2A",  # Poisoning by skeletal muscle relaxants [neuromuscular blocking agents], intentional self-harm, initial encounter
        "T48202A",  # Poisoning by unspecified drugs acting on muscles, intentional self-harm, initial encounter
        "T48292A",  # Poisoning by other drugs acting on muscles, intentional self-harm, initial encounter
        "T483X2A",  # Poisoning by antitussives, intentional self-harm, initial encounter
        "T484X2A",  # Poisoning by expectorants, intentional self-harm, initial encounter
        "T485X2A",  # Poisoning by other anti-common-cold drugs, intentional self-harm, initial encounter
        "T486X2A",  # Poisoning by antiasthmatics, intentional self-harm, initial encounter
        "T48902A",  # Poisoning by unspecified agents primarily acting on the respiratory system, intentional self-harm, initial encounter
        "T48992A",  # Poisoning by other agents primarily acting on the respiratory system, intentional self-harm, initial encounter
        "T490X2A",  # Poisoning by local antifungal, anti-infective and anti-inflammatory drugs, intentional self-harm, initial encounter
        "T491X2A",  # Poisoning by antipruritics, intentional self-harm, initial encounter
        "T492X2A",  # Poisoning by local astringents and local detergents, intentional self-harm, initial encounter
        "T493X2A",  # Poisoning by emollients, demulcents and protectants, intentional self-harm, initial encounter
        "T494X2A",  # Poisoning by keratolytics, keratoplastics, and other hair treatment drugs and preparations, intentional self-harm, initial encounter
        "T495X2A",  # Poisoning by ophthalmological drugs and preparations, intentional self-harm, initial encounter
        "T496X2A",  # Poisoning by otorhinolaryngological drugs and preparations, intentional self-harm, initial encounter
        "T497X2A",  # Poisoning by dental drugs, topically applied, intentional self-harm, initial encounter
        "T498X2A",  # Poisoning by other topical agents, intentional self-harm, initial encounter
        "T4992XA",  # Poisoning by unspecified topical agent, intentional self-harm, initial encounter
        "T500X2A",  # Poisoning by mineralocorticoids and their antagonists, intentional self-harm, initial encounter
        "T501X2A",  # Poisoning by loop [high-ceiling] diuretics, intentional self-harm, initial encounter
        "T502X2A",  # Poisoning by carbonic-anhydrase inhibitors, benzothiadiazides and other diuretics, intentional self-harm, initial encounter
        "T503X2A",  # Poisoning by electrolytic, caloric and water-balance agents, intentional self-harm, initial encounter
        "T504X2A",  # Poisoning by drugs affecting uric acid metabolism, intentional self-harm, initial encounter
        "T505X2A",  # Poisoning by appetite depressants, intentional self-harm, initial encounter
        "T506X2A",  # Poisoning by antidotes and chelating agents, intentional self-harm, initial encounter
        "T507X2A",  # Poisoning by analeptics and opioid receptor antagonists, intentional self-harm, initial encounter
        "T508X2A",  # Poisoning by diagnostic agents, intentional self-harm, initial encounter
        "T50902A",  # Poisoning by unspecified drugs, medicaments and biological substances, intentional self-harm, initial encounter
        "T50912A",  # Poisoning by multiple unspecified drugs, medicaments and biological substances, intentional self-harm, initial encounter
        "T50992A",  # Poisoning by other drugs, medicaments and biological substances, intentional self-harm, initial encounter
        "T50A12A",  # Poisoning by pertussis vaccine, including combinations with a pertussis component, intentional self-harm, initial encounter
        "T50A22A",  # Poisoning by mixed bacterial vaccines without a pertussis component, intentional self-harm, initial encounter
        "T50A92A",  # Poisoning by other bacterial vaccines, intentional self-harm, initial encounter
        "T50B12A",  # Poisoning by smallpox vaccines, intentional self-harm, initial encounter
        "T50B92A",  # Poisoning by other viral vaccines, intentional self-harm, initial encounter
        "T50Z12A",  # Poisoning by immunoglobulin, intentional self-harm, initial encounter
        "T50Z92A",  # Poisoning by other vaccines and biological substances, intentional self-harm, initial encounter
        "T510X2A",  # Toxic effect of ethanol, intentional self-harm, initial encounter
        "T511X2A",  # Toxic effect of methanol, intentional self-harm, initial encounter
        "T512X2A",  # Toxic effect of 2-Propanol, intentional self-harm, initial encounter
        "T513X2A",  # Toxic effect of fusel oil, intentional self-harm, initial encounter
        "T518X2A",  # Toxic effect of other alcohols, intentional self-harm, initial encounter
        "T5192XA",  # Toxic effect of unspecified alcohol, intentional self-harm, initial encounter
        "T520X2A",  # Toxic effect of petroleum products, intentional self-harm, initial encounter
        "T521X2A",  # Toxic effect of benzene, intentional self-harm, initial encounter
        "T522X2A",  # Toxic effect of homologues of benzene, intentional self-harm, initial encounter
        "T523X2A",  # Toxic effect of glycols, intentional self-harm, initial encounter
        "T524X2A",  # Toxic effect of ketones, intentional self-harm, initial encounter
        "T528X2A",  # Toxic effect of other organic solvents, intentional self-harm, initial encounter
        "T5292XA",  # Toxic effect of unspecified organic solvent, intentional self-harm, initial encounter
        "T530X2A",  # Toxic effect of carbon tetrachloride, intentional self-harm, initial encounter
        "T531X2A",  # Toxic effect of chloroform, intentional self-harm, initial encounter
        "T532X2A",  # Toxic effect of trichloroethylene, intentional self-harm, initial encounter
        "T533X2A",  # Toxic effect of tetrachloroethylene, intentional self-harm, initial encounter
        "T534X2A",  # Toxic effect of dichloromethane, intentional self-harm, initial encounter
        "T535X2A",  # Toxic effect of chlorofluorocarbons, intentional self-harm, initial encounter
        "T536X2A",  # Toxic effect of other halogen derivatives of aliphatic hydrocarbons, intentional self-harm, initial encounter
        "T537X2A",  # Toxic effect of other halogen derivatives of aromatic hydrocarbons, intentional self-harm, initial encounter
        "T5392XA",  # Toxic effect of unspecified halogen derivatives of aliphatic and aromatic hydrocarbons, intentional self-harm, initial encounter
        "T540X2A",  # Toxic effect of phenol and phenol homologues, intentional self-harm, initial encounter
        "T541X2A",  # Toxic effect of other corrosive organic compounds, intentional self-harm, initial encounter
        "T542X2A",  # Toxic effect of corrosive acids and acid-like substances, intentional self-harm, initial encounter
        "T543X2A",  # Toxic effect of corrosive alkalis and alkali-like substances, intentional self-harm, initial encounter
        "T5492XA",  # Toxic effect of unspecified corrosive substance, intentional self-harm, initial encounter
        "T550X2A",  # Toxic effect of soaps, intentional self-harm, initial encounter
        "T551X2A",  # Toxic effect of detergents, intentional self-harm, initial encounter
        "T560X2A",  # Toxic effect of lead and its compounds, intentional self-harm, initial encounter
        "T561X2A",  # Toxic effect of mercury and its compounds, intentional self-harm, initial encounter
        "T562X2A",  # Toxic effect of chromium and its compounds, intentional self-harm, initial encounter
        "T563X2A",  # Toxic effect of cadmium and its compounds, intentional self-harm, initial encounter
        "T564X2A",  # Toxic effect of copper and its compounds, intentional self-harm, initial encounter
        "T565X2A",  # Toxic effect of zinc and its compounds, intentional self-harm, initial encounter
        "T566X2A",  # Toxic effect of tin and its compounds, intentional self-harm, initial encounter
        "T567X2A",  # Toxic effect of beryllium and its compounds, intentional self-harm, initial encounter
        "T56812A",  # Toxic effect of thallium, intentional self-harm, initial encounter
        "T56822A",  # Toxic effect of gadolinium, intentional self-harm, initial encounter
        "T56892A",  # Toxic effect of other metals, intentional self-harm, initial encounter
        "T5692XA",  # Toxic effect of unspecified metal, intentional self-harm, initial encounter
        "T570X2A",  # Toxic effect of arsenic and its compounds, intentional self-harm, initial encounter
        "T571X2A",  # Toxic effect of phosphorus and its compounds, intentional self-harm, initial encounter
        "T572X2A",  # Toxic effect of manganese and its compounds, intentional self-harm, initial encounter
        "T573X2A",  # Toxic effect of hydrogen cyanide, intentional self-harm, initial encounter
        "T578X2A",  # Toxic effect of other specified inorganic substances, intentional self-harm, initial encounter
        "T5792XA",  # Toxic effect of unspecified inorganic substance, intentional self-harm, initial encounter
        "T5802XA",  # Toxic effect of carbon monoxide from motor vehicle exhaust, intentional self-harm, initial encounter
        "T5812XA",  # Toxic effect of carbon monoxide from utility gas, intentional self-harm, initial encounter
        "T582X2A",  # Toxic effect of carbon monoxide from incomplete combustion of other domestic fuels, intentional self-harm, initial encounter
        "T588X2A",  # Toxic effect of carbon monoxide from other source, intentional self-harm, initial encounter
        "T5892XA",  # Toxic effect of carbon monoxide from unspecified source, intentional self-harm, initial encounter
        "T590X2A",  # Toxic effect of nitrogen oxides, intentional self-harm, initial encounter
        "T591X2A",  # Toxic effect of sulfur dioxide, intentional self-harm, initial encounter
        "T592X2A",  # Toxic effect of formaldehyde, intentional self-harm, initial encounter
        "T593X2A",  # Toxic effect of lacrimogenic gas, intentional self-harm, initial encounter
        "T594X2A",  # Toxic effect of chlorine gas, intentional self-harm, initial encounter
        "T595X2A",  # Toxic effect of fluorine gas and hydrogen fluoride, intentional self-harm, initial encounter
        "T596X2A",  # Toxic effect of hydrogen sulfide, intentional self-harm, initial encounter
        "T597X2A",  # Toxic effect of carbon dioxide, intentional self-harm, initial encounter
        "T59812A",  # Toxic effect of smoke, intentional self-harm, initial encounter
        "T59892A",  # Toxic effect of other specified gases, fumes and vapors, intentional self-harm, initial encounter
        "T5992XA",  # Toxic effect of unspecified gases, fumes and vapors, intentional self-harm, initial encounter
        "T600X2A",  # Toxic effect of organophosphate and carbamate insecticides, intentional self-harm, initial encounter
        "T601X2A",  # Toxic effect of halogenated insecticides, intentional self-harm, initial encounter
        "T602X2A",  # Toxic effect of other insecticides, intentional self-harm, initial encounter
        "T603X2A",  # Toxic effect of herbicides and fungicides, intentional self-harm, initial encounter
        "T604X2A",  # Toxic effect of rodenticides, intentional self-harm, initial encounter
        "T608X2A",  # Toxic effect of other pesticides, intentional self-harm, initial encounter
        "T6092XA",  # Toxic effect of unspecified pesticide, intentional self-harm, initial encounter
        "T6102XA",  # Ciguatera fish poisoning, intentional self-harm, initial encounter
        "T6112XA",  # Scombroid fish poisoning, intentional self-harm, initial encounter
        "T61772A",  # Other fish poisoning, intentional self-harm, initial encounter
        "T61782A",  # Other shellfish poisoning, intentional self-harm, initial encounter
        "T618X2A",  # Toxic effect of other seafood, intentional self-harm, initial encounter
        "T6192XA",  # Toxic effect of unspecified seafood, intentional self-harm, initial encounter
        "T620X2A",  # Toxic effect of ingested mushrooms, intentional self-harm, initial encounter
        "T621X2A",  # Toxic effect of ingested berries, intentional self-harm, initial encounter
        "T622X2A",  # Toxic effect of other ingested (parts of) plant(s), intentional self-harm, initial encounter
        "T628X2A",  # Toxic effect of other specified noxious substances eaten as food, intentional self-harm, initial encounter
        "T6292XA",  # Toxic effect of unspecified noxious substance eaten as food, intentional self-harm, initial encounter
        "T63002A",  # Toxic effect of unspecified snake venom, intentional self-harm, initial encounter
        "T63012A",  # Toxic effect of rattlesnake venom, intentional self-harm, initial encounter
        "T63022A",  # Toxic effect of coral snake venom, intentional self-harm, initial encounter
        "T63032A",  # Toxic effect of taipan venom, intentional self-harm, initial encounter
        "T63042A",  # Toxic effect of cobra venom, intentional self-harm, initial encounter
        "T63062A",  # Toxic effect of venom of other North and South American snake, intentional self-harm, initial encounter
        "T63072A",  # Toxic effect of venom of other Australian snake, intentional self-harm, initial encounter
        "T63082A",  # Toxic effect of venom of other African and Asian snake, intentional self-harm, initial encounter
        "T63092A",  # Toxic effect of venom of other snake, intentional self-harm, initial encounter
        "T63112A",  # Toxic effect of venom of gila monster, intentional self-harm, initial encounter
        "T63122A",  # Toxic effect of venom of other venomous lizard, intentional self-harm, initial encounter
        "T63192A",  # Toxic effect of venom of other reptiles, intentional self-harm, initial encounter
        "T632X2A",  # Toxic effect of venom of scorpion, intentional self-harm, initial encounter
        "T63302A",  # Toxic effect of unspecified spider venom, intentional self-harm, initial encounter
        "T63312A",  # Toxic effect of venom of black widow spider, intentional self-harm, initial encounter
        "T63322A",  # Toxic effect of venom of tarantula, intentional self-harm, initial encounter
        "T63332A",  # Toxic effect of venom of brown recluse spider, intentional self-harm, initial encounter
        "T63392A",  # Toxic effect of venom of other spider, intentional self-harm, initial encounter
        "T63412A",  # Toxic effect of venom of centipedes and venomous millipedes, intentional self-harm, initial encounter
        "T63422A",  # Toxic effect of venom of ants, intentional self-harm, initial encounter
        "T63432A",  # Toxic effect of venom of caterpillars, intentional self-harm, initial encounter
        "T63442A",  # Toxic effect of venom of bees, intentional self-harm, initial encounter
        "T63452A",  # Toxic effect of venom of hornets, intentional self-harm, initial encounter
        "T63462A",  # Toxic effect of venom of wasps, intentional self-harm, initial encounter
        "T63482A",  # Toxic effect of venom of other arthropod, intentional self-harm, initial encounter
        "T63512A",  # Toxic effect of contact with stingray, intentional self-harm, initial encounter
        "T63592A",  # Toxic effect of contact with other venomous fish, intentional self-harm, initial encounter
        "T63612A",  # Toxic effect of contact with Portuguese Man-o-war, intentional self-harm, initial encounter
        "T63622A",  # Toxic effect of contact with other jellyfish, intentional self-harm, initial encounter
        "T63632A",  # Toxic effect of contact with sea anemone, intentional self-harm, initial encounter
        "T63692A",  # Toxic effect of contact with other venomous marine animals, intentional self-harm, initial encounter
        "T63712A",  # Toxic effect of contact with venomous marine plant, intentional self-harm, initial encounter
        "T63792A",  # Toxic effect of contact with other venomous plant, intentional self-harm, initial encounter
        "T63812A",  # Toxic effect of contact with venomous frog, intentional self-harm, initial encounter
        "T63822A",  # Toxic effect of contact with venomous toad, intentional self-harm, initial encounter
        "T63832A",  # Toxic effect of contact with other venomous amphibian, intentional self-harm, initial encounter
        "T63892A",  # Toxic effect of contact with other venomous animals, intentional self-harm, initial encounter
        "T6392XA",  # Toxic effect of contact with unspecified venomous animal, intentional self-harm, initial encounter
        "T6402XA",  # Toxic effect of aflatoxin, intentional self-harm, initial encounter
        "T6482XA",  # Toxic effect of other mycotoxin food contaminants, intentional self-harm, initial encounter
        "T650X2A",  # Toxic effect of cyanides, intentional self-harm, initial encounter
        "T651X2A",  # Toxic effect of strychnine and its salts, intentional self-harm, initial encounter
        "T65212A",  # Toxic effect of chewing tobacco, intentional self-harm, initial encounter
        "T65222A",  # Toxic effect of tobacco cigarettes, intentional self-harm, initial encounter
        "T65292A",  # Toxic effect of other tobacco and nicotine, intentional self-harm, initial encounter
        "T653X2A",  # Toxic effect of nitroderivatives and aminoderivatives of benzene and its homologues, intentional self-harm, initial encounter
        "T654X2A",  # Toxic effect of carbon disulfide, intentional self-harm, initial encounter
        "T655X2A",  # Toxic effect of nitroglycerin and other nitric acids and esters, intentional self-harm, initial encounter
        "T656X2A",  # Toxic effect of paints and dyes, not elsewhere classified, intentional self-harm, initial encounter
        "T65812A",  # Toxic effect of latex, intentional self-harm, initial encounter
        "T65822A",  # Toxic effect of harmful algae and algae toxins, intentional self-harm, initial encounter
        "T65832A",  # Toxic effect of fiberglass, intentional self-harm, initial encounter
        "T65892A",  # Toxic effect of other specified substances, intentional self-harm, initial encounter
        "T6592XA",  # Toxic effect of unspecified substance, intentional self-harm, initial encounter
        "X710XXA",  # Intentional self-harm by drowning and submersion while in bathtub, initial encounter
        "X711XXA",  # Intentional self-harm by drowning and submersion while in swimming pool, initial encounter
        "X712XXA",  # Intentional self-harm by drowning and submersion after jump into swimming pool, initial encounter
        "X713XXA",  # Intentional self-harm by drowning and submersion in natural water, initial encounter
        "X718XXA",  # Other intentional self-harm by drowning and submersion, initial encounter
        "X719XXA",  # Intentional self-harm by drowning and submersion, unspecified, initial encounter
        "X72XXXA",  # Intentional self-harm by handgun discharge, initial encounter
        "X730XXA",  # Intentional self-harm by shotgun discharge, initial encounter
        "X731XXA",  # Intentional self-harm by hunting rifle discharge, initial encounter
        "X732XXA",  # Intentional self-harm by machine gun discharge, initial encounter
        "X738XXA",  # Intentional self-harm by other larger firearm discharge, initial encounter
        "X739XXA",  # Intentional self-harm by unspecified larger firearm discharge, initial encounter
        "X7401XA",  # Intentional self-harm by airgun, initial encounter
        "X7402XA",  # Intentional self-harm by paintball gun, initial encounter
        "X7409XA",  # Intentional self-harm by other gas, air or spring-operated gun, initial encounter
        "X748XXA",  # Intentional self-harm by other firearm discharge, initial encounter
        "X749XXA",  # Intentional self-harm by unspecified firearm discharge, initial encounter
        "X75XXXA",  # Intentional self-harm by explosive material, initial encounter
        "X76XXXA",  # Intentional self-harm by smoke, fire and flames, initial encounter
        "X770XXA",  # Intentional self-harm by steam or hot vapors, initial encounter
        "X771XXA",  # Intentional self-harm by hot tap water, initial encounter
        "X772XXA",  # Intentional self-harm by other hot fluids, initial encounter
        "X773XXA",  # Intentional self-harm by hot household appliances, initial encounter
        "X778XXA",  # Intentional self-harm by other hot objects, initial encounter
        "X779XXA",  # Intentional self-harm by unspecified hot objects, initial encounter
        "X780XXA",  # Intentional self-harm by sharp glass, initial encounter
        "X781XXA",  # Intentional self-harm by knife, initial encounter
        "X782XXA",  # Intentional self-harm by sword or dagger, initial encounter
        "X788XXA",  # Intentional self-harm by other sharp object, initial encounter
        "X789XXA",  # Intentional self-harm by unspecified sharp object, initial encounter
        "X79XXXA",  # Intentional self-harm by blunt object, initial encounter
        "X80XXXA",  # Intentional self-harm by jumping from a high place, initial encounter
        "X810XXA",  # Intentional self-harm by jumping or lying in front of motor vehicle, initial encounter
        "X811XXA",  # Intentional self-harm by jumping or lying in front of (subway) train, initial encounter
        "X818XXA",  # Intentional self-harm by jumping or lying in front of other moving object, initial encounter
        "X820XXA",  # Intentional collision of motor vehicle with other motor vehicle, initial encounter
        "X821XXA",  # Intentional collision of motor vehicle with train, initial encounter
        "X822XXA",  # Intentional collision of motor vehicle with tree, initial encounter
        "X828XXA",  # Other intentional self-harm by crashing of motor vehicle, initial encounter
        "X830XXA",  # Intentional self-harm by crashing of aircraft, initial encounter
        "X831XXA",  # Intentional self-harm by electrocution, initial encounter
        "X832XXA",  # Intentional self-harm by exposure to extremes of cold, initial encounter
        "X838XXA",  # Intentional self-harm by other specified means, initial encounter
    }

    SNOMEDCT = {
        "101421000119107",  # Dementia due to Parkinson's disease (disorder)
        "10211000132109",  # Perinatal depression (disorder)
        "102911000",  # Thoughts of self harm (finding)
        "10327003",  # Cocaine-induced mood disorder (disorder)
        "10349009",  # Multi-infarct dementia with delirium (disorder)
        "104851000119103",  # Postpartum major depression in remission (disorder)
        "10532003",  # Primary degenerative dementia of the Alzheimer type, presenile onset, with depression (disorder)
        "105421000119105",  # Early onset Alzheimer's disease with behavioral disturbance (disorder)
        "10586006",  # Occupation-related stress disorder (disorder)
        "106021000119105",  # Multi-infarct dementia due to atherosclerosis (disorder)
        "10743001000119103",  # Anxiety disorder in mother complicating childbirth (disorder)
        "10760421000119102",  # Psychotic disorder in mother complicating childbirth (disorder)
        "10760461000119107",  # Psychotic disorder in mother complicating pregnancy (disorder)
        "10783000",  # Symptomatic pedophilia (disorder)
        "10811121000119102",  # Major depressive disorder in mother complicating childbirth (disorder)
        "10811161000119107",  # Major depressive disorder in mother complicating pregnancy (disorder)
        "10835871000119104",  # Depressive disorder in mother complicating childbirth (disorder)
        "10875004",  # Severe mixed bipolar I disorder with psychotic features, mood-incongruent (disorder)
        "109006",  # Anxiety disorder of childhood OR adolescence (disorder)
        "109805003",  # Factitious cheilitis (disorder)
        "10981006",  # Severe mixed bipolar I disorder with psychotic features (disorder)
        "111477005",  # Reactive attachment disorder of infancy OR early childhood, disinhibited type (disorder)
        "111480006",  # Psychoactive substance-induced organic dementia (disorder)
        "111482003",  # Subchronic schizophrenia with acute exacerbations (disorder)
        "111483008",  # Catatonic schizophrenia in remission (disorder)
        "111484002",  # Undifferentiated schizophrenia (disorder)
        "111485001",  # Mixed bipolar I disorder in full remission (disorder)
        "111486000",  # Symptomatic sexual sadism (disorder)
        "111487009",  # Dream anxiety disorder (disorder)
        "111490003",  # Panic disorder with agoraphobia, agoraphobic avoidance in partial remission AND severe panic attacks (disorder)
        "111491004",  # Panic disorder with agoraphobia, agoraphobic avoidance in full remission AND panic attacks in partial remission (disorder)
        "111492006",  # Conversion disorder, single episode (disorder)
        "1145003",  # Developmental speech disorder (disorder)
        "11806006",  # Separation anxiety disorder of childhood (disorder)
        "1187004001",  # Chronic traumatic encephalopathy (disorder)
        "11941006",  # Panic disorder with agoraphobia, agoraphobic avoidance in full remission AND panic attacks in full remission (disorder)
        "1196001",  # Chronic bipolar II disorder, most recent episode major depressive (disorder)
        "1220650006",  # Delusion of emitting foul body odor (disorder)
        "12277671000119109",  # Gender dysphoria in childhood (disorder)
        "12277711000119108",  # Gender dysphoria in adolescence and adulthood (disorder)
        "1230071005",  # Amfetamine and/or amfetamine derivative abuse, episodic (disorder)
        "1230072003",  # Amfetamine and/or amfetamine derivative abuse, continuous (disorder)
        "1230074002",  # Nondependent hypnotic abuse, episodic (disorder)
        "1230075001",  # Nondependent anxiolytic abuse, episodic (disorder)
        "1230076000",  # Nondependent anxiolytic abuse, continuous (disorder)
        "1230077009",  # Nondependent hypnotic abuse, continuous (disorder)
        "1230080005",  # Nondependent anxiolytic abuse (disorder)
        "1230081009",  # Nondependent hypnotic abuse (disorder)
        "1230262006",  # Abuse of steroid hormone (disorder)
        "1234779007",  # Mood disorder caused by ethanol (disorder)
        "1234780005",  # Mood disorder with mixed manic and depressive symptoms caused by ethanol (disorder)
        "1234781009",  # Mood disorder with manic symptoms caused by ethanol (disorder)
        "1234782002",  # Mood disorder with depressive symptoms caused by ethanol (disorder)
        "12348006",  # Presenile dementia (disorder)
        "125851000119106",  # Continuous sedative abuse (disorder)
        "126943008",  # Separation anxiety (disorder)
        "128293007",  # Chronic mental disorder (disorder)
        "12939007",  # Chronic disorganized schizophrenia (disorder)
        "129562004",  # Psychogenic skin disease (disorder)
        "129602009",  # Symbiotic infantile psychosis (disorder)
        "129604005",  # Delusion of heart disease syndrome (disorder)
        "129606007",  # Frontal lobe syndrome (disorder)
        "12969000",  # Severe bipolar II disorder, most recent episode major depressive, in full remission (disorder)
        "130121000119104",  # Dementia due to Rett syndrome (disorder)
        "133091000119105",  # Rapid cycling bipolar I disorder (disorder)
        "133121000119109",  # Severe seasonal affective disorder (disorder)
        "13313007",  # Mild bipolar disorder (disorder)
        "1339031006",  # Dementia caused by ionizing radiation (disorder)
        "133991000119109",  # Fluency disorder as sequela of cerebrovascular disease (disorder)
        "13438001",  # Overanxious disorder of childhood (disorder)
        "13581000",  # Severe bipolar I disorder, single manic episode with psychotic features, mood-congruent (disorder)
        "13601005",  # Paranoid personality disorder (disorder)
        "13670005",  # Gender identity disorder of adulthood, previously heterosexual (disorder)
        "13746004",  # Bipolar disorder (disorder)
        "1376001",  # Obsessive compulsive personality disorder (disorder)
        "1380006",  # Agoraphobia without history of panic disorder with limited symptom attacks (disorder)
        "1383008",  # Hallucinogen mood disorder (disorder)
        "14070001",  # Multi-infarct dementia with depression (disorder)
        "14077003",  # Pica (disorder)
        "14144000",  # Erotomanic delusion disorder (disorder)
        "14183003",  # Chronic major depressive disorder, single episode (disorder)
        "141991000119109",  # Delusions in Alzheimer's disease (disorder)
        "142001000119106",  # Depressed mood in Alzheimer's disease (disorder)
        "142011000119109",  # Alzheimer's disease co-occurrent with delirium (disorder)
        "14291003",  # Subchronic disorganized schizophrenia with acute exacerbations (disorder)
        "14495005",  # Severe bipolar I disorder, single manic episode without psychotic features (disorder)
        "145101000119102",  # Intravenous cocaine abuse (disorder)
        "145121000119106",  # Intravenous nondependent opioid abuse (disorder)
        "145841000119107",  # Episodic phencyclidine abuse (disorder)
        "1499003",  # Bipolar I disorder, single manic episode with postpartum onset (disorder)
        "15167005",  # Alcohol abuse (disorder)
        "15193003",  # Severe recurrent major depression with psychotic features, mood-incongruent (disorder)
        "153071000119108",  # Recurrent manic episodes in partial remission (disorder)
        "15639000",  # Moderate major depression, single episode (disorder)
        "15662003",  # Senile dementia (disorder)
        "1581000119101",  # Dementia of the Alzheimer type with behavioral disturbance (disorder)
        "15840001",  # Symptomatic fetishism (disorder)
        "1591000119103",  # Dementia with behavioral disturbance (disorder)
        "15921731000119106",  # Psychotic disorder caused by methamphetamine (disorder)
        "15945005",  # Psychogenic polydipsia (disorder)
        "15977008",  # Adjustment disorder with academic inhibition (disorder)
        "162004",  # Severe manic bipolar I disorder without psychotic features (disorder)
        "16219201000119101",  # Behavioral disturbance co-occurrent and due to late onset Alzheimer dementia (disorder)
        "162218007",  # Stress-related problem (disorder)
        "162313000",  # Morbid jealousy (disorder)
        "16265701000119107",  # Illness anxiety disorder (disorder)
        "16265951000119109",  # Mild major depressive disorder co-occurrent with anxiety single episode (disorder)
        "16266831000119100",  # Moderate major depressive disorder co-occurrent with anxiety single episode (disorder)
        "16266991000119108",  # Severe major depressive disorder co-occurrent with anxiety single episode (disorder)
        "16276361000119109",  # Vascular dementia without behavioral disturbance (disorder)
        "16295005",  # Bipolar II disorder, most recent episode major depressive (disorder)
        "16506000",  # Mixed bipolar I disorder (disorder)
        "16805009",  # Cluster A personality disorder (disorder)
        "1686006",  # Sedative, hypnotic AND/OR anxiolytic-induced anxiety disorder (disorder)
        "16966009",  # Factitious hypoglycemia (disorder)
        "16990005",  # Subchronic schizophrenia (disorder)
        "17155009",  # Trichotillomania (disorder)
        "17226007",  # Adjustment disorder (disorder)
        "17262008",  # Non-alcoholic Korsakoff's psychosis (disorder)
        "1740001000004102",  # Iatrogenic thyrotoxicosis factitia (disorder)
        "17496003",  # Organic anxiety disorder (disorder)
        "17782008",  # Bipolar I disorder, most recent episode manic with catatonic features (disorder)
        "17961008",  # Conduct disorder, childhood-onset type (disorder)
        "18003009",  # Gender identity disorder of adulthood (disorder)
        "18085000",  # Compulsive gambling (disorder)
        "1816003",  # Panic disorder with agoraphobia, severe agoraphobic avoidance AND mild panic attacks (disorder)
        "18186001",  # True compulsive fetishism (disorder)
        "18193002",  # Hypochondriasis (disorder)
        "18260003",  # Postpartum psychosis (disorder)
        "18478005",  # Adjustment disorder with physical complaints (disorder)
        "1855002",  # Developmental academic disorder (disorder)
        "18573003",  # Obsessional erotomania (disorder)
        "187921002",  # Developmental receptive language disorder (disorder)
        "18818009",  # Moderate recurrent major depression (disorder)
        "18941000",  # Oppositional defiant disorder (disorder)
        "191447007",  # Organic psychotic condition (disorder)
        "191449005",  # Uncomplicated senile dementia (disorder)
        "191451009",  # Uncomplicated presenile dementia (disorder)
        "191452002",  # Presenile dementia with delirium (disorder)
        "191454001",  # Presenile dementia with paranoia (disorder)
        "191455000",  # Presenile dementia with depression (disorder)
        "191457008",  # Senile dementia with depressive or paranoid features (disorder)
        "191458003",  # Senile dementia with paranoia (disorder)
        "191459006",  # Senile dementia with depression (disorder)
        "191461002",  # Senile dementia with delirium (disorder)
        "191463004",  # Uncomplicated arteriosclerotic dementia (disorder)
        "191464005",  # Arteriosclerotic dementia with delirium (disorder)
        "191465006",  # Arteriosclerotic dementia with paranoia (disorder)
        "191466007",  # Arteriosclerotic dementia with depression (disorder)
        "191471000",  # Korsakov's alcoholic psychosis with peripheral neuritis (disorder)
        "191478006",  # Alcoholic paranoia (disorder)
        "191483003",  # Psychotic disorder caused by drug (disorder)
        "191485005",  # Paranoid state caused by drug (disorder)
        "191486006",  # Hallucinosis caused by drug (disorder)
        "191493005",  # Dementia caused by drug (disorder)
        "191494004",  # Amnestic disorder caused by drug (disorder)
        "191495003",  # Depressive disorder caused by drug (disorder)
        "191496002",  # Personality disorder caused by drug (disorder)
        "191499009",  # Transient organic psychoses (disorder)
        "191519005",  # Dementia associated with another disease (disorder)
        "191525009",  # Non-organic psychosis (disorder)
        "191526005",  # Schizophrenic disorders (disorder)
        "191527001",  # Simple schizophrenia (disorder)
        "191531007",  # Acute exacerbation of chronic schizophrenia (disorder)
        "191542003",  # Catatonic schizophrenia (disorder)
        "191547009",  # Acute exacerbation of subchronic catatonic schizophrenia (disorder)
        "191548004",  # Acute exacerbation of chronic catatonic schizophrenia (disorder)
        "191554003",  # Acute exacerbation of subchronic paranoid schizophrenia (disorder)
        "191555002",  # Acute exacerbation of chronic paranoid schizophrenia (disorder)
        "191559008",  # Latent schizophrenia (disorder)
        "191565008",  # Latent schizophrenia in remission (disorder)
        "191567000",  # Schizoaffective schizophrenia (disorder)
        "191569002",  # Subchronic schizoaffective schizophrenia (disorder)
        "191570001",  # Chronic schizoaffective schizophrenia (disorder)
        "191571002",  # Acute exacerbation of subchronic schizoaffective schizophrenia (disorder)
        "191572009",  # Acute exacerbation of chronic schizoaffective schizophrenia (disorder)
        "191574005",  # Schizoaffective schizophrenia in remission (disorder)
        "191577003",  # Cenesthopathic schizophrenia (disorder)
        "191583000",  # Single manic episode, mild (disorder)
        "191584006",  # Single manic episode, moderate (disorder)
        "191586008",  # Single manic episode, severe, with psychosis (disorder)
        "191588009",  # Single manic episode in full remission (disorder)
        "191590005",  # Recurrent manic episodes (disorder)
        "191592002",  # Recurrent manic episodes, mild (disorder)
        "191593007",  # Recurrent manic episodes, moderate (disorder)
        "191595000",  # Recurrent manic episodes, severe, with psychosis (disorder)
        "191597008",  # Recurrent manic episodes, in full remission (disorder)
        "191604000",  # Single major depressive episode, severe, with psychosis (disorder)
        "191610000",  # Recurrent major depressive episodes, mild (disorder)
        "191611001",  # Recurrent major depressive episodes, moderate (disorder)
        "191613003",  # Recurrent major depressive episodes, severe, with psychosis (disorder)
        "191616006",  # Recurrent depression (disorder)
        "191618007",  # Bipolar affective disorder, current episode manic (disorder)
        "191620005",  # Bipolar affective disorder, currently manic, mild (disorder)
        "191621009",  # Bipolar affective disorder, currently manic, moderate (disorder)
        "191623007",  # Bipolar affective disorder, currently manic, severe, with psychosis (disorder)
        "191627008",  # Bipolar affective disorder, current episode depression (disorder)
        "191629006",  # Bipolar affective disorder, currently depressed, mild (disorder)
        "191630001",  # Bipolar affective disorder, currently depressed, moderate (disorder)
        "191636007",  # Mixed bipolar affective disorder (disorder)
        "191638008",  # Mixed bipolar affective disorder, mild (disorder)
        "191639000",  # Mixed bipolar affective disorder, moderate (disorder)
        "191641004",  # Mixed bipolar affective disorder, severe, with psychosis (disorder)
        "191643001",  # Mixed bipolar affective disorder, in full remission (disorder)
        "191658009",  # Atypical manic disorder (disorder)
        "191659001",  # Atypical depressive disorder (disorder)
        "191667009",  # Paranoid disorder (disorder)
        "191668004",  # Simple paranoid state (disorder)
        "191672000",  # Paranoia querulans (disorder)
        "191676002",  # Reactive depressive psychosis (disorder)
        "191677006",  # Acute hysterical psychosis (disorder)
        "191678001",  # Reactive confusion (disorder)
        "191680007",  # Psychogenic paranoid psychosis (disorder)
        "191683009",  # Psychogenic stupor (disorder)
        "191689008",  # Active infantile autism (disorder)
        "191690004",  # Residual infantile autism (disorder)
        "191692007",  # Active disintegrative psychoses (disorder)
        "191693002",  # Residual disintegrative psychoses (disorder)
        "191713008",  # Dissociative neurological symptom disorder with tremor (disorder)
        "191714002",  # Dissociative convulsions (disorder)
        "191722009",  # Agoraphobia with panic attacks (disorder)
        "191724005",  # Social phobia, fear of eating in public (disorder)
        "191725006",  # Social phobia, fear of public speaking (disorder)
        "191726007",  # Social phobia, fear of public washing (disorder)
        "191736004",  # Obsessive-compulsive disorder (disorder)
        "191753006",  # Hypomanic personality disorder (disorder)
        "191765005",  # Emotionally unstable personality disorder (disorder)
        "191772006",  # Eccentric personality disorder (disorder)
        "191773001",  # Immature personality disorder (disorder)
        "191774007",  # Masochistic personality disorder (disorder)
        "191787001",  # Psychosexual identity disorder (disorder)
        "191882002",  # Nondependent alcohol abuse, continuous (disorder)
        "191883007",  # Nondependent alcohol abuse, episodic (disorder)
        "191891003",  # Nondependent cannabis abuse (disorder)
        "191893000",  # Nondependent cannabis abuse, continuous (disorder)
        "191894006",  # Nondependent cannabis abuse, episodic (disorder)
        "191899001",  # Nondependent hallucinogen abuse, continuous (disorder)
        "191900006",  # Nondependent hallucinogen abuse, episodic (disorder)
        "191909007",  # Nondependent opioid abuse (disorder)
        "191912005",  # Nondependent opioid abuse, continuous (disorder)
        "191913000",  # Nondependent opioid abuse, episodic (disorder)
        "191916008",  # Nondependent cocaine abuse (disorder)
        "191918009",  # Nondependent cocaine abuse, continuous (disorder)
        "191919001",  # Nondependent cocaine abuse, episodic (disorder)
        "191928000",  # Abuse of antidepressant drug (disorder)
        "191930003",  # Nondependent antidepressant type drug abuse, continuous (disorder)
        "191931004",  # Nondependent antidepressant type drug abuse, episodic (disorder)
        "191932006",  # Nondependent antidepressant type drug abuse in remission (disorder)
        "191952007",  # Somatoform autonomic dysfunction - respiratory tract (disorder)
        "191953002",  # Psychogenic air hunger (disorder)
        "191962000",  # Neurocirculatory asthenia (disorder)
        "191965003",  # Psychogenic skin symptoms (disorder)
        "191972002",  # Psychogenic dyspepsia (disorder)
        "191973007",  # Psychogenic constipation (disorder)
        "191980009",  # Psychogenic endocrine malfunction (disorder)
        "191981008",  # Psychogenic symptom of special sense organ (disorder)
        "191990001",  # Transient childhood tic (disorder)
        "192016008",  # Non-organic infant feeding disturbance (disorder)
        "192029008",  # Psychogenic backache (disorder)
        "192037000",  # Acute panic state due to acute stress reaction (disorder)
        "192038005",  # Acute fugue state due to acute stress reaction (disorder)
        "192039002",  # Acute stupor state due to acute stress reaction (disorder)
        "192041001",  # Acute situational disturbance (disorder)
        "192042008",  # Acute post-trauma stress state (disorder)
        "192044009",  # Stress reaction causing mixed disturbance of emotion and conduct (disorder)
        "192046006",  # Brief depressive adjustment reaction (disorder)
        "192049004",  # Prolonged depressive adjustment reaction (disorder)
        "192051000",  # Adolescent emancipation disorder (disorder)
        "192052007",  # Early adult emancipation disorder (disorder)
        "192054008",  # Culture shock (disorder)
        "192056005",  # Adjustment reaction with aggression (disorder)
        "192057001",  # Adjustment reaction with antisocial behavior (disorder)
        "192058006",  # Adjustment reaction with destructiveness (disorder)
        "192061007",  # Concentration camp syndrome (disorder)
        "192063005",  # Adjustment reaction with physical symptoms (disorder)
        "192064004",  # Elective mutism due to an adjustment reaction (disorder)
        "192065003",  # Hospitalism (disorder)
        "192073007",  # Change in personality (disorder)
        "192079006",  # Postviral depression (disorder)
        "192080009",  # Chronic depression (disorder)
        "192082001",  # Aggressive unsocial conduct disorder (disorder)
        "192092009",  # Group delinquency (disorder)
        "192097003",  # Isolated explosive disorder (disorder)
        "192099000",  # Childhood disorder of conduct and emotion (disorder)
        "192100008",  # Neurotic delinquency (disorder)
        "192119003",  # Sibling jealousy (disorder)
        "192123006",  # Academic underachievement disorder (disorder)
        "192127007",  # Child attention deficit disorder (disorder)
        "192131001",  # Hyperkinesis with developmental delay (disorder)
        "192132008",  # Hyperkinetic conduct disorder (disorder)
        "192136006",  # Specific reading disorder (disorder)
        "192147004",  # Mixed disorder of psychological development (disorder)
        "192362008",  # Bipolar affective disorder, current episode mixed (disorder)
        "192527004",  # Elaboration of physical symptoms for psychological reasons (disorder)
        "192562009",  # Disorder of psychological development (disorder)
        "192575009",  # Mixed disorder of scholastic skills (disorder)
        "192611004",  # Childhood phobic anxiety disorder (disorder)
        "192630004",  # Psychogenic feeding disorder of infancy and childhood (disorder)
        "192631000",  # Pica of infancy and childhood (disorder)
        "19300006",  # Severe bipolar II disorder, most recent episode major depressive with psychotic features, mood-congruent (disorder)
        "19527009",  # Single episode of major depression in full remission (disorder)
        "19694002",  # Late onset dysthymia (disorder)
        "1973000",  # Sedative, hypnotic AND/OR anxiolytic-induced psychotic disorder with delusions (disorder)
        "197480006",  # Anxiety disorder (disorder)
        "19766004",  # Panic disorder with agoraphobia, mild agoraphobic avoidance AND severe panic attacks (disorder)
        "19886006",  # Sturge-Weber syndrome (disorder)
        "19922006",  # Compulsive sexual sadism (disorder)
        "20010003",  # Borderline personality disorder (disorder)
        "20250007",  # Severe major depression, single episode, with psychotic features, mood-incongruent (disorder)
        "20385005",  # Psychotic disorder with delusions caused by opioid (disorder)
        "20960007",  # Severe bipolar II disorder, most recent episode major depressive with psychotic features, mood-incongruent (disorder)
        "21071000119101",  # Mood disorder of manic type (disorder)
        "21586000",  # Munchausen's syndrome (disorder)
        "21831000119109",  # Psychotic disorder caused by phencyclidine (disorder)
        "21897009",  # Generalized anxiety disorder (disorder)
        "21900002",  # Bipolar I disorder, most recent episode depressed with catatonic features (disorder)
        "21921000119103",  # Dementia co-occurrent and due to Pick's disease (disorder)
        "22121000",  # Depressed bipolar I disorder in full remission (disorder)
        "22230001",  # Panic disorder with agoraphobia, agoraphobic avoidance in partial remission AND panic attacks in full remission (disorder)
        "22381000119105",  # Primary degenerative dementia (disorder)
        "22407005",  # Bipolar II disorder, most recent episode major depressive with catatonic features (disorder)
        "22419002",  # Mood disorder with mixed features due to general medical condition (disorder)
        "225040001",  # Localized dissociative amnesia (disorder)
        "22621000119103",  # Anxiety disorder caused by drug (disorder)
        "229621000",  # Disorder of fluency (disorder)
        "229622007",  # Dysfluency (disorder)
        "229623002",  # Developmental dysfluency (disorder)
        "229625009",  # Normal non-fluency (disorder)
        "229631007",  # Acquired stammering (disorder)
        "229632000",  # Neurogenic stammering (disorder)
        "229683000",  # Motor speech disorder (disorder)
        "229697008",  # Oral-verbal dyspraxia (disorder)
        "229698003",  # Articulatory dyspraxia (disorder)
        "229699006",  # Immature articulatory praxis (disorder)
        "229700007",  # Developmental motor speech disorder (disorder)
        "229701006",  # Developmental articulatory dyspraxia (disorder)
        "229703009",  # Developmental verbal dyspraxia (disorder)
        "229704003",  # Acquired choreiform dyspraxia (disorder)
        "229705002",  # Mixed acquired dyspraxia (disorder)
        "229706001",  # Ideomotor dyspraxia (disorder)
        "229707005",  # Dyspraxia of velopharynx (disorder)
        "229708000",  # Velar dyspraxia (disorder)
        "229709008",  # Tongue tip dyspraxia (disorder)
        "229712006",  # Disorders of attention and motor control (disorder)
        "229715008",  # Deficits in attention motor control and perception (disorder)
        "229721007",  # Speech delay (disorder)
        "229733002",  # Expressive language disorder (disorder)
        "229734008",  # Expressive language delay (disorder)
        "229736005",  # Receptive language delay (disorder)
        "22981000119106",  # Recurrent severe manic episodes (disorder)
        "230265002",  # Familial Alzheimer's disease of early onset (disorder)
        "230266001",  # Non-familial Alzheimer's disease of early onset (disorder)
        "230267005",  # Familial Alzheimer's disease of late onset (disorder)
        "230268000",  # Non-familial Alzheimer's disease of late onset (disorder)
        "230269008",  # Focal Alzheimer's disease (disorder)
        "230280008",  # Progressive aphasia in Alzheimer's disease (disorder)
        "230282000",  # Post-traumatic dementia (disorder)
        "230285003",  # Vascular dementia of acute onset (disorder)
        "230286002",  # Subcortical vascular dementia (disorder)
        "230287006",  # Mixed cortical and subcortical vascular dementia (disorder)
        "230288001",  # Semantic dementia (disorder)
        "230289009",  # Patchy dementia (disorder)
        "230334008",  # Tic caused by drug (disorder)
        "230335009",  # Facial tic disorder (disorder)
        "230336005",  # Vocal tic disorder (disorder)
        "230338006",  # Gestural tic disorder (disorder)
        "230438007",  # Acquired epileptic aphasia (disorder)
        "2312009",  # Reactive attachment disorder of infancy OR early childhood, inhibited type (disorder)
        "231437006",  # Reactive psychoses (disorder)
        "231438001",  # Presbyophrenic psychosis (disorder)
        "231443008",  # Right hemispheric organic affective disorder (disorder)
        "231444002",  # Organic bipolar disorder (disorder)
        "231445001",  # Organic dissociative disorder (disorder)
        "231446000",  # Organic emotionally labile disorder (disorder)
        "231449007",  # Epileptic psychosis (disorder)
        "231452004",  # Limbic epilepsy personality syndrome (disorder)
        "231453009",  # Lobotomy syndrome (disorder)
        "231454003",  # Organic pseudopsychopathic personality (disorder)
        "231455002",  # Organic pseudoretarded personality (disorder)
        "231456001",  # Postleucotomy syndrome (disorder)
        "231459008",  # Abuse of nonpsychotropic analgesic drugs (disorder)
        "231462006",  # Barbiturate abuse (disorder)
        "23148009",  # Undifferentiated attention deficit disorder (disorder)
        "231485007",  # Post-schizophrenic depression (disorder)
        "231487004",  # Persistent delusional disorder (disorder)
        "231489001",  # Acute transient psychotic disorder (disorder)
        "231494001",  # Mania (disorder)
        "231495000",  # Manic stupor (disorder)
        "231496004",  # Hypomania (disorder)
        "231499006",  # Endogenous depression first episode (disorder)
        "231500002",  # Masked depression (disorder)
        "231504006",  # Mixed anxiety and depressive disorder (disorder)
        "231509001",  # Dissociative astasia-abasia (disorder)
        "231515001",  # Hypochondriacal pain (disorder)
        "231516000",  # Cutaneous hypochondriasis (disorder)
        "231517009",  # Somatoform autonomic dysfunction (disorder)
        "231520001",  # Behavioral syndrome associated with physiological disturbance and physical factors (disorder)
        "231521002",  # Weight fixation (disorder)
        "231522009",  # Atypical anorexia nervosa (disorder)
        "231523004",  # Atypical bulimia nervosa (disorder)
        "231524005",  # Interictal behavior disorder (disorder)
        "231525006",  # Manipulative personality disorder (disorder)
        "231526007",  # Fanatic personality (disorder)
        "231527003",  # Explosive personality disorder (disorder)
        "231528008",  # Anxious personality disorder (disorder)
        "231530005",  # Post-concussional personality disorder (disorder)
        "231536004",  # Atypical autism (disorder)
        "231538003",  # Behavioral and emotional disorder with onset in childhood (disorder)
        "231540008",  # Conduct disorder - in family context (disorder)
        "231541007",  # Conduct disorder - unsocialized (disorder)
        "231542000",  # Depressive conduct disorder (disorder)
        "233690008",  # Factitious asthma (disorder)
        "23560001",  # Asperger's disorder (disorder)
        "23645006",  # Organic mood disorder (disorder)
        "237349002",  # Mild postnatal depression (disorder)
        "237350002",  # Severe postnatal depression (disorder)
        "237351003",  # Mild postnatal psychosis (disorder)
        "237352005",  # Severe postnatal psychosis (disorder)
        "23741000119105",  # Severe manic bipolar I disorder (disorder)
        "23772009",  # Dysphonia of Gilles de la Tourette's syndrome (disorder)
        "238961003",  # Trichophobia (disorder)
        "238965007",  # Venereophobia (disorder)
        "238966008",  # Syphilophobia (disorder)
        "238972008",  # Cutaneous monosymptomatic delusional psychosis (disorder)
        "238973003",  # Delusions of parasitosis (disorder)
        "238974009",  # Delusions of infestation (disorder)
        "238977002",  # Delusional hyperhidrosis (disorder)
        "238978007",  # Hyperschemazia (disorder)
        "238979004",  # Hyposchemazia (disorder)
        "24121004",  # Insomnia disorder related to another mental disorder (disorder)
        "2421000119107",  # Hallucinations co-occurrent and due to late onset dementia (disorder)
        "24315006",  # Factitious disorder with combined physical AND psychological symptoms (disorder)
        "247650009",  # Planning suicide (finding)
        "247675008",  # Delusion associated with smell (finding)
        "247803002",  # Seasonal affective disorder (disorder)
        "247804008",  # Schizophrenic prodrome (disorder)
        "24781009",  # Panic disorder with agoraphobia, mild agoraphobic avoidance AND panic attacks in full remission (disorder)
        "248103001",  # Flashing (disorder)
        "248118000",  # Self-induced purging to lose weight (disorder)
        "249520001",  # Self-induced purging (disorder)
        "2506003",  # Early onset dysthymia (disorder)
        "251000119105",  # Severe major depression, single episode (disorder)
        "25501002",  # Social phobia (disorder)
        "25766007",  # Mixed receptive-expressive language disorder (disorder)
        "25772007",  # Multi-infarct dementia with delusions (disorder)
        "25922000",  # Major depressive disorder, single episode with postpartum onset (disorder)
        "25971005",  # Pedophilia, exclusive type (disorder)
        "26025008",  # Residual schizophrenia (disorder)
        "261000119107",  # Severe depressed bipolar I disorder (disorder)
        "2618002",  # Chronic recurrent major depressive disorder (disorder)
        "26203008",  # Severe depressed bipolar I disorder with psychotic features, mood-incongruent (disorder)
        "26472000",  # Paraphrenia (disorder)
        "26516009",  # Severe mood disorder with psychotic features (disorder)
        "26530004",  # Severe bipolar disorder with psychotic features, mood-incongruent (disorder)
        "26665006",  # Antisocial personality disorder (disorder)
        "267073005",  # Suicidal (finding)
        "26852004",  # Primary degenerative dementia of the Alzheimer type, senile onset, with depression (disorder)
        "268612007",  # Senile and presenile organic psychotic conditions (disorder)
        "268617001",  # Acute schizophrenic episode (disorder)
        "268619003",  # Manic disorder, single episode (disorder)
        "268621008",  # Recurrent major depressive episodes (disorder)
        "268622001",  # Chronic paranoid psychosis (disorder)
        "268624000",  # Acute paranoid reaction (disorder)
        "268633003",  # Introverted personality disorder (disorder)
        "268634009",  # Psychoneurotic personality disorder (disorder)
        "268645007",  # Nondependent alcohol abuse (disorder)
        "268646008",  # Nondependent hallucinogen abuse (disorder)
        "268650001",  # Somatoform autonomic dysfunction - gastrointestinal tract (disorder)
        "268658008",  # Specific academic or work inhibition (disorder)
        "268661009",  # Nonaggressive unsocial conduct disorder (disorder)
        "268662002",  # Unsocial childhood truancy (disorder)
        "268672004",  # Disorder of speech and language development (disorder)
        "268673009",  # Developmental aphasia (disorder)
        "268674003",  # Developmental disorder of motor function (disorder)
        "268715000",  # Dissociative motor disorder (disorder)
        "268724009",  # Excessive sexual drive (disorder)
        "268734000",  # Developmental expressive language disorder (disorder)
        "268738002",  # Specific spelling disorder (disorder)
        "26929004",  # Alzheimer's disease (disorder)
        "270291000119109",  # Identity disorder of childhood (disorder)
        "27051000119102",  # Chronic abuse of laxatives (disorder)
        "270901009",  # Schizoaffective disorder, mixed type (disorder)
        "270903007",  # Lack or loss of sexual desire (disorder)
        "270905000",  # Childhood disinhibited attachment disorder (disorder)
        "271000119101",  # Severe mixed bipolar I disorder (disorder)
        "271428004",  # Schizoaffective disorder, manic type (disorder)
        "271952001",  # Stress and adjustment reaction (disorder)
        "27387000",  # Subchronic disorganized schizophrenia (disorder)
        "274948002",  # Endogenous depression - recurrent (disorder)
        "274953007",  # Acute polymorphic psychotic disorder (disorder)
        "275271004",  # Apraxia, developmental (disorder)
        "27544004",  # Developmental coordination disorder (disorder)
        "275446004",  # Gardner-Diamond syndrome (disorder)
        "275473003",  # Specific work inhibition (disorder)
        "275474009",  # Psychogenic overeating (disorder)
        "276296007",  # Dissociative trance (disorder)
        "276297003",  # Dissociative possession disorder (disorder)
        "276300008",  # Dissociative stupor (disorder)
        "278506006",  # Involutional paranoid state (disorder)
        "278508007",  # Delusional dysmorphophobia (disorder)
        "278852008",  # Paranoid-hallucinatory epileptic psychosis (disorder)
        "278853003",  # Acute schizophrenia-like psychotic disorder (disorder)
        "278857002",  # Dementia of frontal lobe type (disorder)
        "278920007",  # Speech and language dyspraxias (disorder)
        "279225001",  # Maternity blues (disorder)
        "279611005",  # Shell shock (disorder)
        "280032002",  # Developmental language disorder (disorder)
        "280901000",  # Couvade (disorder)
        "280943007",  # Dissociative confusion (disorder)
        "280945000",  # Derealization syndrome (disorder)
        "280949006",  # Erotomania (disorder)
        "280982009",  # Abuse of laxatives (disorder)
        "280983004",  # Abuse of vitamins (disorder)
        "280984005",  # Abuse of herbal medicine (disorder)
        "280986007",  # Abuse of antacids (disorder)
        "281000119103",  # Severe recurrent major depression (disorder)
        "281004",  # Dementia associated with alcoholism (disorder)
        "2815001",  # Sexual pyromania (disorder)
        "28357009",  # Transitory postpartum mood disturbance (disorder)
        "284591009",  # Persistent alcohol abuse (disorder)
        "28475009",  # Severe recurrent major depression with psychotic features (disorder)
        "28663008",  # Severe manic bipolar I disorder with psychotic features (disorder)
        "28676002",  # Mood disorder with manic features due to general medical condition (disorder)
        "288271000119103",  # Childhood onset fluency disorder (disorder)
        "288631000119104",  # Vascular dementia with behavioral disturbance (disorder)
        "28864000",  # Sedative, hypnotic AND/OR anxiolytic-induced mood disorder (disorder)
        "288751000119101",  # Reactive depressive psychosis, single episode (disorder)
        "28884001",  # Moderate bipolar I disorder, single manic episode (disorder)
        "288851000119106",  # Opioid-induced mood disorder due to opioid abuse (disorder)
        "288861000119108",  # Opioid-induced mood disorder due to opioid dependence (disorder)
        "290791000119105",  # Fluency disorder due to and following cerebrovascular accident (disorder)
        "291751000119105",  # Fluency disorder due to and following spontaneous intracerebral hemorrhage (disorder)
        "29599000",  # Chronic undifferentiated schizophrenia (disorder)
        "29733004",  # Mood disorder caused by opioid (disorder)
        "29929003",  # Bipolar I disorder, most recent episode depressed with atypical features (disorder)
        "30059008",  # Panic disorder with agoraphobia, severe agoraphobic avoidance AND moderate panic attacks (disorder)
        "300706003",  # Endogenous depression (disorder)
        "30077003",  # Somatoform pain disorder (disorder)
        "300979000",  # Caregiver stress syndrome (disorder)
        "30336007",  # Chronic residual schizophrenia with acute exacerbations (disorder)
        "304594002",  # Suicidal intent (finding)
        "304605000",  # Methanol abuse (disorder)
        "30491001",  # Cocaine delusional disorder (disorder)
        "30509009",  # Gender identity disorder of adolescence, previously homosexual (disorder)
        "30520009",  # Severe bipolar II disorder, most recent episode major depressive with psychotic features (disorder)
        "30605009",  # Major depression in partial remission (disorder)
        "30687003",  # Bipolar II disorder, most recent episode major depressive with postpartum onset (disorder)
        "307417003",  # Cycloid psychosis (disorder)
        "307653008",  # Clumsiness - motor delay (disorder)
        "30935000",  # Manic bipolar I disorder in full remission (disorder)
        "31027006",  # Schizotypal personality disorder (disorder)
        "310495003",  # Mild depression (disorder)
        "310496002",  # Moderate depression (disorder)
        "310497006",  # Severe depression (disorder)
        "31081000119101",  # Presenile dementia with delusions (disorder)
        "310814007",  # Discourse difficulties (disorder)
        "3109008",  # Secondary dysthymia early onset (disorder)
        "31177006",  # Attention deficit hyperactivity disorder, combined type (disorder)
        "31216003",  # Profound intellectual disability (disorder)
        "312214005",  # Floating-Harbor syndrome (disorder)
        "312991009",  # Senile dementia of the Lewy body type (disorder)
        "313182004",  # Chronic post-traumatic stress disorder (disorder)
        "31358003",  # Coprophilia (disorder)
        "31373002",  # Disorganized schizophrenia in remission (disorder)
        "31446002",  # Bipolar I disorder, most recent episode hypomanic (disorder)
        "3158007",  # Panic disorder with agoraphobia, agoraphobic avoidance in partial remission AND panic attacks in partial remission (disorder)
        "31611000",  # Multiple personality disorder (disorder)
        "31658008",  # Chronic paranoid schizophrenia (disorder)
        "31781004",  # Panic disorder with agoraphobia, agoraphobic avoidance in partial remission AND mild panic attacks (disorder)
        "317816007",  # Stockholm syndrome (disorder)
        "318784009",  # Posttraumatic stress disorder, delayed onset (disorder)
        "319768000",  # Recurrent major depressive disorder with melancholic features (disorder)
        "320751009",  # Major depression, melancholic type (disorder)
        "321717001",  # Involutional depression (disorder)
        "32358001",  # Amphetamine delusional disorder (disorder)
        "32388005",  # Panic disorder with agoraphobia, agoraphobic avoidance in partial remission AND moderate panic attacks (disorder)
        "32410009",  # Pederasty (disorder)
        "32552001",  # Organic delusional disorder caused by psychoactive substance (disorder)
        "32721004",  # Bulimia nervosa, purging type (disorder)
        "32875003",  # Inhalant-induced persisting dementia (disorder)
        "32880007",  # Adjustment disorder with work inhibition (disorder)
        "33078009",  # Severe recurrent major depression with psychotic features, mood-congruent (disorder)
        "33135002",  # Recurrent major depression in partial remission (disorder)
        "33323008",  # Somatic delusion disorder (disorder)
        "33380008",  # Severe manic bipolar I disorder with psychotic features, mood-incongruent (disorder)
        "33449004",  # Personality disorder (disorder)
        "33736005",  # Severe major depression with psychotic features, mood-congruent (disorder)
        "34116005",  # Panic disorder with agoraphobia, agoraphobic avoidance in full remission AND severe panic attacks (disorder)
        "34315001",  # Bipolar II disorder, most recent episode major depressive with melancholic features (disorder)
        "34938008",  # Anxiety disorder caused by alcohol (disorder)
        "35218008",  # Chronic disorganized schizophrenia with acute exacerbation (disorder)
        "35252006",  # Disorganized schizophrenia (disorder)
        "35253001",  # Attention deficit hyperactivity disorder, predominantly inattentive type (disorder)
        "3530005",  # Bipolar I disorder, single manic episode, in full remission (disorder)
        "35481005",  # Mixed bipolar I disorder in remission (disorder)
        "35489007",  # Depressive disorder (disorder)
        "35607004",  # Panic disorder with agoraphobia (disorder)
        "35722002",  # Severe bipolar II disorder, most recent episode major depressive, in remission (disorder)
        "357705009",  # Cotard's syndrome (disorder)
        "35827000",  # Recurrent conversion disorder (disorder)
        "35846004",  # Moderate bipolar II disorder, most recent episode major depressive (disorder)
        "3586005",  # Psychogenic fugue (disorder)
        "35919005",  # Pervasive developmental disorder (disorder)
        "359661001",  # Specific number difficulty (disorder)
        "36039004",  # Rumination disorder of infancy (disorder)
        "361275004",  # Oral dyspraxia (disorder)
        "361277007",  # Verbal dyspraxia (disorder)
        "36158005",  # Schizophreniform disorder with good prognostic features (disorder)
        "36170009",  # Secondary dysthymia late onset (disorder)
        "36217008",  # Organic personality disorder (disorder)
        "36262007",  # Pygmalionism (disorder)
        "36474008",  # Severe recurrent major depression without psychotic features (disorder)
        "36583000",  # Mixed bipolar I disorder in partial remission (disorder)
        "36622002",  # Mild mood disorder (disorder)
        "367515004",  # Receptive language disorder (disorder)
        "368361000119108",  # Thyrotoxicosis factitia without thyrotoxic crisis (disorder)
        "36923009",  # Major depression, single episode (disorder)
        "370143000",  # Major depressive disorder (disorder)
        "371024007",  # Senile dementia with delusion (disorder)
        "371026009",  # Senile dementia with psychosis (disorder)
        "371596008",  # Bipolar I disorder (disorder)
        "371599001",  # Severe bipolar I disorder (disorder)
        "371600003",  # Severe bipolar disorder (disorder)
        "371604007",  # Severe bipolar II disorder (disorder)
        "371631005",  # Panic disorder (disorder)
        "37331004",  # Organic mood disorder caused by psychoactive substance (disorder)
        "37344009",  # Cannabis abuse (disorder)
        "373618009",  # Autistic spectrum disorder with isolated skills (disorder)
        "37739004",  # Mood disorder due to a general medical condition (disorder)
        "37746008",  # Avoidant personality disorder (disorder)
        "37868008",  # Anxiety disorder of adolescence (disorder)
        "37872007",  # Avoidant disorder of childhood OR adolescence (disorder)
        "37941009",  # Rumination disorder (disorder)
        "38295006",  # Involutional paraphrenia (disorder)
        "38328002",  # Panic disorder with agoraphobia, severe agoraphobic avoidance AND panic attacks in full remission (disorder)
        "38368003",  # Schizoaffective disorder, bipolar type (disorder)
        "38451003",  # Primary dysthymia early onset (disorder)
        "38547003",  # Mood disorder in full remission (disorder)
        "386537007",  # Psychogenic pylorospasm (disorder)
        "386572005",  # Psychogenic syncope (disorder)
        "386701004",  # Developmental articulation disorder (disorder)
        "386810004",  # Phobic disorder (disorder)
        "386820009",  # Socialized behavior disorder (disorder)
        "386821008",  # Adjustment reaction in infancy (disorder)
        "386822001",  # Adjustment reaction of adolescence (disorder)
        "386823006",  # Adjustment reaction of adult life (disorder)
        "386824000",  # Adjustment reaction of childhood (disorder)
        "386825004",  # Adjustment reaction of late life (disorder)
        "38694004",  # Recurrent major depressive disorder with atypical features (disorder)
        "39610001",  # Undifferentiated schizophrenia in remission (disorder)
        "397795007",  # Polysomatizing disorder (disorder)
        "397826007",  # Briquet's syndrome (disorder)
        "397923000",  # Somatization disorder (disorder)
        "39809009",  # Recurrent major depressive disorder with catatonic features (disorder)
        "39951000119105",  # Pervasive developmental disorder of residual state (disorder)
        "401229000",  # Thoughts of deliberate self harm (finding)
        "401230005",  # Plans for deliberate self harm without intent (finding)
        "401231009",  # Intent of deliberate self harm with detailed plans (finding)
        "402732001",  # Habit tic (disorder)
        "402733006",  # Habit tic affecting skin (disorder)
        "402735004",  # Habit tic affecting hair (disorder)
        "402737007",  # Artefactual skin disease (disorder)
        "403590001",  # Factitious skin disorder imposed on another (disorder)
        "403593004",  # Phobic fear of skin cancer (disorder)
        "403595006",  # Pinocchio syndrome (disorder)
        "40379007",  # Mild recurrent major depression (disorder)
        "40425004",  # Postconcussion syndrome (disorder)
        "40568001",  # Recurrent brief depressive disorder (disorder)
        "405788002",  # Psychogenic loss of appetite (disorder)
        "405790001",  # Excessive chewing (finding)
        "406506008",  # Attention deficit hyperactivity disorder (disorder)
        "408857007",  # Infantile autism (disorder)
        "408858002",  # Infantile psychosis (disorder)
        "40926005",  # Moderate mixed bipolar I disorder (disorder)
        "40987004",  # Intermittent explosive disorder (disorder)
        "41021005",  # Psychologic dyspareunia (disorder)
        "41524005",  # Flagellantism (disorder)
        "41526007",  # Reactive attachment disorder (disorder)
        "41552001",  # Mild bipolar I disorder, single manic episode (disorder)
        "416340002",  # Late onset schizophrenia (disorder)
        "416780008",  # Primary degenerative dementia of the Alzheimer type, presenile onset (disorder)
        "416975007",  # Primary degenerative dementia of the Alzheimer type, senile onset (disorder)
        "41832009",  # Severe bipolar I disorder, single manic episode with psychotic features (disorder)
        "41836007",  # Bipolar disorder in full remission (disorder)
        "41932008",  # Amok (disorder)
        "420614009",  # Organic dementia with acquired immunodeficiency syndrome (disorder)
        "421023003",  # Presenile dementia with acquired immunodeficiency syndrome (disorder)
        "421529006",  # Dementia with acquired immunodeficiency syndrome (disorder)
        "425104003",  # Suicidal behavior (finding)
        "425390006",  # Dementia associated with Parkinson's Disease (disorder)
        "425832009",  # Psychophysiologic insomnia (disorder)
        "425885002",  # Continuous phencyclidine abuse (disorder)
        "425914008",  # Adjustment reaction to medical therapy (disorder)
        "42594001",  # Organic mood disorder of depressed type (disorder)
        "426095000",  # Continuous inhalant abuse (disorder)
        "426174008",  # Chronic stress disorder (disorder)
        "426578000",  # Premenstrual dysphoric disorder in remission (disorder)
        "426881004",  # Developmental delay in feeding (disorder)
        "427145007",  # Articulation disorder due to hyperkinesis (disorder)
        "427229002",  # Episodic inhalant abuse (disorder)
        "427469003",  # Eating disorder in remission (disorder)
        "427975003",  # Delusional disorder caused by drug (disorder)
        "428051000124108",  # Mild dementia (disorder)
        "42810003",  # Major depression in remission (disorder)
        "428351000124105",  # Severe dementia (disorder)
        "42868002",  # Subchronic catatonic schizophrenia (disorder)
        "428687006",  # Nightmares associated with chronic post-traumatic stress disorder (disorder)
        "429001000124103",  # Catha edulis abuse (disorder)
        "429161000124103",  # Primary degenerative dementia of the Alzheimer type, senile onset, with behavioral disturbance (disorder)
        "42925002",  # Major depressive disorder, single episode with atypical features (disorder)
        "429458009",  # Dementia due to Creutzfeldt Jakob disease (disorder)
        "429571005",  # Sleep-related dissociative disorder (disorder)
        "429672007",  # Mood disorder caused by drug (disorder)
        "429998004",  # Vascular dementia (disorder)
        "430099007",  # Gross motor development delay (disorder)
        "4306003",  # Cluster B personality disorder (disorder)
        "430744005",  # Factitious disorder with predominantly physical signs and symptoms (disorder)
        "430751001",  # Factitious disorder with predominantly psychological signs and symptoms (disorder)
        "430771000124100",  # Moderate dementia (disorder)
        "430852001",  # Severe major depression, single episode, with psychotic features (disorder)
        "430909002",  # Conduct disorder (disorder)
        "43150009",  # Panic disorder without agoraphobia with severe panic attacks (disorder)
        "432091002",  # Savant syndrome (disorder)
        "434451000124105",  # Acute tic disorder (disorder)
        "435321000124106",  # Acquired epileptic aphasia, non-refractory (disorder)
        "435331000124109",  # Acquired epileptic aphasia, refractory (disorder)
        "43568002",  # Bipolar II disorder, most recent episode major depressive with atypical features (disorder)
        "436001000124105",  # Insomnia due to anxiety and fear (disorder)
        "43614003",  # Autistic disorder of childhood onset (disorder)
        "43769008",  # Mild mixed bipolar I disorder (disorder)
        "439960005",  # Binge eating disorder (disorder)
        "44124003",  # Reactive attachment disorder of early childhood (disorder)
        "441704009",  # Affective psychosis (disorder)
        "441711008",  # Chronic psychogenic pain (disorder)
        "441719005",  # Speech and language developmental delay due to hearing loss (disorder)
        "441833000",  # Lethal catatonia (disorder)
        "442057004",  # Chronic depressive personality disorder (disorder)
        "442243005",  # Psychosexual dysfunction associated with inhibited libido (disorder)
        "442245003",  # Chronic hypomanic personality disorder (disorder)
        "442314000",  # Active but odd autism (disorder)
        "442344002",  # Dementia due to Huntington chorea (disorder)
        "443735008",  # Nonverbal learning disorder (disorder)
        "44376007",  # Dissociative disorder (disorder)
        "443853005",  # Psychogenic tremor (disorder)
        "443919007",  # Complex posttraumatic stress disorder (disorder)
        "4441000",  # Severe bipolar disorder with psychotic features (disorder)
        "44433009",  # Recurrent transient tic disorder (disorder)
        "444613000",  # Adult attention deficit hyperactivity disorder (disorder)
        "446175003",  # Acute posttraumatic stress disorder following military combat (disorder)
        "446180007",  # Delayed posttraumatic stress disorder following military combat (disorder)
        "44966003",  # Passive aggressive personality disorder (disorder)
        "450714000",  # Severe major depression (disorder)
        "45479006",  # Manic bipolar I disorder in remission (disorder)
        "45677003",  # Developmental expressive writing disorder (disorder)
        "45924006",  # Necrophilia (disorder)
        "45994004",  # Erotic vomiting (disorder)
        "46023009",  # Pedophilia, same AND opposite sex (disorder)
        "46206005",  # Mood disorder (disorder)
        "46229002",  # Severe mixed bipolar I disorder without psychotic features (disorder)
        "46244001",  # Recurrent major depression in full remission (disorder)
        "46263000",  # Cataplexy (disorder)
        "46432001",  # Lecherism (disorder)
        "46721000",  # Organic personality disorder caused by psychoactive substance (disorder)
        "46762006",  # Sexual desire disorder (disorder)
        "472981000",  # Fetishistic transvestism (disorder)
        "473452003",  # Atypical psychosis (disorder)
        "473456000",  # Compulsive personality disorder (disorder)
        "473457009",  # Obsessional personality disorder (disorder)
        "47372000",  # Adjustment disorder with anxious mood (disorder)
        "47447001",  # Grandiose delusion disorder (disorder)
        "47505003",  # Posttraumatic stress disorder (disorder)
        "47916000",  # Developmental arithmetic disorder (disorder)
        "48046002",  # Symptomatic sexual masochism (disorder)
        "4817008",  # Primary degenerative dementia of the Alzheimer type, senile onset, with delirium (disorder)
        "48309007",  # Pedophilia, nonexclusive type (disorder)
        "48500005",  # Delusional disorder (disorder)
        "48589009",  # Minor depressive disorder (disorder)
        "4863002",  # Mood disorder caused by phencyclidine (disorder)
        "48826008",  # Conduct disorder, adolescent-onset type (disorder)
        "48937005",  # Bipolar II disorder, most recent episode hypomanic (disorder)
        "4926007",  # Schizophrenia in remission (disorder)
        "4932002",  # Panic disorder with agoraphobia, moderate agoraphobic avoidance AND mild panic attacks (disorder)
        "49468007",  # Depressed bipolar I disorder (disorder)
        "4949009",  # Motor skill disorder (disorder)
        "49512000",  # Depressed bipolar I disorder in partial remission (disorder)
        "49564006",  # Panic disorder with agoraphobia, mild agoraphobic avoidance AND moderate panic attacks (disorder)
        "4997005",  # Thyrotoxicosis factitia (disorder)
        "50026000",  # Organic anxiety disorder caused by psychoactive substance (disorder)
        "50299009",  # Paraphilia (disorder)
        "50705009",  # Factitious disorder (disorder)
        "50722006",  # Delusional disorder caused by phencyclidine (disorder)
        "50933003",  # Hallucinogen delusional disorder (disorder)
        "5095008",  # Gender identity disorder of childhood (disorder)
        "50983008",  # Panic disorder with agoraphobia, mild agoraphobic avoidance AND panic attacks in partial remission (disorder)
        "51133006",  # Residual schizophrenia in remission (disorder)
        "51239001",  # Sexual masochism (disorder)
        "51493001",  # Anxiety disorder caused by cocaine (disorder)
        "5158005",  # Gilles de la Tourette's syndrome (disorder)
        "51637008",  # Chronic bipolar I disorder, most recent episode depressed (disorder)
        "51928006",  # General paresis - neurosyphilis (disorder)
        "52448006",  # Dementia (disorder)
        "52824009",  # Developmental reading disorder (disorder)
        "52910006",  # Anxiety disorder due to a general medical condition (disorder)
        "52954000",  # Schizoid personality disorder (disorder)
        "53049002",  # Severe bipolar disorder without psychotic features (disorder)
        "53467004",  # Anxiety disorder of childhood (disorder)
        "53607008",  # Depressed bipolar I disorder in remission (disorder)
        "53956006",  # Panic disorder without agoraphobia with panic attacks in partial remission (disorder)
        "54417002",  # Adult gender identity disorder, sexually attracted to females (disorder)
        "54502004",  # Primary degenerative dementia of the Alzheimer type, presenile onset, with delusions (disorder)
        "54587008",  # Simple phobia (disorder)
        "5464005",  # Brief reactive psychosis (disorder)
        "54761006",  # Severe depressed bipolar I disorder with psychotic features, mood-congruent (disorder)
        "55009008",  # Primary degenerative dementia of the Alzheimer type, senile onset, with delusions (disorder)
        "5509004",  # Panic disorder with agoraphobia AND severe panic attacks (disorder)
        "5510009",  # Organic delusional disorder (disorder)
        "55341008",  # Histrionic personality disorder (disorder)
        "55516002",  # Bipolar I disorder, most recent episode manic with postpartum onset (disorder)
        "55668003",  # Adjustment disorder with mixed emotional features (disorder)
        "55728007",  # Sexual aversion disorder (disorder)
        "55736003",  # Schizophreniform disorder without good prognostic features (disorder)
        "55967005",  # Anxiety disorder caused by phencyclidine (disorder)
        "5602001",  # Opioid abuse (disorder)
        "56034001",  # Compulsive exhibitionism (disorder)
        "56095002",  # Necrosadism (disorder)
        "56267009",  # Multi-infarct dementia (disorder)
        "56573006",  # Transient tic disorder (disorder)
        "56576003",  # Panic disorder without agoraphobia (disorder)
        "56627002",  # Psychosexual disorder (disorder)
        "5664002",  # Situational hypoactive sexual desire disorder (disorder)
        "568005",  # Tic disorder (disorder)
        "56882008",  # Anorexia nervosa (disorder)
        "5703000",  # Bipolar disorder in partial remission (disorder)
        "57194009",  # Adjustment disorder with depressed mood (disorder)
        "57715001",  # Gender identity disorder of adolescence (disorder)
        "58214004",  # Schizophrenia (disorder)
        "58329000",  # Organic mood disorder of manic type (disorder)
        "58349009",  # Exhibitionism (disorder)
        "58535001",  # Physical AND emotional exhaustion state (disorder)
        "58647003",  # Severe mood disorder with psychotic features, mood-congruent (disorder)
        "58703003",  # Postpartum depression (disorder)
        "58855008",  # Symptomatic exhibitionism (disorder)
        "59174009",  # Fetishism (disorder)
        "59216005",  # Adult gender identity disorder, sexually attracted to males (disorder)
        "59394009",  # Sexual sadism (disorder)
        "596004",  # Premenstrual dysphoric disorder (disorder)
        "59617007",  # Severe depressed bipolar I disorder with psychotic features (disorder)
        "59645001",  # Bulimia nervosa, nonpurging type (disorder)
        "59651006",  # Sedative, hypnotic AND/OR anxiolytic-induced persisting dementia (disorder)
        "59923000",  # Panic disorder with agoraphobia AND panic attacks in full remission (disorder)
        "600009",  # Pyromania (disorder)
        "60099002",  # Severe major depression with psychotic features, mood-incongruent (disorder)
        "60103007",  # Inhibited female orgasm (disorder)
        "60123008",  # Delusional disorder, mixed type (disorder)
        "60401000119104",  # Postpartum psychosis in remission (disorder)
        "61157009",  # Combat fatigue (disorder)
        "61180001",  # Adult gender identity disorder, sexually attracted to neither sex (disorder)
        "61212007",  # Panic disorder with agoraphobia, severe agoraphobic avoidance AND severe panic attacks (disorder)
        "61403008",  # Severe depressed bipolar I disorder without psychotic features (disorder)
        "61569007",  # Agoraphobia without history of panic disorder (disorder)
        "61831009",  # Induced psychotic disorder (disorder)
        "61901004",  # Conduct disorder, undifferentiated type (disorder)
        "62211000119103",  # Moderate expressive language delay (disorder)
        "62221000119105",  # Severe expressive language delay (disorder)
        "62231000119108",  # Mild expressive language delay (disorder)
        "62351001",  # Generalized social phobia (disorder)
        "62491004",  # Frotteurism (disorder)
        "62792007",  # Urophilia (disorder)
        "63181006",  # Paranoid schizophrenia in remission (disorder)
        "63204009",  # Bouffee delirante (disorder)
        "63249007",  # Manic bipolar I disorder in partial remission (disorder)
        "63393005",  # Anorexia nervosa, binge-eating purging type (disorder)
        "63412003",  # Major depression in full remission (disorder)
        "63649001",  # Cannabis delusional disorder (disorder)
        "63701002",  # Panic disorder with agoraphobia, mild agoraphobic avoidance AND mild panic attacks (disorder)
        "63778009",  # Major depressive disorder, single episode with melancholic features (disorder)
        "63835008",  # Voyeurism (disorder)
        "63909006",  # Panic disorder with agoraphobia AND panic attacks in partial remission (disorder)
        "63990000",  # Psychogenic urticaria (disorder)
        "64060000",  # Panic disorder with agoraphobia, moderate agoraphobic avoidance AND panic attacks in full remission (disorder)
        "64165008",  # Avoidant disorder of childhood (disorder)
        "64386003",  # Sedative abuse (disorder)
        "6471006",  # Suicidal thoughts (finding)
        "64731001",  # Severe mixed bipolar I disorder with psychotic features, mood-congruent (disorder)
        "6475002",  # Primary degenerative dementia of the Alzheimer type, presenile onset, uncomplicated (disorder)
        "64905009",  # Paranoid schizophrenia (disorder)
        "65042007",  # Bipolar I disorder, most recent episode mixed with postpartum onset (disorder)
        "65064003",  # Panic disorder without agoraphobia with moderate panic attacks (disorder)
        "65096006",  # Primary degenerative dementia of the Alzheimer type, presenile onset, with delirium (disorder)
        "65384007",  # Psychogenic alopecia (disorder)
        "65410009",  # Compulsive sexual masochism (disorder)
        "65438001",  # Psychogenic torticollis (disorder)
        "66108005",  # Primary degenerative dementia of the Alzheimer type, senile onset, uncomplicated (disorder)
        "66214007",  # Substance abuse (disorder)
        "66307007",  # Conduct disorder, group type (disorder)
        "66344007",  # Recurrent major depression (disorder)
        "66347000",  # Impulse control disorder (disorder)
        "66381006",  # Adjustment disorder with mixed disturbance of emotions AND conduct (disorder)
        "66631006",  # Moderate depressed bipolar I disorder (disorder)
        "66936004",  # Identity disorder (disorder)
        "67002003",  # Severe bipolar II disorder, most recent episode major depressive, in partial remission (disorder)
        "67123006",  # Adult gender identity disorder, sexually attracted to both sexes (disorder)
        "67195008",  # Acute stress disorder (disorder)
        "67227000",  # Pedophilia, same sex (disorder)
        "672481000119108",  # Fluency disorder due to and following ischemic cerebrovascular accident (disorder)
        "672491000119106",  # Fluency disorder due to and following hemorrhagic cerebrovascular accident (disorder)
        "67698009",  # Obsessional thoughts (finding)
        "67711008",  # Primary dysthymia late onset (disorder)
        "68019004",  # Recurrent major depression in remission (disorder)
        "68569003",  # Manic bipolar I disorder (disorder)
        "68618008",  # Rett syndrome (disorder)
        "68890003",  # Schizoaffective disorder (disorder)
        "68963006",  # Gender identity disorder of adolescence, previously heterosexual (disorder)
        "68995007",  # Chronic catatonic schizophrenia (disorder)
        "69322001",  # Psychotic disorder (disorder)
        "69361009",  # Kleptomania (disorder)
        "69392006",  # Major depressive disorder, single episode with catatonic features (disorder)
        "69479009",  # Anxiety hyperventilation (disorder)
        "69482004",  # Korsakoff's psychosis (disorder)
        "698624003",  # Dementia associated with cerebral lipidosis (disorder)
        "698625002",  # Dementia associated with normal pressure hydrocephalus (disorder)
        "698626001",  # Dementia associated with multiple sclerosis (disorder)
        "698687007",  # Post-traumatic dementia with behavioral change (disorder)
        "698689005",  # Attention deficit hyperactivity disorder, predominantly inattentive type in remission (disorder)
        "698690001",  # Avoidant personality disorder in remission (disorder)
        "698692009",  # Attention deficit hyperactivity disorder, predominantly hyperactive impulsive type in remission (disorder)
        "698693004",  # Adjustment disorder with anxious mood in remission (disorder)
        "698695006",  # Anorexia nervosa in remission (disorder)
        "698696007",  # Adjustment disorder with depressed mood in remission (disorder)
        "698697003",  # Adjustment disorder with mixed disturbance of emotions and conduct in remission (disorder)
        "698698008",  # Bulimia nervosa in remission (disorder)
        "698699000",  # Antisocial personality disorder in remission (disorder)
        "698700004",  # Borderline personality disorder in remission (disorder)
        "698701000",  # Adjustment disorder in remission (disorder)
        "698725008",  # Dementia associated with neurosyphilis (disorder)
        "698726009",  # Dementia associated with viral encephalitis (disorder)
        "698781002",  # Dementia associated with cerebral anoxia (disorder)
        "698946008",  # Cyclothymia in remission (disorder)
        "698947004",  # Conduct disorder in remission (disorder)
        "698948009",  # Vascular dementia in remission (disorder)
        "698949001",  # Dementia in remission (disorder)
        "698951002",  # Delusional disorder in remission (disorder)
        "698952009",  # Dissociative disorder in remission (disorder)
        "698954005",  # Primary degenerative dementia of the Alzheimer type, senile onset in remission (disorder)
        "698955006",  # Primary degenerative dementia of the Alzheimer type, presenile onset in remission (disorder)
        "698957003",  # Depressive disorder in remission (disorder)
        "699241002",  # Chronic post-traumatic stress disorder following military combat (disorder)
        "699449003",  # Methamphetamine abuse (disorder)
        "700213005",  # Avoidant restrictive food intake disorder (disorder)
        "70043001",  # Severe mood disorder with psychotic features, mood-incongruent (disorder)
        "702356009",  # X-linked intellectual disability-psychosis-macroorchidism syndrome (disorder)
        "702450004",  # FOXG1 syndrome (disorder)
        "7025000",  # Subchronic undifferentiated schizophrenia with acute exacerbations (disorder)
        "702528003",  # Developmental delay in receptive-expressive language (disorder)
        "702732007",  # High-functioning autism (disorder)
        "702815001",  # Attention deficit hyperactivity disorder, inattentive presentation (restrictive) (disorder)
        "7031000119100",  # Psychogenic fugue co-occurrent and due to stress reaction (disorder)
        "70340006",  # Inhalant abuse (disorder)
        "705001007",  # Self-induced vomiting to lose weight (disorder)
        "70546001",  # Severe bipolar disorder with psychotic features, mood-congruent (disorder)
        "70691001",  # Agoraphobia (disorder)
        "7071007",  # Phencyclidine abuse (disorder)
        "70747007",  # Major depression single episode, in partial remission (disorder)
        "70764005",  # Depersonalization disorder (disorder)
        "708037001",  # Residual Asperger's disorder (disorder)
        "70814008",  # Subchronic residual schizophrenia with acute exacerbations (disorder)
        "70922000",  # Compulsive pedophilia (disorder)
        "70936005",  # Multi-infarct dementia, uncomplicated (disorder)
        "70967007",  # Dissociative deafness (disorder)
        "710072005",  # Female athlete triad (disorder)
        "71103003",  # Chronic residual schizophrenia (disorder)
        "711561004",  # Has access to planned means of suicide (finding)
        "712823008",  # Acute depression (disorder)
        "712824002",  # Acute polymorphic psychotic disorder without symptoms of schizophrenia (disorder)
        "712850003",  # Acute polymorphic psychotic disorder co-occurrent with symptoms of schizophrenia (disorder)
        "712884004",  # Pathological demand avoidance (disorder)
        "71294008",  # Mild bipolar II disorder, most recent episode major depressive (disorder)
        "71336009",  # Recurrent major depressive disorder with postpartum onset (disorder)
        "713488003",  # Presenile dementia co-occurrent with human immunodeficiency virus infection (disorder)
        "713775002",  # Novel psychoactive substance misuse (disorder)
        "713844000",  # Dementia co-occurrent with human immunodeficiency virus infection (disorder)
        "715737004",  # Parkinsonism co-occurrent with dementia of Guadeloupe (disorder)
        "715924009",  # Disruptive mood dysregulation disorder (disorder)
        "716199000",  # Delayed speech and facial asymmetry with strabismus and ear lobe skin crease syndrome (disorder)
        "717223008",  # X-linked epilepsy with learning disability and behavior disorder syndrome (disorder)
        "71787009",  # Psychologic vaginismus (disorder)
        "71802006",  # Astasia-abasia (disorder)
        "718393002",  # Atypical Rett syndrome (disorder)
        "718636001",  # Minimal depression (disorder)
        "719592004",  # Moderately severe major depression (disorder)
        "719593009",  # Moderately severe depression (disorder)
        "719600006",  # 1p21.3 microdeletion syndrome (disorder)
        "71961003",  # Childhood disintegrative disorder (disorder)
        "719717006",  # Psychosis co-occurrent and due to Parkinson's disease (disorder)
        "71984005",  # Mild manic bipolar I disorder (disorder)
        "720451004",  # Minimal recurrent major depression (disorder)
        "720452006",  # Moderately severe recurrent major depression (disorder)
        "720453001",  # Moderately severe major depression single episode (disorder)
        "720454007",  # Minimal major depression single episode (disorder)
        "720455008",  # Minimal major depression (disorder)
        "722600006",  # Non-amnestic Alzheimer disease (disorder)
        "722877006",  # Adult rumination syndrome of ingested food (disorder)
        "722959000",  # Anorexia nervosa co-occurrent with dangerously low body weight (disorder)
        "722960005",  # Anorexia nervosa co-occurrent with significantly low body weight (disorder)
        "722972004",  # Secondary tic disorder (disorder)
        "722973009",  # Tic due to developmental disorder (disorder)
        "722977005",  # Dementia co-occurrent and due to neurocysticercosis (disorder)
        "722978000",  # Toxic dementia (disorder)
        "722979008",  # Dementia due to metabolic abnormality (disorder)
        "722980006",  # Dementia due to chromosomal anomaly (disorder)
        "723122006",  # Primary tic disorder (disorder)
        "723123001",  # Ischemic vascular dementia (disorder)
        "723332005",  # Isodicentric chromosome 15 syndrome (disorder)
        "723390000",  # Rapidly progressive dementia (disorder)
        "72366004",  # Eating disorder (disorder)
        "723899008",  # Delusional disorder currently symptomatic (disorder)
        "723900003",  # Delusional disorder currently in partial remission (disorder)
        "723901004",  # Delusional disorder currently in full remission (disorder)
        "723903001",  # Bipolar type I disorder currently in full remission (disorder)
        "723905008",  # Bipolar type II disorder currently in full remission (disorder)
        "723912004",  # Secondary mood disorder (disorder)
        "723913009",  # Olfactory reference disorder (disorder)
        "723915002",  # Secondary dissociative disorder (disorder)
        "723917005",  # Dangerously low body weight co-occurrent and due to anorexia nervosa of restricting type (disorder)
        "723918000",  # Dangerously low body weight co-occurrent and due to anorexia nervosa of binge-eating purging type (disorder)
        "723919008",  # Significantly low body weight co-occurrent and due to anorexia nervosa of restricting type (disorder)
        "723920002",  # Significantly low body weight co-occurrent and due to anorexia nervosa of binge-eating purging type (disorder)
        "723936000",  # Psychotic disorder caused by cannabis (disorder)
        "724544000",  # Infection causing tic (disorder)
        "724545004",  # Tic due to and following infection (disorder)
        "724651001",  # Developmental speech fluency disorder (disorder)
        "724654009",  # Anxiety disorder caused by opioid (disorder)
        "724655005",  # Psychotic disorder caused by opioid (disorder)
        "724673008",  # Psychotic disorder caused by sedative (disorder)
        "724674002",  # Psychotic disorder caused by hypnotic (disorder)
        "724675001",  # Psychotic disorder caused by anxiolytic (disorder)
        "724676000",  # Mood disorder with depressive symptoms caused by sedative (disorder)
        "724677009",  # Mood disorder with depressive symptoms caused by hypnotic (disorder)
        "724678004",  # Mood disorder with depressive symptoms caused by anxiolytic (disorder)
        "724679007",  # Mood disorder with manic symptoms caused by sedative (disorder)
        "724680005",  # Mood disorder with manic symptoms caused by hypnotic (disorder)
        "724681009",  # Mood disorder with manic symptoms caused by anxiolytic (disorder)
        "724682002",  # Mood disorder with mixed depressive and manic symptoms caused by sedative (disorder)
        "724683007",  # Mood disorder with mixed depressive and manic symptoms caused by hypnotic (disorder)
        "724684001",  # Mood disorder with mixed depressive and manic symptoms caused by anxiolytic (disorder)
        "724686004",  # Amnestic disorder caused by hypnotic (disorder)
        "724687008",  # Amnestic disorder caused by anxiolytic (disorder)
        "724689006",  # Psychotic disorder caused by cocaine (disorder)
        "724690002",  # Mood disorder with depressive symptoms caused by cocaine (disorder)
        "724691003",  # Mood disorder with manic symptoms caused by cocaine (disorder)
        "724692005",  # Mood disorder with mixed depressive and manic symptoms caused by cocaine (disorder)
        "724693000",  # Obsessive compulsive disorder caused by cocaine (disorder)
        "724696008",  # Psychotic disorder caused by hallucinogen (disorder)
        "724702008",  # Psychotic disorder caused by volatile inhalant (disorder)
        "724706006",  # Psychotic disorder caused by methylenedioxymethamphetamine (disorder)
        "724707002",  # Mood disorder caused by methylenedioxymethamphetamine (disorder)
        "724708007",  # Anxiety disorder caused by methylenedioxymethamphetamine (disorder)
        "724718002",  # Psychotic disorder caused by dissociative drug (disorder)
        "724719005",  # Psychotic disorder caused by ketamine (disorder)
        "724720004",  # Mood disorder caused by dissociative drug (disorder)
        "724721000",  # Mood disorder caused by ketamine (disorder)
        "724722007",  # Anxiety disorder caused by dissociative drug (disorder)
        "724723002",  # Anxiety disorder caused by ketamine (disorder)
        "724729003",  # Psychotic disorder caused by psychoactive substance (disorder)
        "724730008",  # Obsessive compulsive disorder caused by psychoactive substance (disorder)
        "724733005",  # Oppositional defiant disorder co-occurrent with chronic irritability-anger (disorder)
        "724734004",  # Oppositional defiant disorder co-occurrent with chronic irritability-anger with normal prosocial emotions (disorder)
        "724735003",  # Oppositional defiant disorder without chronic irritability-anger (disorder)
        "724736002",  # Oppositional defiant disorder without chronic irritability-anger with limited prosocial emotions (disorder)
        "724737006",  # Oppositional defiant disorder without chronic irritability-anger with normal prosocial emotions (disorder)
        "724738001",  # Childhood onset conduct-dissocial disorder with limited prosocial emotions (disorder)
        "724739009",  # Childhood onset conduct-dissocial disorder with normal prosocial emotions (disorder)
        "724740006",  # Adolescent onset conduct-dissocial disorder (disorder)
        "724741005",  # Adolescent onset conduct-dissocial disorder with limited prosocial emotions (disorder)
        "724742003",  # Adolescent onset conduct-dissocial disorder with normal prosocial emotions (disorder)
        "724743008",  # Coercive sexual sadism (disorder)
        "724744002",  # Paraphilia involving non-consenting individual (disorder)
        "724745001",  # Paraphilia involving solitary behavior or consenting individuals (disorder)
        "724752004",  # Hypnogogic exploding head syndrome (disorder)
        "724755002",  # Positive symptoms co-occurrent and due to primary psychotic disorder (disorder)
        "724756001",  # Negative symptoms co-occurrent and due to primary psychotic disorder (disorder)
        "724757005",  # Depressive symptoms due to primary psychotic disorder (disorder)
        "724758000",  # Manic symptoms co-occurrent and due to primary psychotic disorder (disorder)
        "724759008",  # Psychomotor symptom co-occurrent and due to psychotic disorder (disorder)
        "724760003",  # Cognitive impairment co-occurrent and due to primary psychotic disorder (disorder)
        "724776007",  # Dementia due to disorder of central nervous system (disorder)
        "724777003",  # Dementia due to infectious disease (disorder)
        "724818008",  # Functional monoparesis (disorder)
        "724819000",  # Functional paraparesis (disorder)
        "724992007",  # Epilepsy co-occurrent and due to dementia (disorder)
        "725898002",  # Delirium co-occurrent with dementia (disorder)
        "726772006",  # Major depression with psychotic features (disorder)
        "72861004",  # Panic disorder without agoraphobia with mild panic attacks (disorder)
        "7291006",  # Reactive attachment disorder of infancy (disorder)
        "733184002",  # Dementia caused by heavy metal exposure (disorder)
        "733190003",  # Dementia due to primary malignant neoplasm of brain (disorder)
        "733191004",  # Dementia due to chronic subdural hematoma (disorder)
        "733192006",  # Dementia due to herpes encephalitis (disorder)
        "733193001",  # Dementia co-occurrent and due to progressive multifocal leukoencephalopathy (disorder)
        "733194007",  # Dementia co-occurrent and due to Down syndrome (disorder)
        "733623005",  # Autism spectrum disorder, epilepsy, arthrogryposis syndrome (disorder)
        "73462009",  # Chronic vocal tic disorder (disorder)
        "73471000",  # Bipolar I disorder, most recent episode mixed with catatonic features (disorder)
        "735541006",  # Dissociative neurological symptom disorder (disorder)
        "735542004",  # Dissociative neurological disorder with symptom of weakness (disorder)
        "735543009",  # Dissociative neurological disorder with symptom of alteration of sensation (disorder)
        "735544003",  # Dissociative neurological disorder with symptom of movement disorder (disorder)
        "735545002",  # Dissociative neurological symptom disorder with visual symptom (disorder)
        "735546001",  # Dissociative neurological symptom disorder with swallowing symptom (disorder)
        "735547005",  # Dissociative neurological symptom disorder co-occurrent with auditory symptom (disorder)
        "735548000",  # Dissociative neurological symptom disorder co-occurrent with dizziness (disorder)
        "735549008",  # Gambling disorder predominantly offline (disorder)
        "735550008",  # Gambling disorder predominantly online (disorder)
        "735551007",  # Gaming disorder (disorder)
        "735552000",  # Gaming disorder predominantly online (disorder)
        "735553005",  # Gaming disorder predominantly offline (disorder)
        "735625001",  # Acquired generalized anorgasmia (disorder)
        "735626000",  # Acquired situational anorgasmia (disorder)
        "735627009",  # Lifelong generalized anorgasmia (disorder)
        "735628004",  # Lifelong situational anorgasmia (disorder)
        "735750005",  # Psychotic disorder with schizophreniform symptoms caused by cocaine (disorder)
        "736313002",  # Dissociative neurological symptom disorder co-occurrent with symptoms of gait disorder (disorder)
        "736314008",  # Dissociative neurological symptom disorder co-occurrent with cognitive impairment (disorder)
        "736315009",  # Dissociative neurological symptom disorder co-occurrent with alteration of consciousness (disorder)
        "736316005",  # Dissociative neurological symptom disorder co-occurrent with symptom of speech production (disorder)
        "737225007",  # Secondary psychotic syndrome with hallucinations and delusions (disorder)
        "737340007",  # Psychotic disorder caused by synthetic cannabinoid (disorder)
        "737341006",  # Anxiety disorder caused by synthetic cannabinoid (disorder)
        "73867007",  # Severe major depression with psychotic features (disorder)
        "7397008",  # Aggressor identification syndrome (disorder)
        "74010007",  # Panic disorder with agoraphobia, severe agoraphobic avoidance AND panic attacks in partial remission (disorder)
        "74142004",  # Feeding disorder of infancy OR early childhood (disorder)
        "74266001",  # Mood disorder in partial remission (disorder)
        "7461003",  # Attention deficit hyperactivity disorder, predominantly hyperactive impulsive type (disorder)
        "74686005",  # Mild depressed bipolar I disorder (disorder)
        "74732009",  # Mental disorder (disorder)
        "74791000",  # Pedophilia, limited to incest (disorder)
        "74850006",  # Conduct disorder, solitary aggressive type (disorder)
        "74851005",  # Hallucinogen abuse (disorder)
        "75084000",  # Severe major depression without psychotic features (disorder)
        "75122001",  # Inhalant-induced psychotic disorder with delusions (disorder)
        "75360000",  # Bipolar I disorder, single manic episode, in remission (disorder)
        "75752004",  # Bipolar I disorder, most recent episode depressed with melancholic features (disorder)
        "75837004",  # Mood disorder with depressive features due to general medical condition (disorder)
        "76105009",  # Cyclothymia (disorder)
        "76129002",  # Ganser syndrome (disorder)
        "762317007",  # Developmental language disorder co-occurrent with impairment of receptive and expressive language (disorder)
        "762318002",  # Developmental language disorder co-occurrent with impairment of expressive language (disorder)
        "762319005",  # Developmental language disorder co-occurrent with impairment of mainly pragmatic language (disorder)
        "762320004",  # Mood disorder with manic symptoms caused by opioid (disorder)
        "762321000",  # Mood disorder with depressive symptoms caused by opioid (disorder)
        "762322007",  # Mood disorder with mixed depressive and manic symptoms caused by opioid (disorder)
        "762325009",  # Psychotic disorder caused by stimulant (disorder)
        "762326005",  # Psychotic disorder with hallucinations caused by stimulant (disorder)
        "762327001",  # Psychotic disorder with delusions caused by stimulant (disorder)
        "762328006",  # Mood disorder caused by stimulant (disorder)
        "762329003",  # Mood disorder with depressive symptoms caused by stimulant (disorder)
        "762330008",  # Mood disorder with mixed depressive and manic symptoms caused by stimulant (disorder)
        "762331007",  # Anxiety disorder caused by stimulant (disorder)
        "762332000",  # Obsessive compulsive disorder caused by stimulant (disorder)
        "762335003",  # Mood disorder with manic symptoms caused by hallucinogen (disorder)
        "762336002",  # Mood disorder with depressive symptoms caused by hallucinogen (disorder)
        "762337006",  # Mood disorder with mixed depressive and manic symptoms caused by hallucinogen (disorder)
        "762338001",  # Mood disorder with manic symptoms caused by volatile inhalant (disorder)
        "762339009",  # Mood disorder with depressive symptoms caused by volatile inhalant (disorder)
        "762340006",  # Mood disorder with mixed depressive and manic symptoms caused by volatile inhalant (disorder)
        "762344002",  # Mood disorder with manic symptoms caused by dissociative drug (disorder)
        "762345001",  # Mood disorder with depressive symptoms caused by dissociative drug (disorder)
        "762346000",  # Mood disorder with mixed depressive and manic symptoms caused by dissociative drug (disorder)
        "762347009",  # Childhood onset conduct-dissocial disorder (disorder)
        "762350007",  # Dementia due to prion disease (disorder)
        "762351006",  # Dementia due to and following injury of head (disorder)
        "76236006",  # Atypical tic disorder (disorder)
        "762461003",  # Complex dissociative intrusion disorder (disorder)
        "762502009",  # Developmental language disorder co-occurrent with language impairment (disorder)
        "762507003",  # Psychotic disorder caused by synthetic cathinone (disorder)
        "762508008",  # Psychotic disorder with hallucinations caused by synthetic cathinone (disorder)
        "762509000",  # Psychotic disorder with delusions caused by synthetic cathinone (disorder)
        "762510005",  # Psychotic disorder with schizophreniform symptoms caused by synthetic cathinone (disorder)
        "762511009",  # Mood disorder caused by synthetic cathinone (disorder)
        "762512002",  # Mood disorder with depressive symptoms caused by synthetic cathinone (disorder)
        "762513007",  # Mood disorder with manic symptoms caused by synthetic cathinone (disorder)
        "762514001",  # Mood disorder with mixed depressive and manic symptoms caused by synthetic cathinone (disorder)
        "762515000",  # Anxiety disorder caused by synthetic cathinone (disorder)
        "762516004",  # Obsessive compulsive disorder caused by synthetic cathinone (disorder)
        "762522008",  # Penoscrotodynia (disorder)
        "762707000",  # Subcortical dementia (disorder)
        "763626009",  # Intellectual disability due to nutritional deficiency (disorder)
        "76441001",  # Severe major depression, single episode, without psychotic features (disorder)
        "76566000",  # Subchronic residual schizophrenia (disorder)
        "76812003",  # Panic disorder with agoraphobia, moderate agoraphobic avoidance AND panic attacks in partial remission (disorder)
        "76868007",  # Panic disorder with agoraphobia, agoraphobic avoidance in full remission AND mild panic attacks (disorder)
        "772999000",  # Harmful use of hypnotic (disorder)
        "773000004",  # Harmful use of anxiolytic (disorder)
        "77332003",  # Partialism (disorder)
        "77475008",  # Jealous delusion disorder (disorder)
        "77486005",  # Mood disorder with major depressive-like episode due to general medical condition (disorder)
        "7761000119106",  # Psychotic disorder caused by amphetamine (disorder)
        "77675002",  # Anorexia nervosa, restricting type (disorder)
        "77815007",  # Gender identity disorder of adulthood, previously homosexual (disorder)
        "77911002",  # Severe major depression, single episode, with psychotic features, mood-congruent (disorder)
        "7794004",  # Chronic motor tic disorder (disorder)
        "78004001",  # Bulimia nervosa (disorder)
        "78267003",  # Cocaine abuse (disorder)
        "78269000",  # Bipolar I disorder, single manic episode, in partial remission (disorder)
        "785277001",  # Harmful pattern of use of amfetamine and/or amfetamine derivative (disorder)
        "78640000",  # Severe manic bipolar I disorder with psychotic features, mood-congruent (disorder)
        "78667006",  # Dysthymia (disorder)
        "79204003",  # Chronic undifferentiated schizophrenia with acute exacerbations (disorder)
        "79298009",  # Mild major depression, single episode (disorder)
        "79341000119107",  # Mixed dementia (disorder)
        "79524000",  # Ecouteurism (disorder)
        "79584002",  # Moderate bipolar disorder (disorder)
        "79842004",  # Stuporous depression (disorder)
        "79866005",  # Subchronic paranoid schizophrenia (disorder)
        "80193009",  # Postgastric surgery syndrome (disorder)
        "80711002",  # Narcissistic personality disorder (disorder)
        "81319007",  # Severe bipolar II disorder, most recent episode major depressive without psychotic features (disorder)
        "81463002",  # Bestiality (disorder)
        "8185002",  # Panic disorder with agoraphobia AND moderate panic attacks (disorder)
        "81903006",  # Inhibited male orgasm (disorder)
        "82218004",  # Postoperative depression (disorder)
        "82339009",  # Anxiety disorder caused by amfetamine (disorder)
        "82361000119107",  # Altered behavior in dementia due to Huntington chorea (disorder)
        "82371000119101",  # Dementia due to multiple sclerosis with altered behavior (disorder)
        "82381000119103",  # Epileptic dementia with behavioral disturbance (disorder)
        "82415003",  # Agoraphobia without history of panic disorder without limited symptom attacks (disorder)
        "82494000",  # Panic disorder without agoraphobia with panic attacks in full remission (disorder)
        "82636008",  # Orgasm disorder (disorder)
        "82738004",  # Panic disorder with agoraphobia, moderate agoraphobic avoidance AND moderate panic attacks (disorder)
        "82959004",  # Dementia paralytica juvenilis (disorder)
        "82998009",  # Moderate manic bipolar I disorder (disorder)
        "83176005",  # Primary dysthymia (disorder)
        "832007",  # Moderate major depression (disorder)
        "83225003",  # Bipolar II disorder (disorder)
        "83253003",  # Shyness disorder of childhood (disorder)
        "83458005",  # Agitated depression (disorder)
        "83482000",  # Body dysmorphic disorder (disorder)
        "83501007",  # Organic mood disorder of mixed type (disorder)
        "83631006",  # Panic disorder with agoraphobia, moderate agoraphobic avoidance AND severe panic attacks (disorder)
        "83746006",  # Chronic schizophrenia (disorder)
        "83890006",  # Cluster C personality disorder (disorder)
        "84002002",  # Pedophilia (disorder)
        "84209002",  # Psychogenic amnesia (disorder)
        "84466009",  # Dependent personality disorder (disorder)
        "84760002",  # Schizoaffective disorder, depressive type (disorder)
        "84788008",  # Menopausal depression (disorder)
        "84984002",  # Adjustment disorder with disturbance of conduct (disorder)
        "85061001",  # Separation anxiety disorder of childhood, early onset (disorder)
        "85080004",  # Secondary dysthymia (disorder)
        "8511007",  # Transient tic disorder, single episode (disorder)
        "8522006",  # Klismaphilia (disorder)
        "85248005",  # Bipolar disorder in remission (disorder)
        "85861002",  # Subchronic undifferentiated schizophrenia (disorder)
        "86058007",  # Severe bipolar I disorder, single manic episode with psychotic features, mood-incongruent (disorder)
        "86110000",  # Rumination - thoughts (finding)
        "87203005",  # Bipolar I disorder, most recent episode depressed with postpartum onset (disorder)
        "87414006",  # Reactive depression (situational) (disorder)
        "87512008",  # Mild major depression (disorder)
        "87798009",  # Panic disorder with agoraphobia, agoraphobic avoidance in full remission AND moderate panic attacks (disorder)
        "87842000",  # Generalized neuromuscular exhaustion syndrome (disorder)
        "87950005",  # Bipolar I disorder, single manic episode with catatonic features (disorder)
        "87991007",  # Gender identity disorder (disorder)
        "88740003",  # Thyrotoxicosis factitia with thyrotoxic crisis (disorder)
        "88845000",  # Explosive type organic personality disorder (disorder)
        "88902008",  # Dissociative blindness (disorder)
        "88939009",  # Severe mood disorder without psychotic features (disorder)
        "88975006",  # Schizophreniform disorder (disorder)
        "88984006",  # Dissociative paralysis (disorder)
        "89248000",  # Erotic zoophilia (disorder)
        "89361000119103",  # Mild developmental articulation disorder (disorder)
        "89381000119107",  # Moderate receptive language delay (disorder)
        "89391000119105",  # Severe receptive language delay (disorder)
        "89415002",  # Hypersomnia disorder related to another mental disorder (disorder)
        "89501000119108",  # Mild receptive language delay (disorder)
        "89618007",  # Persecutory delusion disorder (disorder)
        "89948007",  # Panic disorder with agoraphobia AND mild panic attacks (disorder)
        "90099008",  # Subcortical leukoencephalopathy (disorder)
        "90790003",  # Avoidant disorder of adolescence (disorder)
        "9083002",  # Pedophilia, opposite sex (disorder)
        "91388009",  # Psychoactive substance abuse (disorder)
        "9167000",  # Moderate mood disorder (disorder)
        "92501000119101",  # Stress reaction with psychomotor agitation (disorder)
        "9340000",  # Bipolar I disorder, single manic episode (disorder)
        "9345005",  # Dialysis dementia (disorder)
        "93461009",  # Gender dysphoria (disorder)
        "94631000119100",  # Depressive disorder in mother complicating pregnancy (disorder)
        "94921000119107",  # Episodic mood disorder (disorder)
        "95636001",  # Sadomasochism (disorder)
        "95637005",  # Factitious disorder imposed on another (disorder)
        "9674006",  # Adjustment disorder with withdrawal (disorder)
        "97751000119108",  # Altered behavior in Alzheimer's disease (disorder)
    }

class ObstetricalOrPregnancyRelatedConditions(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to identify concepts of diagnoses of a condition related to pregnancy or obstetrics.

    **Data Element Scope:** This value set may use a model element related to Diagnosis.

    **Inclusion Criteria:** Includes concepts that describe a diagnosis related to pregnancy or obstetrics.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Obstetrical or Pregnancy Related Conditions"
    OID = "2.16.840.1.113883.3.117.1.7.1.263"
    DEFINITION_VERSION = "20210220"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "O0000",  # Abdominal pregnancy without intrauterine pregnancy
        "O0001",  # Abdominal pregnancy with intrauterine pregnancy
        "O00101",  # Right tubal pregnancy without intrauterine pregnancy
        "O00102",  # Left tubal pregnancy without intrauterine pregnancy
        "O00109",  # Unspecified tubal pregnancy without intrauterine pregnancy
        "O00111",  # Right tubal pregnancy with intrauterine pregnancy
        "O00112",  # Left tubal pregnancy with intrauterine pregnancy
        "O00119",  # Unspecified tubal pregnancy with intrauterine pregnancy
        "O00201",  # Right ovarian pregnancy without intrauterine pregnancy
        "O00202",  # Left ovarian pregnancy without intrauterine pregnancy
        "O00209",  # Unspecified ovarian pregnancy without intrauterine pregnancy
        "O00211",  # Right ovarian pregnancy with intrauterine pregnancy
        "O00212",  # Left ovarian pregnancy with intrauterine pregnancy
        "O00219",  # Unspecified ovarian pregnancy with intrauterine pregnancy
        "O0080",  # Other ectopic pregnancy without intrauterine pregnancy
        "O0081",  # Other ectopic pregnancy with intrauterine pregnancy
        "O0090",  # Unspecified ectopic pregnancy without intrauterine pregnancy
        "O0091",  # Unspecified ectopic pregnancy with intrauterine pregnancy
        "O010",  # Classical hydatidiform mole
        "O011",  # Incomplete and partial hydatidiform mole
        "O019",  # Hydatidiform mole, unspecified
        "O020",  # Blighted ovum and nonhydatidiform mole
        "O021",  # Missed abortion
        "O0281",  # Inappropriate change in quantitative human chorionic gonadotropin (hCG) in early pregnancy
        "O0289",  # Other abnormal products of conception
        "O029",  # Abnormal product of conception, unspecified
        "O030",  # Genital tract and pelvic infection following incomplete spontaneous abortion
        "O031",  # Delayed or excessive hemorrhage following incomplete spontaneous abortion
        "O032",  # Embolism following incomplete spontaneous abortion
        "O0330",  # Unspecified complication following incomplete spontaneous abortion
        "O0331",  # Shock following incomplete spontaneous abortion
        "O0332",  # Renal failure following incomplete spontaneous abortion
        "O0333",  # Metabolic disorder following incomplete spontaneous abortion
        "O0334",  # Damage to pelvic organs following incomplete spontaneous abortion
        "O0335",  # Other venous complications following incomplete spontaneous abortion
        "O0336",  # Cardiac arrest following incomplete spontaneous abortion
        "O0337",  # Sepsis following incomplete spontaneous abortion
        "O0338",  # Urinary tract infection following incomplete spontaneous abortion
        "O0339",  # Incomplete spontaneous abortion with other complications
        "O034",  # Incomplete spontaneous abortion without complication
        "O035",  # Genital tract and pelvic infection following complete or unspecified spontaneous abortion
        "O036",  # Delayed or excessive hemorrhage following complete or unspecified spontaneous abortion
        "O037",  # Embolism following complete or unspecified spontaneous abortion
        "O0380",  # Unspecified complication following complete or unspecified spontaneous abortion
        "O0381",  # Shock following complete or unspecified spontaneous abortion
        "O0382",  # Renal failure following complete or unspecified spontaneous abortion
        "O0383",  # Metabolic disorder following complete or unspecified spontaneous abortion
        "O0384",  # Damage to pelvic organs following complete or unspecified spontaneous abortion
        "O0385",  # Other venous complications following complete or unspecified spontaneous abortion
        "O0386",  # Cardiac arrest following complete or unspecified spontaneous abortion
        "O0387",  # Sepsis following complete or unspecified spontaneous abortion
        "O0388",  # Urinary tract infection following complete or unspecified spontaneous abortion
        "O0389",  # Complete or unspecified spontaneous abortion with other complications
        "O039",  # Complete or unspecified spontaneous abortion without complication
        "O045",  # Genital tract and pelvic infection following (induced) termination of pregnancy
        "O046",  # Delayed or excessive hemorrhage following (induced) termination of pregnancy
        "O047",  # Embolism following (induced) termination of pregnancy
        "O0480",  # (Induced) termination of pregnancy with unspecified complications
        "O0481",  # Shock following (induced) termination of pregnancy
        "O0482",  # Renal failure following (induced) termination of pregnancy
        "O0483",  # Metabolic disorder following (induced) termination of pregnancy
        "O0484",  # Damage to pelvic organs following (induced) termination of pregnancy
        "O0485",  # Other venous complications following (induced) termination of pregnancy
        "O0486",  # Cardiac arrest following (induced) termination of pregnancy
        "O0487",  # Sepsis following (induced) termination of pregnancy
        "O0488",  # Urinary tract infection following (induced) termination of pregnancy
        "O0489",  # (Induced) termination of pregnancy with other complications
        "O070",  # Genital tract and pelvic infection following failed attempted termination of pregnancy
        "O071",  # Delayed or excessive hemorrhage following failed attempted termination of pregnancy
        "O072",  # Embolism following failed attempted termination of pregnancy
        "O0730",  # Failed attempted termination of pregnancy with unspecified complications
        "O0731",  # Shock following failed attempted termination of pregnancy
        "O0732",  # Renal failure following failed attempted termination of pregnancy
        "O0733",  # Metabolic disorder following failed attempted termination of pregnancy
        "O0734",  # Damage to pelvic organs following failed attempted termination of pregnancy
        "O0735",  # Other venous complications following failed attempted termination of pregnancy
        "O0736",  # Cardiac arrest following failed attempted termination of pregnancy
        "O0737",  # Sepsis following failed attempted termination of pregnancy
        "O0738",  # Urinary tract infection following failed attempted termination of pregnancy
        "O0739",  # Failed attempted termination of pregnancy with other complications
        "O074",  # Failed attempted termination of pregnancy without complication
        "O080",  # Genital tract and pelvic infection following ectopic and molar pregnancy
        "O081",  # Delayed or excessive hemorrhage following ectopic and molar pregnancy
        "O082",  # Embolism following ectopic and molar pregnancy
        "O083",  # Shock following ectopic and molar pregnancy
        "O084",  # Renal failure following ectopic and molar pregnancy
        "O085",  # Metabolic disorders following an ectopic and molar pregnancy
        "O086",  # Damage to pelvic organs and tissues following an ectopic and molar pregnancy
        "O087",  # Other venous complications following an ectopic and molar pregnancy
        "O0881",  # Cardiac arrest following an ectopic and molar pregnancy
        "O0882",  # Sepsis following ectopic and molar pregnancy
        "O0883",  # Urinary tract infection following an ectopic and molar pregnancy
        "O0889",  # Other complications following an ectopic and molar pregnancy
        "O089",  # Unspecified complication following an ectopic and molar pregnancy
        "O0900",  # Supervision of pregnancy with history of infertility, unspecified trimester
        "O0901",  # Supervision of pregnancy with history of infertility, first trimester
        "O0902",  # Supervision of pregnancy with history of infertility, second trimester
        "O0903",  # Supervision of pregnancy with history of infertility, third trimester
        "O0910",  # Supervision of pregnancy with history of ectopic pregnancy, unspecified trimester
        "O0911",  # Supervision of pregnancy with history of ectopic pregnancy, first trimester
        "O0912",  # Supervision of pregnancy with history of ectopic pregnancy, second trimester
        "O0913",  # Supervision of pregnancy with history of ectopic pregnancy, third trimester
        "O09211",  # Supervision of pregnancy with history of pre-term labor, first trimester
        "O09212",  # Supervision of pregnancy with history of pre-term labor, second trimester
        "O09213",  # Supervision of pregnancy with history of pre-term labor, third trimester
        "O09219",  # Supervision of pregnancy with history of pre-term labor, unspecified trimester
        "O09291",  # Supervision of pregnancy with other poor reproductive or obstetric history, first trimester
        "O09292",  # Supervision of pregnancy with other poor reproductive or obstetric history, second trimester
        "O09293",  # Supervision of pregnancy with other poor reproductive or obstetric history, third trimester
        "O09299",  # Supervision of pregnancy with other poor reproductive or obstetric history, unspecified trimester
        "O0930",  # Supervision of pregnancy with insufficient antenatal care, unspecified trimester
        "O0931",  # Supervision of pregnancy with insufficient antenatal care, first trimester
        "O0932",  # Supervision of pregnancy with insufficient antenatal care, second trimester
        "O0933",  # Supervision of pregnancy with insufficient antenatal care, third trimester
        "O0940",  # Supervision of pregnancy with grand multiparity, unspecified trimester
        "O0941",  # Supervision of pregnancy with grand multiparity, first trimester
        "O0942",  # Supervision of pregnancy with grand multiparity, second trimester
        "O0943",  # Supervision of pregnancy with grand multiparity, third trimester
        "O09511",  # Supervision of elderly primigravida, first trimester
        "O09512",  # Supervision of elderly primigravida, second trimester
        "O09513",  # Supervision of elderly primigravida, third trimester
        "O09519",  # Supervision of elderly primigravida, unspecified trimester
        "O09521",  # Supervision of elderly multigravida, first trimester
        "O09522",  # Supervision of elderly multigravida, second trimester
        "O09523",  # Supervision of elderly multigravida, third trimester
        "O09529",  # Supervision of elderly multigravida, unspecified trimester
        "O09611",  # Supervision of young primigravida, first trimester
        "O09612",  # Supervision of young primigravida, second trimester
        "O09613",  # Supervision of young primigravida, third trimester
        "O09619",  # Supervision of young primigravida, unspecified trimester
        "O09621",  # Supervision of young multigravida, first trimester
        "O09622",  # Supervision of young multigravida, second trimester
        "O09623",  # Supervision of young multigravida, third trimester
        "O09629",  # Supervision of young multigravida, unspecified trimester
        "O0970",  # Supervision of high risk pregnancy due to social problems, unspecified trimester
        "O0971",  # Supervision of high risk pregnancy due to social problems, first trimester
        "O0972",  # Supervision of high risk pregnancy due to social problems, second trimester
        "O0973",  # Supervision of high risk pregnancy due to social problems, third trimester
        "O09811",  # Supervision of pregnancy resulting from assisted reproductive technology, first trimester
        "O09812",  # Supervision of pregnancy resulting from assisted reproductive technology, second trimester
        "O09813",  # Supervision of pregnancy resulting from assisted reproductive technology, third trimester
        "O09819",  # Supervision of pregnancy resulting from assisted reproductive technology, unspecified trimester
        "O09821",  # Supervision of pregnancy with history of in utero procedure during previous pregnancy, first trimester
        "O09822",  # Supervision of pregnancy with history of in utero procedure during previous pregnancy, second trimester
        "O09823",  # Supervision of pregnancy with history of in utero procedure during previous pregnancy, third trimester
        "O09829",  # Supervision of pregnancy with history of in utero procedure during previous pregnancy, unspecified trimester
        "O09891",  # Supervision of other high risk pregnancies, first trimester
        "O09892",  # Supervision of other high risk pregnancies, second trimester
        "O09893",  # Supervision of other high risk pregnancies, third trimester
        "O09899",  # Supervision of other high risk pregnancies, unspecified trimester
        "O0990",  # Supervision of high risk pregnancy, unspecified, unspecified trimester
        "O0991",  # Supervision of high risk pregnancy, unspecified, first trimester
        "O0992",  # Supervision of high risk pregnancy, unspecified, second trimester
        "O0993",  # Supervision of high risk pregnancy, unspecified, third trimester
        "O09A0",  # Supervision of pregnancy with history of molar pregnancy, unspecified trimester
        "O09A1",  # Supervision of pregnancy with history of molar pregnancy, first trimester
        "O09A2",  # Supervision of pregnancy with history of molar pregnancy, second trimester
        "O09A3",  # Supervision of pregnancy with history of molar pregnancy, third trimester
        "O10011",  # Pre-existing essential hypertension complicating pregnancy, first trimester
        "O10012",  # Pre-existing essential hypertension complicating pregnancy, second trimester
        "O10013",  # Pre-existing essential hypertension complicating pregnancy, third trimester
        "O10019",  # Pre-existing essential hypertension complicating pregnancy, unspecified trimester
        "O1002",  # Pre-existing essential hypertension complicating childbirth
        "O1003",  # Pre-existing essential hypertension complicating the puerperium
        "O10111",  # Pre-existing hypertensive heart disease complicating pregnancy, first trimester
        "O10112",  # Pre-existing hypertensive heart disease complicating pregnancy, second trimester
        "O10113",  # Pre-existing hypertensive heart disease complicating pregnancy, third trimester
        "O10119",  # Pre-existing hypertensive heart disease complicating pregnancy, unspecified trimester
        "O1012",  # Pre-existing hypertensive heart disease complicating childbirth
        "O1013",  # Pre-existing hypertensive heart disease complicating the puerperium
        "O10211",  # Pre-existing hypertensive chronic kidney disease complicating pregnancy, first trimester
        "O10212",  # Pre-existing hypertensive chronic kidney disease complicating pregnancy, second trimester
        "O10213",  # Pre-existing hypertensive chronic kidney disease complicating pregnancy, third trimester
        "O10219",  # Pre-existing hypertensive chronic kidney disease complicating pregnancy, unspecified trimester
        "O1022",  # Pre-existing hypertensive chronic kidney disease complicating childbirth
        "O1023",  # Pre-existing hypertensive chronic kidney disease complicating the puerperium
        "O10311",  # Pre-existing hypertensive heart and chronic kidney disease complicating pregnancy, first trimester
        "O10312",  # Pre-existing hypertensive heart and chronic kidney disease complicating pregnancy, second trimester
        "O10313",  # Pre-existing hypertensive heart and chronic kidney disease complicating pregnancy, third trimester
        "O10319",  # Pre-existing hypertensive heart and chronic kidney disease complicating pregnancy, unspecified trimester
        "O1032",  # Pre-existing hypertensive heart and chronic kidney disease complicating childbirth
        "O1033",  # Pre-existing hypertensive heart and chronic kidney disease complicating the puerperium
        "O10411",  # Pre-existing secondary hypertension complicating pregnancy, first trimester
        "O10412",  # Pre-existing secondary hypertension complicating pregnancy, second trimester
        "O10413",  # Pre-existing secondary hypertension complicating pregnancy, third trimester
        "O10419",  # Pre-existing secondary hypertension complicating pregnancy, unspecified trimester
        "O1042",  # Pre-existing secondary hypertension complicating childbirth
        "O1043",  # Pre-existing secondary hypertension complicating the puerperium
        "O10911",  # Unspecified pre-existing hypertension complicating pregnancy, first trimester
        "O10912",  # Unspecified pre-existing hypertension complicating pregnancy, second trimester
        "O10913",  # Unspecified pre-existing hypertension complicating pregnancy, third trimester
        "O10919",  # Unspecified pre-existing hypertension complicating pregnancy, unspecified trimester
        "O1092",  # Unspecified pre-existing hypertension complicating childbirth
        "O1093",  # Unspecified pre-existing hypertension complicating the puerperium
        "O111",  # Pre-existing hypertension with pre-eclampsia, first trimester
        "O112",  # Pre-existing hypertension with pre-eclampsia, second trimester
        "O113",  # Pre-existing hypertension with pre-eclampsia, third trimester
        "O114",  # Pre-existing hypertension with pre-eclampsia, complicating childbirth
        "O115",  # Pre-existing hypertension with pre-eclampsia, complicating the puerperium
        "O119",  # Pre-existing hypertension with pre-eclampsia, unspecified trimester
        "O1200",  # Gestational edema, unspecified trimester
        "O1201",  # Gestational edema, first trimester
        "O1202",  # Gestational edema, second trimester
        "O1203",  # Gestational edema, third trimester
        "O1204",  # Gestational edema, complicating childbirth
        "O1205",  # Gestational edema, complicating the puerperium
        "O1210",  # Gestational proteinuria, unspecified trimester
        "O1211",  # Gestational proteinuria, first trimester
        "O1212",  # Gestational proteinuria, second trimester
        "O1213",  # Gestational proteinuria, third trimester
        "O1214",  # Gestational proteinuria, complicating childbirth
        "O1215",  # Gestational proteinuria, complicating the puerperium
        "O1220",  # Gestational edema with proteinuria, unspecified trimester
        "O1221",  # Gestational edema with proteinuria, first trimester
        "O1222",  # Gestational edema with proteinuria, second trimester
        "O1223",  # Gestational edema with proteinuria, third trimester
        "O1224",  # Gestational edema with proteinuria, complicating childbirth
        "O1225",  # Gestational edema with proteinuria, complicating the puerperium
        "O131",  # Gestational [pregnancy-induced] hypertension without significant proteinuria, first trimester
        "O132",  # Gestational [pregnancy-induced] hypertension without significant proteinuria, second trimester
        "O133",  # Gestational [pregnancy-induced] hypertension without significant proteinuria, third trimester
        "O134",  # Gestational [pregnancy-induced] hypertension without significant proteinuria, complicating childbirth
        "O135",  # Gestational [pregnancy-induced] hypertension without significant proteinuria, complicating the puerperium
        "O139",  # Gestational [pregnancy-induced] hypertension without significant proteinuria, unspecified trimester
        "O1400",  # Mild to moderate pre-eclampsia, unspecified trimester
        "O1402",  # Mild to moderate pre-eclampsia, second trimester
        "O1403",  # Mild to moderate pre-eclampsia, third trimester
        "O1404",  # Mild to moderate pre-eclampsia, complicating childbirth
        "O1405",  # Mild to moderate pre-eclampsia, complicating the puerperium
        "O1410",  # Severe pre-eclampsia, unspecified trimester
        "O1412",  # Severe pre-eclampsia, second trimester
        "O1413",  # Severe pre-eclampsia, third trimester
        "O1414",  # Severe pre-eclampsia complicating childbirth
        "O1415",  # Severe pre-eclampsia, complicating the puerperium
        "O1420",  # HELLP syndrome (HELLP), unspecified trimester
        "O1422",  # HELLP syndrome (HELLP), second trimester
        "O1423",  # HELLP syndrome (HELLP), third trimester
        "O1424",  # HELLP syndrome, complicating childbirth
        "O1425",  # HELLP syndrome, complicating the puerperium
        "O1490",  # Unspecified pre-eclampsia, unspecified trimester
        "O1492",  # Unspecified pre-eclampsia, second trimester
        "O1493",  # Unspecified pre-eclampsia, third trimester
        "O1494",  # Unspecified pre-eclampsia, complicating childbirth
        "O1495",  # Unspecified pre-eclampsia, complicating the puerperium
        "O1500",  # Eclampsia complicating pregnancy, unspecified trimester
        "O1502",  # Eclampsia complicating pregnancy, second trimester
        "O1503",  # Eclampsia complicating pregnancy, third trimester
        "O151",  # Eclampsia complicating labor
        "O152",  # Eclampsia complicating the puerperium
        "O159",  # Eclampsia, unspecified as to time period
        "O161",  # Unspecified maternal hypertension, first trimester
        "O162",  # Unspecified maternal hypertension, second trimester
        "O163",  # Unspecified maternal hypertension, third trimester
        "O164",  # Unspecified maternal hypertension, complicating childbirth
        "O165",  # Unspecified maternal hypertension, complicating the puerperium
        "O169",  # Unspecified maternal hypertension, unspecified trimester
        "O200",  # Threatened abortion
        "O208",  # Other hemorrhage in early pregnancy
        "O209",  # Hemorrhage in early pregnancy, unspecified
        "O210",  # Mild hyperemesis gravidarum
        "O211",  # Hyperemesis gravidarum with metabolic disturbance
        "O212",  # Late vomiting of pregnancy
        "O218",  # Other vomiting complicating pregnancy
        "O219",  # Vomiting of pregnancy, unspecified
        "O2200",  # Varicose veins of lower extremity in pregnancy, unspecified trimester
        "O2201",  # Varicose veins of lower extremity in pregnancy, first trimester
        "O2202",  # Varicose veins of lower extremity in pregnancy, second trimester
        "O2203",  # Varicose veins of lower extremity in pregnancy, third trimester
        "O2210",  # Genital varices in pregnancy, unspecified trimester
        "O2211",  # Genital varices in pregnancy, first trimester
        "O2212",  # Genital varices in pregnancy, second trimester
        "O2213",  # Genital varices in pregnancy, third trimester
        "O2220",  # Superficial thrombophlebitis in pregnancy, unspecified trimester
        "O2221",  # Superficial thrombophlebitis in pregnancy, first trimester
        "O2222",  # Superficial thrombophlebitis in pregnancy, second trimester
        "O2223",  # Superficial thrombophlebitis in pregnancy, third trimester
        "O2230",  # Deep phlebothrombosis in pregnancy, unspecified trimester
        "O2231",  # Deep phlebothrombosis in pregnancy, first trimester
        "O2232",  # Deep phlebothrombosis in pregnancy, second trimester
        "O2233",  # Deep phlebothrombosis in pregnancy, third trimester
        "O2240",  # Hemorrhoids in pregnancy, unspecified trimester
        "O2241",  # Hemorrhoids in pregnancy, first trimester
        "O2242",  # Hemorrhoids in pregnancy, second trimester
        "O2243",  # Hemorrhoids in pregnancy, third trimester
        "O2250",  # Cerebral venous thrombosis in pregnancy, unspecified trimester
        "O2251",  # Cerebral venous thrombosis in pregnancy, first trimester
        "O2252",  # Cerebral venous thrombosis in pregnancy, second trimester
        "O2253",  # Cerebral venous thrombosis in pregnancy, third trimester
        "O228X1",  # Other venous complications in pregnancy, first trimester
        "O228X2",  # Other venous complications in pregnancy, second trimester
        "O228X3",  # Other venous complications in pregnancy, third trimester
        "O228X9",  # Other venous complications in pregnancy, unspecified trimester
        "O2290",  # Venous complication in pregnancy, unspecified, unspecified trimester
        "O2291",  # Venous complication in pregnancy, unspecified, first trimester
        "O2292",  # Venous complication in pregnancy, unspecified, second trimester
        "O2293",  # Venous complication in pregnancy, unspecified, third trimester
        "O2300",  # Infections of kidney in pregnancy, unspecified trimester
        "O2301",  # Infections of kidney in pregnancy, first trimester
        "O2302",  # Infections of kidney in pregnancy, second trimester
        "O2303",  # Infections of kidney in pregnancy, third trimester
        "O2310",  # Infections of bladder in pregnancy, unspecified trimester
        "O2311",  # Infections of bladder in pregnancy, first trimester
        "O2312",  # Infections of bladder in pregnancy, second trimester
        "O2313",  # Infections of bladder in pregnancy, third trimester
        "O2320",  # Infections of urethra in pregnancy, unspecified trimester
        "O2321",  # Infections of urethra in pregnancy, first trimester
        "O2322",  # Infections of urethra in pregnancy, second trimester
        "O2323",  # Infections of urethra in pregnancy, third trimester
        "O2330",  # Infections of other parts of urinary tract in pregnancy, unspecified trimester
        "O2331",  # Infections of other parts of urinary tract in pregnancy, first trimester
        "O2332",  # Infections of other parts of urinary tract in pregnancy, second trimester
        "O2333",  # Infections of other parts of urinary tract in pregnancy, third trimester
        "O2340",  # Unspecified infection of urinary tract in pregnancy, unspecified trimester
        "O2341",  # Unspecified infection of urinary tract in pregnancy, first trimester
        "O2342",  # Unspecified infection of urinary tract in pregnancy, second trimester
        "O2343",  # Unspecified infection of urinary tract in pregnancy, third trimester
        "O23511",  # Infections of cervix in pregnancy, first trimester
        "O23512",  # Infections of cervix in pregnancy, second trimester
        "O23513",  # Infections of cervix in pregnancy, third trimester
        "O23519",  # Infections of cervix in pregnancy, unspecified trimester
        "O23521",  # Salpingo-oophoritis in pregnancy, first trimester
        "O23522",  # Salpingo-oophoritis in pregnancy, second trimester
        "O23523",  # Salpingo-oophoritis in pregnancy, third trimester
        "O23529",  # Salpingo-oophoritis in pregnancy, unspecified trimester
        "O23591",  # Infection of other part of genital tract in pregnancy, first trimester
        "O23592",  # Infection of other part of genital tract in pregnancy, second trimester
        "O23593",  # Infection of other part of genital tract in pregnancy, third trimester
        "O23599",  # Infection of other part of genital tract in pregnancy, unspecified trimester
        "O2390",  # Unspecified genitourinary tract infection in pregnancy, unspecified trimester
        "O2391",  # Unspecified genitourinary tract infection in pregnancy, first trimester
        "O2392",  # Unspecified genitourinary tract infection in pregnancy, second trimester
        "O2393",  # Unspecified genitourinary tract infection in pregnancy, third trimester
        "O24011",  # Pre-existing type 1 diabetes mellitus, in pregnancy, first trimester
        "O24012",  # Pre-existing type 1 diabetes mellitus, in pregnancy, second trimester
        "O24013",  # Pre-existing type 1 diabetes mellitus, in pregnancy, third trimester
        "O24019",  # Pre-existing type 1 diabetes mellitus, in pregnancy, unspecified trimester
        "O2402",  # Pre-existing type 1 diabetes mellitus, in childbirth
        "O2403",  # Pre-existing type 1 diabetes mellitus, in the puerperium
        "O24111",  # Pre-existing type 2 diabetes mellitus, in pregnancy, first trimester
        "O24112",  # Pre-existing type 2 diabetes mellitus, in pregnancy, second trimester
        "O24113",  # Pre-existing type 2 diabetes mellitus, in pregnancy, third trimester
        "O24119",  # Pre-existing type 2 diabetes mellitus, in pregnancy, unspecified trimester
        "O2412",  # Pre-existing type 2 diabetes mellitus, in childbirth
        "O2413",  # Pre-existing type 2 diabetes mellitus, in the puerperium
        "O24311",  # Unspecified pre-existing diabetes mellitus in pregnancy, first trimester
        "O24312",  # Unspecified pre-existing diabetes mellitus in pregnancy, second trimester
        "O24313",  # Unspecified pre-existing diabetes mellitus in pregnancy, third trimester
        "O24319",  # Unspecified pre-existing diabetes mellitus in pregnancy, unspecified trimester
        "O2432",  # Unspecified pre-existing diabetes mellitus in childbirth
        "O2433",  # Unspecified pre-existing diabetes mellitus in the puerperium
        "O24410",  # Gestational diabetes mellitus in pregnancy, diet controlled
        "O24414",  # Gestational diabetes mellitus in pregnancy, insulin controlled
        "O24415",  # Gestational diabetes mellitus in pregnancy, controlled by oral hypoglycemic drugs
        "O24419",  # Gestational diabetes mellitus in pregnancy, unspecified control
        "O24420",  # Gestational diabetes mellitus in childbirth, diet controlled
        "O24424",  # Gestational diabetes mellitus in childbirth, insulin controlled
        "O24425",  # Gestational diabetes mellitus in childbirth, controlled by oral hypoglycemic drugs
        "O24429",  # Gestational diabetes mellitus in childbirth, unspecified control
        "O24430",  # Gestational diabetes mellitus in the puerperium, diet controlled
        "O24434",  # Gestational diabetes mellitus in the puerperium, insulin controlled
        "O24435",  # Gestational diabetes mellitus in puerperium, controlled by oral hypoglycemic drugs
        "O24439",  # Gestational diabetes mellitus in the puerperium, unspecified control
        "O24811",  # Other pre-existing diabetes mellitus in pregnancy, first trimester
        "O24812",  # Other pre-existing diabetes mellitus in pregnancy, second trimester
        "O24813",  # Other pre-existing diabetes mellitus in pregnancy, third trimester
        "O24819",  # Other pre-existing diabetes mellitus in pregnancy, unspecified trimester
        "O2482",  # Other pre-existing diabetes mellitus in childbirth
        "O2483",  # Other pre-existing diabetes mellitus in the puerperium
        "O24911",  # Unspecified diabetes mellitus in pregnancy, first trimester
        "O24912",  # Unspecified diabetes mellitus in pregnancy, second trimester
        "O24913",  # Unspecified diabetes mellitus in pregnancy, third trimester
        "O24919",  # Unspecified diabetes mellitus in pregnancy, unspecified trimester
        "O2492",  # Unspecified diabetes mellitus in childbirth
        "O2493",  # Unspecified diabetes mellitus in the puerperium
        "O2510",  # Malnutrition in pregnancy, unspecified trimester
        "O2511",  # Malnutrition in pregnancy, first trimester
        "O2512",  # Malnutrition in pregnancy, second trimester
        "O2513",  # Malnutrition in pregnancy, third trimester
        "O252",  # Malnutrition in childbirth
        "O253",  # Malnutrition in the puerperium
        "O2600",  # Excessive weight gain in pregnancy, unspecified trimester
        "O2601",  # Excessive weight gain in pregnancy, first trimester
        "O2602",  # Excessive weight gain in pregnancy, second trimester
        "O2603",  # Excessive weight gain in pregnancy, third trimester
        "O2610",  # Low weight gain in pregnancy, unspecified trimester
        "O2611",  # Low weight gain in pregnancy, first trimester
        "O2612",  # Low weight gain in pregnancy, second trimester
        "O2613",  # Low weight gain in pregnancy, third trimester
        "O2620",  # Pregnancy care for patient with recurrent pregnancy loss, unspecified trimester
        "O2621",  # Pregnancy care for patient with recurrent pregnancy loss, first trimester
        "O2622",  # Pregnancy care for patient with recurrent pregnancy loss, second trimester
        "O2623",  # Pregnancy care for patient with recurrent pregnancy loss, third trimester
        "O2630",  # Retained intrauterine contraceptive device in pregnancy, unspecified trimester
        "O2631",  # Retained intrauterine contraceptive device in pregnancy, first trimester
        "O2632",  # Retained intrauterine contraceptive device in pregnancy, second trimester
        "O2633",  # Retained intrauterine contraceptive device in pregnancy, third trimester
        "O2640",  # Herpes gestationis, unspecified trimester
        "O2641",  # Herpes gestationis, first trimester
        "O2642",  # Herpes gestationis, second trimester
        "O2643",  # Herpes gestationis, third trimester
        "O2650",  # Maternal hypotension syndrome, unspecified trimester
        "O2651",  # Maternal hypotension syndrome, first trimester
        "O2652",  # Maternal hypotension syndrome, second trimester
        "O2653",  # Maternal hypotension syndrome, third trimester
        "O26611",  # Liver and biliary tract disorders in pregnancy, first trimester
        "O26612",  # Liver and biliary tract disorders in pregnancy, second trimester
        "O26613",  # Liver and biliary tract disorders in pregnancy, third trimester
        "O26619",  # Liver and biliary tract disorders in pregnancy, unspecified trimester
        "O2662",  # Liver and biliary tract disorders in childbirth
        "O2663",  # Liver and biliary tract disorders in the puerperium
        "O26641",  # Intrahepatic cholestasis of pregnancy, first trimester
        "O26642",  # Intrahepatic cholestasis of pregnancy, second trimester
        "O26643",  # Intrahepatic cholestasis of pregnancy, third trimester
        "O26649",  # Intrahepatic cholestasis of pregnancy, unspecified trimester
        "O26711",  # Subluxation of symphysis (pubis) in pregnancy, first trimester
        "O26712",  # Subluxation of symphysis (pubis) in pregnancy, second trimester
        "O26713",  # Subluxation of symphysis (pubis) in pregnancy, third trimester
        "O26719",  # Subluxation of symphysis (pubis) in pregnancy, unspecified trimester
        "O2672",  # Subluxation of symphysis (pubis) in childbirth
        "O2673",  # Subluxation of symphysis (pubis) in the puerperium
        "O26811",  # Pregnancy related exhaustion and fatigue, first trimester
        "O26812",  # Pregnancy related exhaustion and fatigue, second trimester
        "O26813",  # Pregnancy related exhaustion and fatigue, third trimester
        "O26819",  # Pregnancy related exhaustion and fatigue, unspecified trimester
        "O26821",  # Pregnancy related peripheral neuritis, first trimester
        "O26822",  # Pregnancy related peripheral neuritis, second trimester
        "O26823",  # Pregnancy related peripheral neuritis, third trimester
        "O26829",  # Pregnancy related peripheral neuritis, unspecified trimester
        "O26831",  # Pregnancy related renal disease, first trimester
        "O26832",  # Pregnancy related renal disease, second trimester
        "O26833",  # Pregnancy related renal disease, third trimester
        "O26839",  # Pregnancy related renal disease, unspecified trimester
        "O26841",  # Uterine size-date discrepancy, first trimester
        "O26842",  # Uterine size-date discrepancy, second trimester
        "O26843",  # Uterine size-date discrepancy, third trimester
        "O26849",  # Uterine size-date discrepancy, unspecified trimester
        "O26851",  # Spotting complicating pregnancy, first trimester
        "O26852",  # Spotting complicating pregnancy, second trimester
        "O26853",  # Spotting complicating pregnancy, third trimester
        "O26859",  # Spotting complicating pregnancy, unspecified trimester
        "O2686",  # Pruritic urticarial papules and plaques of pregnancy (PUPPP)
        "O26872",  # Cervical shortening, second trimester
        "O26873",  # Cervical shortening, third trimester
        "O26879",  # Cervical shortening, unspecified trimester
        "O26891",  # Other specified pregnancy related conditions, first trimester
        "O26892",  # Other specified pregnancy related conditions, second trimester
        "O26893",  # Other specified pregnancy related conditions, third trimester
        "O26899",  # Other specified pregnancy related conditions, unspecified trimester
        "O2690",  # Pregnancy related conditions, unspecified, unspecified trimester
        "O2691",  # Pregnancy related conditions, unspecified, first trimester
        "O2692",  # Pregnancy related conditions, unspecified, second trimester
        "O2693",  # Pregnancy related conditions, unspecified, third trimester
        "O280",  # Abnormal hematological finding on antenatal screening of mother
        "O281",  # Abnormal biochemical finding on antenatal screening of mother
        "O282",  # Abnormal cytological finding on antenatal screening of mother
        "O283",  # Abnormal ultrasonic finding on antenatal screening of mother
        "O284",  # Abnormal radiological finding on antenatal screening of mother
        "O285",  # Abnormal chromosomal and genetic finding on antenatal screening of mother
        "O288",  # Other abnormal findings on antenatal screening of mother
        "O289",  # Unspecified abnormal findings on antenatal screening of mother
        "O29011",  # Aspiration pneumonitis due to anesthesia during pregnancy, first trimester
        "O29012",  # Aspiration pneumonitis due to anesthesia during pregnancy, second trimester
        "O29013",  # Aspiration pneumonitis due to anesthesia during pregnancy, third trimester
        "O29019",  # Aspiration pneumonitis due to anesthesia during pregnancy, unspecified trimester
        "O29021",  # Pressure collapse of lung due to anesthesia during pregnancy, first trimester
        "O29022",  # Pressure collapse of lung due to anesthesia during pregnancy, second trimester
        "O29023",  # Pressure collapse of lung due to anesthesia during pregnancy, third trimester
        "O29029",  # Pressure collapse of lung due to anesthesia during pregnancy, unspecified trimester
        "O29091",  # Other pulmonary complications of anesthesia during pregnancy, first trimester
        "O29092",  # Other pulmonary complications of anesthesia during pregnancy, second trimester
        "O29093",  # Other pulmonary complications of anesthesia during pregnancy, third trimester
        "O29099",  # Other pulmonary complications of anesthesia during pregnancy, unspecified trimester
        "O29111",  # Cardiac arrest due to anesthesia during pregnancy, first trimester
        "O29112",  # Cardiac arrest due to anesthesia during pregnancy, second trimester
        "O29113",  # Cardiac arrest due to anesthesia during pregnancy, third trimester
        "O29119",  # Cardiac arrest due to anesthesia during pregnancy, unspecified trimester
        "O29121",  # Cardiac failure due to anesthesia during pregnancy, first trimester
        "O29122",  # Cardiac failure due to anesthesia during pregnancy, second trimester
        "O29123",  # Cardiac failure due to anesthesia during pregnancy, third trimester
        "O29129",  # Cardiac failure due to anesthesia during pregnancy, unspecified trimester
        "O29191",  # Other cardiac complications of anesthesia during pregnancy, first trimester
        "O29192",  # Other cardiac complications of anesthesia during pregnancy, second trimester
        "O29193",  # Other cardiac complications of anesthesia during pregnancy, third trimester
        "O29199",  # Other cardiac complications of anesthesia during pregnancy, unspecified trimester
        "O29211",  # Cerebral anoxia due to anesthesia during pregnancy, first trimester
        "O29212",  # Cerebral anoxia due to anesthesia during pregnancy, second trimester
        "O29213",  # Cerebral anoxia due to anesthesia during pregnancy, third trimester
        "O29219",  # Cerebral anoxia due to anesthesia during pregnancy, unspecified trimester
        "O29291",  # Other central nervous system complications of anesthesia during pregnancy, first trimester
        "O29292",  # Other central nervous system complications of anesthesia during pregnancy, second trimester
        "O29293",  # Other central nervous system complications of anesthesia during pregnancy, third trimester
        "O29299",  # Other central nervous system complications of anesthesia during pregnancy, unspecified trimester
        "O293X1",  # Toxic reaction to local anesthesia during pregnancy, first trimester
        "O293X2",  # Toxic reaction to local anesthesia during pregnancy, second trimester
        "O293X3",  # Toxic reaction to local anesthesia during pregnancy, third trimester
        "O293X9",  # Toxic reaction to local anesthesia during pregnancy, unspecified trimester
        "O2940",  # Spinal and epidural anesthesia induced headache during pregnancy, unspecified trimester
        "O2941",  # Spinal and epidural anesthesia induced headache during pregnancy, first trimester
        "O2942",  # Spinal and epidural anesthesia induced headache during pregnancy, second trimester
        "O2943",  # Spinal and epidural anesthesia induced headache during pregnancy, third trimester
        "O295X1",  # Other complications of spinal and epidural anesthesia during pregnancy, first trimester
        "O295X2",  # Other complications of spinal and epidural anesthesia during pregnancy, second trimester
        "O295X3",  # Other complications of spinal and epidural anesthesia during pregnancy, third trimester
        "O295X9",  # Other complications of spinal and epidural anesthesia during pregnancy, unspecified trimester
        "O2960",  # Failed or difficult intubation for anesthesia during pregnancy, unspecified trimester
        "O2961",  # Failed or difficult intubation for anesthesia during pregnancy, first trimester
        "O2962",  # Failed or difficult intubation for anesthesia during pregnancy, second trimester
        "O2963",  # Failed or difficult intubation for anesthesia during pregnancy, third trimester
        "O298X1",  # Other complications of anesthesia during pregnancy, first trimester
        "O298X2",  # Other complications of anesthesia during pregnancy, second trimester
        "O298X3",  # Other complications of anesthesia during pregnancy, third trimester
        "O298X9",  # Other complications of anesthesia during pregnancy, unspecified trimester
        "O2990",  # Unspecified complication of anesthesia during pregnancy, unspecified trimester
        "O2991",  # Unspecified complication of anesthesia during pregnancy, first trimester
        "O2992",  # Unspecified complication of anesthesia during pregnancy, second trimester
        "O2993",  # Unspecified complication of anesthesia during pregnancy, third trimester
        "O30001",  # Twin pregnancy, unspecified number of placenta and unspecified number of amniotic sacs, first trimester
        "O30002",  # Twin pregnancy, unspecified number of placenta and unspecified number of amniotic sacs, second trimester
        "O30003",  # Twin pregnancy, unspecified number of placenta and unspecified number of amniotic sacs, third trimester
        "O30009",  # Twin pregnancy, unspecified number of placenta and unspecified number of amniotic sacs, unspecified trimester
        "O30011",  # Twin pregnancy, monochorionic/monoamniotic, first trimester
        "O30012",  # Twin pregnancy, monochorionic/monoamniotic, second trimester
        "O30013",  # Twin pregnancy, monochorionic/monoamniotic, third trimester
        "O30019",  # Twin pregnancy, monochorionic/monoamniotic, unspecified trimester
        "O30021",  # Conjoined twin pregnancy, first trimester
        "O30022",  # Conjoined twin pregnancy, second trimester
        "O30023",  # Conjoined twin pregnancy, third trimester
        "O30029",  # Conjoined twin pregnancy, unspecified trimester
        "O30031",  # Twin pregnancy, monochorionic/diamniotic, first trimester
        "O30032",  # Twin pregnancy, monochorionic/diamniotic, second trimester
        "O30033",  # Twin pregnancy, monochorionic/diamniotic, third trimester
        "O30039",  # Twin pregnancy, monochorionic/diamniotic, unspecified trimester
        "O30041",  # Twin pregnancy, dichorionic/diamniotic, first trimester
        "O30042",  # Twin pregnancy, dichorionic/diamniotic, second trimester
        "O30043",  # Twin pregnancy, dichorionic/diamniotic, third trimester
        "O30049",  # Twin pregnancy, dichorionic/diamniotic, unspecified trimester
        "O30091",  # Twin pregnancy, unable to determine number of placenta and number of amniotic sacs, first trimester
        "O30092",  # Twin pregnancy, unable to determine number of placenta and number of amniotic sacs, second trimester
        "O30093",  # Twin pregnancy, unable to determine number of placenta and number of amniotic sacs, third trimester
        "O30099",  # Twin pregnancy, unable to determine number of placenta and number of amniotic sacs, unspecified trimester
        "O30101",  # Triplet pregnancy, unspecified number of placenta and unspecified number of amniotic sacs, first trimester
        "O30102",  # Triplet pregnancy, unspecified number of placenta and unspecified number of amniotic sacs, second trimester
        "O30103",  # Triplet pregnancy, unspecified number of placenta and unspecified number of amniotic sacs, third trimester
        "O30109",  # Triplet pregnancy, unspecified number of placenta and unspecified number of amniotic sacs, unspecified trimester
        "O30111",  # Triplet pregnancy with two or more monochorionic fetuses, first trimester
        "O30112",  # Triplet pregnancy with two or more monochorionic fetuses, second trimester
        "O30113",  # Triplet pregnancy with two or more monochorionic fetuses, third trimester
        "O30119",  # Triplet pregnancy with two or more monochorionic fetuses, unspecified trimester
        "O30121",  # Triplet pregnancy with two or more monoamniotic fetuses, first trimester
        "O30122",  # Triplet pregnancy with two or more monoamniotic fetuses, second trimester
        "O30123",  # Triplet pregnancy with two or more monoamniotic fetuses, third trimester
        "O30129",  # Triplet pregnancy with two or more monoamniotic fetuses, unspecified trimester
        "O30131",  # Triplet pregnancy, trichorionic/triamniotic, first trimester
        "O30132",  # Triplet pregnancy, trichorionic/triamniotic, second trimester
        "O30133",  # Triplet pregnancy, trichorionic/triamniotic, third trimester
        "O30139",  # Triplet pregnancy, trichorionic/triamniotic, unspecified trimester
        "O30191",  # Triplet pregnancy, unable to determine number of placenta and number of amniotic sacs, first trimester
        "O30192",  # Triplet pregnancy, unable to determine number of placenta and number of amniotic sacs, second trimester
        "O30193",  # Triplet pregnancy, unable to determine number of placenta and number of amniotic sacs, third trimester
        "O30199",  # Triplet pregnancy, unable to determine number of placenta and number of amniotic sacs, unspecified trimester
        "O30201",  # Quadruplet pregnancy, unspecified number of placenta and unspecified number of amniotic sacs, first trimester
        "O30202",  # Quadruplet pregnancy, unspecified number of placenta and unspecified number of amniotic sacs, second trimester
        "O30203",  # Quadruplet pregnancy, unspecified number of placenta and unspecified number of amniotic sacs, third trimester
        "O30209",  # Quadruplet pregnancy, unspecified number of placenta and unspecified number of amniotic sacs, unspecified trimester
        "O30211",  # Quadruplet pregnancy with two or more monochorionic fetuses, first trimester
        "O30212",  # Quadruplet pregnancy with two or more monochorionic fetuses, second trimester
        "O30213",  # Quadruplet pregnancy with two or more monochorionic fetuses, third trimester
        "O30219",  # Quadruplet pregnancy with two or more monochorionic fetuses, unspecified trimester
        "O30221",  # Quadruplet pregnancy with two or more monoamniotic fetuses, first trimester
        "O30222",  # Quadruplet pregnancy with two or more monoamniotic fetuses, second trimester
        "O30223",  # Quadruplet pregnancy with two or more monoamniotic fetuses, third trimester
        "O30229",  # Quadruplet pregnancy with two or more monoamniotic fetuses, unspecified trimester
        "O30231",  # Quadruplet pregnancy, quadrachorionic/quadra-amniotic, first trimester
        "O30232",  # Quadruplet pregnancy, quadrachorionic/quadra-amniotic, second trimester
        "O30233",  # Quadruplet pregnancy, quadrachorionic/quadra-amniotic, third trimester
        "O30239",  # Quadruplet pregnancy, quadrachorionic/quadra-amniotic, unspecified trimester
        "O30291",  # Quadruplet pregnancy, unable to determine number of placenta and number of amniotic sacs, first trimester
        "O30292",  # Quadruplet pregnancy, unable to determine number of placenta and number of amniotic sacs, second trimester
        "O30293",  # Quadruplet pregnancy, unable to determine number of placenta and number of amniotic sacs, third trimester
        "O30299",  # Quadruplet pregnancy, unable to determine number of placenta and number of amniotic sacs, unspecified trimester
        "O30801",  # Other specified multiple gestation, unspecified number of placenta and unspecified number of amniotic sacs, first trimester
        "O30802",  # Other specified multiple gestation, unspecified number of placenta and unspecified number of amniotic sacs, second trimester
        "O30803",  # Other specified multiple gestation, unspecified number of placenta and unspecified number of amniotic sacs, third trimester
        "O30809",  # Other specified multiple gestation, unspecified number of placenta and unspecified number of amniotic sacs, unspecified trimester
        "O30811",  # Other specified multiple gestation with two or more monochorionic fetuses, first trimester
        "O30812",  # Other specified multiple gestation with two or more monochorionic fetuses, second trimester
        "O30813",  # Other specified multiple gestation with two or more monochorionic fetuses, third trimester
        "O30819",  # Other specified multiple gestation with two or more monochorionic fetuses, unspecified trimester
        "O30821",  # Other specified multiple gestation with two or more monoamniotic fetuses, first trimester
        "O30822",  # Other specified multiple gestation with two or more monoamniotic fetuses, second trimester
        "O30823",  # Other specified multiple gestation with two or more monoamniotic fetuses, third trimester
        "O30829",  # Other specified multiple gestation with two or more monoamniotic fetuses, unspecified trimester
        "O30831",  # Other specified multiple gestation, number of chorions and amnions are both equal to the number of fetuses, first trimester
        "O30832",  # Other specified multiple gestation, number of chorions and amnions are both equal to the number of fetuses, second trimester
        "O30833",  # Other specified multiple gestation, number of chorions and amnions are both equal to the number of fetuses, third trimester
        "O30839",  # Other specified multiple gestation, number of chorions and amnions are both equal to the number of fetuses, unspecified trimester
        "O30891",  # Other specified multiple gestation, unable to determine number of placenta and number of amniotic sacs, first trimester
        "O30892",  # Other specified multiple gestation, unable to determine number of placenta and number of amniotic sacs, second trimester
        "O30893",  # Other specified multiple gestation, unable to determine number of placenta and number of amniotic sacs, third trimester
        "O30899",  # Other specified multiple gestation, unable to determine number of placenta and number of amniotic sacs, unspecified trimester
        "O3090",  # Multiple gestation, unspecified, unspecified trimester
        "O3091",  # Multiple gestation, unspecified, first trimester
        "O3092",  # Multiple gestation, unspecified, second trimester
        "O3093",  # Multiple gestation, unspecified, third trimester
        "O3100X0",  # Papyraceous fetus, unspecified trimester, not applicable or unspecified
        "O3100X1",  # Papyraceous fetus, unspecified trimester, fetus 1
        "O3100X2",  # Papyraceous fetus, unspecified trimester, fetus 2
        "O3100X3",  # Papyraceous fetus, unspecified trimester, fetus 3
        "O3100X4",  # Papyraceous fetus, unspecified trimester, fetus 4
        "O3100X5",  # Papyraceous fetus, unspecified trimester, fetus 5
        "O3100X9",  # Papyraceous fetus, unspecified trimester, other fetus
        "O3101X0",  # Papyraceous fetus, first trimester, not applicable or unspecified
        "O3101X1",  # Papyraceous fetus, first trimester, fetus 1
        "O3101X2",  # Papyraceous fetus, first trimester, fetus 2
        "O3101X3",  # Papyraceous fetus, first trimester, fetus 3
        "O3101X4",  # Papyraceous fetus, first trimester, fetus 4
        "O3101X5",  # Papyraceous fetus, first trimester, fetus 5
        "O3101X9",  # Papyraceous fetus, first trimester, other fetus
        "O3102X0",  # Papyraceous fetus, second trimester, not applicable or unspecified
        "O3102X1",  # Papyraceous fetus, second trimester, fetus 1
        "O3102X2",  # Papyraceous fetus, second trimester, fetus 2
        "O3102X3",  # Papyraceous fetus, second trimester, fetus 3
        "O3102X4",  # Papyraceous fetus, second trimester, fetus 4
        "O3102X5",  # Papyraceous fetus, second trimester, fetus 5
        "O3102X9",  # Papyraceous fetus, second trimester, other fetus
        "O3103X0",  # Papyraceous fetus, third trimester, not applicable or unspecified
        "O3103X1",  # Papyraceous fetus, third trimester, fetus 1
        "O3103X2",  # Papyraceous fetus, third trimester, fetus 2
        "O3103X3",  # Papyraceous fetus, third trimester, fetus 3
        "O3103X4",  # Papyraceous fetus, third trimester, fetus 4
        "O3103X5",  # Papyraceous fetus, third trimester, fetus 5
        "O3103X9",  # Papyraceous fetus, third trimester, other fetus
        "O3110X0",  # Continuing pregnancy after spontaneous abortion of one fetus or more, unspecified trimester, not applicable or unspecified
        "O3110X1",  # Continuing pregnancy after spontaneous abortion of one fetus or more, unspecified trimester, fetus 1
        "O3110X2",  # Continuing pregnancy after spontaneous abortion of one fetus or more, unspecified trimester, fetus 2
        "O3110X3",  # Continuing pregnancy after spontaneous abortion of one fetus or more, unspecified trimester, fetus 3
        "O3110X4",  # Continuing pregnancy after spontaneous abortion of one fetus or more, unspecified trimester, fetus 4
        "O3110X5",  # Continuing pregnancy after spontaneous abortion of one fetus or more, unspecified trimester, fetus 5
        "O3110X9",  # Continuing pregnancy after spontaneous abortion of one fetus or more, unspecified trimester, other fetus
        "O3111X0",  # Continuing pregnancy after spontaneous abortion of one fetus or more, first trimester, not applicable or unspecified
        "O3111X1",  # Continuing pregnancy after spontaneous abortion of one fetus or more, first trimester, fetus 1
        "O3111X2",  # Continuing pregnancy after spontaneous abortion of one fetus or more, first trimester, fetus 2
        "O3111X3",  # Continuing pregnancy after spontaneous abortion of one fetus or more, first trimester, fetus 3
        "O3111X4",  # Continuing pregnancy after spontaneous abortion of one fetus or more, first trimester, fetus 4
        "O3111X5",  # Continuing pregnancy after spontaneous abortion of one fetus or more, first trimester, fetus 5
        "O3111X9",  # Continuing pregnancy after spontaneous abortion of one fetus or more, first trimester, other fetus
        "O3112X0",  # Continuing pregnancy after spontaneous abortion of one fetus or more, second trimester, not applicable or unspecified
        "O3112X1",  # Continuing pregnancy after spontaneous abortion of one fetus or more, second trimester, fetus 1
        "O3112X2",  # Continuing pregnancy after spontaneous abortion of one fetus or more, second trimester, fetus 2
        "O3112X3",  # Continuing pregnancy after spontaneous abortion of one fetus or more, second trimester, fetus 3
        "O3112X4",  # Continuing pregnancy after spontaneous abortion of one fetus or more, second trimester, fetus 4
        "O3112X5",  # Continuing pregnancy after spontaneous abortion of one fetus or more, second trimester, fetus 5
        "O3112X9",  # Continuing pregnancy after spontaneous abortion of one fetus or more, second trimester, other fetus
        "O3113X0",  # Continuing pregnancy after spontaneous abortion of one fetus or more, third trimester, not applicable or unspecified
        "O3113X1",  # Continuing pregnancy after spontaneous abortion of one fetus or more, third trimester, fetus 1
        "O3113X2",  # Continuing pregnancy after spontaneous abortion of one fetus or more, third trimester, fetus 2
        "O3113X3",  # Continuing pregnancy after spontaneous abortion of one fetus or more, third trimester, fetus 3
        "O3113X4",  # Continuing pregnancy after spontaneous abortion of one fetus or more, third trimester, fetus 4
        "O3113X5",  # Continuing pregnancy after spontaneous abortion of one fetus or more, third trimester, fetus 5
        "O3113X9",  # Continuing pregnancy after spontaneous abortion of one fetus or more, third trimester, other fetus
        "O3120X0",  # Continuing pregnancy after intrauterine death of one fetus or more, unspecified trimester, not applicable or unspecified
        "O3120X1",  # Continuing pregnancy after intrauterine death of one fetus or more, unspecified trimester, fetus 1
        "O3120X2",  # Continuing pregnancy after intrauterine death of one fetus or more, unspecified trimester, fetus 2
        "O3120X3",  # Continuing pregnancy after intrauterine death of one fetus or more, unspecified trimester, fetus 3
        "O3120X4",  # Continuing pregnancy after intrauterine death of one fetus or more, unspecified trimester, fetus 4
        "O3120X5",  # Continuing pregnancy after intrauterine death of one fetus or more, unspecified trimester, fetus 5
        "O3120X9",  # Continuing pregnancy after intrauterine death of one fetus or more, unspecified trimester, other fetus
        "O3121X0",  # Continuing pregnancy after intrauterine death of one fetus or more, first trimester, not applicable or unspecified
        "O3121X1",  # Continuing pregnancy after intrauterine death of one fetus or more, first trimester, fetus 1
        "O3121X2",  # Continuing pregnancy after intrauterine death of one fetus or more, first trimester, fetus 2
        "O3121X3",  # Continuing pregnancy after intrauterine death of one fetus or more, first trimester, fetus 3
        "O3121X4",  # Continuing pregnancy after intrauterine death of one fetus or more, first trimester, fetus 4
        "O3121X5",  # Continuing pregnancy after intrauterine death of one fetus or more, first trimester, fetus 5
        "O3121X9",  # Continuing pregnancy after intrauterine death of one fetus or more, first trimester, other fetus
        "O3122X0",  # Continuing pregnancy after intrauterine death of one fetus or more, second trimester, not applicable or unspecified
        "O3122X1",  # Continuing pregnancy after intrauterine death of one fetus or more, second trimester, fetus 1
        "O3122X2",  # Continuing pregnancy after intrauterine death of one fetus or more, second trimester, fetus 2
        "O3122X3",  # Continuing pregnancy after intrauterine death of one fetus or more, second trimester, fetus 3
        "O3122X4",  # Continuing pregnancy after intrauterine death of one fetus or more, second trimester, fetus 4
        "O3122X5",  # Continuing pregnancy after intrauterine death of one fetus or more, second trimester, fetus 5
        "O3122X9",  # Continuing pregnancy after intrauterine death of one fetus or more, second trimester, other fetus
        "O3123X0",  # Continuing pregnancy after intrauterine death of one fetus or more, third trimester, not applicable or unspecified
        "O3123X1",  # Continuing pregnancy after intrauterine death of one fetus or more, third trimester, fetus 1
        "O3123X2",  # Continuing pregnancy after intrauterine death of one fetus or more, third trimester, fetus 2
        "O3123X3",  # Continuing pregnancy after intrauterine death of one fetus or more, third trimester, fetus 3
        "O3123X4",  # Continuing pregnancy after intrauterine death of one fetus or more, third trimester, fetus 4
        "O3123X5",  # Continuing pregnancy after intrauterine death of one fetus or more, third trimester, fetus 5
        "O3123X9",  # Continuing pregnancy after intrauterine death of one fetus or more, third trimester, other fetus
        "O3130X0",  # Continuing pregnancy after elective fetal reduction of one fetus or more, unspecified trimester, not applicable or unspecified
        "O3130X1",  # Continuing pregnancy after elective fetal reduction of one fetus or more, unspecified trimester, fetus 1
        "O3130X2",  # Continuing pregnancy after elective fetal reduction of one fetus or more, unspecified trimester, fetus 2
        "O3130X3",  # Continuing pregnancy after elective fetal reduction of one fetus or more, unspecified trimester, fetus 3
        "O3130X4",  # Continuing pregnancy after elective fetal reduction of one fetus or more, unspecified trimester, fetus 4
        "O3130X5",  # Continuing pregnancy after elective fetal reduction of one fetus or more, unspecified trimester, fetus 5
        "O3130X9",  # Continuing pregnancy after elective fetal reduction of one fetus or more, unspecified trimester, other fetus
        "O3131X0",  # Continuing pregnancy after elective fetal reduction of one fetus or more, first trimester, not applicable or unspecified
        "O3131X1",  # Continuing pregnancy after elective fetal reduction of one fetus or more, first trimester, fetus 1
        "O3131X2",  # Continuing pregnancy after elective fetal reduction of one fetus or more, first trimester, fetus 2
        "O3131X3",  # Continuing pregnancy after elective fetal reduction of one fetus or more, first trimester, fetus 3
        "O3131X4",  # Continuing pregnancy after elective fetal reduction of one fetus or more, first trimester, fetus 4
        "O3131X5",  # Continuing pregnancy after elective fetal reduction of one fetus or more, first trimester, fetus 5
        "O3131X9",  # Continuing pregnancy after elective fetal reduction of one fetus or more, first trimester, other fetus
        "O3132X0",  # Continuing pregnancy after elective fetal reduction of one fetus or more, second trimester, not applicable or unspecified
        "O3132X1",  # Continuing pregnancy after elective fetal reduction of one fetus or more, second trimester, fetus 1
        "O3132X2",  # Continuing pregnancy after elective fetal reduction of one fetus or more, second trimester, fetus 2
        "O3132X3",  # Continuing pregnancy after elective fetal reduction of one fetus or more, second trimester, fetus 3
        "O3132X4",  # Continuing pregnancy after elective fetal reduction of one fetus or more, second trimester, fetus 4
        "O3132X5",  # Continuing pregnancy after elective fetal reduction of one fetus or more, second trimester, fetus 5
        "O3132X9",  # Continuing pregnancy after elective fetal reduction of one fetus or more, second trimester, other fetus
        "O3133X0",  # Continuing pregnancy after elective fetal reduction of one fetus or more, third trimester, not applicable or unspecified
        "O3133X1",  # Continuing pregnancy after elective fetal reduction of one fetus or more, third trimester, fetus 1
        "O3133X2",  # Continuing pregnancy after elective fetal reduction of one fetus or more, third trimester, fetus 2
        "O3133X3",  # Continuing pregnancy after elective fetal reduction of one fetus or more, third trimester, fetus 3
        "O3133X4",  # Continuing pregnancy after elective fetal reduction of one fetus or more, third trimester, fetus 4
        "O3133X5",  # Continuing pregnancy after elective fetal reduction of one fetus or more, third trimester, fetus 5
        "O3133X9",  # Continuing pregnancy after elective fetal reduction of one fetus or more, third trimester, other fetus
        "O318X10",  # Other complications specific to multiple gestation, first trimester, not applicable or unspecified
        "O318X11",  # Other complications specific to multiple gestation, first trimester, fetus 1
        "O318X12",  # Other complications specific to multiple gestation, first trimester, fetus 2
        "O318X13",  # Other complications specific to multiple gestation, first trimester, fetus 3
        "O318X14",  # Other complications specific to multiple gestation, first trimester, fetus 4
        "O318X15",  # Other complications specific to multiple gestation, first trimester, fetus 5
        "O318X19",  # Other complications specific to multiple gestation, first trimester, other fetus
        "O318X20",  # Other complications specific to multiple gestation, second trimester, not applicable or unspecified
        "O318X21",  # Other complications specific to multiple gestation, second trimester, fetus 1
        "O318X22",  # Other complications specific to multiple gestation, second trimester, fetus 2
        "O318X23",  # Other complications specific to multiple gestation, second trimester, fetus 3
        "O318X24",  # Other complications specific to multiple gestation, second trimester, fetus 4
        "O318X25",  # Other complications specific to multiple gestation, second trimester, fetus 5
        "O318X29",  # Other complications specific to multiple gestation, second trimester, other fetus
        "O318X30",  # Other complications specific to multiple gestation, third trimester, not applicable or unspecified
        "O318X31",  # Other complications specific to multiple gestation, third trimester, fetus 1
        "O318X32",  # Other complications specific to multiple gestation, third trimester, fetus 2
        "O318X33",  # Other complications specific to multiple gestation, third trimester, fetus 3
        "O318X34",  # Other complications specific to multiple gestation, third trimester, fetus 4
        "O318X35",  # Other complications specific to multiple gestation, third trimester, fetus 5
        "O318X39",  # Other complications specific to multiple gestation, third trimester, other fetus
        "O318X90",  # Other complications specific to multiple gestation, unspecified trimester, not applicable or unspecified
        "O318X91",  # Other complications specific to multiple gestation, unspecified trimester, fetus 1
        "O318X92",  # Other complications specific to multiple gestation, unspecified trimester, fetus 2
        "O318X93",  # Other complications specific to multiple gestation, unspecified trimester, fetus 3
        "O318X94",  # Other complications specific to multiple gestation, unspecified trimester, fetus 4
        "O318X95",  # Other complications specific to multiple gestation, unspecified trimester, fetus 5
        "O318X99",  # Other complications specific to multiple gestation, unspecified trimester, other fetus
        "O320XX0",  # Maternal care for unstable lie, not applicable or unspecified
        "O320XX1",  # Maternal care for unstable lie, fetus 1
        "O320XX2",  # Maternal care for unstable lie, fetus 2
        "O320XX3",  # Maternal care for unstable lie, fetus 3
        "O320XX4",  # Maternal care for unstable lie, fetus 4
        "O320XX5",  # Maternal care for unstable lie, fetus 5
        "O320XX9",  # Maternal care for unstable lie, other fetus
        "O321XX0",  # Maternal care for breech presentation, not applicable or unspecified
        "O321XX1",  # Maternal care for breech presentation, fetus 1
        "O321XX2",  # Maternal care for breech presentation, fetus 2
        "O321XX3",  # Maternal care for breech presentation, fetus 3
        "O321XX4",  # Maternal care for breech presentation, fetus 4
        "O321XX5",  # Maternal care for breech presentation, fetus 5
        "O321XX9",  # Maternal care for breech presentation, other fetus
        "O322XX0",  # Maternal care for transverse and oblique lie, not applicable or unspecified
        "O322XX1",  # Maternal care for transverse and oblique lie, fetus 1
        "O322XX2",  # Maternal care for transverse and oblique lie, fetus 2
        "O322XX3",  # Maternal care for transverse and oblique lie, fetus 3
        "O322XX4",  # Maternal care for transverse and oblique lie, fetus 4
        "O322XX5",  # Maternal care for transverse and oblique lie, fetus 5
        "O322XX9",  # Maternal care for transverse and oblique lie, other fetus
        "O323XX0",  # Maternal care for face, brow and chin presentation, not applicable or unspecified
        "O323XX1",  # Maternal care for face, brow and chin presentation, fetus 1
        "O323XX2",  # Maternal care for face, brow and chin presentation, fetus 2
        "O323XX3",  # Maternal care for face, brow and chin presentation, fetus 3
        "O323XX4",  # Maternal care for face, brow and chin presentation, fetus 4
        "O323XX5",  # Maternal care for face, brow and chin presentation, fetus 5
        "O323XX9",  # Maternal care for face, brow and chin presentation, other fetus
        "O324XX0",  # Maternal care for high head at term, not applicable or unspecified
        "O324XX1",  # Maternal care for high head at term, fetus 1
        "O324XX2",  # Maternal care for high head at term, fetus 2
        "O324XX3",  # Maternal care for high head at term, fetus 3
        "O324XX4",  # Maternal care for high head at term, fetus 4
        "O324XX5",  # Maternal care for high head at term, fetus 5
        "O324XX9",  # Maternal care for high head at term, other fetus
        "O326XX0",  # Maternal care for compound presentation, not applicable or unspecified
        "O326XX1",  # Maternal care for compound presentation, fetus 1
        "O326XX2",  # Maternal care for compound presentation, fetus 2
        "O326XX3",  # Maternal care for compound presentation, fetus 3
        "O326XX4",  # Maternal care for compound presentation, fetus 4
        "O326XX5",  # Maternal care for compound presentation, fetus 5
        "O326XX9",  # Maternal care for compound presentation, other fetus
        "O328XX0",  # Maternal care for other malpresentation of fetus, not applicable or unspecified
        "O328XX1",  # Maternal care for other malpresentation of fetus, fetus 1
        "O328XX2",  # Maternal care for other malpresentation of fetus, fetus 2
        "O328XX3",  # Maternal care for other malpresentation of fetus, fetus 3
        "O328XX4",  # Maternal care for other malpresentation of fetus, fetus 4
        "O328XX5",  # Maternal care for other malpresentation of fetus, fetus 5
        "O328XX9",  # Maternal care for other malpresentation of fetus, other fetus
        "O329XX0",  # Maternal care for malpresentation of fetus, unspecified, not applicable or unspecified
        "O329XX1",  # Maternal care for malpresentation of fetus, unspecified, fetus 1
        "O329XX2",  # Maternal care for malpresentation of fetus, unspecified, fetus 2
        "O329XX3",  # Maternal care for malpresentation of fetus, unspecified, fetus 3
        "O329XX4",  # Maternal care for malpresentation of fetus, unspecified, fetus 4
        "O329XX5",  # Maternal care for malpresentation of fetus, unspecified, fetus 5
        "O329XX9",  # Maternal care for malpresentation of fetus, unspecified, other fetus
        "O330",  # Maternal care for disproportion due to deformity of maternal pelvic bones
        "O331",  # Maternal care for disproportion due to generally contracted pelvis
        "O332",  # Maternal care for disproportion due to inlet contraction of pelvis
        "O333XX0",  # Maternal care for disproportion due to outlet contraction of pelvis, not applicable or unspecified
        "O333XX1",  # Maternal care for disproportion due to outlet contraction of pelvis, fetus 1
        "O333XX2",  # Maternal care for disproportion due to outlet contraction of pelvis, fetus 2
        "O333XX3",  # Maternal care for disproportion due to outlet contraction of pelvis, fetus 3
        "O333XX4",  # Maternal care for disproportion due to outlet contraction of pelvis, fetus 4
        "O333XX5",  # Maternal care for disproportion due to outlet contraction of pelvis, fetus 5
        "O333XX9",  # Maternal care for disproportion due to outlet contraction of pelvis, other fetus
        "O334XX0",  # Maternal care for disproportion of mixed maternal and fetal origin, not applicable or unspecified
        "O334XX1",  # Maternal care for disproportion of mixed maternal and fetal origin, fetus 1
        "O334XX2",  # Maternal care for disproportion of mixed maternal and fetal origin, fetus 2
        "O334XX3",  # Maternal care for disproportion of mixed maternal and fetal origin, fetus 3
        "O334XX4",  # Maternal care for disproportion of mixed maternal and fetal origin, fetus 4
        "O334XX5",  # Maternal care for disproportion of mixed maternal and fetal origin, fetus 5
        "O334XX9",  # Maternal care for disproportion of mixed maternal and fetal origin, other fetus
        "O335XX0",  # Maternal care for disproportion due to unusually large fetus, not applicable or unspecified
        "O335XX1",  # Maternal care for disproportion due to unusually large fetus, fetus 1
        "O335XX2",  # Maternal care for disproportion due to unusually large fetus, fetus 2
        "O335XX3",  # Maternal care for disproportion due to unusually large fetus, fetus 3
        "O335XX4",  # Maternal care for disproportion due to unusually large fetus, fetus 4
        "O335XX5",  # Maternal care for disproportion due to unusually large fetus, fetus 5
        "O335XX9",  # Maternal care for disproportion due to unusually large fetus, other fetus
        "O336XX0",  # Maternal care for disproportion due to hydrocephalic fetus, not applicable or unspecified
        "O336XX1",  # Maternal care for disproportion due to hydrocephalic fetus, fetus 1
        "O336XX2",  # Maternal care for disproportion due to hydrocephalic fetus, fetus 2
        "O336XX3",  # Maternal care for disproportion due to hydrocephalic fetus, fetus 3
        "O336XX4",  # Maternal care for disproportion due to hydrocephalic fetus, fetus 4
        "O336XX5",  # Maternal care for disproportion due to hydrocephalic fetus, fetus 5
        "O336XX9",  # Maternal care for disproportion due to hydrocephalic fetus, other fetus
        "O337XX0",  # Maternal care for disproportion due to other fetal deformities, not applicable or unspecified
        "O337XX1",  # Maternal care for disproportion due to other fetal deformities, fetus 1
        "O337XX2",  # Maternal care for disproportion due to other fetal deformities, fetus 2
        "O337XX3",  # Maternal care for disproportion due to other fetal deformities, fetus 3
        "O337XX4",  # Maternal care for disproportion due to other fetal deformities, fetus 4
        "O337XX5",  # Maternal care for disproportion due to other fetal deformities, fetus 5
        "O337XX9",  # Maternal care for disproportion due to other fetal deformities, other fetus
        "O338",  # Maternal care for disproportion of other origin
        "O339",  # Maternal care for disproportion, unspecified
        "O3400",  # Maternal care for unspecified congenital malformation of uterus, unspecified trimester
        "O3401",  # Maternal care for unspecified congenital malformation of uterus, first trimester
        "O3402",  # Maternal care for unspecified congenital malformation of uterus, second trimester
        "O3403",  # Maternal care for unspecified congenital malformation of uterus, third trimester
        "O3410",  # Maternal care for benign tumor of corpus uteri, unspecified trimester
        "O3411",  # Maternal care for benign tumor of corpus uteri, first trimester
        "O3412",  # Maternal care for benign tumor of corpus uteri, second trimester
        "O3413",  # Maternal care for benign tumor of corpus uteri, third trimester
        "O34211",  # Maternal care for low transverse scar from previous cesarean delivery
        "O34212",  # Maternal care for vertical scar from previous cesarean delivery
        "O34218",  # Maternal care for other type scar from previous cesarean delivery
        "O34219",  # Maternal care for unspecified type scar from previous cesarean delivery
        "O3422",  # Maternal care for cesarean scar defect (isthmocele)
        "O3429",  # Maternal care due to uterine scar from other previous surgery
        "O3430",  # Maternal care for cervical incompetence, unspecified trimester
        "O3431",  # Maternal care for cervical incompetence, first trimester
        "O3432",  # Maternal care for cervical incompetence, second trimester
        "O3433",  # Maternal care for cervical incompetence, third trimester
        "O3440",  # Maternal care for other abnormalities of cervix, unspecified trimester
        "O3441",  # Maternal care for other abnormalities of cervix, first trimester
        "O3442",  # Maternal care for other abnormalities of cervix, second trimester
        "O3443",  # Maternal care for other abnormalities of cervix, third trimester
        "O34511",  # Maternal care for incarceration of gravid uterus, first trimester
        "O34512",  # Maternal care for incarceration of gravid uterus, second trimester
        "O34513",  # Maternal care for incarceration of gravid uterus, third trimester
        "O34519",  # Maternal care for incarceration of gravid uterus, unspecified trimester
        "O34521",  # Maternal care for prolapse of gravid uterus, first trimester
        "O34522",  # Maternal care for prolapse of gravid uterus, second trimester
        "O34523",  # Maternal care for prolapse of gravid uterus, third trimester
        "O34529",  # Maternal care for prolapse of gravid uterus, unspecified trimester
        "O34531",  # Maternal care for retroversion of gravid uterus, first trimester
        "O34532",  # Maternal care for retroversion of gravid uterus, second trimester
        "O34533",  # Maternal care for retroversion of gravid uterus, third trimester
        "O34539",  # Maternal care for retroversion of gravid uterus, unspecified trimester
        "O34591",  # Maternal care for other abnormalities of gravid uterus, first trimester
        "O34592",  # Maternal care for other abnormalities of gravid uterus, second trimester
        "O34593",  # Maternal care for other abnormalities of gravid uterus, third trimester
        "O34599",  # Maternal care for other abnormalities of gravid uterus, unspecified trimester
        "O3460",  # Maternal care for abnormality of vagina, unspecified trimester
        "O3461",  # Maternal care for abnormality of vagina, first trimester
        "O3462",  # Maternal care for abnormality of vagina, second trimester
        "O3463",  # Maternal care for abnormality of vagina, third trimester
        "O3470",  # Maternal care for abnormality of vulva and perineum, unspecified trimester
        "O3471",  # Maternal care for abnormality of vulva and perineum, first trimester
        "O3472",  # Maternal care for abnormality of vulva and perineum, second trimester
        "O3473",  # Maternal care for abnormality of vulva and perineum, third trimester
        "O3480",  # Maternal care for other abnormalities of pelvic organs, unspecified trimester
        "O3481",  # Maternal care for other abnormalities of pelvic organs, first trimester
        "O3482",  # Maternal care for other abnormalities of pelvic organs, second trimester
        "O3483",  # Maternal care for other abnormalities of pelvic organs, third trimester
        "O3490",  # Maternal care for abnormality of pelvic organ, unspecified, unspecified trimester
        "O3491",  # Maternal care for abnormality of pelvic organ, unspecified, first trimester
        "O3492",  # Maternal care for abnormality of pelvic organ, unspecified, second trimester
        "O3493",  # Maternal care for abnormality of pelvic organ, unspecified, third trimester
        "O3500X0",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, unspecified, not applicable or unspecified
        "O3500X1",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, unspecified, fetus 1
        "O3500X2",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, unspecified, fetus 2
        "O3500X3",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, unspecified, fetus 3
        "O3500X4",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, unspecified, fetus 4
        "O3500X5",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, unspecified, fetus 5
        "O3500X9",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, unspecified, other fetus
        "O3501X0",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, agenesis of the corpus callosum, not applicable or unspecified
        "O3501X1",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, agenesis of the corpus callosum, fetus 1
        "O3501X2",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, agenesis of the corpus callosum, fetus 2
        "O3501X3",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, agenesis of the corpus callosum, fetus 3
        "O3501X4",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, agenesis of the corpus callosum, fetus 4
        "O3501X5",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, agenesis of the corpus callosum, fetus 5
        "O3501X9",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, agenesis of the corpus callosum, other fetus
        "O3502X0",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, anencephaly, not applicable or unspecified
        "O3502X1",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, anencephaly, fetus 1
        "O3502X2",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, anencephaly, fetus 2
        "O3502X3",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, anencephaly, fetus 3
        "O3502X4",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, anencephaly, fetus 4
        "O3502X5",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, anencephaly, fetus 5
        "O3502X9",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, anencephaly, other fetus
        "O3503X0",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, choroid plexus cysts, not applicable or unspecified
        "O3503X1",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, choroid plexus cysts, fetus 1
        "O3503X2",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, choroid plexus cysts, fetus 2
        "O3503X3",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, choroid plexus cysts, fetus 3
        "O3503X4",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, choroid plexus cysts, fetus 4
        "O3503X5",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, choroid plexus cysts, fetus 5
        "O3503X9",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, choroid plexus cysts, other fetus
        "O3504X0",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, encephalocele, not applicable or unspecified
        "O3504X1",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, encephalocele, fetus 1
        "O3504X2",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, encephalocele, fetus 2
        "O3504X3",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, encephalocele, fetus 3
        "O3504X4",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, encephalocele, fetus 4
        "O3504X5",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, encephalocele, fetus 5
        "O3504X9",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, encephalocele, other fetus
        "O3505X0",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, holoprosencephaly, not applicable or unspecified
        "O3505X1",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, holoprosencephaly, fetus 1
        "O3505X2",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, holoprosencephaly, fetus 2
        "O3505X3",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, holoprosencephaly, fetus 3
        "O3505X4",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, holoprosencephaly, fetus 4
        "O3505X5",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, holoprosencephaly, fetus 5
        "O3505X9",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, holoprosencephaly, other fetus
        "O3506X0",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, hydrocephaly, not applicable or unspecified
        "O3506X1",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, hydrocephaly, fetus 1
        "O3506X2",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, hydrocephaly, fetus 2
        "O3506X3",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, hydrocephaly, fetus 3
        "O3506X4",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, hydrocephaly, fetus 4
        "O3506X5",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, hydrocephaly, fetus 5
        "O3506X9",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, hydrocephaly, other fetus
        "O3507X0",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, microcephaly, not applicable or unspecified
        "O3507X1",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, microcephaly, fetus 1
        "O3507X2",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, microcephaly, fetus 2
        "O3507X3",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, microcephaly, fetus 3
        "O3507X4",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, microcephaly, fetus 4
        "O3507X5",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, microcephaly, fetus 5
        "O3507X9",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, microcephaly, other fetus
        "O3508X0",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, spina bifida, not applicable or unspecified
        "O3508X1",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, spina bifida, fetus 1
        "O3508X2",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, spina bifida, fetus 2
        "O3508X3",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, spina bifida, fetus 3
        "O3508X4",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, spina bifida, fetus 4
        "O3508X5",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, spina bifida, fetus 5
        "O3508X9",  # Maternal care for (suspected) central nervous system malformation or damage in fetus, spina bifida, other fetus
        "O3509X0",  # Maternal care for (suspected) other central nervous system malformation or damage in fetus, not applicable or unspecified
        "O3509X1",  # Maternal care for (suspected) other central nervous system malformation or damage in fetus, fetus 1
        "O3509X2",  # Maternal care for (suspected) other central nervous system malformation or damage in fetus, fetus 2
        "O3509X3",  # Maternal care for (suspected) other central nervous system malformation or damage in fetus, fetus 3
        "O3509X4",  # Maternal care for (suspected) other central nervous system malformation or damage in fetus, fetus 4
        "O3509X5",  # Maternal care for (suspected) other central nervous system malformation or damage in fetus, fetus 5
        "O3509X9",  # Maternal care for (suspected) other central nervous system malformation or damage in fetus, other fetus
        "O3510X0",  # Maternal care for (suspected) chromosomal abnormality in fetus, unspecified, not applicable or unspecified
        "O3510X1",  # Maternal care for (suspected) chromosomal abnormality in fetus, unspecified, fetus 1
        "O3510X2",  # Maternal care for (suspected) chromosomal abnormality in fetus, unspecified, fetus 2
        "O3510X3",  # Maternal care for (suspected) chromosomal abnormality in fetus, unspecified, fetus 3
        "O3510X4",  # Maternal care for (suspected) chromosomal abnormality in fetus, unspecified, fetus 4
        "O3510X5",  # Maternal care for (suspected) chromosomal abnormality in fetus, unspecified, fetus 5
        "O3510X9",  # Maternal care for (suspected) chromosomal abnormality in fetus, unspecified, other fetus
        "O3511X0",  # Maternal care for (suspected) chromosomal abnormality in fetus, Trisomy 13, not applicable or unspecified
        "O3511X1",  # Maternal care for (suspected) chromosomal abnormality in fetus, Trisomy 13, fetus 1
        "O3511X2",  # Maternal care for (suspected) chromosomal abnormality in fetus, Trisomy 13, fetus 2
        "O3511X3",  # Maternal care for (suspected) chromosomal abnormality in fetus, Trisomy 13, fetus 3
        "O3511X4",  # Maternal care for (suspected) chromosomal abnormality in fetus, Trisomy 13, fetus 4
        "O3511X5",  # Maternal care for (suspected) chromosomal abnormality in fetus, Trisomy 13, fetus 5
        "O3511X9",  # Maternal care for (suspected) chromosomal abnormality in fetus, Trisomy 13, other fetus
        "O3512X0",  # Maternal care for (suspected) chromosomal abnormality in fetus, Trisomy 18, not applicable or unspecified
        "O3512X1",  # Maternal care for (suspected) chromosomal abnormality in fetus, Trisomy 18, fetus 1
        "O3512X2",  # Maternal care for (suspected) chromosomal abnormality in fetus, Trisomy 18, fetus 2
        "O3512X3",  # Maternal care for (suspected) chromosomal abnormality in fetus, Trisomy 18, fetus 3
        "O3512X4",  # Maternal care for (suspected) chromosomal abnormality in fetus, Trisomy 18, fetus 4
        "O3512X5",  # Maternal care for (suspected) chromosomal abnormality in fetus, Trisomy 18, fetus 5
        "O3512X9",  # Maternal care for (suspected) chromosomal abnormality in fetus, Trisomy 18, other fetus
        "O3513X0",  # Maternal care for (suspected) chromosomal abnormality in fetus, Trisomy 21, not applicable or unspecified
        "O3513X1",  # Maternal care for (suspected) chromosomal abnormality in fetus, Trisomy 21, fetus 1
        "O3513X2",  # Maternal care for (suspected) chromosomal abnormality in fetus, Trisomy 21, fetus 2
        "O3513X3",  # Maternal care for (suspected) chromosomal abnormality in fetus, Trisomy 21, fetus 3
        "O3513X4",  # Maternal care for (suspected) chromosomal abnormality in fetus, Trisomy 21, fetus 4
        "O3513X5",  # Maternal care for (suspected) chromosomal abnormality in fetus, Trisomy 21, fetus 5
        "O3513X9",  # Maternal care for (suspected) chromosomal abnormality in fetus, Trisomy 21, other fetus
        "O3514X0",  # Maternal care for (suspected) chromosomal abnormality in fetus, Turner Syndrome, not applicable or unspecified
        "O3514X1",  # Maternal care for (suspected) chromosomal abnormality in fetus, Turner Syndrome, fetus 1
        "O3514X2",  # Maternal care for (suspected) chromosomal abnormality in fetus, Turner Syndrome, fetus 2
        "O3514X3",  # Maternal care for (suspected) chromosomal abnormality in fetus, Turner Syndrome, fetus 3
        "O3514X4",  # Maternal care for (suspected) chromosomal abnormality in fetus, Turner Syndrome, fetus 4
        "O3514X5",  # Maternal care for (suspected) chromosomal abnormality in fetus, Turner Syndrome, fetus 5
        "O3514X9",  # Maternal care for (suspected) chromosomal abnormality in fetus, Turner Syndrome, other fetus
        "O3515X0",  # Maternal care for (suspected) chromosomal abnormality in fetus, sex chromosome abnormality, not applicable or unspecified
        "O3515X1",  # Maternal care for (suspected) chromosomal abnormality in fetus, sex chromosome abnormality, fetus 1
        "O3515X2",  # Maternal care for (suspected) chromosomal abnormality in fetus, sex chromosome abnormality, fetus 2
        "O3515X3",  # Maternal care for (suspected) chromosomal abnormality in fetus, sex chromosome abnormality, fetus 3
        "O3515X4",  # Maternal care for (suspected) chromosomal abnormality in fetus, sex chromosome abnormality, fetus 4
        "O3515X5",  # Maternal care for (suspected) chromosomal abnormality in fetus, sex chromosome abnormality, fetus 5
        "O3515X9",  # Maternal care for (suspected) chromosomal abnormality in fetus, sex chromosome abnormality, other fetus
        "O3519X0",  # Maternal care for (suspected) chromosomal abnormality in fetus, other chromosomal abnormality, not applicable or unspecified
        "O3519X1",  # Maternal care for (suspected) chromosomal abnormality in fetus, other chromosomal abnormality, fetus 1
        "O3519X2",  # Maternal care for (suspected) chromosomal abnormality in fetus, other chromosomal abnormality, fetus 2
        "O3519X3",  # Maternal care for (suspected) chromosomal abnormality in fetus, other chromosomal abnormality, fetus 3
        "O3519X4",  # Maternal care for (suspected) chromosomal abnormality in fetus, other chromosomal abnormality, fetus 4
        "O3519X5",  # Maternal care for (suspected) chromosomal abnormality in fetus, other chromosomal abnormality, fetus 5
        "O3519X9",  # Maternal care for (suspected) chromosomal abnormality in fetus, other chromosomal abnormality, other fetus
        "O352XX0",  # Maternal care for (suspected) hereditary disease in fetus, not applicable or unspecified
        "O352XX1",  # Maternal care for (suspected) hereditary disease in fetus, fetus 1
        "O352XX2",  # Maternal care for (suspected) hereditary disease in fetus, fetus 2
        "O352XX3",  # Maternal care for (suspected) hereditary disease in fetus, fetus 3
        "O352XX4",  # Maternal care for (suspected) hereditary disease in fetus, fetus 4
        "O352XX5",  # Maternal care for (suspected) hereditary disease in fetus, fetus 5
        "O352XX9",  # Maternal care for (suspected) hereditary disease in fetus, other fetus
        "O353XX0",  # Maternal care for (suspected) damage to fetus from viral disease in mother, not applicable or unspecified
        "O353XX1",  # Maternal care for (suspected) damage to fetus from viral disease in mother, fetus 1
        "O353XX2",  # Maternal care for (suspected) damage to fetus from viral disease in mother, fetus 2
        "O353XX3",  # Maternal care for (suspected) damage to fetus from viral disease in mother, fetus 3
        "O353XX4",  # Maternal care for (suspected) damage to fetus from viral disease in mother, fetus 4
        "O353XX5",  # Maternal care for (suspected) damage to fetus from viral disease in mother, fetus 5
        "O353XX9",  # Maternal care for (suspected) damage to fetus from viral disease in mother, other fetus
        "O354XX0",  # Maternal care for (suspected) damage to fetus from alcohol, not applicable or unspecified
        "O354XX1",  # Maternal care for (suspected) damage to fetus from alcohol, fetus 1
        "O354XX2",  # Maternal care for (suspected) damage to fetus from alcohol, fetus 2
        "O354XX3",  # Maternal care for (suspected) damage to fetus from alcohol, fetus 3
        "O354XX4",  # Maternal care for (suspected) damage to fetus from alcohol, fetus 4
        "O354XX5",  # Maternal care for (suspected) damage to fetus from alcohol, fetus 5
        "O354XX9",  # Maternal care for (suspected) damage to fetus from alcohol, other fetus
        "O355XX0",  # Maternal care for (suspected) damage to fetus by drugs, not applicable or unspecified
        "O355XX1",  # Maternal care for (suspected) damage to fetus by drugs, fetus 1
        "O355XX2",  # Maternal care for (suspected) damage to fetus by drugs, fetus 2
        "O355XX3",  # Maternal care for (suspected) damage to fetus by drugs, fetus 3
        "O355XX4",  # Maternal care for (suspected) damage to fetus by drugs, fetus 4
        "O355XX5",  # Maternal care for (suspected) damage to fetus by drugs, fetus 5
        "O355XX9",  # Maternal care for (suspected) damage to fetus by drugs, other fetus
        "O356XX0",  # Maternal care for (suspected) damage to fetus by radiation, not applicable or unspecified
        "O356XX1",  # Maternal care for (suspected) damage to fetus by radiation, fetus 1
        "O356XX2",  # Maternal care for (suspected) damage to fetus by radiation, fetus 2
        "O356XX3",  # Maternal care for (suspected) damage to fetus by radiation, fetus 3
        "O356XX4",  # Maternal care for (suspected) damage to fetus by radiation, fetus 4
        "O356XX5",  # Maternal care for (suspected) damage to fetus by radiation, fetus 5
        "O356XX9",  # Maternal care for (suspected) damage to fetus by radiation, other fetus
        "O357XX0",  # Maternal care for (suspected) damage to fetus by other medical procedures, not applicable or unspecified
        "O357XX1",  # Maternal care for (suspected) damage to fetus by other medical procedures, fetus 1
        "O357XX2",  # Maternal care for (suspected) damage to fetus by other medical procedures, fetus 2
        "O357XX3",  # Maternal care for (suspected) damage to fetus by other medical procedures, fetus 3
        "O357XX4",  # Maternal care for (suspected) damage to fetus by other medical procedures, fetus 4
        "O357XX5",  # Maternal care for (suspected) damage to fetus by other medical procedures, fetus 5
        "O357XX9",  # Maternal care for (suspected) damage to fetus by other medical procedures, other fetus
        "O358XX0",  # Maternal care for other (suspected) fetal abnormality and damage, not applicable or unspecified
        "O358XX1",  # Maternal care for other (suspected) fetal abnormality and damage, fetus 1
        "O358XX2",  # Maternal care for other (suspected) fetal abnormality and damage, fetus 2
        "O358XX3",  # Maternal care for other (suspected) fetal abnormality and damage, fetus 3
        "O358XX4",  # Maternal care for other (suspected) fetal abnormality and damage, fetus 4
        "O358XX5",  # Maternal care for other (suspected) fetal abnormality and damage, fetus 5
        "O358XX9",  # Maternal care for other (suspected) fetal abnormality and damage, other fetus
        "O359XX0",  # Maternal care for (suspected) fetal abnormality and damage, unspecified, not applicable or unspecified
        "O359XX1",  # Maternal care for (suspected) fetal abnormality and damage, unspecified, fetus 1
        "O359XX2",  # Maternal care for (suspected) fetal abnormality and damage, unspecified, fetus 2
        "O359XX3",  # Maternal care for (suspected) fetal abnormality and damage, unspecified, fetus 3
        "O359XX4",  # Maternal care for (suspected) fetal abnormality and damage, unspecified, fetus 4
        "O359XX5",  # Maternal care for (suspected) fetal abnormality and damage, unspecified, fetus 5
        "O359XX9",  # Maternal care for (suspected) fetal abnormality and damage, unspecified, other fetus
        "O35AXX0",  # Maternal care for other (suspected) fetal abnormality and damage, fetal facial anomalies, not applicable or unspecified
        "O35AXX1",  # Maternal care for other (suspected) fetal abnormality and damage, fetal facial anomalies, fetus 1
        "O35AXX2",  # Maternal care for other (suspected) fetal abnormality and damage, fetal facial anomalies, fetus 2
        "O35AXX3",  # Maternal care for other (suspected) fetal abnormality and damage, fetal facial anomalies, fetus 3
        "O35AXX4",  # Maternal care for other (suspected) fetal abnormality and damage, fetal facial anomalies, fetus 4
        "O35AXX5",  # Maternal care for other (suspected) fetal abnormality and damage, fetal facial anomalies, fetus 5
        "O35AXX9",  # Maternal care for other (suspected) fetal abnormality and damage, fetal facial anomalies, other fetus
        "O35BXX0",  # Maternal care for other (suspected) fetal abnormality and damage, fetal cardiac anomalies, not applicable or unspecified
        "O35BXX1",  # Maternal care for other (suspected) fetal abnormality and damage, fetal cardiac anomalies, fetus 1
        "O35BXX2",  # Maternal care for other (suspected) fetal abnormality and damage, fetal cardiac anomalies, fetus 2
        "O35BXX3",  # Maternal care for other (suspected) fetal abnormality and damage, fetal cardiac anomalies, fetus 3
        "O35BXX4",  # Maternal care for other (suspected) fetal abnormality and damage, fetal cardiac anomalies, fetus 4
        "O35BXX5",  # Maternal care for other (suspected) fetal abnormality and damage, fetal cardiac anomalies, fetus 5
        "O35BXX9",  # Maternal care for other (suspected) fetal abnormality and damage, fetal cardiac anomalies, other fetus
        "O35CXX0",  # Maternal care for other (suspected) fetal abnormality and damage, fetal pulmonary anomalies, not applicable or unspecified
        "O35CXX1",  # Maternal care for other (suspected) fetal abnormality and damage, fetal pulmonary anomalies, fetus 1
        "O35CXX2",  # Maternal care for other (suspected) fetal abnormality and damage, fetal pulmonary anomalies, fetus 2
        "O35CXX3",  # Maternal care for other (suspected) fetal abnormality and damage, fetal pulmonary anomalies, fetus 3
        "O35CXX4",  # Maternal care for other (suspected) fetal abnormality and damage, fetal pulmonary anomalies, fetus 4
        "O35CXX5",  # Maternal care for other (suspected) fetal abnormality and damage, fetal pulmonary anomalies, fetus 5
        "O35CXX9",  # Maternal care for other (suspected) fetal abnormality and damage, fetal pulmonary anomalies, other fetus
        "O35DXX0",  # Maternal care for other (suspected) fetal abnormality and damage, fetal gastrointestinal anomalies, not applicable or unspecified
        "O35DXX1",  # Maternal care for other (suspected) fetal abnormality and damage, fetal gastrointestinal anomalies, fetus 1
        "O35DXX2",  # Maternal care for other (suspected) fetal abnormality and damage, fetal gastrointestinal anomalies, fetus 2
        "O35DXX3",  # Maternal care for other (suspected) fetal abnormality and damage, fetal gastrointestinal anomalies, fetus 3
        "O35DXX4",  # Maternal care for other (suspected) fetal abnormality and damage, fetal gastrointestinal anomalies, fetus 4
        "O35DXX5",  # Maternal care for other (suspected) fetal abnormality and damage, fetal gastrointestinal anomalies, fetus 5
        "O35DXX9",  # Maternal care for other (suspected) fetal abnormality and damage, fetal gastrointestinal anomalies, other fetus
        "O35EXX0",  # Maternal care for other (suspected) fetal abnormality and damage, fetal genitourinary anomalies, not applicable or unspecified
        "O35EXX1",  # Maternal care for other (suspected) fetal abnormality and damage, fetal genitourinary anomalies, fetus 1
        "O35EXX2",  # Maternal care for other (suspected) fetal abnormality and damage, fetal genitourinary anomalies, fetus 2
        "O35EXX3",  # Maternal care for other (suspected) fetal abnormality and damage, fetal genitourinary anomalies, fetus 3
        "O35EXX4",  # Maternal care for other (suspected) fetal abnormality and damage, fetal genitourinary anomalies, fetus 4
        "O35EXX5",  # Maternal care for other (suspected) fetal abnormality and damage, fetal genitourinary anomalies, fetus 5
        "O35EXX9",  # Maternal care for other (suspected) fetal abnormality and damage, fetal genitourinary anomalies, other fetus
        "O35FXX0",  # Maternal care for other (suspected) fetal abnormality and damage, fetal musculoskeletal anomalies of trunk, not applicable or unspecified
        "O35FXX1",  # Maternal care for other (suspected) fetal abnormality and damage, fetal musculoskeletal anomalies of trunk, fetus 1
        "O35FXX2",  # Maternal care for other (suspected) fetal abnormality and damage, fetal musculoskeletal anomalies of trunk, fetus 2
        "O35FXX3",  # Maternal care for other (suspected) fetal abnormality and damage, fetal musculoskeletal anomalies of trunk, fetus 3
        "O35FXX4",  # Maternal care for other (suspected) fetal abnormality and damage, fetal musculoskeletal anomalies of trunk, fetus 4
        "O35FXX5",  # Maternal care for other (suspected) fetal abnormality and damage, fetal musculoskeletal anomalies of trunk, fetus 5
        "O35FXX9",  # Maternal care for other (suspected) fetal abnormality and damage, fetal musculoskeletal anomalies of trunk, other fetus
        "O35GXX0",  # Maternal care for other (suspected) fetal abnormality and damage, fetal upper extremities anomalies, not applicable or unspecified
        "O35GXX1",  # Maternal care for other (suspected) fetal abnormality and damage, fetal upper extremities anomalies, fetus 1
        "O35GXX2",  # Maternal care for other (suspected) fetal abnormality and damage, fetal upper extremities anomalies, fetus 2
        "O35GXX3",  # Maternal care for other (suspected) fetal abnormality and damage, fetal upper extremities anomalies, fetus 3
        "O35GXX4",  # Maternal care for other (suspected) fetal abnormality and damage, fetal upper extremities anomalies, fetus 4
        "O35GXX5",  # Maternal care for other (suspected) fetal abnormality and damage, fetal upper extremities anomalies, fetus 5
        "O35GXX9",  # Maternal care for other (suspected) fetal abnormality and damage, fetal upper extremities anomalies, other fetus
        "O35HXX0",  # Maternal care for other (suspected) fetal abnormality and damage, fetal lower extremities anomalies, not applicable or unspecified
        "O35HXX1",  # Maternal care for other (suspected) fetal abnormality and damage, fetal lower extremities anomalies, fetus 1
        "O35HXX2",  # Maternal care for other (suspected) fetal abnormality and damage, fetal lower extremities anomalies, fetus 2
        "O35HXX3",  # Maternal care for other (suspected) fetal abnormality and damage, fetal lower extremities anomalies, fetus 3
        "O35HXX4",  # Maternal care for other (suspected) fetal abnormality and damage, fetal lower extremities anomalies, fetus 4
        "O35HXX5",  # Maternal care for other (suspected) fetal abnormality and damage, fetal lower extremities anomalies, fetus 5
        "O35HXX9",  # Maternal care for other (suspected) fetal abnormality and damage, fetal lower extremities anomalies, other fetus
        "O360110",  # Maternal care for anti-D [Rh] antibodies, first trimester, not applicable or unspecified
        "O360111",  # Maternal care for anti-D [Rh] antibodies, first trimester, fetus 1
        "O360112",  # Maternal care for anti-D [Rh] antibodies, first trimester, fetus 2
        "O360113",  # Maternal care for anti-D [Rh] antibodies, first trimester, fetus 3
        "O360114",  # Maternal care for anti-D [Rh] antibodies, first trimester, fetus 4
        "O360115",  # Maternal care for anti-D [Rh] antibodies, first trimester, fetus 5
        "O360119",  # Maternal care for anti-D [Rh] antibodies, first trimester, other fetus
        "O360120",  # Maternal care for anti-D [Rh] antibodies, second trimester, not applicable or unspecified
        "O360121",  # Maternal care for anti-D [Rh] antibodies, second trimester, fetus 1
        "O360122",  # Maternal care for anti-D [Rh] antibodies, second trimester, fetus 2
        "O360123",  # Maternal care for anti-D [Rh] antibodies, second trimester, fetus 3
        "O360124",  # Maternal care for anti-D [Rh] antibodies, second trimester, fetus 4
        "O360125",  # Maternal care for anti-D [Rh] antibodies, second trimester, fetus 5
        "O360129",  # Maternal care for anti-D [Rh] antibodies, second trimester, other fetus
        "O360130",  # Maternal care for anti-D [Rh] antibodies, third trimester, not applicable or unspecified
        "O360131",  # Maternal care for anti-D [Rh] antibodies, third trimester, fetus 1
        "O360132",  # Maternal care for anti-D [Rh] antibodies, third trimester, fetus 2
        "O360133",  # Maternal care for anti-D [Rh] antibodies, third trimester, fetus 3
        "O360134",  # Maternal care for anti-D [Rh] antibodies, third trimester, fetus 4
        "O360135",  # Maternal care for anti-D [Rh] antibodies, third trimester, fetus 5
        "O360139",  # Maternal care for anti-D [Rh] antibodies, third trimester, other fetus
        "O360190",  # Maternal care for anti-D [Rh] antibodies, unspecified trimester, not applicable or unspecified
        "O360191",  # Maternal care for anti-D [Rh] antibodies, unspecified trimester, fetus 1
        "O360192",  # Maternal care for anti-D [Rh] antibodies, unspecified trimester, fetus 2
        "O360193",  # Maternal care for anti-D [Rh] antibodies, unspecified trimester, fetus 3
        "O360194",  # Maternal care for anti-D [Rh] antibodies, unspecified trimester, fetus 4
        "O360195",  # Maternal care for anti-D [Rh] antibodies, unspecified trimester, fetus 5
        "O360199",  # Maternal care for anti-D [Rh] antibodies, unspecified trimester, other fetus
        "O360910",  # Maternal care for other rhesus isoimmunization, first trimester, not applicable or unspecified
        "O360911",  # Maternal care for other rhesus isoimmunization, first trimester, fetus 1
        "O360912",  # Maternal care for other rhesus isoimmunization, first trimester, fetus 2
        "O360913",  # Maternal care for other rhesus isoimmunization, first trimester, fetus 3
        "O360914",  # Maternal care for other rhesus isoimmunization, first trimester, fetus 4
        "O360915",  # Maternal care for other rhesus isoimmunization, first trimester, fetus 5
        "O360919",  # Maternal care for other rhesus isoimmunization, first trimester, other fetus
        "O360920",  # Maternal care for other rhesus isoimmunization, second trimester, not applicable or unspecified
        "O360921",  # Maternal care for other rhesus isoimmunization, second trimester, fetus 1
        "O360922",  # Maternal care for other rhesus isoimmunization, second trimester, fetus 2
        "O360923",  # Maternal care for other rhesus isoimmunization, second trimester, fetus 3
        "O360924",  # Maternal care for other rhesus isoimmunization, second trimester, fetus 4
        "O360925",  # Maternal care for other rhesus isoimmunization, second trimester, fetus 5
        "O360929",  # Maternal care for other rhesus isoimmunization, second trimester, other fetus
        "O360930",  # Maternal care for other rhesus isoimmunization, third trimester, not applicable or unspecified
        "O360931",  # Maternal care for other rhesus isoimmunization, third trimester, fetus 1
        "O360932",  # Maternal care for other rhesus isoimmunization, third trimester, fetus 2
        "O360933",  # Maternal care for other rhesus isoimmunization, third trimester, fetus 3
        "O360934",  # Maternal care for other rhesus isoimmunization, third trimester, fetus 4
        "O360935",  # Maternal care for other rhesus isoimmunization, third trimester, fetus 5
        "O360939",  # Maternal care for other rhesus isoimmunization, third trimester, other fetus
        "O360990",  # Maternal care for other rhesus isoimmunization, unspecified trimester, not applicable or unspecified
        "O360991",  # Maternal care for other rhesus isoimmunization, unspecified trimester, fetus 1
        "O360992",  # Maternal care for other rhesus isoimmunization, unspecified trimester, fetus 2
        "O360993",  # Maternal care for other rhesus isoimmunization, unspecified trimester, fetus 3
        "O360994",  # Maternal care for other rhesus isoimmunization, unspecified trimester, fetus 4
        "O360995",  # Maternal care for other rhesus isoimmunization, unspecified trimester, fetus 5
        "O360999",  # Maternal care for other rhesus isoimmunization, unspecified trimester, other fetus
        "O361110",  # Maternal care for Anti-A sensitization, first trimester, not applicable or unspecified
        "O361111",  # Maternal care for Anti-A sensitization, first trimester, fetus 1
        "O361112",  # Maternal care for Anti-A sensitization, first trimester, fetus 2
        "O361113",  # Maternal care for Anti-A sensitization, first trimester, fetus 3
        "O361114",  # Maternal care for Anti-A sensitization, first trimester, fetus 4
        "O361115",  # Maternal care for Anti-A sensitization, first trimester, fetus 5
        "O361119",  # Maternal care for Anti-A sensitization, first trimester, other fetus
        "O361120",  # Maternal care for Anti-A sensitization, second trimester, not applicable or unspecified
        "O361121",  # Maternal care for Anti-A sensitization, second trimester, fetus 1
        "O361122",  # Maternal care for Anti-A sensitization, second trimester, fetus 2
        "O361123",  # Maternal care for Anti-A sensitization, second trimester, fetus 3
        "O361124",  # Maternal care for Anti-A sensitization, second trimester, fetus 4
        "O361125",  # Maternal care for Anti-A sensitization, second trimester, fetus 5
        "O361129",  # Maternal care for Anti-A sensitization, second trimester, other fetus
        "O361130",  # Maternal care for Anti-A sensitization, third trimester, not applicable or unspecified
        "O361131",  # Maternal care for Anti-A sensitization, third trimester, fetus 1
        "O361132",  # Maternal care for Anti-A sensitization, third trimester, fetus 2
        "O361133",  # Maternal care for Anti-A sensitization, third trimester, fetus 3
        "O361134",  # Maternal care for Anti-A sensitization, third trimester, fetus 4
        "O361135",  # Maternal care for Anti-A sensitization, third trimester, fetus 5
        "O361139",  # Maternal care for Anti-A sensitization, third trimester, other fetus
        "O361190",  # Maternal care for Anti-A sensitization, unspecified trimester, not applicable or unspecified
        "O361191",  # Maternal care for Anti-A sensitization, unspecified trimester, fetus 1
        "O361192",  # Maternal care for Anti-A sensitization, unspecified trimester, fetus 2
        "O361193",  # Maternal care for Anti-A sensitization, unspecified trimester, fetus 3
        "O361194",  # Maternal care for Anti-A sensitization, unspecified trimester, fetus 4
        "O361195",  # Maternal care for Anti-A sensitization, unspecified trimester, fetus 5
        "O361199",  # Maternal care for Anti-A sensitization, unspecified trimester, other fetus
        "O361910",  # Maternal care for other isoimmunization, first trimester, not applicable or unspecified
        "O361911",  # Maternal care for other isoimmunization, first trimester, fetus 1
        "O361912",  # Maternal care for other isoimmunization, first trimester, fetus 2
        "O361913",  # Maternal care for other isoimmunization, first trimester, fetus 3
        "O361914",  # Maternal care for other isoimmunization, first trimester, fetus 4
        "O361915",  # Maternal care for other isoimmunization, first trimester, fetus 5
        "O361919",  # Maternal care for other isoimmunization, first trimester, other fetus
        "O361920",  # Maternal care for other isoimmunization, second trimester, not applicable or unspecified
        "O361921",  # Maternal care for other isoimmunization, second trimester, fetus 1
        "O361922",  # Maternal care for other isoimmunization, second trimester, fetus 2
        "O361923",  # Maternal care for other isoimmunization, second trimester, fetus 3
        "O361924",  # Maternal care for other isoimmunization, second trimester, fetus 4
        "O361925",  # Maternal care for other isoimmunization, second trimester, fetus 5
        "O361929",  # Maternal care for other isoimmunization, second trimester, other fetus
        "O361930",  # Maternal care for other isoimmunization, third trimester, not applicable or unspecified
        "O361931",  # Maternal care for other isoimmunization, third trimester, fetus 1
        "O361932",  # Maternal care for other isoimmunization, third trimester, fetus 2
        "O361933",  # Maternal care for other isoimmunization, third trimester, fetus 3
        "O361934",  # Maternal care for other isoimmunization, third trimester, fetus 4
        "O361935",  # Maternal care for other isoimmunization, third trimester, fetus 5
        "O361939",  # Maternal care for other isoimmunization, third trimester, other fetus
        "O361990",  # Maternal care for other isoimmunization, unspecified trimester, not applicable or unspecified
        "O361991",  # Maternal care for other isoimmunization, unspecified trimester, fetus 1
        "O361992",  # Maternal care for other isoimmunization, unspecified trimester, fetus 2
        "O361993",  # Maternal care for other isoimmunization, unspecified trimester, fetus 3
        "O361994",  # Maternal care for other isoimmunization, unspecified trimester, fetus 4
        "O361995",  # Maternal care for other isoimmunization, unspecified trimester, fetus 5
        "O361999",  # Maternal care for other isoimmunization, unspecified trimester, other fetus
        "O3620X0",  # Maternal care for hydrops fetalis, unspecified trimester, not applicable or unspecified
        "O3620X1",  # Maternal care for hydrops fetalis, unspecified trimester, fetus 1
        "O3620X2",  # Maternal care for hydrops fetalis, unspecified trimester, fetus 2
        "O3620X3",  # Maternal care for hydrops fetalis, unspecified trimester, fetus 3
        "O3620X4",  # Maternal care for hydrops fetalis, unspecified trimester, fetus 4
        "O3620X5",  # Maternal care for hydrops fetalis, unspecified trimester, fetus 5
        "O3620X9",  # Maternal care for hydrops fetalis, unspecified trimester, other fetus
        "O3621X0",  # Maternal care for hydrops fetalis, first trimester, not applicable or unspecified
        "O3621X1",  # Maternal care for hydrops fetalis, first trimester, fetus 1
        "O3621X2",  # Maternal care for hydrops fetalis, first trimester, fetus 2
        "O3621X3",  # Maternal care for hydrops fetalis, first trimester, fetus 3
        "O3621X4",  # Maternal care for hydrops fetalis, first trimester, fetus 4
        "O3621X5",  # Maternal care for hydrops fetalis, first trimester, fetus 5
        "O3621X9",  # Maternal care for hydrops fetalis, first trimester, other fetus
        "O3622X0",  # Maternal care for hydrops fetalis, second trimester, not applicable or unspecified
        "O3622X1",  # Maternal care for hydrops fetalis, second trimester, fetus 1
        "O3622X2",  # Maternal care for hydrops fetalis, second trimester, fetus 2
        "O3622X3",  # Maternal care for hydrops fetalis, second trimester, fetus 3
        "O3622X4",  # Maternal care for hydrops fetalis, second trimester, fetus 4
        "O3622X5",  # Maternal care for hydrops fetalis, second trimester, fetus 5
        "O3622X9",  # Maternal care for hydrops fetalis, second trimester, other fetus
        "O3623X0",  # Maternal care for hydrops fetalis, third trimester, not applicable or unspecified
        "O3623X1",  # Maternal care for hydrops fetalis, third trimester, fetus 1
        "O3623X2",  # Maternal care for hydrops fetalis, third trimester, fetus 2
        "O3623X3",  # Maternal care for hydrops fetalis, third trimester, fetus 3
        "O3623X4",  # Maternal care for hydrops fetalis, third trimester, fetus 4
        "O3623X5",  # Maternal care for hydrops fetalis, third trimester, fetus 5
        "O3623X9",  # Maternal care for hydrops fetalis, third trimester, other fetus
        "O364XX0",  # Maternal care for intrauterine death, not applicable or unspecified
        "O364XX1",  # Maternal care for intrauterine death, fetus 1
        "O364XX2",  # Maternal care for intrauterine death, fetus 2
        "O364XX3",  # Maternal care for intrauterine death, fetus 3
        "O364XX4",  # Maternal care for intrauterine death, fetus 4
        "O364XX5",  # Maternal care for intrauterine death, fetus 5
        "O364XX9",  # Maternal care for intrauterine death, other fetus
        "O365110",  # Maternal care for known or suspected placental insufficiency, first trimester, not applicable or unspecified
        "O365111",  # Maternal care for known or suspected placental insufficiency, first trimester, fetus 1
        "O365112",  # Maternal care for known or suspected placental insufficiency, first trimester, fetus 2
        "O365113",  # Maternal care for known or suspected placental insufficiency, first trimester, fetus 3
        "O365114",  # Maternal care for known or suspected placental insufficiency, first trimester, fetus 4
        "O365115",  # Maternal care for known or suspected placental insufficiency, first trimester, fetus 5
        "O365119",  # Maternal care for known or suspected placental insufficiency, first trimester, other fetus
        "O365120",  # Maternal care for known or suspected placental insufficiency, second trimester, not applicable or unspecified
        "O365121",  # Maternal care for known or suspected placental insufficiency, second trimester, fetus 1
        "O365122",  # Maternal care for known or suspected placental insufficiency, second trimester, fetus 2
        "O365123",  # Maternal care for known or suspected placental insufficiency, second trimester, fetus 3
        "O365124",  # Maternal care for known or suspected placental insufficiency, second trimester, fetus 4
        "O365125",  # Maternal care for known or suspected placental insufficiency, second trimester, fetus 5
        "O365129",  # Maternal care for known or suspected placental insufficiency, second trimester, other fetus
        "O365130",  # Maternal care for known or suspected placental insufficiency, third trimester, not applicable or unspecified
        "O365131",  # Maternal care for known or suspected placental insufficiency, third trimester, fetus 1
        "O365132",  # Maternal care for known or suspected placental insufficiency, third trimester, fetus 2
        "O365133",  # Maternal care for known or suspected placental insufficiency, third trimester, fetus 3
        "O365134",  # Maternal care for known or suspected placental insufficiency, third trimester, fetus 4
        "O365135",  # Maternal care for known or suspected placental insufficiency, third trimester, fetus 5
        "O365139",  # Maternal care for known or suspected placental insufficiency, third trimester, other fetus
        "O365190",  # Maternal care for known or suspected placental insufficiency, unspecified trimester, not applicable or unspecified
        "O365191",  # Maternal care for known or suspected placental insufficiency, unspecified trimester, fetus 1
        "O365192",  # Maternal care for known or suspected placental insufficiency, unspecified trimester, fetus 2
        "O365193",  # Maternal care for known or suspected placental insufficiency, unspecified trimester, fetus 3
        "O365194",  # Maternal care for known or suspected placental insufficiency, unspecified trimester, fetus 4
        "O365195",  # Maternal care for known or suspected placental insufficiency, unspecified trimester, fetus 5
        "O365199",  # Maternal care for known or suspected placental insufficiency, unspecified trimester, other fetus
        "O365910",  # Maternal care for other known or suspected poor fetal growth, first trimester, not applicable or unspecified
        "O365911",  # Maternal care for other known or suspected poor fetal growth, first trimester, fetus 1
        "O365912",  # Maternal care for other known or suspected poor fetal growth, first trimester, fetus 2
        "O365913",  # Maternal care for other known or suspected poor fetal growth, first trimester, fetus 3
        "O365914",  # Maternal care for other known or suspected poor fetal growth, first trimester, fetus 4
        "O365915",  # Maternal care for other known or suspected poor fetal growth, first trimester, fetus 5
        "O365919",  # Maternal care for other known or suspected poor fetal growth, first trimester, other fetus
        "O365920",  # Maternal care for other known or suspected poor fetal growth, second trimester, not applicable or unspecified
        "O365921",  # Maternal care for other known or suspected poor fetal growth, second trimester, fetus 1
        "O365922",  # Maternal care for other known or suspected poor fetal growth, second trimester, fetus 2
        "O365923",  # Maternal care for other known or suspected poor fetal growth, second trimester, fetus 3
        "O365924",  # Maternal care for other known or suspected poor fetal growth, second trimester, fetus 4
        "O365925",  # Maternal care for other known or suspected poor fetal growth, second trimester, fetus 5
        "O365929",  # Maternal care for other known or suspected poor fetal growth, second trimester, other fetus
        "O365930",  # Maternal care for other known or suspected poor fetal growth, third trimester, not applicable or unspecified
        "O365931",  # Maternal care for other known or suspected poor fetal growth, third trimester, fetus 1
        "O365932",  # Maternal care for other known or suspected poor fetal growth, third trimester, fetus 2
        "O365933",  # Maternal care for other known or suspected poor fetal growth, third trimester, fetus 3
        "O365934",  # Maternal care for other known or suspected poor fetal growth, third trimester, fetus 4
        "O365935",  # Maternal care for other known or suspected poor fetal growth, third trimester, fetus 5
        "O365939",  # Maternal care for other known or suspected poor fetal growth, third trimester, other fetus
        "O365990",  # Maternal care for other known or suspected poor fetal growth, unspecified trimester, not applicable or unspecified
        "O365991",  # Maternal care for other known or suspected poor fetal growth, unspecified trimester, fetus 1
        "O365992",  # Maternal care for other known or suspected poor fetal growth, unspecified trimester, fetus 2
        "O365993",  # Maternal care for other known or suspected poor fetal growth, unspecified trimester, fetus 3
        "O365994",  # Maternal care for other known or suspected poor fetal growth, unspecified trimester, fetus 4
        "O365995",  # Maternal care for other known or suspected poor fetal growth, unspecified trimester, fetus 5
        "O365999",  # Maternal care for other known or suspected poor fetal growth, unspecified trimester, other fetus
        "O3660X0",  # Maternal care for excessive fetal growth, unspecified trimester, not applicable or unspecified
        "O3660X1",  # Maternal care for excessive fetal growth, unspecified trimester, fetus 1
        "O3660X2",  # Maternal care for excessive fetal growth, unspecified trimester, fetus 2
        "O3660X3",  # Maternal care for excessive fetal growth, unspecified trimester, fetus 3
        "O3660X4",  # Maternal care for excessive fetal growth, unspecified trimester, fetus 4
        "O3660X5",  # Maternal care for excessive fetal growth, unspecified trimester, fetus 5
        "O3660X9",  # Maternal care for excessive fetal growth, unspecified trimester, other fetus
        "O3661X0",  # Maternal care for excessive fetal growth, first trimester, not applicable or unspecified
        "O3661X1",  # Maternal care for excessive fetal growth, first trimester, fetus 1
        "O3661X2",  # Maternal care for excessive fetal growth, first trimester, fetus 2
        "O3661X3",  # Maternal care for excessive fetal growth, first trimester, fetus 3
        "O3661X4",  # Maternal care for excessive fetal growth, first trimester, fetus 4
        "O3661X5",  # Maternal care for excessive fetal growth, first trimester, fetus 5
        "O3661X9",  # Maternal care for excessive fetal growth, first trimester, other fetus
        "O3662X0",  # Maternal care for excessive fetal growth, second trimester, not applicable or unspecified
        "O3662X1",  # Maternal care for excessive fetal growth, second trimester, fetus 1
        "O3662X2",  # Maternal care for excessive fetal growth, second trimester, fetus 2
        "O3662X3",  # Maternal care for excessive fetal growth, second trimester, fetus 3
        "O3662X4",  # Maternal care for excessive fetal growth, second trimester, fetus 4
        "O3662X5",  # Maternal care for excessive fetal growth, second trimester, fetus 5
        "O3662X9",  # Maternal care for excessive fetal growth, second trimester, other fetus
        "O3663X0",  # Maternal care for excessive fetal growth, third trimester, not applicable or unspecified
        "O3663X1",  # Maternal care for excessive fetal growth, third trimester, fetus 1
        "O3663X2",  # Maternal care for excessive fetal growth, third trimester, fetus 2
        "O3663X3",  # Maternal care for excessive fetal growth, third trimester, fetus 3
        "O3663X4",  # Maternal care for excessive fetal growth, third trimester, fetus 4
        "O3663X5",  # Maternal care for excessive fetal growth, third trimester, fetus 5
        "O3663X9",  # Maternal care for excessive fetal growth, third trimester, other fetus
        "O3670X0",  # Maternal care for viable fetus in abdominal pregnancy, unspecified trimester, not applicable or unspecified
        "O3670X1",  # Maternal care for viable fetus in abdominal pregnancy, unspecified trimester, fetus 1
        "O3670X2",  # Maternal care for viable fetus in abdominal pregnancy, unspecified trimester, fetus 2
        "O3670X3",  # Maternal care for viable fetus in abdominal pregnancy, unspecified trimester, fetus 3
        "O3670X4",  # Maternal care for viable fetus in abdominal pregnancy, unspecified trimester, fetus 4
        "O3670X5",  # Maternal care for viable fetus in abdominal pregnancy, unspecified trimester, fetus 5
        "O3670X9",  # Maternal care for viable fetus in abdominal pregnancy, unspecified trimester, other fetus
        "O3671X0",  # Maternal care for viable fetus in abdominal pregnancy, first trimester, not applicable or unspecified
        "O3671X1",  # Maternal care for viable fetus in abdominal pregnancy, first trimester, fetus 1
        "O3671X2",  # Maternal care for viable fetus in abdominal pregnancy, first trimester, fetus 2
        "O3671X3",  # Maternal care for viable fetus in abdominal pregnancy, first trimester, fetus 3
        "O3671X4",  # Maternal care for viable fetus in abdominal pregnancy, first trimester, fetus 4
        "O3671X5",  # Maternal care for viable fetus in abdominal pregnancy, first trimester, fetus 5
        "O3671X9",  # Maternal care for viable fetus in abdominal pregnancy, first trimester, other fetus
        "O3672X0",  # Maternal care for viable fetus in abdominal pregnancy, second trimester, not applicable or unspecified
        "O3672X1",  # Maternal care for viable fetus in abdominal pregnancy, second trimester, fetus 1
        "O3672X2",  # Maternal care for viable fetus in abdominal pregnancy, second trimester, fetus 2
        "O3672X3",  # Maternal care for viable fetus in abdominal pregnancy, second trimester, fetus 3
        "O3672X4",  # Maternal care for viable fetus in abdominal pregnancy, second trimester, fetus 4
        "O3672X5",  # Maternal care for viable fetus in abdominal pregnancy, second trimester, fetus 5
        "O3672X9",  # Maternal care for viable fetus in abdominal pregnancy, second trimester, other fetus
        "O3673X0",  # Maternal care for viable fetus in abdominal pregnancy, third trimester, not applicable or unspecified
        "O3673X1",  # Maternal care for viable fetus in abdominal pregnancy, third trimester, fetus 1
        "O3673X2",  # Maternal care for viable fetus in abdominal pregnancy, third trimester, fetus 2
        "O3673X3",  # Maternal care for viable fetus in abdominal pregnancy, third trimester, fetus 3
        "O3673X4",  # Maternal care for viable fetus in abdominal pregnancy, third trimester, fetus 4
        "O3673X5",  # Maternal care for viable fetus in abdominal pregnancy, third trimester, fetus 5
        "O3673X9",  # Maternal care for viable fetus in abdominal pregnancy, third trimester, other fetus
        "O3680X0",  # Pregnancy with inconclusive fetal viability, not applicable or unspecified
        "O3680X1",  # Pregnancy with inconclusive fetal viability, fetus 1
        "O3680X2",  # Pregnancy with inconclusive fetal viability, fetus 2
        "O3680X3",  # Pregnancy with inconclusive fetal viability, fetus 3
        "O3680X4",  # Pregnancy with inconclusive fetal viability, fetus 4
        "O3680X5",  # Pregnancy with inconclusive fetal viability, fetus 5
        "O3680X9",  # Pregnancy with inconclusive fetal viability, other fetus
        "O368120",  # Decreased fetal movements, second trimester, not applicable or unspecified
        "O368121",  # Decreased fetal movements, second trimester, fetus 1
        "O368122",  # Decreased fetal movements, second trimester, fetus 2
        "O368123",  # Decreased fetal movements, second trimester, fetus 3
        "O368124",  # Decreased fetal movements, second trimester, fetus 4
        "O368125",  # Decreased fetal movements, second trimester, fetus 5
        "O368129",  # Decreased fetal movements, second trimester, other fetus
        "O368130",  # Decreased fetal movements, third trimester, not applicable or unspecified
        "O368131",  # Decreased fetal movements, third trimester, fetus 1
        "O368132",  # Decreased fetal movements, third trimester, fetus 2
        "O368133",  # Decreased fetal movements, third trimester, fetus 3
        "O368134",  # Decreased fetal movements, third trimester, fetus 4
        "O368135",  # Decreased fetal movements, third trimester, fetus 5
        "O368139",  # Decreased fetal movements, third trimester, other fetus
        "O368190",  # Decreased fetal movements, unspecified trimester, not applicable or unspecified
        "O368191",  # Decreased fetal movements, unspecified trimester, fetus 1
        "O368192",  # Decreased fetal movements, unspecified trimester, fetus 2
        "O368193",  # Decreased fetal movements, unspecified trimester, fetus 3
        "O368194",  # Decreased fetal movements, unspecified trimester, fetus 4
        "O368195",  # Decreased fetal movements, unspecified trimester, fetus 5
        "O368199",  # Decreased fetal movements, unspecified trimester, other fetus
        "O368210",  # Fetal anemia and thrombocytopenia, first trimester, not applicable or unspecified
        "O368211",  # Fetal anemia and thrombocytopenia, first trimester, fetus 1
        "O368212",  # Fetal anemia and thrombocytopenia, first trimester, fetus 2
        "O368213",  # Fetal anemia and thrombocytopenia, first trimester, fetus 3
        "O368214",  # Fetal anemia and thrombocytopenia, first trimester, fetus 4
        "O368215",  # Fetal anemia and thrombocytopenia, first trimester, fetus 5
        "O368219",  # Fetal anemia and thrombocytopenia, first trimester, other fetus
        "O368220",  # Fetal anemia and thrombocytopenia, second trimester, not applicable or unspecified
        "O368221",  # Fetal anemia and thrombocytopenia, second trimester, fetus 1
        "O368222",  # Fetal anemia and thrombocytopenia, second trimester, fetus 2
        "O368223",  # Fetal anemia and thrombocytopenia, second trimester, fetus 3
        "O368224",  # Fetal anemia and thrombocytopenia, second trimester, fetus 4
        "O368225",  # Fetal anemia and thrombocytopenia, second trimester, fetus 5
        "O368229",  # Fetal anemia and thrombocytopenia, second trimester, other fetus
        "O368230",  # Fetal anemia and thrombocytopenia, third trimester, not applicable or unspecified
        "O368231",  # Fetal anemia and thrombocytopenia, third trimester, fetus 1
        "O368232",  # Fetal anemia and thrombocytopenia, third trimester, fetus 2
        "O368233",  # Fetal anemia and thrombocytopenia, third trimester, fetus 3
        "O368234",  # Fetal anemia and thrombocytopenia, third trimester, fetus 4
        "O368235",  # Fetal anemia and thrombocytopenia, third trimester, fetus 5
        "O368239",  # Fetal anemia and thrombocytopenia, third trimester, other fetus
        "O368290",  # Fetal anemia and thrombocytopenia, unspecified trimester, not applicable or unspecified
        "O368291",  # Fetal anemia and thrombocytopenia, unspecified trimester, fetus 1
        "O368292",  # Fetal anemia and thrombocytopenia, unspecified trimester, fetus 2
        "O368293",  # Fetal anemia and thrombocytopenia, unspecified trimester, fetus 3
        "O368294",  # Fetal anemia and thrombocytopenia, unspecified trimester, fetus 4
        "O368295",  # Fetal anemia and thrombocytopenia, unspecified trimester, fetus 5
        "O368299",  # Fetal anemia and thrombocytopenia, unspecified trimester, other fetus
        "O368310",  # Maternal care for abnormalities of the fetal heart rate or rhythm, first trimester, not applicable or unspecified
        "O368311",  # Maternal care for abnormalities of the fetal heart rate or rhythm, first trimester, fetus 1
        "O368312",  # Maternal care for abnormalities of the fetal heart rate or rhythm, first trimester, fetus 2
        "O368313",  # Maternal care for abnormalities of the fetal heart rate or rhythm, first trimester, fetus 3
        "O368314",  # Maternal care for abnormalities of the fetal heart rate or rhythm, first trimester, fetus 4
        "O368315",  # Maternal care for abnormalities of the fetal heart rate or rhythm, first trimester, fetus 5
        "O368319",  # Maternal care for abnormalities of the fetal heart rate or rhythm, first trimester, other fetus
        "O368320",  # Maternal care for abnormalities of the fetal heart rate or rhythm, second trimester, not applicable or unspecified
        "O368321",  # Maternal care for abnormalities of the fetal heart rate or rhythm, second trimester, fetus 1
        "O368322",  # Maternal care for abnormalities of the fetal heart rate or rhythm, second trimester, fetus 2
        "O368323",  # Maternal care for abnormalities of the fetal heart rate or rhythm, second trimester, fetus 3
        "O368324",  # Maternal care for abnormalities of the fetal heart rate or rhythm, second trimester, fetus 4
        "O368325",  # Maternal care for abnormalities of the fetal heart rate or rhythm, second trimester, fetus 5
        "O368329",  # Maternal care for abnormalities of the fetal heart rate or rhythm, second trimester, other fetus
        "O368330",  # Maternal care for abnormalities of the fetal heart rate or rhythm, third trimester, not applicable or unspecified
        "O368331",  # Maternal care for abnormalities of the fetal heart rate or rhythm, third trimester, fetus 1
        "O368332",  # Maternal care for abnormalities of the fetal heart rate or rhythm, third trimester, fetus 2
        "O368333",  # Maternal care for abnormalities of the fetal heart rate or rhythm, third trimester, fetus 3
        "O368334",  # Maternal care for abnormalities of the fetal heart rate or rhythm, third trimester, fetus 4
        "O368335",  # Maternal care for abnormalities of the fetal heart rate or rhythm, third trimester, fetus 5
        "O368339",  # Maternal care for abnormalities of the fetal heart rate or rhythm, third trimester, other fetus
        "O368390",  # Maternal care for abnormalities of the fetal heart rate or rhythm, unspecified trimester, not applicable or unspecified
        "O368391",  # Maternal care for abnormalities of the fetal heart rate or rhythm, unspecified trimester, fetus 1
        "O368392",  # Maternal care for abnormalities of the fetal heart rate or rhythm, unspecified trimester, fetus 2
        "O368393",  # Maternal care for abnormalities of the fetal heart rate or rhythm, unspecified trimester, fetus 3
        "O368394",  # Maternal care for abnormalities of the fetal heart rate or rhythm, unspecified trimester, fetus 4
        "O368395",  # Maternal care for abnormalities of the fetal heart rate or rhythm, unspecified trimester, fetus 5
        "O368399",  # Maternal care for abnormalities of the fetal heart rate or rhythm, unspecified trimester, other fetus
        "O368910",  # Maternal care for other specified fetal problems, first trimester, not applicable or unspecified
        "O368911",  # Maternal care for other specified fetal problems, first trimester, fetus 1
        "O368912",  # Maternal care for other specified fetal problems, first trimester, fetus 2
        "O368913",  # Maternal care for other specified fetal problems, first trimester, fetus 3
        "O368914",  # Maternal care for other specified fetal problems, first trimester, fetus 4
        "O368915",  # Maternal care for other specified fetal problems, first trimester, fetus 5
        "O368919",  # Maternal care for other specified fetal problems, first trimester, other fetus
        "O368920",  # Maternal care for other specified fetal problems, second trimester, not applicable or unspecified
        "O368921",  # Maternal care for other specified fetal problems, second trimester, fetus 1
        "O368922",  # Maternal care for other specified fetal problems, second trimester, fetus 2
        "O368923",  # Maternal care for other specified fetal problems, second trimester, fetus 3
        "O368924",  # Maternal care for other specified fetal problems, second trimester, fetus 4
        "O368925",  # Maternal care for other specified fetal problems, second trimester, fetus 5
        "O368929",  # Maternal care for other specified fetal problems, second trimester, other fetus
        "O368930",  # Maternal care for other specified fetal problems, third trimester, not applicable or unspecified
        "O368931",  # Maternal care for other specified fetal problems, third trimester, fetus 1
        "O368932",  # Maternal care for other specified fetal problems, third trimester, fetus 2
        "O368933",  # Maternal care for other specified fetal problems, third trimester, fetus 3
        "O368934",  # Maternal care for other specified fetal problems, third trimester, fetus 4
        "O368935",  # Maternal care for other specified fetal problems, third trimester, fetus 5
        "O368939",  # Maternal care for other specified fetal problems, third trimester, other fetus
        "O368990",  # Maternal care for other specified fetal problems, unspecified trimester, not applicable or unspecified
        "O368991",  # Maternal care for other specified fetal problems, unspecified trimester, fetus 1
        "O368992",  # Maternal care for other specified fetal problems, unspecified trimester, fetus 2
        "O368993",  # Maternal care for other specified fetal problems, unspecified trimester, fetus 3
        "O368994",  # Maternal care for other specified fetal problems, unspecified trimester, fetus 4
        "O368995",  # Maternal care for other specified fetal problems, unspecified trimester, fetus 5
        "O368999",  # Maternal care for other specified fetal problems, unspecified trimester, other fetus
        "O3690X0",  # Maternal care for fetal problem, unspecified, unspecified trimester, not applicable or unspecified
        "O3690X1",  # Maternal care for fetal problem, unspecified, unspecified trimester, fetus 1
        "O3690X2",  # Maternal care for fetal problem, unspecified, unspecified trimester, fetus 2
        "O3690X3",  # Maternal care for fetal problem, unspecified, unspecified trimester, fetus 3
        "O3690X4",  # Maternal care for fetal problem, unspecified, unspecified trimester, fetus 4
        "O3690X5",  # Maternal care for fetal problem, unspecified, unspecified trimester, fetus 5
        "O3690X9",  # Maternal care for fetal problem, unspecified, unspecified trimester, other fetus
        "O3691X0",  # Maternal care for fetal problem, unspecified, first trimester, not applicable or unspecified
        "O3691X1",  # Maternal care for fetal problem, unspecified, first trimester, fetus 1
        "O3691X2",  # Maternal care for fetal problem, unspecified, first trimester, fetus 2
        "O3691X3",  # Maternal care for fetal problem, unspecified, first trimester, fetus 3
        "O3691X4",  # Maternal care for fetal problem, unspecified, first trimester, fetus 4
        "O3691X5",  # Maternal care for fetal problem, unspecified, first trimester, fetus 5
        "O3691X9",  # Maternal care for fetal problem, unspecified, first trimester, other fetus
        "O3692X0",  # Maternal care for fetal problem, unspecified, second trimester, not applicable or unspecified
        "O3692X1",  # Maternal care for fetal problem, unspecified, second trimester, fetus 1
        "O3692X2",  # Maternal care for fetal problem, unspecified, second trimester, fetus 2
        "O3692X3",  # Maternal care for fetal problem, unspecified, second trimester, fetus 3
        "O3692X4",  # Maternal care for fetal problem, unspecified, second trimester, fetus 4
        "O3692X5",  # Maternal care for fetal problem, unspecified, second trimester, fetus 5
        "O3692X9",  # Maternal care for fetal problem, unspecified, second trimester, other fetus
        "O3693X0",  # Maternal care for fetal problem, unspecified, third trimester, not applicable or unspecified
        "O3693X1",  # Maternal care for fetal problem, unspecified, third trimester, fetus 1
        "O3693X2",  # Maternal care for fetal problem, unspecified, third trimester, fetus 2
        "O3693X3",  # Maternal care for fetal problem, unspecified, third trimester, fetus 3
        "O3693X4",  # Maternal care for fetal problem, unspecified, third trimester, fetus 4
        "O3693X5",  # Maternal care for fetal problem, unspecified, third trimester, fetus 5
        "O3693X9",  # Maternal care for fetal problem, unspecified, third trimester, other fetus
        "O401XX0",  # Polyhydramnios, first trimester, not applicable or unspecified
        "O401XX1",  # Polyhydramnios, first trimester, fetus 1
        "O401XX2",  # Polyhydramnios, first trimester, fetus 2
        "O401XX3",  # Polyhydramnios, first trimester, fetus 3
        "O401XX4",  # Polyhydramnios, first trimester, fetus 4
        "O401XX5",  # Polyhydramnios, first trimester, fetus 5
        "O401XX9",  # Polyhydramnios, first trimester, other fetus
        "O402XX0",  # Polyhydramnios, second trimester, not applicable or unspecified
        "O402XX1",  # Polyhydramnios, second trimester, fetus 1
        "O402XX2",  # Polyhydramnios, second trimester, fetus 2
        "O402XX3",  # Polyhydramnios, second trimester, fetus 3
        "O402XX4",  # Polyhydramnios, second trimester, fetus 4
        "O402XX5",  # Polyhydramnios, second trimester, fetus 5
        "O402XX9",  # Polyhydramnios, second trimester, other fetus
        "O403XX0",  # Polyhydramnios, third trimester, not applicable or unspecified
        "O403XX1",  # Polyhydramnios, third trimester, fetus 1
        "O403XX2",  # Polyhydramnios, third trimester, fetus 2
        "O403XX3",  # Polyhydramnios, third trimester, fetus 3
        "O403XX4",  # Polyhydramnios, third trimester, fetus 4
        "O403XX5",  # Polyhydramnios, third trimester, fetus 5
        "O403XX9",  # Polyhydramnios, third trimester, other fetus
        "O409XX0",  # Polyhydramnios, unspecified trimester, not applicable or unspecified
        "O409XX1",  # Polyhydramnios, unspecified trimester, fetus 1
        "O409XX2",  # Polyhydramnios, unspecified trimester, fetus 2
        "O409XX3",  # Polyhydramnios, unspecified trimester, fetus 3
        "O409XX4",  # Polyhydramnios, unspecified trimester, fetus 4
        "O409XX5",  # Polyhydramnios, unspecified trimester, fetus 5
        "O409XX9",  # Polyhydramnios, unspecified trimester, other fetus
        "O4100X0",  # Oligohydramnios, unspecified trimester, not applicable or unspecified
        "O4100X1",  # Oligohydramnios, unspecified trimester, fetus 1
        "O4100X2",  # Oligohydramnios, unspecified trimester, fetus 2
        "O4100X3",  # Oligohydramnios, unspecified trimester, fetus 3
        "O4100X4",  # Oligohydramnios, unspecified trimester, fetus 4
        "O4100X5",  # Oligohydramnios, unspecified trimester, fetus 5
        "O4100X9",  # Oligohydramnios, unspecified trimester, other fetus
        "O4101X0",  # Oligohydramnios, first trimester, not applicable or unspecified
        "O4101X1",  # Oligohydramnios, first trimester, fetus 1
        "O4101X2",  # Oligohydramnios, first trimester, fetus 2
        "O4101X3",  # Oligohydramnios, first trimester, fetus 3
        "O4101X4",  # Oligohydramnios, first trimester, fetus 4
        "O4101X5",  # Oligohydramnios, first trimester, fetus 5
        "O4101X9",  # Oligohydramnios, first trimester, other fetus
        "O4102X0",  # Oligohydramnios, second trimester, not applicable or unspecified
        "O4102X1",  # Oligohydramnios, second trimester, fetus 1
        "O4102X2",  # Oligohydramnios, second trimester, fetus 2
        "O4102X3",  # Oligohydramnios, second trimester, fetus 3
        "O4102X4",  # Oligohydramnios, second trimester, fetus 4
        "O4102X5",  # Oligohydramnios, second trimester, fetus 5
        "O4102X9",  # Oligohydramnios, second trimester, other fetus
        "O4103X0",  # Oligohydramnios, third trimester, not applicable or unspecified
        "O4103X1",  # Oligohydramnios, third trimester, fetus 1
        "O4103X2",  # Oligohydramnios, third trimester, fetus 2
        "O4103X3",  # Oligohydramnios, third trimester, fetus 3
        "O4103X4",  # Oligohydramnios, third trimester, fetus 4
        "O4103X5",  # Oligohydramnios, third trimester, fetus 5
        "O4103X9",  # Oligohydramnios, third trimester, other fetus
        "O411010",  # Infection of amniotic sac and membranes, unspecified, first trimester, not applicable or unspecified
        "O411011",  # Infection of amniotic sac and membranes, unspecified, first trimester, fetus 1
        "O411012",  # Infection of amniotic sac and membranes, unspecified, first trimester, fetus 2
        "O411013",  # Infection of amniotic sac and membranes, unspecified, first trimester, fetus 3
        "O411014",  # Infection of amniotic sac and membranes, unspecified, first trimester, fetus 4
        "O411015",  # Infection of amniotic sac and membranes, unspecified, first trimester, fetus 5
        "O411019",  # Infection of amniotic sac and membranes, unspecified, first trimester, other fetus
        "O411020",  # Infection of amniotic sac and membranes, unspecified, second trimester, not applicable or unspecified
        "O411021",  # Infection of amniotic sac and membranes, unspecified, second trimester, fetus 1
        "O411022",  # Infection of amniotic sac and membranes, unspecified, second trimester, fetus 2
        "O411023",  # Infection of amniotic sac and membranes, unspecified, second trimester, fetus 3
        "O411024",  # Infection of amniotic sac and membranes, unspecified, second trimester, fetus 4
        "O411025",  # Infection of amniotic sac and membranes, unspecified, second trimester, fetus 5
        "O411029",  # Infection of amniotic sac and membranes, unspecified, second trimester, other fetus
        "O411030",  # Infection of amniotic sac and membranes, unspecified, third trimester, not applicable or unspecified
        "O411031",  # Infection of amniotic sac and membranes, unspecified, third trimester, fetus 1
        "O411032",  # Infection of amniotic sac and membranes, unspecified, third trimester, fetus 2
        "O411033",  # Infection of amniotic sac and membranes, unspecified, third trimester, fetus 3
        "O411034",  # Infection of amniotic sac and membranes, unspecified, third trimester, fetus 4
        "O411035",  # Infection of amniotic sac and membranes, unspecified, third trimester, fetus 5
        "O411039",  # Infection of amniotic sac and membranes, unspecified, third trimester, other fetus
        "O411090",  # Infection of amniotic sac and membranes, unspecified, unspecified trimester, not applicable or unspecified
        "O411091",  # Infection of amniotic sac and membranes, unspecified, unspecified trimester, fetus 1
        "O411092",  # Infection of amniotic sac and membranes, unspecified, unspecified trimester, fetus 2
        "O411093",  # Infection of amniotic sac and membranes, unspecified, unspecified trimester, fetus 3
        "O411094",  # Infection of amniotic sac and membranes, unspecified, unspecified trimester, fetus 4
        "O411095",  # Infection of amniotic sac and membranes, unspecified, unspecified trimester, fetus 5
        "O411099",  # Infection of amniotic sac and membranes, unspecified, unspecified trimester, other fetus
        "O411210",  # Chorioamnionitis, first trimester, not applicable or unspecified
        "O411211",  # Chorioamnionitis, first trimester, fetus 1
        "O411212",  # Chorioamnionitis, first trimester, fetus 2
        "O411213",  # Chorioamnionitis, first trimester, fetus 3
        "O411214",  # Chorioamnionitis, first trimester, fetus 4
        "O411215",  # Chorioamnionitis, first trimester, fetus 5
        "O411219",  # Chorioamnionitis, first trimester, other fetus
        "O411220",  # Chorioamnionitis, second trimester, not applicable or unspecified
        "O411221",  # Chorioamnionitis, second trimester, fetus 1
        "O411222",  # Chorioamnionitis, second trimester, fetus 2
        "O411223",  # Chorioamnionitis, second trimester, fetus 3
        "O411224",  # Chorioamnionitis, second trimester, fetus 4
        "O411225",  # Chorioamnionitis, second trimester, fetus 5
        "O411229",  # Chorioamnionitis, second trimester, other fetus
        "O411230",  # Chorioamnionitis, third trimester, not applicable or unspecified
        "O411231",  # Chorioamnionitis, third trimester, fetus 1
        "O411232",  # Chorioamnionitis, third trimester, fetus 2
        "O411233",  # Chorioamnionitis, third trimester, fetus 3
        "O411234",  # Chorioamnionitis, third trimester, fetus 4
        "O411235",  # Chorioamnionitis, third trimester, fetus 5
        "O411239",  # Chorioamnionitis, third trimester, other fetus
        "O411290",  # Chorioamnionitis, unspecified trimester, not applicable or unspecified
        "O411291",  # Chorioamnionitis, unspecified trimester, fetus 1
        "O411292",  # Chorioamnionitis, unspecified trimester, fetus 2
        "O411293",  # Chorioamnionitis, unspecified trimester, fetus 3
        "O411294",  # Chorioamnionitis, unspecified trimester, fetus 4
        "O411295",  # Chorioamnionitis, unspecified trimester, fetus 5
        "O411299",  # Chorioamnionitis, unspecified trimester, other fetus
        "O411410",  # Placentitis, first trimester, not applicable or unspecified
        "O411411",  # Placentitis, first trimester, fetus 1
        "O411412",  # Placentitis, first trimester, fetus 2
        "O411413",  # Placentitis, first trimester, fetus 3
        "O411414",  # Placentitis, first trimester, fetus 4
        "O411415",  # Placentitis, first trimester, fetus 5
        "O411419",  # Placentitis, first trimester, other fetus
        "O411420",  # Placentitis, second trimester, not applicable or unspecified
        "O411421",  # Placentitis, second trimester, fetus 1
        "O411422",  # Placentitis, second trimester, fetus 2
        "O411423",  # Placentitis, second trimester, fetus 3
        "O411424",  # Placentitis, second trimester, fetus 4
        "O411425",  # Placentitis, second trimester, fetus 5
        "O411429",  # Placentitis, second trimester, other fetus
        "O411430",  # Placentitis, third trimester, not applicable or unspecified
        "O411431",  # Placentitis, third trimester, fetus 1
        "O411432",  # Placentitis, third trimester, fetus 2
        "O411433",  # Placentitis, third trimester, fetus 3
        "O411434",  # Placentitis, third trimester, fetus 4
        "O411435",  # Placentitis, third trimester, fetus 5
        "O411439",  # Placentitis, third trimester, other fetus
        "O411490",  # Placentitis, unspecified trimester, not applicable or unspecified
        "O411491",  # Placentitis, unspecified trimester, fetus 1
        "O411492",  # Placentitis, unspecified trimester, fetus 2
        "O411493",  # Placentitis, unspecified trimester, fetus 3
        "O411494",  # Placentitis, unspecified trimester, fetus 4
        "O411495",  # Placentitis, unspecified trimester, fetus 5
        "O411499",  # Placentitis, unspecified trimester, other fetus
        "O418X10",  # Other specified disorders of amniotic fluid and membranes, first trimester, not applicable or unspecified
        "O418X11",  # Other specified disorders of amniotic fluid and membranes, first trimester, fetus 1
        "O418X12",  # Other specified disorders of amniotic fluid and membranes, first trimester, fetus 2
        "O418X13",  # Other specified disorders of amniotic fluid and membranes, first trimester, fetus 3
        "O418X14",  # Other specified disorders of amniotic fluid and membranes, first trimester, fetus 4
        "O418X15",  # Other specified disorders of amniotic fluid and membranes, first trimester, fetus 5
        "O418X19",  # Other specified disorders of amniotic fluid and membranes, first trimester, other fetus
        "O418X20",  # Other specified disorders of amniotic fluid and membranes, second trimester, not applicable or unspecified
        "O418X21",  # Other specified disorders of amniotic fluid and membranes, second trimester, fetus 1
        "O418X22",  # Other specified disorders of amniotic fluid and membranes, second trimester, fetus 2
        "O418X23",  # Other specified disorders of amniotic fluid and membranes, second trimester, fetus 3
        "O418X24",  # Other specified disorders of amniotic fluid and membranes, second trimester, fetus 4
        "O418X25",  # Other specified disorders of amniotic fluid and membranes, second trimester, fetus 5
        "O418X29",  # Other specified disorders of amniotic fluid and membranes, second trimester, other fetus
        "O418X30",  # Other specified disorders of amniotic fluid and membranes, third trimester, not applicable or unspecified
        "O418X31",  # Other specified disorders of amniotic fluid and membranes, third trimester, fetus 1
        "O418X32",  # Other specified disorders of amniotic fluid and membranes, third trimester, fetus 2
        "O418X33",  # Other specified disorders of amniotic fluid and membranes, third trimester, fetus 3
        "O418X34",  # Other specified disorders of amniotic fluid and membranes, third trimester, fetus 4
        "O418X35",  # Other specified disorders of amniotic fluid and membranes, third trimester, fetus 5
        "O418X39",  # Other specified disorders of amniotic fluid and membranes, third trimester, other fetus
        "O418X90",  # Other specified disorders of amniotic fluid and membranes, unspecified trimester, not applicable or unspecified
        "O418X91",  # Other specified disorders of amniotic fluid and membranes, unspecified trimester, fetus 1
        "O418X92",  # Other specified disorders of amniotic fluid and membranes, unspecified trimester, fetus 2
        "O418X93",  # Other specified disorders of amniotic fluid and membranes, unspecified trimester, fetus 3
        "O418X94",  # Other specified disorders of amniotic fluid and membranes, unspecified trimester, fetus 4
        "O418X95",  # Other specified disorders of amniotic fluid and membranes, unspecified trimester, fetus 5
        "O418X99",  # Other specified disorders of amniotic fluid and membranes, unspecified trimester, other fetus
        "O4190X0",  # Disorder of amniotic fluid and membranes, unspecified, unspecified trimester, not applicable or unspecified
        "O4190X1",  # Disorder of amniotic fluid and membranes, unspecified, unspecified trimester, fetus 1
        "O4190X2",  # Disorder of amniotic fluid and membranes, unspecified, unspecified trimester, fetus 2
        "O4190X3",  # Disorder of amniotic fluid and membranes, unspecified, unspecified trimester, fetus 3
        "O4190X4",  # Disorder of amniotic fluid and membranes, unspecified, unspecified trimester, fetus 4
        "O4190X5",  # Disorder of amniotic fluid and membranes, unspecified, unspecified trimester, fetus 5
        "O4190X9",  # Disorder of amniotic fluid and membranes, unspecified, unspecified trimester, other fetus
        "O4191X0",  # Disorder of amniotic fluid and membranes, unspecified, first trimester, not applicable or unspecified
        "O4191X1",  # Disorder of amniotic fluid and membranes, unspecified, first trimester, fetus 1
        "O4191X2",  # Disorder of amniotic fluid and membranes, unspecified, first trimester, fetus 2
        "O4191X3",  # Disorder of amniotic fluid and membranes, unspecified, first trimester, fetus 3
        "O4191X4",  # Disorder of amniotic fluid and membranes, unspecified, first trimester, fetus 4
        "O4191X5",  # Disorder of amniotic fluid and membranes, unspecified, first trimester, fetus 5
        "O4191X9",  # Disorder of amniotic fluid and membranes, unspecified, first trimester, other fetus
        "O4192X0",  # Disorder of amniotic fluid and membranes, unspecified, second trimester, not applicable or unspecified
        "O4192X1",  # Disorder of amniotic fluid and membranes, unspecified, second trimester, fetus 1
        "O4192X2",  # Disorder of amniotic fluid and membranes, unspecified, second trimester, fetus 2
        "O4192X3",  # Disorder of amniotic fluid and membranes, unspecified, second trimester, fetus 3
        "O4192X4",  # Disorder of amniotic fluid and membranes, unspecified, second trimester, fetus 4
        "O4192X5",  # Disorder of amniotic fluid and membranes, unspecified, second trimester, fetus 5
        "O4192X9",  # Disorder of amniotic fluid and membranes, unspecified, second trimester, other fetus
        "O4193X0",  # Disorder of amniotic fluid and membranes, unspecified, third trimester, not applicable or unspecified
        "O4193X1",  # Disorder of amniotic fluid and membranes, unspecified, third trimester, fetus 1
        "O4193X2",  # Disorder of amniotic fluid and membranes, unspecified, third trimester, fetus 2
        "O4193X3",  # Disorder of amniotic fluid and membranes, unspecified, third trimester, fetus 3
        "O4193X4",  # Disorder of amniotic fluid and membranes, unspecified, third trimester, fetus 4
        "O4193X5",  # Disorder of amniotic fluid and membranes, unspecified, third trimester, fetus 5
        "O4193X9",  # Disorder of amniotic fluid and membranes, unspecified, third trimester, other fetus
        "O4200",  # Premature rupture of membranes, onset of labor within 24 hours of rupture, unspecified weeks of gestation
        "O42011",  # Preterm premature rupture of membranes, onset of labor within 24 hours of rupture, first trimester
        "O42012",  # Preterm premature rupture of membranes, onset of labor within 24 hours of rupture, second trimester
        "O42013",  # Preterm premature rupture of membranes, onset of labor within 24 hours of rupture, third trimester
        "O42019",  # Preterm premature rupture of membranes, onset of labor within 24 hours of rupture, unspecified trimester
        "O4202",  # Full-term premature rupture of membranes, onset of labor within 24 hours of rupture
        "O4210",  # Premature rupture of membranes, onset of labor more than 24 hours following rupture, unspecified weeks of gestation
        "O42111",  # Preterm premature rupture of membranes, onset of labor more than 24 hours following rupture, first trimester
        "O42112",  # Preterm premature rupture of membranes, onset of labor more than 24 hours following rupture, second trimester
        "O42113",  # Preterm premature rupture of membranes, onset of labor more than 24 hours following rupture, third trimester
        "O42119",  # Preterm premature rupture of membranes, onset of labor more than 24 hours following rupture, unspecified trimester
        "O4212",  # Full-term premature rupture of membranes, onset of labor more than 24 hours following rupture
        "O4290",  # Premature rupture of membranes, unspecified as to length of time between rupture and onset of labor, unspecified weeks of gestation
        "O42911",  # Preterm premature rupture of membranes, unspecified as to length of time between rupture and onset of labor, first trimester
        "O42912",  # Preterm premature rupture of membranes, unspecified as to length of time between rupture and onset of labor, second trimester
        "O42913",  # Preterm premature rupture of membranes, unspecified as to length of time between rupture and onset of labor, third trimester
        "O42919",  # Preterm premature rupture of membranes, unspecified as to length of time between rupture and onset of labor, unspecified trimester
        "O4292",  # Full-term premature rupture of membranes, unspecified as to length of time between rupture and onset of labor
        "O43011",  # Fetomaternal placental transfusion syndrome, first trimester
        "O43012",  # Fetomaternal placental transfusion syndrome, second trimester
        "O43013",  # Fetomaternal placental transfusion syndrome, third trimester
        "O43019",  # Fetomaternal placental transfusion syndrome, unspecified trimester
        "O43021",  # Fetus-to-fetus placental transfusion syndrome, first trimester
        "O43022",  # Fetus-to-fetus placental transfusion syndrome, second trimester
        "O43023",  # Fetus-to-fetus placental transfusion syndrome, third trimester
        "O43029",  # Fetus-to-fetus placental transfusion syndrome, unspecified trimester
        "O43101",  # Malformation of placenta, unspecified, first trimester
        "O43102",  # Malformation of placenta, unspecified, second trimester
        "O43103",  # Malformation of placenta, unspecified, third trimester
        "O43109",  # Malformation of placenta, unspecified, unspecified trimester
        "O43111",  # Circumvallate placenta, first trimester
        "O43112",  # Circumvallate placenta, second trimester
        "O43113",  # Circumvallate placenta, third trimester
        "O43119",  # Circumvallate placenta, unspecified trimester
        "O43121",  # Velamentous insertion of umbilical cord, first trimester
        "O43122",  # Velamentous insertion of umbilical cord, second trimester
        "O43123",  # Velamentous insertion of umbilical cord, third trimester
        "O43129",  # Velamentous insertion of umbilical cord, unspecified trimester
        "O43191",  # Other malformation of placenta, first trimester
        "O43192",  # Other malformation of placenta, second trimester
        "O43193",  # Other malformation of placenta, third trimester
        "O43199",  # Other malformation of placenta, unspecified trimester
        "O43211",  # Placenta accreta, first trimester
        "O43212",  # Placenta accreta, second trimester
        "O43213",  # Placenta accreta, third trimester
        "O43219",  # Placenta accreta, unspecified trimester
        "O43221",  # Placenta increta, first trimester
        "O43222",  # Placenta increta, second trimester
        "O43223",  # Placenta increta, third trimester
        "O43229",  # Placenta increta, unspecified trimester
        "O43231",  # Placenta percreta, first trimester
        "O43232",  # Placenta percreta, second trimester
        "O43233",  # Placenta percreta, third trimester
        "O43239",  # Placenta percreta, unspecified trimester
        "O43811",  # Placental infarction, first trimester
        "O43812",  # Placental infarction, second trimester
        "O43813",  # Placental infarction, third trimester
        "O43819",  # Placental infarction, unspecified trimester
        "O43891",  # Other placental disorders, first trimester
        "O43892",  # Other placental disorders, second trimester
        "O43893",  # Other placental disorders, third trimester
        "O43899",  # Other placental disorders, unspecified trimester
        "O4390",  # Unspecified placental disorder, unspecified trimester
        "O4391",  # Unspecified placental disorder, first trimester
        "O4392",  # Unspecified placental disorder, second trimester
        "O4393",  # Unspecified placental disorder, third trimester
        "O4400",  # Complete placenta previa NOS or without hemorrhage, unspecified trimester
        "O4401",  # Complete placenta previa NOS or without hemorrhage, first trimester
        "O4402",  # Complete placenta previa NOS or without hemorrhage, second trimester
        "O4403",  # Complete placenta previa NOS or without hemorrhage, third trimester
        "O4410",  # Complete placenta previa with hemorrhage, unspecified trimester
        "O4411",  # Complete placenta previa with hemorrhage, first trimester
        "O4412",  # Complete placenta previa with hemorrhage, second trimester
        "O4413",  # Complete placenta previa with hemorrhage, third trimester
        "O4420",  # Partial placenta previa NOS or without hemorrhage, unspecified trimester
        "O4421",  # Partial placenta previa NOS or without hemorrhage, first trimester
        "O4422",  # Partial placenta previa NOS or without hemorrhage, second trimester
        "O4423",  # Partial placenta previa NOS or without hemorrhage, third trimester
        "O4430",  # Partial placenta previa with hemorrhage, unspecified trimester
        "O4431",  # Partial placenta previa with hemorrhage, first trimester
        "O4432",  # Partial placenta previa with hemorrhage, second trimester
        "O4433",  # Partial placenta previa with hemorrhage, third trimester
        "O4440",  # Low lying placenta NOS or without hemorrhage, unspecified trimester
        "O4441",  # Low lying placenta NOS or without hemorrhage, first trimester
        "O4442",  # Low lying placenta NOS or without hemorrhage, second trimester
        "O4443",  # Low lying placenta NOS or without hemorrhage, third trimester
        "O4450",  # Low lying placenta with hemorrhage, unspecified trimester
        "O4451",  # Low lying placenta with hemorrhage, first trimester
        "O4452",  # Low lying placenta with hemorrhage, second trimester
        "O4453",  # Low lying placenta with hemorrhage, third trimester
        "O45001",  # Premature separation of placenta with coagulation defect, unspecified, first trimester
        "O45002",  # Premature separation of placenta with coagulation defect, unspecified, second trimester
        "O45003",  # Premature separation of placenta with coagulation defect, unspecified, third trimester
        "O45009",  # Premature separation of placenta with coagulation defect, unspecified, unspecified trimester
        "O45011",  # Premature separation of placenta with afibrinogenemia, first trimester
        "O45012",  # Premature separation of placenta with afibrinogenemia, second trimester
        "O45013",  # Premature separation of placenta with afibrinogenemia, third trimester
        "O45019",  # Premature separation of placenta with afibrinogenemia, unspecified trimester
        "O45021",  # Premature separation of placenta with disseminated intravascular coagulation, first trimester
        "O45022",  # Premature separation of placenta with disseminated intravascular coagulation, second trimester
        "O45023",  # Premature separation of placenta with disseminated intravascular coagulation, third trimester
        "O45029",  # Premature separation of placenta with disseminated intravascular coagulation, unspecified trimester
        "O45091",  # Premature separation of placenta with other coagulation defect, first trimester
        "O45092",  # Premature separation of placenta with other coagulation defect, second trimester
        "O45093",  # Premature separation of placenta with other coagulation defect, third trimester
        "O45099",  # Premature separation of placenta with other coagulation defect, unspecified trimester
        "O458X1",  # Other premature separation of placenta, first trimester
        "O458X2",  # Other premature separation of placenta, second trimester
        "O458X3",  # Other premature separation of placenta, third trimester
        "O458X9",  # Other premature separation of placenta, unspecified trimester
        "O4590",  # Premature separation of placenta, unspecified, unspecified trimester
        "O4591",  # Premature separation of placenta, unspecified, first trimester
        "O4592",  # Premature separation of placenta, unspecified, second trimester
        "O4593",  # Premature separation of placenta, unspecified, third trimester
        "O46001",  # Antepartum hemorrhage with coagulation defect, unspecified, first trimester
        "O46002",  # Antepartum hemorrhage with coagulation defect, unspecified, second trimester
        "O46003",  # Antepartum hemorrhage with coagulation defect, unspecified, third trimester
        "O46009",  # Antepartum hemorrhage with coagulation defect, unspecified, unspecified trimester
        "O46011",  # Antepartum hemorrhage with afibrinogenemia, first trimester
        "O46012",  # Antepartum hemorrhage with afibrinogenemia, second trimester
        "O46013",  # Antepartum hemorrhage with afibrinogenemia, third trimester
        "O46019",  # Antepartum hemorrhage with afibrinogenemia, unspecified trimester
        "O46021",  # Antepartum hemorrhage with disseminated intravascular coagulation, first trimester
        "O46022",  # Antepartum hemorrhage with disseminated intravascular coagulation, second trimester
        "O46023",  # Antepartum hemorrhage with disseminated intravascular coagulation, third trimester
        "O46029",  # Antepartum hemorrhage with disseminated intravascular coagulation, unspecified trimester
        "O46091",  # Antepartum hemorrhage with other coagulation defect, first trimester
        "O46092",  # Antepartum hemorrhage with other coagulation defect, second trimester
        "O46093",  # Antepartum hemorrhage with other coagulation defect, third trimester
        "O46099",  # Antepartum hemorrhage with other coagulation defect, unspecified trimester
        "O468X1",  # Other antepartum hemorrhage, first trimester
        "O468X2",  # Other antepartum hemorrhage, second trimester
        "O468X3",  # Other antepartum hemorrhage, third trimester
        "O468X9",  # Other antepartum hemorrhage, unspecified trimester
        "O4690",  # Antepartum hemorrhage, unspecified, unspecified trimester
        "O4691",  # Antepartum hemorrhage, unspecified, first trimester
        "O4692",  # Antepartum hemorrhage, unspecified, second trimester
        "O4693",  # Antepartum hemorrhage, unspecified, third trimester
        "O4700",  # False labor before 37 completed weeks of gestation, unspecified trimester
        "O4702",  # False labor before 37 completed weeks of gestation, second trimester
        "O4703",  # False labor before 37 completed weeks of gestation, third trimester
        "O471",  # False labor at or after 37 completed weeks of gestation
        "O479",  # False labor, unspecified
        "O480",  # Post-term pregnancy
        "O481",  # Prolonged pregnancy
        "O6000",  # Preterm labor without delivery, unspecified trimester
        "O6002",  # Preterm labor without delivery, second trimester
        "O6003",  # Preterm labor without delivery, third trimester
        "O6010X0",  # Preterm labor with preterm delivery, unspecified trimester, not applicable or unspecified
        "O6010X1",  # Preterm labor with preterm delivery, unspecified trimester, fetus 1
        "O6010X2",  # Preterm labor with preterm delivery, unspecified trimester, fetus 2
        "O6010X3",  # Preterm labor with preterm delivery, unspecified trimester, fetus 3
        "O6010X4",  # Preterm labor with preterm delivery, unspecified trimester, fetus 4
        "O6010X5",  # Preterm labor with preterm delivery, unspecified trimester, fetus 5
        "O6010X9",  # Preterm labor with preterm delivery, unspecified trimester, other fetus
        "O6012X0",  # Preterm labor second trimester with preterm delivery second trimester, not applicable or unspecified
        "O6012X1",  # Preterm labor second trimester with preterm delivery second trimester, fetus 1
        "O6012X2",  # Preterm labor second trimester with preterm delivery second trimester, fetus 2
        "O6012X3",  # Preterm labor second trimester with preterm delivery second trimester, fetus 3
        "O6012X4",  # Preterm labor second trimester with preterm delivery second trimester, fetus 4
        "O6012X5",  # Preterm labor second trimester with preterm delivery second trimester, fetus 5
        "O6012X9",  # Preterm labor second trimester with preterm delivery second trimester, other fetus
        "O6013X0",  # Preterm labor second trimester with preterm delivery third trimester, not applicable or unspecified
        "O6013X1",  # Preterm labor second trimester with preterm delivery third trimester, fetus 1
        "O6013X2",  # Preterm labor second trimester with preterm delivery third trimester, fetus 2
        "O6013X3",  # Preterm labor second trimester with preterm delivery third trimester, fetus 3
        "O6013X4",  # Preterm labor second trimester with preterm delivery third trimester, fetus 4
        "O6013X5",  # Preterm labor second trimester with preterm delivery third trimester, fetus 5
        "O6013X9",  # Preterm labor second trimester with preterm delivery third trimester, other fetus
        "O6014X0",  # Preterm labor third trimester with preterm delivery third trimester, not applicable or unspecified
        "O6014X1",  # Preterm labor third trimester with preterm delivery third trimester, fetus 1
        "O6014X2",  # Preterm labor third trimester with preterm delivery third trimester, fetus 2
        "O6014X3",  # Preterm labor third trimester with preterm delivery third trimester, fetus 3
        "O6014X4",  # Preterm labor third trimester with preterm delivery third trimester, fetus 4
        "O6014X5",  # Preterm labor third trimester with preterm delivery third trimester, fetus 5
        "O6014X9",  # Preterm labor third trimester with preterm delivery third trimester, other fetus
        "O6020X0",  # Term delivery with preterm labor, unspecified trimester, not applicable or unspecified
        "O6020X1",  # Term delivery with preterm labor, unspecified trimester, fetus 1
        "O6020X2",  # Term delivery with preterm labor, unspecified trimester, fetus 2
        "O6020X3",  # Term delivery with preterm labor, unspecified trimester, fetus 3
        "O6020X4",  # Term delivery with preterm labor, unspecified trimester, fetus 4
        "O6020X5",  # Term delivery with preterm labor, unspecified trimester, fetus 5
        "O6020X9",  # Term delivery with preterm labor, unspecified trimester, other fetus
        "O6022X0",  # Term delivery with preterm labor, second trimester, not applicable or unspecified
        "O6022X1",  # Term delivery with preterm labor, second trimester, fetus 1
        "O6022X2",  # Term delivery with preterm labor, second trimester, fetus 2
        "O6022X3",  # Term delivery with preterm labor, second trimester, fetus 3
        "O6022X4",  # Term delivery with preterm labor, second trimester, fetus 4
        "O6022X5",  # Term delivery with preterm labor, second trimester, fetus 5
        "O6022X9",  # Term delivery with preterm labor, second trimester, other fetus
        "O6023X0",  # Term delivery with preterm labor, third trimester, not applicable or unspecified
        "O6023X1",  # Term delivery with preterm labor, third trimester, fetus 1
        "O6023X2",  # Term delivery with preterm labor, third trimester, fetus 2
        "O6023X3",  # Term delivery with preterm labor, third trimester, fetus 3
        "O6023X4",  # Term delivery with preterm labor, third trimester, fetus 4
        "O6023X5",  # Term delivery with preterm labor, third trimester, fetus 5
        "O6023X9",  # Term delivery with preterm labor, third trimester, other fetus
        "O610",  # Failed medical induction of labor
        "O611",  # Failed instrumental induction of labor
        "O618",  # Other failed induction of labor
        "O619",  # Failed induction of labor, unspecified
        "O620",  # Primary inadequate contractions
        "O621",  # Secondary uterine inertia
        "O622",  # Other uterine inertia
        "O623",  # Precipitate labor
        "O624",  # Hypertonic, incoordinate, and prolonged uterine contractions
        "O628",  # Other abnormalities of forces of labor
        "O629",  # Abnormality of forces of labor, unspecified
        "O630",  # Prolonged first stage (of labor)
        "O631",  # Prolonged second stage (of labor)
        "O632",  # Delayed delivery of second twin, triplet, etc.
        "O639",  # Long labor, unspecified
        "O640XX0",  # Obstructed labor due to incomplete rotation of fetal head, not applicable or unspecified
        "O640XX1",  # Obstructed labor due to incomplete rotation of fetal head, fetus 1
        "O640XX2",  # Obstructed labor due to incomplete rotation of fetal head, fetus 2
        "O640XX3",  # Obstructed labor due to incomplete rotation of fetal head, fetus 3
        "O640XX4",  # Obstructed labor due to incomplete rotation of fetal head, fetus 4
        "O640XX5",  # Obstructed labor due to incomplete rotation of fetal head, fetus 5
        "O640XX9",  # Obstructed labor due to incomplete rotation of fetal head, other fetus
        "O641XX0",  # Obstructed labor due to breech presentation, not applicable or unspecified
        "O641XX1",  # Obstructed labor due to breech presentation, fetus 1
        "O641XX2",  # Obstructed labor due to breech presentation, fetus 2
        "O641XX3",  # Obstructed labor due to breech presentation, fetus 3
        "O641XX4",  # Obstructed labor due to breech presentation, fetus 4
        "O641XX5",  # Obstructed labor due to breech presentation, fetus 5
        "O641XX9",  # Obstructed labor due to breech presentation, other fetus
        "O642XX0",  # Obstructed labor due to face presentation, not applicable or unspecified
        "O642XX1",  # Obstructed labor due to face presentation, fetus 1
        "O642XX2",  # Obstructed labor due to face presentation, fetus 2
        "O642XX3",  # Obstructed labor due to face presentation, fetus 3
        "O642XX4",  # Obstructed labor due to face presentation, fetus 4
        "O642XX5",  # Obstructed labor due to face presentation, fetus 5
        "O642XX9",  # Obstructed labor due to face presentation, other fetus
        "O643XX0",  # Obstructed labor due to brow presentation, not applicable or unspecified
        "O643XX1",  # Obstructed labor due to brow presentation, fetus 1
        "O643XX2",  # Obstructed labor due to brow presentation, fetus 2
        "O643XX3",  # Obstructed labor due to brow presentation, fetus 3
        "O643XX4",  # Obstructed labor due to brow presentation, fetus 4
        "O643XX5",  # Obstructed labor due to brow presentation, fetus 5
        "O643XX9",  # Obstructed labor due to brow presentation, other fetus
        "O644XX0",  # Obstructed labor due to shoulder presentation, not applicable or unspecified
        "O644XX1",  # Obstructed labor due to shoulder presentation, fetus 1
        "O644XX2",  # Obstructed labor due to shoulder presentation, fetus 2
        "O644XX3",  # Obstructed labor due to shoulder presentation, fetus 3
        "O644XX4",  # Obstructed labor due to shoulder presentation, fetus 4
        "O644XX5",  # Obstructed labor due to shoulder presentation, fetus 5
        "O644XX9",  # Obstructed labor due to shoulder presentation, other fetus
        "O645XX0",  # Obstructed labor due to compound presentation, not applicable or unspecified
        "O645XX1",  # Obstructed labor due to compound presentation, fetus 1
        "O645XX2",  # Obstructed labor due to compound presentation, fetus 2
        "O645XX3",  # Obstructed labor due to compound presentation, fetus 3
        "O645XX4",  # Obstructed labor due to compound presentation, fetus 4
        "O645XX5",  # Obstructed labor due to compound presentation, fetus 5
        "O645XX9",  # Obstructed labor due to compound presentation, other fetus
        "O648XX0",  # Obstructed labor due to other malposition and malpresentation, not applicable or unspecified
        "O648XX1",  # Obstructed labor due to other malposition and malpresentation, fetus 1
        "O648XX2",  # Obstructed labor due to other malposition and malpresentation, fetus 2
        "O648XX3",  # Obstructed labor due to other malposition and malpresentation, fetus 3
        "O648XX4",  # Obstructed labor due to other malposition and malpresentation, fetus 4
        "O648XX5",  # Obstructed labor due to other malposition and malpresentation, fetus 5
        "O648XX9",  # Obstructed labor due to other malposition and malpresentation, other fetus
        "O649XX0",  # Obstructed labor due to malposition and malpresentation, unspecified, not applicable or unspecified
        "O649XX1",  # Obstructed labor due to malposition and malpresentation, unspecified, fetus 1
        "O649XX2",  # Obstructed labor due to malposition and malpresentation, unspecified, fetus 2
        "O649XX3",  # Obstructed labor due to malposition and malpresentation, unspecified, fetus 3
        "O649XX4",  # Obstructed labor due to malposition and malpresentation, unspecified, fetus 4
        "O649XX5",  # Obstructed labor due to malposition and malpresentation, unspecified, fetus 5
        "O649XX9",  # Obstructed labor due to malposition and malpresentation, unspecified, other fetus
        "O650",  # Obstructed labor due to deformed pelvis
        "O651",  # Obstructed labor due to generally contracted pelvis
        "O652",  # Obstructed labor due to pelvic inlet contraction
        "O653",  # Obstructed labor due to pelvic outlet and mid-cavity contraction
        "O654",  # Obstructed labor due to fetopelvic disproportion, unspecified
        "O655",  # Obstructed labor due to abnormality of maternal pelvic organs
        "O658",  # Obstructed labor due to other maternal pelvic abnormalities
        "O659",  # Obstructed labor due to maternal pelvic abnormality, unspecified
        "O660",  # Obstructed labor due to shoulder dystocia
        "O661",  # Obstructed labor due to locked twins
        "O662",  # Obstructed labor due to unusually large fetus
        "O663",  # Obstructed labor due to other abnormalities of fetus
        "O6640",  # Failed trial of labor, unspecified
        "O6641",  # Failed attempted vaginal birth after previous cesarean delivery
        "O665",  # Attempted application of vacuum extractor and forceps
        "O666",  # Obstructed labor due to other multiple fetuses
        "O668",  # Other specified obstructed labor
        "O669",  # Obstructed labor, unspecified
        "O670",  # Intrapartum hemorrhage with coagulation defect
        "O678",  # Other intrapartum hemorrhage
        "O679",  # Intrapartum hemorrhage, unspecified
        "O68",  # Labor and delivery complicated by abnormality of fetal acid-base balance
        "O690XX0",  # Labor and delivery complicated by prolapse of cord, not applicable or unspecified
        "O690XX1",  # Labor and delivery complicated by prolapse of cord, fetus 1
        "O690XX2",  # Labor and delivery complicated by prolapse of cord, fetus 2
        "O690XX3",  # Labor and delivery complicated by prolapse of cord, fetus 3
        "O690XX4",  # Labor and delivery complicated by prolapse of cord, fetus 4
        "O690XX5",  # Labor and delivery complicated by prolapse of cord, fetus 5
        "O690XX9",  # Labor and delivery complicated by prolapse of cord, other fetus
        "O691XX0",  # Labor and delivery complicated by cord around neck, with compression, not applicable or unspecified
        "O691XX1",  # Labor and delivery complicated by cord around neck, with compression, fetus 1
        "O691XX2",  # Labor and delivery complicated by cord around neck, with compression, fetus 2
        "O691XX3",  # Labor and delivery complicated by cord around neck, with compression, fetus 3
        "O691XX4",  # Labor and delivery complicated by cord around neck, with compression, fetus 4
        "O691XX5",  # Labor and delivery complicated by cord around neck, with compression, fetus 5
        "O691XX9",  # Labor and delivery complicated by cord around neck, with compression, other fetus
        "O692XX0",  # Labor and delivery complicated by other cord entanglement, with compression, not applicable or unspecified
        "O692XX1",  # Labor and delivery complicated by other cord entanglement, with compression, fetus 1
        "O692XX2",  # Labor and delivery complicated by other cord entanglement, with compression, fetus 2
        "O692XX3",  # Labor and delivery complicated by other cord entanglement, with compression, fetus 3
        "O692XX4",  # Labor and delivery complicated by other cord entanglement, with compression, fetus 4
        "O692XX5",  # Labor and delivery complicated by other cord entanglement, with compression, fetus 5
        "O692XX9",  # Labor and delivery complicated by other cord entanglement, with compression, other fetus
        "O693XX0",  # Labor and delivery complicated by short cord, not applicable or unspecified
        "O693XX1",  # Labor and delivery complicated by short cord, fetus 1
        "O693XX2",  # Labor and delivery complicated by short cord, fetus 2
        "O693XX3",  # Labor and delivery complicated by short cord, fetus 3
        "O693XX4",  # Labor and delivery complicated by short cord, fetus 4
        "O693XX5",  # Labor and delivery complicated by short cord, fetus 5
        "O693XX9",  # Labor and delivery complicated by short cord, other fetus
        "O694XX0",  # Labor and delivery complicated by vasa previa, not applicable or unspecified
        "O694XX1",  # Labor and delivery complicated by vasa previa, fetus 1
        "O694XX2",  # Labor and delivery complicated by vasa previa, fetus 2
        "O694XX3",  # Labor and delivery complicated by vasa previa, fetus 3
        "O694XX4",  # Labor and delivery complicated by vasa previa, fetus 4
        "O694XX5",  # Labor and delivery complicated by vasa previa, fetus 5
        "O694XX9",  # Labor and delivery complicated by vasa previa, other fetus
        "O695XX0",  # Labor and delivery complicated by vascular lesion of cord, not applicable or unspecified
        "O695XX1",  # Labor and delivery complicated by vascular lesion of cord, fetus 1
        "O695XX2",  # Labor and delivery complicated by vascular lesion of cord, fetus 2
        "O695XX3",  # Labor and delivery complicated by vascular lesion of cord, fetus 3
        "O695XX4",  # Labor and delivery complicated by vascular lesion of cord, fetus 4
        "O695XX5",  # Labor and delivery complicated by vascular lesion of cord, fetus 5
        "O695XX9",  # Labor and delivery complicated by vascular lesion of cord, other fetus
        "O6981X0",  # Labor and delivery complicated by cord around neck, without compression, not applicable or unspecified
        "O6981X1",  # Labor and delivery complicated by cord around neck, without compression, fetus 1
        "O6981X2",  # Labor and delivery complicated by cord around neck, without compression, fetus 2
        "O6981X3",  # Labor and delivery complicated by cord around neck, without compression, fetus 3
        "O6981X4",  # Labor and delivery complicated by cord around neck, without compression, fetus 4
        "O6981X5",  # Labor and delivery complicated by cord around neck, without compression, fetus 5
        "O6981X9",  # Labor and delivery complicated by cord around neck, without compression, other fetus
        "O6982X0",  # Labor and delivery complicated by other cord entanglement, without compression, not applicable or unspecified
        "O6982X1",  # Labor and delivery complicated by other cord entanglement, without compression, fetus 1
        "O6982X2",  # Labor and delivery complicated by other cord entanglement, without compression, fetus 2
        "O6982X3",  # Labor and delivery complicated by other cord entanglement, without compression, fetus 3
        "O6982X4",  # Labor and delivery complicated by other cord entanglement, without compression, fetus 4
        "O6982X5",  # Labor and delivery complicated by other cord entanglement, without compression, fetus 5
        "O6982X9",  # Labor and delivery complicated by other cord entanglement, without compression, other fetus
        "O6989X0",  # Labor and delivery complicated by other cord complications, not applicable or unspecified
        "O6989X1",  # Labor and delivery complicated by other cord complications, fetus 1
        "O6989X2",  # Labor and delivery complicated by other cord complications, fetus 2
        "O6989X3",  # Labor and delivery complicated by other cord complications, fetus 3
        "O6989X4",  # Labor and delivery complicated by other cord complications, fetus 4
        "O6989X5",  # Labor and delivery complicated by other cord complications, fetus 5
        "O6989X9",  # Labor and delivery complicated by other cord complications, other fetus
        "O699XX0",  # Labor and delivery complicated by cord complication, unspecified, not applicable or unspecified
        "O699XX1",  # Labor and delivery complicated by cord complication, unspecified, fetus 1
        "O699XX2",  # Labor and delivery complicated by cord complication, unspecified, fetus 2
        "O699XX3",  # Labor and delivery complicated by cord complication, unspecified, fetus 3
        "O699XX4",  # Labor and delivery complicated by cord complication, unspecified, fetus 4
        "O699XX5",  # Labor and delivery complicated by cord complication, unspecified, fetus 5
        "O699XX9",  # Labor and delivery complicated by cord complication, unspecified, other fetus
        "O700",  # First degree perineal laceration during delivery
        "O701",  # Second degree perineal laceration during delivery
        "O7020",  # Third degree perineal laceration during delivery, unspecified
        "O7021",  # Third degree perineal laceration during delivery, IIIa
        "O7022",  # Third degree perineal laceration during delivery, IIIb
        "O7023",  # Third degree perineal laceration during delivery, IIIc
        "O703",  # Fourth degree perineal laceration during delivery
        "O704",  # Anal sphincter tear complicating delivery, not associated with third degree laceration
        "O709",  # Perineal laceration during delivery, unspecified
        "O7100",  # Rupture of uterus before onset of labor, unspecified trimester
        "O7102",  # Rupture of uterus before onset of labor, second trimester
        "O7103",  # Rupture of uterus before onset of labor, third trimester
        "O711",  # Rupture of uterus during labor
        "O712",  # Postpartum inversion of uterus
        "O713",  # Obstetric laceration of cervix
        "O714",  # Obstetric high vaginal laceration alone
        "O715",  # Other obstetric injury to pelvic organs
        "O716",  # Obstetric damage to pelvic joints and ligaments
        "O717",  # Obstetric hematoma of pelvis
        "O7181",  # Laceration of uterus, not elsewhere classified
        "O7182",  # Other specified trauma to perineum and vulva
        "O7189",  # Other specified obstetric trauma
        "O719",  # Obstetric trauma, unspecified
        "O720",  # Third-stage hemorrhage
        "O721",  # Other immediate postpartum hemorrhage
        "O722",  # Delayed and secondary postpartum hemorrhage
        "O723",  # Postpartum coagulation defects
        "O730",  # Retained placenta without hemorrhage
        "O731",  # Retained portions of placenta and membranes, without hemorrhage
        "O740",  # Aspiration pneumonitis due to anesthesia during labor and delivery
        "O741",  # Other pulmonary complications of anesthesia during labor and delivery
        "O742",  # Cardiac complications of anesthesia during labor and delivery
        "O743",  # Central nervous system complications of anesthesia during labor and delivery
        "O744",  # Toxic reaction to local anesthesia during labor and delivery
        "O745",  # Spinal and epidural anesthesia-induced headache during labor and delivery
        "O746",  # Other complications of spinal and epidural anesthesia during labor and delivery
        "O747",  # Failed or difficult intubation for anesthesia during labor and delivery
        "O748",  # Other complications of anesthesia during labor and delivery
        "O749",  # Complication of anesthesia during labor and delivery, unspecified
        "O750",  # Maternal distress during labor and delivery
        "O751",  # Shock during or following labor and delivery
        "O752",  # Pyrexia during labor, not elsewhere classified
        "O753",  # Other infection during labor
        "O754",  # Other complications of obstetric surgery and procedures
        "O755",  # Delayed delivery after artificial rupture of membranes
        "O7581",  # Maternal exhaustion complicating labor and delivery
        "O7582",  # Onset (spontaneous) of labor after 37 completed weeks of gestation but before 39 completed weeks gestation, with delivery by (planned) cesarean section
        "O7589",  # Other specified complications of labor and delivery
        "O759",  # Complication of labor and delivery, unspecified
        "O76",  # Abnormality in fetal heart rate and rhythm complicating labor and delivery
        "O770",  # Labor and delivery complicated by meconium in amniotic fluid
        "O771",  # Fetal stress in labor or delivery due to drug administration
        "O778",  # Labor and delivery complicated by other evidence of fetal stress
        "O779",  # Labor and delivery complicated by fetal stress, unspecified
        "O80",  # Encounter for full-term uncomplicated delivery
        "O82",  # Encounter for cesarean delivery without indication
        "O85",  # Puerperal sepsis
        "O8600",  # Infection of obstetric surgical wound, unspecified
        "O8601",  # Infection of obstetric surgical wound, superficial incisional site
        "O8602",  # Infection of obstetric surgical wound, deep incisional site
        "O8603",  # Infection of obstetric surgical wound, organ and space site
        "O8604",  # Sepsis following an obstetrical procedure
        "O8609",  # Infection of obstetric surgical wound, other surgical site
        "O8611",  # Cervicitis following delivery
        "O8612",  # Endometritis following delivery
        "O8613",  # Vaginitis following delivery
        "O8619",  # Other infection of genital tract following delivery
        "O8620",  # Urinary tract infection following delivery, unspecified
        "O8621",  # Infection of kidney following delivery
        "O8622",  # Infection of bladder following delivery
        "O8629",  # Other urinary tract infection following delivery
        "O864",  # Pyrexia of unknown origin following delivery
        "O8681",  # Puerperal septic thrombophlebitis
        "O8689",  # Other specified puerperal infections
        "O870",  # Superficial thrombophlebitis in the puerperium
        "O871",  # Deep phlebothrombosis in the puerperium
        "O872",  # Hemorrhoids in the puerperium
        "O873",  # Cerebral venous thrombosis in the puerperium
        "O874",  # Varicose veins of lower extremity in the puerperium
        "O878",  # Other venous complications in the puerperium
        "O879",  # Venous complication in the puerperium, unspecified
        "O88011",  # Air embolism in pregnancy, first trimester
        "O88012",  # Air embolism in pregnancy, second trimester
        "O88013",  # Air embolism in pregnancy, third trimester
        "O88019",  # Air embolism in pregnancy, unspecified trimester
        "O8802",  # Air embolism in childbirth
        "O8803",  # Air embolism in the puerperium
        "O88111",  # Amniotic fluid embolism in pregnancy, first trimester
        "O88112",  # Amniotic fluid embolism in pregnancy, second trimester
        "O88113",  # Amniotic fluid embolism in pregnancy, third trimester
        "O88119",  # Amniotic fluid embolism in pregnancy, unspecified trimester
        "O8812",  # Amniotic fluid embolism in childbirth
        "O8813",  # Amniotic fluid embolism in the puerperium
        "O88211",  # Thromboembolism in pregnancy, first trimester
        "O88212",  # Thromboembolism in pregnancy, second trimester
        "O88213",  # Thromboembolism in pregnancy, third trimester
        "O88219",  # Thromboembolism in pregnancy, unspecified trimester
        "O8822",  # Thromboembolism in childbirth
        "O8823",  # Thromboembolism in the puerperium
        "O88311",  # Pyemic and septic embolism in pregnancy, first trimester
        "O88312",  # Pyemic and septic embolism in pregnancy, second trimester
        "O88313",  # Pyemic and septic embolism in pregnancy, third trimester
        "O88319",  # Pyemic and septic embolism in pregnancy, unspecified trimester
        "O8832",  # Pyemic and septic embolism in childbirth
        "O8833",  # Pyemic and septic embolism in the puerperium
        "O88811",  # Other embolism in pregnancy, first trimester
        "O88812",  # Other embolism in pregnancy, second trimester
        "O88813",  # Other embolism in pregnancy, third trimester
        "O88819",  # Other embolism in pregnancy, unspecified trimester
        "O8882",  # Other embolism in childbirth
        "O8883",  # Other embolism in the puerperium
        "O8901",  # Aspiration pneumonitis due to anesthesia during the puerperium
        "O8909",  # Other pulmonary complications of anesthesia during the puerperium
        "O891",  # Cardiac complications of anesthesia during the puerperium
        "O892",  # Central nervous system complications of anesthesia during the puerperium
        "O893",  # Toxic reaction to local anesthesia during the puerperium
        "O894",  # Spinal and epidural anesthesia-induced headache during the puerperium
        "O895",  # Other complications of spinal and epidural anesthesia during the puerperium
        "O896",  # Failed or difficult intubation for anesthesia during the puerperium
        "O898",  # Other complications of anesthesia during the puerperium
        "O899",  # Complication of anesthesia during the puerperium, unspecified
        "O900",  # Disruption of cesarean delivery wound
        "O901",  # Disruption of perineal obstetric wound
        "O902",  # Hematoma of obstetric wound
        "O903",  # Peripartum cardiomyopathy
        "O9041",  # Hepatorenal syndrome following labor and delivery
        "O9049",  # Other postpartum acute kidney failure
        "O905",  # Postpartum thyroiditis
        "O906",  # Postpartum mood disturbance
        "O9081",  # Anemia of the puerperium
        "O9089",  # Other complications of the puerperium, not elsewhere classified
        "O909",  # Complication of the puerperium, unspecified
        "O91011",  # Infection of nipple associated with pregnancy, first trimester
        "O91012",  # Infection of nipple associated with pregnancy, second trimester
        "O91013",  # Infection of nipple associated with pregnancy, third trimester
        "O91019",  # Infection of nipple associated with pregnancy, unspecified trimester
        "O9102",  # Infection of nipple associated with the puerperium
        "O9103",  # Infection of nipple associated with lactation
        "O91111",  # Abscess of breast associated with pregnancy, first trimester
        "O91112",  # Abscess of breast associated with pregnancy, second trimester
        "O91113",  # Abscess of breast associated with pregnancy, third trimester
        "O91119",  # Abscess of breast associated with pregnancy, unspecified trimester
        "O9112",  # Abscess of breast associated with the puerperium
        "O9113",  # Abscess of breast associated with lactation
        "O91211",  # Nonpurulent mastitis associated with pregnancy, first trimester
        "O91212",  # Nonpurulent mastitis associated with pregnancy, second trimester
        "O91213",  # Nonpurulent mastitis associated with pregnancy, third trimester
        "O91219",  # Nonpurulent mastitis associated with pregnancy, unspecified trimester
        "O9122",  # Nonpurulent mastitis associated with the puerperium
        "O9123",  # Nonpurulent mastitis associated with lactation
        "O92011",  # Retracted nipple associated with pregnancy, first trimester
        "O92012",  # Retracted nipple associated with pregnancy, second trimester
        "O92013",  # Retracted nipple associated with pregnancy, third trimester
        "O92019",  # Retracted nipple associated with pregnancy, unspecified trimester
        "O9202",  # Retracted nipple associated with the puerperium
        "O9203",  # Retracted nipple associated with lactation
        "O92111",  # Cracked nipple associated with pregnancy, first trimester
        "O92112",  # Cracked nipple associated with pregnancy, second trimester
        "O92113",  # Cracked nipple associated with pregnancy, third trimester
        "O92119",  # Cracked nipple associated with pregnancy, unspecified trimester
        "O9212",  # Cracked nipple associated with the puerperium
        "O9213",  # Cracked nipple associated with lactation
        "O9220",  # Unspecified disorder of breast associated with pregnancy and the puerperium
        "O9229",  # Other disorders of breast associated with pregnancy and the puerperium
        "O923",  # Agalactia
        "O924",  # Hypogalactia
        "O925",  # Suppressed lactation
        "O926",  # Galactorrhea
        "O9270",  # Unspecified disorders of lactation
        "O9279",  # Other disorders of lactation
        "O94",  # Sequelae of complication of pregnancy, childbirth, and the puerperium
        "O98011",  # Tuberculosis complicating pregnancy, first trimester
        "O98012",  # Tuberculosis complicating pregnancy, second trimester
        "O98013",  # Tuberculosis complicating pregnancy, third trimester
        "O98019",  # Tuberculosis complicating pregnancy, unspecified trimester
        "O9802",  # Tuberculosis complicating childbirth
        "O9803",  # Tuberculosis complicating the puerperium
        "O98111",  # Syphilis complicating pregnancy, first trimester
        "O98112",  # Syphilis complicating pregnancy, second trimester
        "O98113",  # Syphilis complicating pregnancy, third trimester
        "O98119",  # Syphilis complicating pregnancy, unspecified trimester
        "O9812",  # Syphilis complicating childbirth
        "O9813",  # Syphilis complicating the puerperium
        "O98211",  # Gonorrhea complicating pregnancy, first trimester
        "O98212",  # Gonorrhea complicating pregnancy, second trimester
        "O98213",  # Gonorrhea complicating pregnancy, third trimester
        "O98219",  # Gonorrhea complicating pregnancy, unspecified trimester
        "O9822",  # Gonorrhea complicating childbirth
        "O9823",  # Gonorrhea complicating the puerperium
        "O98311",  # Other infections with a predominantly sexual mode of transmission complicating pregnancy, first trimester
        "O98312",  # Other infections with a predominantly sexual mode of transmission complicating pregnancy, second trimester
        "O98313",  # Other infections with a predominantly sexual mode of transmission complicating pregnancy, third trimester
        "O98319",  # Other infections with a predominantly sexual mode of transmission complicating pregnancy, unspecified trimester
        "O9832",  # Other infections with a predominantly sexual mode of transmission complicating childbirth
        "O9833",  # Other infections with a predominantly sexual mode of transmission complicating the puerperium
        "O98411",  # Viral hepatitis complicating pregnancy, first trimester
        "O98412",  # Viral hepatitis complicating pregnancy, second trimester
        "O98413",  # Viral hepatitis complicating pregnancy, third trimester
        "O98419",  # Viral hepatitis complicating pregnancy, unspecified trimester
        "O9842",  # Viral hepatitis complicating childbirth
        "O9843",  # Viral hepatitis complicating the puerperium
        "O98511",  # Other viral diseases complicating pregnancy, first trimester
        "O98512",  # Other viral diseases complicating pregnancy, second trimester
        "O98513",  # Other viral diseases complicating pregnancy, third trimester
        "O98519",  # Other viral diseases complicating pregnancy, unspecified trimester
        "O9852",  # Other viral diseases complicating childbirth
        "O9853",  # Other viral diseases complicating the puerperium
        "O98611",  # Protozoal diseases complicating pregnancy, first trimester
        "O98612",  # Protozoal diseases complicating pregnancy, second trimester
        "O98613",  # Protozoal diseases complicating pregnancy, third trimester
        "O98619",  # Protozoal diseases complicating pregnancy, unspecified trimester
        "O9862",  # Protozoal diseases complicating childbirth
        "O9863",  # Protozoal diseases complicating the puerperium
        "O98711",  # Human immunodeficiency virus [HIV] disease complicating pregnancy, first trimester
        "O98712",  # Human immunodeficiency virus [HIV] disease complicating pregnancy, second trimester
        "O98713",  # Human immunodeficiency virus [HIV] disease complicating pregnancy, third trimester
        "O98719",  # Human immunodeficiency virus [HIV] disease complicating pregnancy, unspecified trimester
        "O9872",  # Human immunodeficiency virus [HIV] disease complicating childbirth
        "O9873",  # Human immunodeficiency virus [HIV] disease complicating the puerperium
        "O98811",  # Other maternal infectious and parasitic diseases complicating pregnancy, first trimester
        "O98812",  # Other maternal infectious and parasitic diseases complicating pregnancy, second trimester
        "O98813",  # Other maternal infectious and parasitic diseases complicating pregnancy, third trimester
        "O98819",  # Other maternal infectious and parasitic diseases complicating pregnancy, unspecified trimester
        "O9882",  # Other maternal infectious and parasitic diseases complicating childbirth
        "O9883",  # Other maternal infectious and parasitic diseases complicating the puerperium
        "O98911",  # Unspecified maternal infectious and parasitic disease complicating pregnancy, first trimester
        "O98912",  # Unspecified maternal infectious and parasitic disease complicating pregnancy, second trimester
        "O98913",  # Unspecified maternal infectious and parasitic disease complicating pregnancy, third trimester
        "O98919",  # Unspecified maternal infectious and parasitic disease complicating pregnancy, unspecified trimester
        "O9892",  # Unspecified maternal infectious and parasitic disease complicating childbirth
        "O9893",  # Unspecified maternal infectious and parasitic disease complicating the puerperium
        "O99011",  # Anemia complicating pregnancy, first trimester
        "O99012",  # Anemia complicating pregnancy, second trimester
        "O99013",  # Anemia complicating pregnancy, third trimester
        "O99019",  # Anemia complicating pregnancy, unspecified trimester
        "O9902",  # Anemia complicating childbirth
        "O9903",  # Anemia complicating the puerperium
        "O99111",  # Other diseases of the blood and blood-forming organs and certain disorders involving the immune mechanism complicating pregnancy, first trimester
        "O99112",  # Other diseases of the blood and blood-forming organs and certain disorders involving the immune mechanism complicating pregnancy, second trimester
        "O99113",  # Other diseases of the blood and blood-forming organs and certain disorders involving the immune mechanism complicating pregnancy, third trimester
        "O99119",  # Other diseases of the blood and blood-forming organs and certain disorders involving the immune mechanism complicating pregnancy, unspecified trimester
        "O9912",  # Other diseases of the blood and blood-forming organs and certain disorders involving the immune mechanism complicating childbirth
        "O9913",  # Other diseases of the blood and blood-forming organs and certain disorders involving the immune mechanism complicating the puerperium
        "O99210",  # Obesity complicating pregnancy, unspecified trimester
        "O99211",  # Obesity complicating pregnancy, first trimester
        "O99212",  # Obesity complicating pregnancy, second trimester
        "O99213",  # Obesity complicating pregnancy, third trimester
        "O99214",  # Obesity complicating childbirth
        "O99215",  # Obesity complicating the puerperium
        "O99280",  # Endocrine, nutritional and metabolic diseases complicating pregnancy, unspecified trimester
        "O99281",  # Endocrine, nutritional and metabolic diseases complicating pregnancy, first trimester
        "O99282",  # Endocrine, nutritional and metabolic diseases complicating pregnancy, second trimester
        "O99283",  # Endocrine, nutritional and metabolic diseases complicating pregnancy, third trimester
        "O99284",  # Endocrine, nutritional and metabolic diseases complicating childbirth
        "O99285",  # Endocrine, nutritional and metabolic diseases complicating the puerperium
        "O99310",  # Alcohol use complicating pregnancy, unspecified trimester
        "O99311",  # Alcohol use complicating pregnancy, first trimester
        "O99312",  # Alcohol use complicating pregnancy, second trimester
        "O99313",  # Alcohol use complicating pregnancy, third trimester
        "O99314",  # Alcohol use complicating childbirth
        "O99315",  # Alcohol use complicating the puerperium
        "O99320",  # Drug use complicating pregnancy, unspecified trimester
        "O99321",  # Drug use complicating pregnancy, first trimester
        "O99322",  # Drug use complicating pregnancy, second trimester
        "O99323",  # Drug use complicating pregnancy, third trimester
        "O99324",  # Drug use complicating childbirth
        "O99325",  # Drug use complicating the puerperium
        "O99330",  # Smoking (tobacco) complicating pregnancy, unspecified trimester
        "O99331",  # Smoking (tobacco) complicating pregnancy, first trimester
        "O99332",  # Smoking (tobacco) complicating pregnancy, second trimester
        "O99333",  # Smoking (tobacco) complicating pregnancy, third trimester
        "O99334",  # Smoking (tobacco) complicating childbirth
        "O99335",  # Smoking (tobacco) complicating the puerperium
        "O99340",  # Other mental disorders complicating pregnancy, unspecified trimester
        "O99341",  # Other mental disorders complicating pregnancy, first trimester
        "O99342",  # Other mental disorders complicating pregnancy, second trimester
        "O99343",  # Other mental disorders complicating pregnancy, third trimester
        "O99344",  # Other mental disorders complicating childbirth
        "O99345",  # Other mental disorders complicating the puerperium
        "O99350",  # Diseases of the nervous system complicating pregnancy, unspecified trimester
        "O99351",  # Diseases of the nervous system complicating pregnancy, first trimester
        "O99352",  # Diseases of the nervous system complicating pregnancy, second trimester
        "O99353",  # Diseases of the nervous system complicating pregnancy, third trimester
        "O99354",  # Diseases of the nervous system complicating childbirth
        "O99355",  # Diseases of the nervous system complicating the puerperium
        "O99411",  # Diseases of the circulatory system complicating pregnancy, first trimester
        "O99412",  # Diseases of the circulatory system complicating pregnancy, second trimester
        "O99413",  # Diseases of the circulatory system complicating pregnancy, third trimester
        "O99419",  # Diseases of the circulatory system complicating pregnancy, unspecified trimester
        "O9942",  # Diseases of the circulatory system complicating childbirth
        "O9943",  # Diseases of the circulatory system complicating the puerperium
        "O99511",  # Diseases of the respiratory system complicating pregnancy, first trimester
        "O99512",  # Diseases of the respiratory system complicating pregnancy, second trimester
        "O99513",  # Diseases of the respiratory system complicating pregnancy, third trimester
        "O99519",  # Diseases of the respiratory system complicating pregnancy, unspecified trimester
        "O9952",  # Diseases of the respiratory system complicating childbirth
        "O9953",  # Diseases of the respiratory system complicating the puerperium
        "O99611",  # Diseases of the digestive system complicating pregnancy, first trimester
        "O99612",  # Diseases of the digestive system complicating pregnancy, second trimester
        "O99613",  # Diseases of the digestive system complicating pregnancy, third trimester
        "O99619",  # Diseases of the digestive system complicating pregnancy, unspecified trimester
        "O9962",  # Diseases of the digestive system complicating childbirth
        "O9963",  # Diseases of the digestive system complicating the puerperium
        "O99711",  # Diseases of the skin and subcutaneous tissue complicating pregnancy, first trimester
        "O99712",  # Diseases of the skin and subcutaneous tissue complicating pregnancy, second trimester
        "O99713",  # Diseases of the skin and subcutaneous tissue complicating pregnancy, third trimester
        "O99719",  # Diseases of the skin and subcutaneous tissue complicating pregnancy, unspecified trimester
        "O9972",  # Diseases of the skin and subcutaneous tissue complicating childbirth
        "O9973",  # Diseases of the skin and subcutaneous tissue complicating the puerperium
        "O99810",  # Abnormal glucose complicating pregnancy
        "O99814",  # Abnormal glucose complicating childbirth
        "O99815",  # Abnormal glucose complicating the puerperium
        "O99820",  # Streptococcus B carrier state complicating pregnancy
        "O99824",  # Streptococcus B carrier state complicating childbirth
        "O99825",  # Streptococcus B carrier state complicating the puerperium
        "O99830",  # Other infection carrier state complicating pregnancy
        "O99834",  # Other infection carrier state complicating childbirth
        "O99835",  # Other infection carrier state complicating the puerperium
        "O99840",  # Bariatric surgery status complicating pregnancy, unspecified trimester
        "O99841",  # Bariatric surgery status complicating pregnancy, first trimester
        "O99842",  # Bariatric surgery status complicating pregnancy, second trimester
        "O99843",  # Bariatric surgery status complicating pregnancy, third trimester
        "O99844",  # Bariatric surgery status complicating childbirth
        "O99845",  # Bariatric surgery status complicating the puerperium
        "O99891",  # Other specified diseases and conditions complicating pregnancy
        "O99892",  # Other specified diseases and conditions complicating childbirth
        "O99893",  # Other specified diseases and conditions complicating puerperium
        "O9A111",  # Malignant neoplasm complicating pregnancy, first trimester
        "O9A112",  # Malignant neoplasm complicating pregnancy, second trimester
        "O9A113",  # Malignant neoplasm complicating pregnancy, third trimester
        "O9A119",  # Malignant neoplasm complicating pregnancy, unspecified trimester
        "O9A12",  # Malignant neoplasm complicating childbirth
        "O9A13",  # Malignant neoplasm complicating the puerperium
        "O9A211",  # Injury, poisoning and certain other consequences of external causes complicating pregnancy, first trimester
        "O9A212",  # Injury, poisoning and certain other consequences of external causes complicating pregnancy, second trimester
        "O9A213",  # Injury, poisoning and certain other consequences of external causes complicating pregnancy, third trimester
        "O9A219",  # Injury, poisoning and certain other consequences of external causes complicating pregnancy, unspecified trimester
        "O9A22",  # Injury, poisoning and certain other consequences of external causes complicating childbirth
        "O9A23",  # Injury, poisoning and certain other consequences of external causes complicating the puerperium
        "O9A311",  # Physical abuse complicating pregnancy, first trimester
        "O9A312",  # Physical abuse complicating pregnancy, second trimester
        "O9A313",  # Physical abuse complicating pregnancy, third trimester
        "O9A319",  # Physical abuse complicating pregnancy, unspecified trimester
        "O9A32",  # Physical abuse complicating childbirth
        "O9A33",  # Physical abuse complicating the puerperium
        "O9A411",  # Sexual abuse complicating pregnancy, first trimester
        "O9A412",  # Sexual abuse complicating pregnancy, second trimester
        "O9A413",  # Sexual abuse complicating pregnancy, third trimester
        "O9A419",  # Sexual abuse complicating pregnancy, unspecified trimester
        "O9A42",  # Sexual abuse complicating childbirth
        "O9A43",  # Sexual abuse complicating the puerperium
        "O9A511",  # Psychological abuse complicating pregnancy, first trimester
        "O9A512",  # Psychological abuse complicating pregnancy, second trimester
        "O9A513",  # Psychological abuse complicating pregnancy, third trimester
        "O9A519",  # Psychological abuse complicating pregnancy, unspecified trimester
        "O9A52",  # Psychological abuse complicating childbirth
        "O9A53",  # Psychological abuse complicating the puerperium
        "Z3400",  # Encounter for supervision of normal first pregnancy, unspecified trimester
        "Z3401",  # Encounter for supervision of normal first pregnancy, first trimester
        "Z3402",  # Encounter for supervision of normal first pregnancy, second trimester
        "Z3403",  # Encounter for supervision of normal first pregnancy, third trimester
        "Z3480",  # Encounter for supervision of other normal pregnancy, unspecified trimester
        "Z3481",  # Encounter for supervision of other normal pregnancy, first trimester
        "Z3482",  # Encounter for supervision of other normal pregnancy, second trimester
        "Z3483",  # Encounter for supervision of other normal pregnancy, third trimester
        "Z3490",  # Encounter for supervision of normal pregnancy, unspecified, unspecified trimester
        "Z3491",  # Encounter for supervision of normal pregnancy, unspecified, first trimester
        "Z3492",  # Encounter for supervision of normal pregnancy, unspecified, second trimester
        "Z3493",  # Encounter for supervision of normal pregnancy, unspecified, third trimester
    }

    SNOMEDCT = {
        "100801000119107",  # Maternal tobacco use in pregnancy (finding)
        "10217006",  # Third degree perineal laceration (disorder)
        "102882004",  # Abnormal placental secretion of chorionic gonadotropin (disorder)
        "102885002",  # Absence of placental secretion of chorionic gonadotropin (disorder)
        "1052284009",  # Restless leg syndrome in pregnancy (disorder)
        "10562009",  # Malignant hypertension complicating AND/OR reason for care during childbirth (disorder)
        "10573002",  # Infection of amniotic cavity (disorder)
        "106004004",  # Hemorrhagic complication of pregnancy (disorder)
        "106005003",  # Hypertension AND/OR vomiting complicating pregnancy childbirth AND/OR puerperium (disorder)
        "106008001",  # Delivery AND/OR maternal condition affecting management (disorder)
        "106009009",  # Fetal condition affecting obstetrical care of mother (disorder)
        "106010004",  # Pelvic dystocia AND/OR uterine disorder (disorder)
        "106281000119103",  # Pre-existing diabetes mellitus in mother complicating childbirth (disorder)
        "10741751000119100",  # Anemia in mother complicating childbirth (disorder)
        "10741871000119101",  # Alcohol dependence in pregnancy (disorder)
        "10742121000119104",  # Asthma in mother complicating childbirth (disorder)
        "10742471000119108",  # Previous bariatric surgery in mother complicating childbirth (disorder)
        "10743001000119103",  # Anxiety disorder in mother complicating childbirth (disorder)
        "10743121000119108",  # Aortic valve disorder in mother complicating childbirth (disorder)
        "10743651000119105",  # Inflammation of cervix in pregnancy (disorder)
        "10743741000119103",  # Cardiac arrhythmia in mother complicating childbirth (disorder)
        "10743831000119100",  # Neoplasm of uterus affecting pregnancy (disorder)
        "10745231000119102",  # Cardiac arrest due to administration of anesthesia in pregnancy (disorder)
        "10745291000119103",  # Malignant neoplastic disease in mother complicating childbirth (disorder)
        "10746341000119109",  # Acquired immune deficiency syndrome complicating childbirth (disorder)
        "10749581000119100",  # Blood coagulation disorder complicating childbirth (disorder)
        "10749641000119106",  # Blood coagulation disorder complicating pregnancy (disorder)
        "10749811000119108",  # Obstetric anesthesia with central nervous system complication in childbirth (disorder)
        "10749871000119100",  # Malignant neoplastic disease in pregnancy (disorder)
        "10750051000119105",  # Chlamydia trachomatis infection in mother complicating childbirth (disorder)
        "10750111000119108",  # Breast lump in pregnancy (finding)
        "10750161000119106",  # Cholestasis of pregnancy complicating childbirth (disorder)
        "10750551000119100",  # Obesity in mother complicating childbirth (disorder)
        "10750951000119106",  # Epilepsy in mother complicating childbirth (disorder)
        "10750991000119101",  # Cyst of ovary in pregnancy (disorder)
        "10751471000119101",  # Nutritional deficiency in mother complicating childbirth (disorder)
        "10752251000119103",  # Galactorrhea in pregnancy (disorder)
        "10752641000119102",  # Eclampsia with pre-existing hypertension in childbirth (disorder)
        "10752771000119100",  # Renal failure after ectopic pregnancy (disorder)
        "10753101000119102",  # Heart disease in mother complicating childbirth (disorder)
        "10753491000119101",  # Gestational diabetes mellitus in childbirth (disorder)
        "10754031000119105",  # Gonorrhea in mother complicating childbirth (disorder)
        "10754331000119108",  # Air embolism in childbirth (disorder)
        "10754701000119100",  # Genital herpes simplex in mother complicating childbirth (disorder)
        "10754781000119108",  # Gallbladder calculus in mother complicating childbirth (disorder)
        "10754881000119104",  # Diabetes mellitus in mother complicating childbirth (disorder)
        "10754921000119106",  # Hyperthyroidism in childbirth (disorder)
        "10755041000119100",  # Alcohol dependence in childbirth (disorder)
        "10755381000119108",  # Postpartum iron deficiency anemia (disorder)
        "10755671000119100",  # Human immunodeficiency virus in mother complicating childbirth (disorder)
        "10755951000119102",  # Heart murmur in mother in childbirth (finding)
        "10756101000119107",  # Group B streptococcus infection in mother complicating childbirth (disorder)
        "10756261000119102",  # Physical abuse complicating childbirth (finding)
        "10756301000119105",  # Physical abuse complicating pregnancy (finding)
        "10757401000119104",  # Pre-existing hypertensive heart and chronic kidney disease in mother complicating childbirth (disorder)
        "10757441000119102",  # Pre-existing hypertensive heart disease in mother complicating childbirth (disorder)
        "10759111000119102",  # Viral hepatitis in mother complicating childbirth (disorder)
        "10759231000119102",  # Salpingo-oophoritis in pregnancy (disorder)
        "10759311000119104",  # Pulmonary embolism in childbirth (disorder)
        "10759351000119103",  # Sickle cell anemia in mother complicating childbirth (disorder)
        "10759401000119105",  # Sickle cell trait in mother complicating childbirth (disorder)
        "10759761000119100",  # Rubella in mother complicating childbirth (disorder)
        "10759841000119105",  # Sexually transmitted infectious disease in mother complicating childbirth (disorder)
        "10759881000119100",  # Tuberculosis in mother complicating childbirth (disorder)
        "10759921000119107",  # Syphilis in mother complicating childbirth (disorder)
        "10759961000119102",  # Viral disease in mother complicating childbirth (disorder)
        "10760001000119100",  # Thyroid disease in mother complicating childbirth (disorder)
        "10760041000119103",  # Thyroiditis in mother complicating childbirth (disorder)
        "10760081000119108",  # Pyemic and septic embolism in childbirth (disorder)
        "10760131000119108",  # Pyemic and septic embolism in pregnancy (disorder)
        "10760221000119101",  # Uterine prolapse in pregnancy (disorder)
        "10760341000119101",  # Retraction of nipple in pregnancy (finding)
        "10760381000119106",  # Thyroiditis in pregnancy (disorder)
        "10760421000119102",  # Psychotic disorder in mother complicating childbirth (disorder)
        "10760581000119104",  # Pain in round ligament in pregnancy (finding)
        "10760981000119107",  # Psychological abuse complicating pregnancy (finding)
        "10761061000119107",  # Sexual abuse complicating pregnancy (finding)
        "10805641000119102",  # Congenital cardiovascular anomaly in mother complicating childbirth (disorder)
        "10806241000119108",  # Thalassemia in mother complicating childbirth (disorder)
        "10807061000119103",  # Liver disorder in mother complicating childbirth (disorder)
        "10809061000119106",  # Malaria in mother complicating childbirth (disorder)
        "10809101000119109",  # Hypothyroidism in childbirth (disorder)
        "10809641000119100",  # Mitral valve disorder in mother complicating childbirth (disorder)
        "10811121000119102",  # Major depressive disorder in mother complicating childbirth (disorder)
        "10811201000119102",  # Mental disorder in mother complicating childbirth (disorder)
        "10812131000119108",  # Malnutrition in mother complicating childbirth (disorder)
        "10835781000119105",  # Amniotic fluid embolism in childbirth (disorder)
        "10835871000119104",  # Depressive disorder in mother complicating childbirth (disorder)
        "10835971000119109",  # Anti-A sensitization in pregnancy (disorder)
        "10836071000119101",  # Dislocation of symphysis pubis in pregnancy (disorder)
        "10853001",  # Obstetrical complication of general anesthesia (disorder)
        "10884004",  # Threatened abortion in third trimester (disorder)
        "109562007",  # Abnormal chorion (disorder)
        "109891004",  # Detached products of conception (disorder)
        "109892006",  # Detached chorionic villi (disorder)
        "109893001",  # Detached trophoblast (disorder)
        "109894007",  # Retained placenta (disorder)
        "109895008",  # Retained placental fragment (disorder)
        "110081000119109",  # Bacterial vaginosis in pregnancy (disorder)
        "110091000119107",  # Candidiasis of vagina in pregnancy (disorder)
        "111208003",  # Melasma gravidarum (disorder)
        "111365004",  # Funicular indirect inguinal hernia (disorder)
        "111438007",  # Hypertension secondary to renal disease in obstetric context (disorder)
        "111447004",  # Placental condition affecting management of mother (disorder)
        "111451002",  # Obstetrical injury to pelvic organ (disorder)
        "111452009",  # Postpartum afibrinogenemia with hemorrhage (disorder)
        "111453004",  # Retained placenta, without hemorrhage (disorder)
        "111458008",  # Venous thrombosis in puerperium (disorder)
        "111459000",  # Infection of nipple, associated with childbirth (disorder)
        "112073004",  # Right sacroposterior position (finding)
        "11246006",  # Brow left anterior position (finding)
        "1125006",  # Sepsis during labor (disorder)
        "1144435009",  # Varicose veins of perineum in pregnancy (disorder)
        "1144807000",  # Varicose veins of bilateral lower limbs in pregnancy (disorder)
        "11454006",  # Failed attempted abortion with amniotic fluid embolism (disorder)
        "1148583001",  # Phlebitis in pregnancy (disorder)
        "1148584007",  # Venous thrombosis in pregnancy (disorder)
        "1148587000",  # Phlegmasia alba dolens in pregnancy (disorder)
        "1149472000",  # Thrombophlebitis of bilateral lower limbs in pregnancy (disorder)
        "1156027008",  # Thrombus of dural sinus in pregnancy (disorder)
        "1156031002",  # Venous varices in pregnancy (disorder)
        "11612004",  # Chorioamnionitis (disorder)
        "11618000",  # Intra-amniotic infection of fetus (disorder)
        "11687002",  # Gestational diabetes mellitus (disorder)
        "11718971000119100",  # Diarrhea in pregnancy (disorder)
        "11763009",  # Placenta increta (disorder)
        "11914001",  # Transverse OR oblique presentation of fetus (disorder)
        "11942004",  # Perineal laceration involving pelvic floor (disorder)
        "1204037006",  # Sepsis following induced termination of pregnancy (disorder)
        "1220564001",  # Incomplete induced termination of pregnancy complicated by shock (disorder)
        "1220586000",  # Incomplete induced termination of pregnancy complicated by renal failure (disorder)
        "1220625008",  # Incomplete induced termination of pregnancy complicated by metabolic disorder (disorder)
        "1220626009",  # Incomplete induced termination of pregnancy complicated by genital-pelvic infection (disorder)
        "1220630007",  # Incomplete induced termination of pregnancy complicated by embolism (disorder)
        "1220631006",  # Incomplete induced termination of pregnancy complicated by delayed or excessive hemorrhage (disorder)
        "1220632004",  # Incomplete induced termination of pregnancy complicated by damage to pelvic organs or tissues (disorder)
        "1220645000",  # Shock due to and following complete induced termination of pregnancy (disorder)
        "1220648003",  # Renal failure due to and following complete induced termination of pregnancy (disorder)
        "1220651005",  # Metabolic disease due to and following complete induced termination of pregnancy (disorder)
        "1220652003",  # Embolism due to and following complete induced termination of pregnancy (disorder)
        "1220656000",  # Genital-pelvic infection due to and following complete induced termination of pregnancy (disorder)
        "1220657009",  # Damage to pelvic organs and/or tissue due to and following complete induced termination of pregnancy (disorder)
        "12275071000119109",  # Conjoined twin pregnancy (disorder)
        "1230040001",  # Cornual placenta accreta (disorder)
        "1230061008",  # Premature aging of placenta (disorder)
        "1231436008",  # Breech position of fetus in pregnancy (disorder)
        "123667006",  # Abnormal mature chorion (disorder)
        "124736009",  # Compound presentation (finding)
        "1252747005",  # Polymorphic eruption of pregnancy (disorder)
        "1254988002",  # Substance dependence in mother complicating pregnancy, childbirth and/or puerperium (disorder)
        "125586008",  # Disorder of placenta (disorder)
        "1258895002",  # Entanglement and compression of umbilical cord (disorder)
        "1264396000",  # Excessive hemorrhage due to and following miscarriage (disorder)
        "1269247005",  # Infection of female genital tract due to incomplete miscarriage (disorder)
        "1269249008",  # Infection of pelvis due to incomplete miscarriage (disorder)
        "1269255003",  # Damage to organ of pelvis due to incomplete miscarriage (disorder)
        "1269256002",  # Damage to tissue of pelvis due to incomplete miscarriage (disorder)
        "12729009",  # Prolonged rupture of membranes (disorder)
        "128076000",  # Bone AND/OR joint disorder in mother complicating pregnancy, childbirth AND/OR puerperium (disorder)
        "128077009",  # Trauma to vagina during delivery (disorder)
        "12867002",  # Fetal distress affecting management of mother (disorder)
        "1287713006",  # Iron deficiency anemia during maternal intrapartum period (disorder)
        "129597002",  # Moderate hyperemesis gravidarum (disorder)
        "129598007",  # Severe hyperemesis gravidarum (disorder)
        "12983003",  # Failed attempted abortion with septic shock (disorder)
        "130958001",  # Disorder of placental circulatory function (disorder)
        "1343000",  # Deep transverse arrest (disorder)
        "13842006",  # Subinvolution of uterus in puerperium (disorder)
        "13866000",  # Fetal acidemia affecting management of mother (disorder)
        "13943000",  # Failed attempted abortion complicated by embolism (disorder)
        "14022007",  # Fetal death, affecting management of mother (disorder)
        "14094001",  # Excessive vomiting in pregnancy (disorder)
        "1474004",  # Hypertensive heart AND renal disease complicating AND/OR reason for care during childbirth (disorder)
        "15196006",  # Intraplacental hematoma (disorder)
        "15230009",  # Liver disorder in pregnancy (disorder)
        "1538006",  # Central nervous system malformation in fetus affecting obstetrical care (disorder)
        "15400003",  # Obstetrical air embolism (disorder)
        "15406009",  # Retromammary abscess associated with childbirth (disorder)
        "15504009",  # Rupture of gravid uterus (disorder)
        "156222001",  # Short umbilical cord (disorder)
        "15643101000119103",  # Gastroesophageal reflux disease in pregnancy (disorder)
        "15663008",  # Placenta previa centralis (disorder)
        "15692007",  # Right lateral brow position (finding)
        "1592005",  # Failed attempted abortion with uremia (disorder)
        "15938005",  # Eclampsia (disorder)
        "1621000119101",  # Chlamydia trachomatis infection in pregnancy (disorder)
        "16271000119108",  # Pyelonephritis in pregnancy (disorder)
        "16316801000119102",  # Postpartum purulent mastitis (disorder)
        "1639007",  # Abnormality of organs AND/OR soft tissues of pelvis affecting pregnancy (disorder)
        "16574001",  # Cardiac arrest after obstetrical surgery AND/OR other procedure including delivery (disorder)
        "16607004",  # Missed abortion (disorder)
        "16756008",  # Albuminuria in pregnancy without hypertension (disorder)
        "16950007",  # Fourth degree perineal laceration involving anal mucosa (disorder)
        "169581008",  # Antenatal care: grand multiparity (situation)
        "169593004",  # Antenatal care: poor antenatal attender (situation)
        "171000119107",  # Maternal obesity complicating pregnancy, childbirth and the puerperium, antepartum (disorder)
        "17263003",  # Amniotic fluid embolism (disorder)
        "173300003",  # Disorder of pregnancy (disorder)
        "17380002",  # Failed attempted abortion with acute renal failure (disorder)
        "17382005",  # Cervical incompetence (disorder)
        "17433009",  # Ruptured ectopic pregnancy (disorder)
        "17532001",  # Breech malpresentation successfully converted to cephalic presentation (disorder)
        "17594002",  # Fetal bradycardia affecting management of mother (disorder)
        "17787002",  # Peripheral neuritis in pregnancy (disorder)
        "178280004",  # Postnatal infection (disorder)
        "18237006",  # Parenchymatous mastitis associated with childbirth (disorder)
        "18260003",  # Postpartum psychosis (disorder)
        "18416000",  # Essential hypertension complicating AND/OR reason for care during childbirth (disorder)
        "18559007",  # Frank breech presentation (finding)
        "18606002",  # Dyscoordinate labor (disorder)
        "18656007",  # Grand multipara (finding)
        "19099008",  # Failed attempted abortion with laceration of urinary bladder (disorder)
        "19117007",  # Placenta reflexa (disorder)
        "19228003",  # Failed attempted abortion with perforation of urinary bladder (disorder)
        "19236007",  # Immature abnormal placenta (disorder)
        "19258009",  # Placenta extrachorales (disorder)
        "19363005",  # Failed attempted abortion with blood-clot embolism (disorder)
        "19569008",  # Mild hyperemesis gravidarum (disorder)
        "196040003",  # Aspiration pneumonitis due to and following anesthesia during labor and delivery (disorder)
        "19729005",  # Prolapse of anterior lip of cervix obstructing labor (disorder)
        "19773009",  # Infection of the breast AND/OR nipple associated with childbirth (disorder)
        "198347000",  # Cicatrix (postpartum) of cervix (disorder)
        "198609003",  # Complication of pregnancy, childbirth and/or puerperium (disorder)
        "198620003",  # Ruptured tubal pregnancy (disorder)
        "198648003",  # Metabolic disorder due to incomplete miscarriage (disorder)
        "198655001",  # Complete miscarriage with genital tract or pelvic infection (disorder)
        "198656000",  # Complete miscarriage with delayed or excessive hemorrhage (disorder)
        "19866007",  # Previous operation to cervix affecting pregnancy (disorder)
        "198806007",  # Failed attempted abortion with genital tract or pelvic infection (disorder)
        "198807003",  # Failed attempted abortion with delayed or excessive hemorrhage (disorder)
        "198808008",  # Failed attempted abortion with damage to pelvic organs or tissues (disorder)
        "198809000",  # Failed attempted abortion with renal failure (disorder)
        "198810005",  # Failed attempted abortion with metabolic disorder (disorder)
        "198811009",  # Failed attempted abortion with shock (disorder)
        "198812002",  # Failed attempted abortion with embolism (disorder)
        "198832001",  # Damage to pelvic organs or tissues following abortive pregnancy (disorder)
        "198874006",  # Failed medical abortion, complicated by genital tract and pelvic infection (disorder)
        "198875007",  # Failed medical abortion, complicated by delayed or excessive hemorrhage (disorder)
        "198876008",  # Failed medical abortion, complicated by embolism (disorder)
        "198903000",  # Hemorrhage due to placenta previa (disorder)
        "198912003",  # Premature separation of placenta with coagulation defect (disorder)
        "198920001",  # Antepartum hemorrhage with trauma (disorder)
        "198925006",  # Antepartum hemorrhage with uterine leiomyoma (disorder)
        "198941007",  # Hypertension complicating pregnancy, childbirth and the puerperium (disorder)
        "198942000",  # Benign essential hypertension complicating pregnancy, childbirth and the puerperium (disorder)
        "198947006",  # Benign essential hypertension complicating pregnancy, childbirth and the puerperium with postnatal complication (disorder)
        "198949009",  # Renal hypertension complicating pregnancy, childbirth and the puerperium (disorder)
        "198968007",  # Transient hypertension of pregnancy with postnatal complication (disorder)
        "198986005",  # Severe pre-eclampsia with postnatal complication (disorder)
        "198992004",  # Eclampsia in pregnancy (disorder)
        "198993009",  # Eclampsia with postnatal complication (disorder)
        "198997005",  # Pre-eclampsia or eclampsia with pre-existing hypertension (disorder)
        "199003007",  # Pre-eclampsia or eclampsia with pre-existing hypertension with postnatal complication (disorder)
        "199004",  # Decreased lactation (finding)
        "199005000",  # Pre-existing hypertension complicating pregnancy, childbirth and puerperium (disorder)
        "199006004",  # Pre-existing hypertensive heart disease complicating pregnancy, childbirth and the puerperium (disorder)
        "199007008",  # Pre-existing hypertensive heart and renal disease complicating pregnancy, childbirth and the puerperium (disorder)
        "199008003",  # Pre-existing secondary hypertension complicating pregnancy, childbirth and puerperium (disorder)
        "199025001",  # Hyperemesis gravidarum with metabolic disturbance (disorder)
        "199047001",  # False labor (finding)
        "199050003",  # False labor at or after 37 completed weeks of gestation (finding)
        "199096006",  # Peripheral neuritis in pregnancy with postnatal complication (disorder)
        "199102004",  # Asymptomatic bacteriuria in pregnancy with postnatal complication (disorder)
        "199109008",  # Genitourinary tract infection in pregnancy with postnatal complication (disorder)
        "199110003",  # Infections of kidney in pregnancy (disorder)
        "199111004",  # Urinary tract infection following delivery (disorder)
        "199112006",  # Infections of the genital tract in pregnancy (disorder)
        "199124004",  # Fatigue during pregnancy with postnatal complication (disorder)
        "199139003",  # Pregnancy-induced edema and proteinuria without hypertension (disorder)
        "199141002",  # Gestational edema with proteinuria (disorder)
        "199154009",  # Maternal syphilis during pregnancy, childbirth and the puerperium (disorder)
        "199161008",  # Maternal gonorrhea during pregnancy, childbirth and the puerperium (disorder)
        "199175001",  # Maternal tuberculosis during pregnancy, childbirth and the puerperium (disorder)
        "199183007",  # Maternal malaria during pregnancy, childbirth and the puerperium (disorder)
        "199203001",  # Viral hepatitis complicating pregnancy, childbirth and the puerperium (disorder)
        "199206009",  # Infections of urethra in pregnancy (disorder)
        "199223000",  # Diabetes mellitus during pregnancy, childbirth and the puerperium (disorder)
        "199248002",  # Iron deficiency anemia of pregnancy (disorder)
        "199257008",  # Mental disorders during pregnancy, childbirth and the puerperium (disorder)
        "199279003",  # Orthopedic disorders during pregnancy, childbirth and the puerperium (disorder)
        "199293005",  # Disease of the respiratory system complicating pregnancy, childbirth and/or the puerperium (disorder)
        "199294004",  # Disease of the digestive system complicating pregnancy, childbirth and/or the puerperium (disorder)
        "199295003",  # Disease of skin and subcutaneous tissue complicating pregnancy, childbirth and/or puerperium (disorder)
        "199296002",  # Endocrine, nutritional and metabolic disease complicating pregnancy, childbirth and puerperium (disorder)
        "199297006",  # Disease of nervous system complicating pregnancy, childbirth and puerperium (disorder)
        "199305006",  # Complications specific to multiple gestation (disorder)
        "199306007",  # Continuing pregnancy after abortion of one fetus or more (disorder)
        "199307003",  # Continuing pregnancy after intrauterine death of one or more fetuses (disorder)
        "199308008",  # Subluxation of symphysis pubis in pregnancy, childbirth and the puerperium (disorder)
        "199314001",  # Normal delivery but ante- or post- natal conditions present (disorder)
        "199318003",  # Twin pregnancy with antenatal problem (disorder)
        "199322008",  # Triplet pregnancy with antenatal problem (disorder)
        "199326006",  # Quadruplet pregnancy with antenatal problem (disorder)
        "199345002",  # Unstable lie with antenatal problem (disorder)
        "199355003",  # Breech presentation with antenatal problem (finding)
        "199359009",  # Oblique lie with antenatal problem (disorder)
        "199363002",  # Transverse lie with antenatal problem (disorder)
        "199373000",  # High head at term (finding)
        "199376008",  # High head at term with antenatal problem (finding)
        "199378009",  # Multiple pregnancy with malpresentation (disorder)
        "199381004",  # Multiple pregnancy with malpresentation with antenatal problem (disorder)
        "199385008",  # Prolapsed arm with antenatal problem (disorder)
        "199397009",  # Cephalopelvic disproportion (disorder)
        "199406006",  # Generally contracted pelvis with antenatal problem (disorder)
        "199410009",  # Inlet pelvic contraction with antenatal problem (disorder)
        "199414000",  # Outlet pelvic contraction with antenatal problem (disorder)
        "199416003",  # Mixed feto-pelvic disproportion (disorder)
        "199419005",  # Mixed feto-pelvic disproportion with antenatal problem (disorder)
        "199423002",  # Large fetus causing disproportion with antenatal problem (disorder)
        "199425009",  # Hydrocephalic disproportion (disorder)
        "199428006",  # Hydrocephalic disproportion with antenatal problem (disorder)
        "199446000",  # Pelvic soft tissue abnormality in pregnancy, childbirth and the puerperium (disorder)
        "199466009",  # Retroverted incarcerated gravid uterus (disorder)
        "199484006",  # Cervical incompetence with antenatal problem (disorder)
        "199485007",  # Cervical incompetence with postnatal complication (disorder)
        "199513008",  # Pelvic soft tissue abnormality in pregnancy, childbirth and the puerperium with antenatal problem (disorder)
        "199514002",  # Pelvic soft tissue abnormality in pregnancy, childbirth and the puerperium with postnatal complication (disorder)
        "199531009",  # Fetus with hereditary disease (disorder)
        "199534001",  # Fetus with hereditary disease with antenatal problem (disorder)
        "199561001",  # Fetus with damage due to intrauterine contraceptive device with antenatal problem (disorder)
        "199578005",  # Fetal-maternal hemorrhage with antenatal problem (disorder)
        "199583002",  # Rhesus isoimmunization with antenatal problem (disorder)
        "199595002",  # Labor and delivery complication by meconium in amniotic fluid (disorder)
        "199596001",  # Labor and delivery complicated by fetal heart rate anomaly with meconium in amniotic fluid (disorder)
        "199597005",  # Labor and delivery complicated by biochemical evidence of fetal stress (disorder)
        "199608004",  # Intrauterine death with antenatal problem (event)
        "199647002",  # Polyhydramnios with antenatal problem (disorder)
        "199654008",  # Oligohydramnios with antenatal problem (disorder)
        "199659003",  # Premature rupture of membranes with antenatal problem (disorder)
        "199660008",  # Premature rupture of membranes with onset of labor within 24 hours of the rupture (disorder)
        "199661007",  # Premature rupture of membranes, labor delayed by therapy (disorder)
        "199662000",  # Premature rupture of membranes with onset of labor after 24 hours of the rupture (disorder)
        "199670005",  # Prolonged artificial rupture of membranes (disorder)
        "199673007",  # Prolonged artificial rupture of membranes with antenatal problem (disorder)
        "199678003",  # Amniotic cavity infection with antenatal problem (disorder)
        "199695006",  # Failed mechanical induction with antenatal problem (disorder)
        "199715003",  # Grand multiparity with antenatal problem (finding)
        "199719009",  # Elderly primigravida with antenatal problem (finding)
        "199741009",  # Malnutrition in pregnancy (disorder)
        "199745000",  # Complication occurring during labor and delivery (disorder)
        "199746004",  # Obstructed labor (disorder)
        "199747008",  # Obstructed labor due to fetal malposition (disorder)
        "199750006",  # Obstructed labor due to fetal malposition with antenatal problem (disorder)
        "199751005",  # Obstructed labor due to breech presentation (disorder)
        "199752003",  # Obstructed labor due to face presentation (disorder)
        "199753008",  # Obstructed labor due to brow presentation (disorder)
        "199754002",  # Obstructed labor due to shoulder presentation (disorder)
        "199755001",  # Obstructed labor due to compound presentation (disorder)
        "199757009",  # Obstructed labor caused by bony pelvis (disorder)
        "199760002",  # Obstructed labor caused by bony pelvis with antenatal problem (disorder)
        "199761003",  # Obstructed labor due to deformed pelvis (disorder)
        "199762005",  # Obstructed labor due to generally contracted pelvis (disorder)
        "199763000",  # Obstructed labor due to pelvic inlet contraction (disorder)
        "199764006",  # Obstructed labor due to pelvic outlet and mid-cavity contraction (disorder)
        "199765007",  # Obstructed labor due to abnormality of maternal pelvic organs (disorder)
        "199767004",  # Obstructed labor caused by pelvic soft tissues (disorder)
        "199770000",  # Obstructed labor caused by pelvic soft tissues with antenatal problem (disorder)
        "199775005",  # Deep transverse arrest with antenatal problem (disorder)
        "199784005",  # Shoulder dystocia with antenatal problem (disorder)
        "199806003",  # Obstructed labor due to unusually large fetus (disorder)
        "199821009",  # Primary uterine inertia with antenatal problem (disorder)
        "199825000",  # Secondary uterine inertia with antenatal problem (disorder)
        "199834005",  # Precipitate labor with antenatal problem (disorder)
        "199839000",  # Hypertonic uterine inertia with antenatal problem (disorder)
        "199848005",  # Prolonged first stage with antenatal problem (disorder)
        "199858009",  # Prolonged second stage with antenatal problem (disorder)
        "199863008",  # Delayed delivery second twin with antenatal problem (disorder)
        "199896005",  # Vasa previa with antenatal problem (disorder)
        "199917001",  # First degree perineal tear during delivery with postnatal problem (disorder)
        "199926003",  # Second degree perineal tear during delivery with postnatal problem (disorder)
        "199931001",  # Third degree perineal tear during delivery with postnatal problem (disorder)
        "199935005",  # Fourth degree perineal tear during delivery with postnatal problem (disorder)
        "199961009",  # Rupture of uterus before labor with antenatal problem (disorder)
        "199972004",  # Laceration of cervix due to childbirth (disorder)
        "199975002",  # Obstetric laceration of cervix with postnatal problem (disorder)
        "199977005",  # Obstetric high vaginal laceration (disorder)
        "199980006",  # Obstetric high vaginal laceration with postnatal problem (disorder)
        "199991004",  # Obstetric damage to pelvic joints and ligaments with postnatal problem (disorder)
        "199993001",  # Obstetric trauma causing pelvic hematoma (disorder)
        "199997000",  # Obstetric pelvic hematoma with postnatal problem (disorder)
        "200031006",  # Postpartum coagulation defects with postnatal problem (disorder)
        "200038000",  # Retained placenta with no hemorrhage with postnatal problem (disorder)
        "200046004",  # Complications of anesthesia during labor and delivery (disorder)
        "200054002",  # Obstetric anesthesia with cardiac complications (disorder)
        "200058004",  # Obstetric anesthesia with cardiac complications with antenatal problem (disorder)
        "200061003",  # Obstetric anesthesia with central nervous system complications (disorder)
        "200065007",  # Obstetric anesthesia with central nervous system complication with antenatal problem (disorder)
        "200066008",  # Obstetric anesthesia with central nervous system complication with postnatal problem (disorder)
        "200068009",  # Obstetric toxic reaction caused by local anesthesia (disorder)
        "200069001",  # Toxic reaction caused by local anesthesia during pregnancy (disorder)
        "200070000",  # Toxic reaction caused by local anesthesia during puerperium (disorder)
        "200071001",  # Obstetric spinal and epidural anesthesia-induced headache (disorder)
        "200072008",  # Spinal and epidural anesthesia-induced headache during pregnancy (disorder)
        "200075005",  # Toxic reaction caused by local anesthetic during labor and delivery (disorder)
        "200077002",  # Cardiac complications of anesthesia during labor and delivery (disorder)
        "200078007",  # Central nervous system complications of anesthesia during labor and delivery (disorder)
        "200101003",  # Maternal distress with antenatal problem (disorder)
        "200102005",  # Maternal distress with postnatal problem (disorder)
        "200113008",  # Maternal hypotension syndrome with antenatal problem (disorder)
        "200114002",  # Maternal hypotension syndrome with postnatal problem (disorder)
        "200125006",  # Infection of obstetric surgical wound (disorder)
        "200144004",  # Deliveries by cesarean (finding)
        "200164009",  # Exhaustion during labor (disorder)
        "200173001",  # Intrapartum hemorrhage with coagulation defect (disorder)
        "200249004",  # Hemorrhoids in pregnancy and puerperium (disorder)
        "200259003",  # Cerebral venous thrombosis in pregnancy (disorder)
        "200277008",  # Puerperal pyrexia of unknown origin (disorder)
        "200284000",  # Obstetric pulmonary embolism (disorder)
        "200286003",  # Obstetric air pulmonary embolism (disorder)
        "200299000",  # Obstetric blood-clot pulmonary embolism (disorder)
        "200310004",  # Obstetric pyemic and septic pulmonary embolism with antenatal complication (disorder)
        "200311000",  # Obstetric pyemic and septic pulmonary embolism with postnatal complication (disorder)
        "200338007",  # Cesarean wound disruption with postnatal complication (disorder)
        "200343000",  # Obstetric perineal wound disruption with postnatal complication (disorder)
        "200352009",  # Placental polyp with postnatal complication (disorder)
        "200369006",  # Obstetric nipple infection with antenatal complication (disorder)
        "200370007",  # Obstetric nipple infection with postnatal complication (disorder)
        "200376001",  # Obstetric breast abscess with antenatal complication (disorder)
        "200377005",  # Obstetric breast abscess with postnatal complication (disorder)
        "200383008",  # Obstetric non-purulent mastitis with antenatal complication (disorder)
        "200385001",  # Obstetric non-purulent mastitis with postnatal complication (disorder)
        "200402001",  # Retraction of nipple in pregnancy, the puerperium or lactation (finding)
        "200406003",  # Retraction of nipple in pregnancy, the puerperium or lactation with antenatal complication (finding)
        "200407007",  # Retraction of nipple in pregnancy, the puerperium or lactation with postnatal complication (finding)
        "200413003",  # Cracked nipple in pregnancy, the puerperium or lactation with antenatal complication (disorder)
        "200414009",  # Cracked nipple in pregnancy, the puerperium or lactation with postnatal complication (disorder)
        "200441004",  # Suppressed lactation with antenatal complication (disorder)
        "200442006",  # Suppressed lactation with postnatal complication (disorder)
        "200444007",  # Galactorrhea in pregnancy and the puerperium (disorder)
        "200448005",  # Galactorrhea in pregnancy and the puerperium with antenatal complication (disorder)
        "200449002",  # Galactorrhea in pregnancy and the puerperium with postnatal complication (disorder)
        "20391007",  # Amniotic cyst (disorder)
        "206244002",  # Vulval hematoma due to birth trauma (disorder)
        "20625004",  # Obstruction caused by position of fetus at onset of labor (disorder)
        "206365006",  # Clostridial intra-amniotic fetal infection (disorder)
        "206366007",  # Escherichia coli intra-amniotic fetal infection (disorder)
        "20753005",  # Hypertensive heart disease complicating AND/OR reason for care during pregnancy (disorder)
        "20845005",  # Meconium in amniotic fluid affecting management of mother (disorder)
        "2132004",  # Meconium in amniotic fluid noted before labor in liveborn infant (disorder)
        "21334005",  # Failed attempted abortion with oliguria (disorder)
        "21346009",  # Double uterus affecting pregnancy (disorder)
        "2138000",  # Left sacroposterior position (finding)
        "21737000",  # Retained fetal tissue (disorder)
        "21987001",  # Delayed delivery of second of multiple births (disorder)
        "22173004",  # Excessive fetal growth affecting management of mother (disorder)
        "22271007",  # Abnormal fetal heart beat first noted during labor AND/OR delivery in liveborn infant (disorder)
        "22288000",  # Tumor of cervix affecting pregnancy (disorder)
        "223003",  # Tumor of body of uterus affecting pregnancy (disorder)
        "2261009",  # Obstetrical pulmonary fat embolism (disorder)
        "22753004",  # Fetal AND/OR placental disorder affecting management of mother (disorder)
        "22846003",  # Hepatorenal syndrome following delivery (disorder)
        "22966008",  # Hypertensive heart AND renal disease complicating AND/OR reason for care during pregnancy (disorder)
        "23001005",  # Stenosis AND/OR stricture of cervix affecting pregnancy (disorder)
        "23171006",  # Delayed AND/OR secondary postpartum hemorrhage (disorder)
        "23332002",  # Failed trial of labor (disorder)
        "234058009",  # Varicose veins of genitalia in pregnancy (disorder)
        "23431000119106",  # Rupture of uterus during labor (disorder)
        "23508005",  # Uterine incoordination, first degree (disorder)
        "235888006",  # Cholestasis of pregnancy (disorder)
        "23717007",  # Benign essential hypertension complicating AND/OR reason for care during pregnancy (disorder)
        "237186006",  # Stenosis of cervix in pregnancy, childbirth and the puerperium (disorder)
        "237205002",  # Rectocele affecting obstetric care (disorder)
        "237208000",  # Rectocele in pregnancy, childbirth and puerperium (disorder)
        "237209008",  # Pendulous abdomen in pregnancy, childbirth and/or the puerperium (disorder)
        "237227006",  # Congenital heart disease in pregnancy (disorder)
        "237230004",  # Uremia in pregnancy without hypertension (disorder)
        "237235009",  # Undiagnosed breech (disorder)
        "237236005",  # Undiagnosed multiple pregnancy (disorder)
        "237237001",  # Undiagnosed twin pregnancy (disorder)
        "237245006",  # Vanishing twin syndrome (disorder)
        "237247003",  # Continuing pregnancy after abortion of sibling fetus (disorder)
        "237249000",  # Complete hydatidiform mole (disorder)
        "237250000",  # Incomplete hydatidiform mole (disorder)
        "237254009",  # Unruptured tubal pregnancy (disorder)
        "237256006",  # Disorder of pelvic size and disproportion (disorder)
        "237257002",  # Midpelvic contraction (disorder)
        "237259004",  # Variation of placental position (disorder)
        "237267007",  # Prolonged premature rupture of membranes (disorder)
        "237270006",  # Antepartum hemorrhage with hypofibrinogenemia (disorder)
        "237271005",  # Antepartum hemorrhage with hyperfibrinolysis (disorder)
        "237272003",  # Antepartum hemorrhage with afibrinogenemia (disorder)
        "237273008",  # Revealed placental abruption (disorder)
        "237274002",  # Concealed placental abruption (disorder)
        "237275001",  # Mixed placental abruption (disorder)
        "237276000",  # Indeterminate antepartum hemorrhage (disorder)
        "237277009",  # Marginal placental hemorrhage (disorder)
        "237279007",  # Transient hypertension of pregnancy (disorder)
        "237281009",  # Moderate proteinuric hypertension of pregnancy (disorder)
        "237282002",  # Impending eclampsia (disorder)
        "237283007",  # Eclampsia in labor (disorder)
        "237284001",  # Symptomatic disorders in pregnancy (disorder)
        "237285000",  # Gestational edema (disorder)
        "237286004",  # Varicose veins of vulva in pregnancy (disorder)
        "237292005",  # Placental insufficiency (disorder)
        "237296008",  # Morbidly adherent placenta (disorder)
        "237297004",  # Placenta adherent to previous uterine scar (disorder)
        "237300009",  # Pregnancy with isoimmunization (disorder)
        "237302001",  # Kell isoimmunization in pregnancy (disorder)
        "237303006",  # Duffy isoimmunization in pregnancy (disorder)
        "237304000",  # Lewis isoimmunization in pregnancy (disorder)
        "237321009",  # Delayed delivery of triplet (disorder)
        "237325000",  # Head entrapment during breech delivery (disorder)
        "237327008",  # Obstetric pelvic ligament damage (disorder)
        "237328003",  # Obstetric pelvic joint damage (disorder)
        "237329006",  # Urethra injury - obstetric (disorder)
        "237336007",  # Fibrinolysis - postpartum (disorder)
        "237337003",  # Afibrinogenemia - postpartum (disorder)
        "237338008",  # Blood dyscrasia puerperal (disorder)
        "237342006",  # Fat embolism - obstetric (disorder)
        "237343001",  # Phlebitis in puerperium (disorder)
        "237348005",  # Puerperal pyrexia (disorder)
        "237349002",  # Mild postnatal depression (disorder)
        "237350002",  # Severe postnatal depression (disorder)
        "237351003",  # Mild postnatal psychosis (disorder)
        "237352005",  # Severe postnatal psychosis (disorder)
        "237355007",  # Milk engorgement of breast (disorder)
        "237357004",  # Vascular engorgement of breast (disorder)
        "237363008",  # Intrauterine death of one twin (event)
        "237506002",  # Thyrotoxicosis in pregnancy (disorder)
        "237627000",  # Pregnancy and type 2 diabetes mellitus (disorder)
        "23786008",  # Malignant hypertension complicating AND/OR reason for care during puerperium (disorder)
        "238613007",  # Generalized pustular psoriasis of pregnancy (disorder)
        "23885003",  # Inversion of uterus during delivery (disorder)
        "239103006",  # Prurigo of pregnancy (disorder)
        "239104000",  # Pruritic folliculitis of pregnancy (disorder)
        "240154002",  # Idiopathic osteoporosis in pregnancy (disorder)
        "240160002",  # Transient osteoporosis of hip in pregnancy (disorder)
        "240167004",  # Osteomalacia secondary to pregnancy (disorder)
        "240278000",  # External cephalic version (procedure)
        "24042004",  # Chronic hypertension complicating AND/OR reason for care during puerperium (disorder)
        "24095001",  # Placenta previa partialis (disorder)
        "24258008",  # Damage to pelvic joints AND/OR ligaments during delivery (disorder)
        "2437000",  # Placenta circumvallata (disorder)
        "24444009",  # Failed attempted abortion with sepsis (disorder)
        "24536007",  # Right mentoanterior position (finding)
        "24699006",  # Arrested active phase of labor (disorder)
        "248996001",  # Transversely contracted pelvis (disorder)
        "249064003",  # Oblique lie, head in iliac fossa (disorder)
        "249065002",  # Oblique lie, breech in iliac fossa (disorder)
        "249084004",  # Mentoanterior position (finding)
        "249085003",  # Direct mentoanterior position (finding)
        "249086002",  # Mentoposterior position (finding)
        "249087006",  # Direct mentoposterior position (finding)
        "249088001",  # Mentolateral position (finding)
        "249089009",  # Fetal mouth presenting (disorder)
        "249090000",  # Fetal ear presenting (disorder)
        "249091001",  # Fetal nose presenting (disorder)
        "249094009",  # Anterior brow position (finding)
        "249095005",  # Posterior brow position (finding)
        "249096006",  # Lateral brow position (finding)
        "249098007",  # Knee presentation (disorder)
        "249099004",  # Single knee presentation (disorder)
        "249100007",  # Double knee presentation (disorder)
        "249102004",  # Direct sacroposterior position (finding)
        "249103009",  # Sacrolateral position (finding)
        "249104003",  # Dorsoanterior shoulder presentation (disorder)
        "249105002",  # Dorsoposterior shoulder presentation (disorder)
        "249106001",  # Anterior shoulder presentation (finding)
        "249107005",  # Shoulder right anterior position (finding)
        "249108000",  # Shoulder left anterior position (finding)
        "249109008",  # Posterior shoulder presentation (finding)
        "249189006",  # Wharton's jelly excessive (disorder)
        "249196008",  # Distress from pain in labor (disorder)
        "249218000",  # Postpartum vulval hematoma (disorder)
        "249219008",  # Genital tear resulting from childbirth (disorder)
        "249220002",  # Vaginal tear resulting from childbirth (disorder)
        "25032009",  # Failed attempted abortion with laceration of cervix (disorder)
        "25053000",  # Obstetrical central nervous system complication of anesthesia AND/OR sedation (disorder)
        "25113000",  # Chorea gravidarum (disorder)
        "25585008",  # Placenta percreta (disorder)
        "25749005",  # Disproportion between fetus and pelvis (disorder)
        "25922000",  # Major depressive disorder, single episode with postpartum onset (disorder)
        "26078007",  # Hypertension secondary to renal disease complicating AND/OR reason for care during childbirth (disorder)
        "26158002",  # Uterine inertia (disorder)
        "26224003",  # Failed attempted abortion complicated by genital-pelvic infection (disorder)
        "26358008",  # Ectopic placenta (disorder)
        "26623000",  # Failed attempted termination of pregnancy complicated by delayed and/or excessive hemorrhage (disorder)
        "26644000",  # Shoulder right posterior position (finding)
        "267197003",  # Antepartum hemorrhage due to abruptio placentae and placenta previa (disorder)
        "267199000",  # Antepartum hemorrhage with coagulation defect (disorder)
        "267204006",  # Genitourinary tract infection in pregnancy (disorder)
        "267207004",  # Congenital cardiovascular disorders during pregnancy, childbirth and the puerperium (disorder)
        "267219007",  # Tumor of uterine body in pregnancy, childbirth and the puerperium (disorder)
        "267257007",  # Labor and delivery complicated by fetal heart rate anomaly (disorder)
        "267262008",  # Prolonged spontaneous rupture of membranes (disorder)
        "267265005",  # Hypertonic uterine inertia (disorder)
        "267268007",  # Trauma to perineum and/or vulva during delivery (disorder)
        "267272006",  # Postpartum coagulation defects (disorder)
        "267276009",  # Obstetric anesthesia with pulmonary complications (disorder)
        "267280004",  # Venous complication of pregnancy and/or puerperium (disorder)
        "267282007",  # Varicose veins of perineum and vulva in pregnancy and the puerperium (disorder)
        "267284008",  # Obstetric pyemic and septic pulmonary embolism (disorder)
        "267289003",  # Obstetric nipple infection (disorder)
        "267291006",  # Cracked nipple in pregnancy, the puerperium or lactation (disorder)
        "267317007",  # Tuberculosis in pregnancy (disorder)
        "267320004",  # Pregnancy with mental disorders (disorder)
        "267322007",  # Pregnancy with orthopedic problem (disorder)
        "267340006",  # Maternal pyrexia in labor (disorder)
        "267350007",  # Obstetric anesthesia problems (disorder)
        "26828006",  # Rectocele affecting pregnancy (disorder)
        "268585006",  # Placental infarct (disorder)
        "270498000",  # Malposition and malpresentation of fetus (disorder)
        "270500004",  # Prolapsed cord (disorder)
        "270502007",  # Obstetric breast abscess (disorder)
        "27068000",  # Failed attempted abortion with afibrinogenemia (disorder)
        "27075004",  # Venereal disease in mother complicating pregnancy, childbirth AND/OR puerperium (disorder)
        "271372000",  # Obstetric non-purulent mastitis (disorder)
        "27152008",  # Hyperemesis gravidarum before end of 22 week gestation with carbohydrate depletion (disorder)
        "271954000",  # Failed attempted medical abortion (disorder)
        "27214003",  # Atonic postpartum hemorrhage (disorder)
        "27215002",  # Inversion of uterus (disorder)
        "27342004",  # Anemia of pregnancy (disorder)
        "27388005",  # Intrapartum hemorrhage due to partial placenta previa (disorder)
        "273983009",  # Maternal cord or placental problem (disorder)
        "274118001",  # Venereal disease in pregnancy (disorder)
        "274119009",  # Rubella in pregnancy (disorder)
        "274120003",  # Thyroid disease in pregnancy (disorder)
        "274121004",  # Cardiac disease in pregnancy (disorder)
        "275412000",  # Cystitis of pregnancy (disorder)
        "275421004",  # Miscarriage with heavy bleeding (disorder)
        "275426009",  # Pelvic disproportion (disorder)
        "275429002",  # Delayed delivery of second twin (disorder)
        "275434003",  # Stroke in the puerperium (disorder)
        "276369006",  # Reduced fetal movement (finding)
        "276462003",  # Posterior fourchette scarring (disorder)
        "276604007",  # Fetal growth abnormality (disorder)
        "276881003",  # Secondary abdominal pregnancy (disorder)
        "27921008",  # Shoulder left posterior position (finding)
        "280732008",  # Obstetric disorder of uterus (disorder)
        "282020008",  # Premature delivery (finding)
        "28357009",  # Transitory postpartum mood disturbance (disorder)
        "283963001",  # Laceration of uterus (disorder)
        "284075002",  # Spotting per vagina in pregnancy (finding)
        "2858002",  # Puerperal sepsis (disorder)
        "288250001",  # Maternal hypertension (disorder)
        "288261009",  # Was malpresentation pre-labor (disorder)
        "28911003",  # Adherent placenta (disorder)
        "289240005",  # Long duration of labor (finding)
        "289254002",  # Expulsion of intrauterine contraceptive device during third stage of labor (finding)
        "289355004",  # Oblique lie head in right iliac fossa (disorder)
        "289356003",  # Oblique lie head in left iliac fossa (disorder)
        "289357007",  # Oblique lie breech in right iliac fossa (disorder)
        "289358002",  # Oblique lie breech in left iliac fossa (disorder)
        "289365005",  # Finding of malposition of fetus (finding)
        "289366006",  # Malposition of fetus in face presentation (finding)
        "289367002",  # Malposition of fetus in brow presentation (finding)
        "289368007",  # Malposition of fetus in shoulder presentation (finding)
        "289399008",  # Compound presentation palpable vaginally (finding)
        "291665000",  # Postpartum intrapituitary hemorrhage (disorder)
        "29171003",  # Trapped placenta (disorder)
        "29259002",  # Malignant hypertension complicating AND/OR reason for care during pregnancy (disorder)
        "29399001",  # Elderly primigravida (finding)
        "29421008",  # Failed attempted abortion complicated by renal failure (disorder)
        "29847008",  # Obstetrical complication of anesthesia AND/OR sedation (disorder)
        "300927001",  # Episiotomy infection (disorder)
        "302078000",  # Abnormal immature chorionic villi (disorder)
        "302644007",  # Abnormal immature chorion (disorder)
        "303063000",  # Eclampsia in puerperium (disorder)
        "3033000",  # Bone AND/OR joint disorder of pelvis in mother complicating pregnancy, childbirth AND/OR puerperium (disorder)
        "30506002",  # Suppressed lactation (disorder)
        "307333004",  # Rhesus isoimmunization due to anti-D (disorder)
        "307534009",  # Urinary tract infection in pregnancy (disorder)
        "307632004",  # Non-proteinuric hypertension of pregnancy (disorder)
        "307734007",  # Complete inevitable abortion complicated by genital tract and pelvic infection (disorder)
        "307735008",  # Complete inevitable abortion complicated by delayed or excessive hemorrhage (disorder)
        "307749004",  # Incomplete inevitable abortion complicated by genital tract and pelvic infection (disorder)
        "307752007",  # Incomplete inevitable abortion complicated by delayed or excessive hemorrhage (disorder)
        "308135003",  # Varicose veins of genitalia in puerperium (disorder)
        "308136002",  # Superficial thrombophlebitis in pregnancy (disorder)
        "308137006",  # Superficial thrombophlebitis in puerperium (disorder)
        "308140006",  # Hemorrhoids in pregnancy (disorder)
        "308187004",  # Varicose veins of vagina in puerperium (disorder)
        "31026002",  # Obstetrical complication of sedation (disorder)
        "312974005",  # Preterm premature rupture of membranes (disorder)
        "313017000",  # Anhydramnios (disorder)
        "313291009",  # Anemia during the puerperium (disorder)
        "31383003",  # Tumor of vagina affecting pregnancy (disorder)
        "31407004",  # Pre-existing hypertension complicating AND/OR reason for care during puerperium (disorder)
        "31516002",  # Viral disease in mother complicating pregnancy, childbirth AND/OR puerperium (disorder)
        "31563000",  # Asymptomatic bacteriuria in pregnancy (disorder)
        "31805001",  # Fetal disproportion (disorder)
        "31821006",  # Uterine scar from previous surgery affecting pregnancy (disorder)
        "32801000119106",  # Infectious disease in mother complicating childbirth (disorder)
        "32808002",  # Brow left posterior position (finding)
        "32999002",  # Complication of obstetrical surgical wound (disorder)
        "33058001",  # Placenta accreta without hemorrhage (disorder)
        "33370009",  # Hyperemesis gravidarum before end of 22 week gestation with electrolyte imbalance (disorder)
        "33490001",  # Failed attempted abortion with fat embolism (disorder)
        "33552005",  # Anomaly of placenta (disorder)
        "33627001",  # Prolonged first stage of labor (disorder)
        "34165000",  # Gestational proteinuria (disorder)
        "34262005",  # Fourth degree perineal laceration involving rectal mucosa (disorder)
        "34273003",  # Hypertensive heart disease complicating AND/OR reason for care during puerperium (disorder)
        "34327003",  # Parturient hemorrhage associated with hyperfibrinolysis (disorder)
        "34367002",  # Failed attempted abortion with perforation of bowel (disorder)
        "34430009",  # Rupture of uterus (disorder)
        "34478009",  # Failed attempted abortion with defibrination syndrome (disorder)
        "34530006",  # Failed attempted abortion with electrolyte imbalance (disorder)
        "34694006",  # Pre-existing hypertension complicating AND/OR reason for care during childbirth (disorder)
        "34801009",  # Ectopic pregnancy (disorder)
        "34842007",  # Antepartum hemorrhage (disorder)
        "34981006",  # Hypertonic uterine dysfunction (disorder)
        "35303009",  # Benign essential hypertension complicating AND/OR reason for care during puerperium (disorder)
        "35347003",  # Delayed delivery after artificial rupture of membranes (disorder)
        "35381000119101",  # Quadruplet pregnancy with loss of one or more fetuses (disorder)
        "35716006",  # Cracked nipple associated with childbirth (disorder)
        "35746009",  # Uterine fibroids affecting pregnancy (disorder)
        "35882009",  # Abnormality of forces of labor (disorder)
        "35999006",  # Blighted ovum (disorder)
        "361095003",  # Dehiscence AND/OR disruption of uterine wound in the puerperium (disorder)
        "36297009",  # Septate vagina affecting pregnancy (disorder)
        "362972006",  # Disorder of labor / delivery (disorder)
        "363093002",  # Disorders of fetal movement (disorder)
        "364748006",  # Finding of position of breech presentation (finding)
        "36497006",  # Traumatic extension of episiotomy (disorder)
        "36664002",  # Failed attempted abortion with air embolism (disorder)
        "367390009",  # Hypertension in the obstetric context (disorder)
        "36801000119105",  # Continuing triplet pregnancy after spontaneous abortion of one or more fetuses (disorder)
        "36813001",  # Placenta previa (disorder)
        "36854009",  # Inlet contraction of pelvis (disorder)
        "36916008",  # Bone AND/OR joint disorder of back in mother complicating pregnancy, childbirth AND/OR puerperium (disorder)
        "371374003",  # Retained products of conception (disorder)
        "371375002",  # Retained secundines (disorder)
        "371380006",  # Amniotic fluid leaking (disorder)
        "371614003",  # Hematoma of obstetric wound (disorder)
        "37618003",  # Chronic hypertension complicating AND/OR reason for care during pregnancy (disorder)
        "38010008",  # Intrapartum hemorrhage (disorder)
        "38049006",  # Incomplete breech presentation (finding)
        "38099005",  # Failed attempted abortion with endometritis (disorder)
        "38451000119105",  # Failed attempted vaginal birth after previous cesarean section (disorder)
        "38720006",  # Septuplet pregnancy (finding)
        "387692004",  # Hypotonic uterine inertia (disorder)
        "387696001",  # Primary hypotonic uterine dysfunction (disorder)
        "387699008",  # Primary uterine inertia (disorder)
        "387700009",  # Prolonged latent phase of labor (disorder)
        "3885002",  # ABO isoimmunization affecting pregnancy (disorder)
        "388604008",  # Villitis (disorder)
        "388605009",  # Disorder of chorion (disorder)
        "38951007",  # Failed attempted abortion with laceration of bowel (disorder)
        "39120007",  # Failed attempted abortion with salpingo-oophoritis (disorder)
        "39121000119100",  # Pelvic mass in pregnancy (disorder)
        "39208009",  # Fetal hydrops causing disproportion (disorder)
        "39249009",  # Placentitis (disorder)
        "3944006",  # Placental sulfatase deficiency (X-linked steryl-sulfatase deficiency) in a female (disorder)
        "39587000",  # Left mentolateral position (finding)
        "396544001",  # Cesarean wound disruption (disorder)
        "39727004",  # Hypertension secondary to renal disease complicating AND/OR reason for care during puerperium (disorder)
        "39763004",  # Abnormal glucose tolerance in mother complicating pregnancy, childbirth AND/OR puerperium (disorder)
        "397752008",  # Obstetric perineal wound disruption (disorder)
        "397949005",  # Poor fetal growth affecting management (disorder)
        "397952002",  # Trauma to perineum during delivery (disorder)
        "398019008",  # Perineal laceration during delivery (disorder)
        "398254007",  # Pre-eclampsia (disorder)
        "398262004",  # Disruption of episiotomy wound in the puerperium (disorder)
        "398276003",  # Placental insufficiency affecting management of mother (disorder)
        "399031001",  # Fourth degree perineal laceration (disorder)
        "399363000",  # Late fetal death affecting management of mother (disorder)
        "4006006",  # Fetal tachycardia affecting management of mother (disorder)
        "4026005",  # Interstitial mastitis associated with childbirth (disorder)
        "40609001",  # Infectious disease in mother complicating pregnancy, childbirth AND/OR puerperium (disorder)
        "408812003",  # Direct sacroanterior position (finding)
        "41114007",  # Mild pre-eclampsia (disorder)
        "41215002",  # Congenital abnormality of uterus, affecting pregnancy (disorder)
        "413567003",  # Aplastic anemia associated with pregnancy (disorder)
        "415105001",  # Placental abruption (disorder)
        "416669000",  # Invasive hydatidiform mole (disorder)
        "41679006",  # Toxoplasmosis, other infections, rubella, cytomegalovirus, and herpes simplex virus syndrome (disorder)
        "417044008",  # Hydatidiform mole, benign (disorder)
        "417150000",  # Exaggerated placental site (disorder)
        "417364008",  # Placental site nodule (disorder)
        "4174008",  # Placenta tripartita (disorder)
        "41962002",  # Oligohydramnios sequence (disorder)
        "41991004",  # Angiectasis pregnancy (disorder)
        "42537006",  # Secondary perineal tear in the puerperium (disorder)
        "42553009",  # Deficiency of placental barrier function (disorder)
        "425708006",  # Placental aromatase deficiency (disorder)
        "42571002",  # Failed induction of labor (disorder)
        "42599006",  # Trauma from instrument during delivery (disorder)
        "42686001",  # Chromosomal abnormality in fetus affecting obstetrical care (disorder)
        "426997005",  # Traumatic injury during pregnancy (disorder)
        "427139004",  # Third trimester bleeding (disorder)
        "428017002",  # Condyloma acuminata of vulva in pregnancy (disorder)
        "428164004",  # Mitral valve disorder in pregnancy (disorder)
        "428165003",  # Hypothyroidism in pregnancy (disorder)
        "428230005",  # Trichomonal vaginitis in pregnancy (disorder)
        "428252001",  # Vaginitis in pregnancy (disorder)
        "428511009",  # Multiple pregnancy with one fetal loss (disorder)
        "428707000",  # Nutritional deficiency in pregnancy (disorder)
        "429187001",  # Continuing pregnancy after intrauterine death of twin fetus (disorder)
        "430881000",  # Second trimester bleeding (disorder)
        "430933008",  # Gravid uterus size for dates discrepancy (finding)
        "43195002",  # Tenney changes of placenta (disorder)
        "43293004",  # Failed attempted abortion with septic embolism (disorder)
        "43651009",  # Acquired stenosis of vagina affecting pregnancy (disorder)
        "43715006",  # Secondary uterine inertia (disorder)
        "43957006",  # Left lateral brow position (finding)
        "43970002",  # Congenital stenosis of vagina affecting pregnancy (disorder)
        "43990006",  # Sextuplet pregnancy (finding)
        "44216000",  # Retained products of conception, following delivery with hemorrhage (disorder)
        "44223004",  # Premature rupture of membranes (disorder)
        "442478007",  # Multiple pregnancy involving intrauterine pregnancy and tubal pregnancy (disorder)
        "443006",  # Cystocele affecting pregnancy (disorder)
        "443460007",  # Multigravida of advanced maternal age (finding)
        "444661007",  # High risk pregnancy due to history of preterm labor (finding)
        "44640004",  # Failed attempted abortion with parametritis (disorder)
        "44795003",  # Rhesus isoimmunization affecting pregnancy (disorder)
        "449807005",  # Type 3a third degree laceration of perineum (disorder)
        "449808000",  # Type 3b third degree laceration of perineum (disorder)
        "449809008",  # Type 3c third degree laceration of perineum (disorder)
        "44992005",  # Failed attempted abortion with intravascular hemolysis (disorder)
        "45079001",  # Acromion left anterior position (finding)
        "45759004",  # Rigid perineum affecting pregnancy (disorder)
        "45828008",  # Anemia in mother complicating pregnancy, childbirth AND/OR puerperium (disorder)
        "459166009",  # Dichorionic diamniotic twin pregnancy (finding)
        "459167000",  # Monochorionic twin pregnancy (finding)
        "459168005",  # Monochorionic diamniotic twin pregnancy (finding)
        "459169002",  # Monochorionic diamniotic twin pregnancy with similar amniotic fluid volumes (finding)
        "459170001",  # Monochorionic diamniotic twin pregnancy with dissimilar amniotic fluid volumes (disorder)
        "459171002",  # Monochorionic monoamniotic twin pregnancy (finding)
        "46273003",  # Abscess of nipple associated with childbirth (disorder)
        "46311005",  # Perineal laceration involving fourchette (disorder)
        "46365005",  # Failed attempted abortion with perforation of periurethral tissue (disorder)
        "46502006",  # Hematoma of vagina during delivery (disorder)
        "46764007",  # Severe pre-eclampsia (disorder)
        "46894009",  # Gestational diabetes mellitus class A2 (disorder)
        "47161002",  # Failed attempted abortion with perforation of cervix (disorder)
        "47200007",  # High risk pregnancy (finding)
        "472321009",  # Continuing pregnancy after intrauterine death of one twin with intrauterine retention of dead twin (disorder)
        "47236005",  # Third stage hemorrhage (disorder)
        "47821001",  # Postpartum hemorrhage (disorder)
        "48194001",  # Pregnancy-induced hypertension (disorder)
        "48200009",  # Bone AND/OR joint disorder of lower extremities in mother complicating pregnancy, childbirth AND/OR puerperium (disorder)
        "48552006",  # Hypertension secondary to renal disease complicating AND/OR reason for care during pregnancy (disorder)
        "48782003",  # Delivery normal (finding)
        "48906005",  # Breech presentation, double footling (finding)
        "4907004",  # Non-involution of uterus (disorder)
        "49102001",  # Hypertensive heart AND renal disease in obstetric context (disorder)
        "49168004",  # Complete breech presentation (finding)
        "49171007",  # Hypertensive renal disease complicating AND/OR reason for care during childbirth (disorder)
        "49177006",  # Postpartum coagulation defect with hemorrhage (disorder)
        "49279000",  # Slow slope active phase of labor (disorder)
        "49342001",  # Stricture of vagina affecting pregnancy (disorder)
        "49364005",  # Subareolar abscess associated with childbirth (disorder)
        "49416000",  # Failed attempted abortion (disorder)
        "49561003",  # Rupture of gravid uterus before onset of labor (disorder)
        "49815007",  # Damage to coccyx during delivery (disorder)
        "50120008",  # Abnormal acid-base balance affecting management of mother (disorder)
        "50557007",  # Healed pelvic floor repair affecting pregnancy (disorder)
        "50726009",  # Failed attempted abortion with perforation of uterus (disorder)
        "50764006",  # Vomiting due to organic disease during pregnancy (disorder)
        "50844007",  # Failed attempted abortion with pelvic peritonitis (disorder)
        "51154004",  # Obstetrical pulmonary complication of anesthesia AND/OR sedation (disorder)
        "51195001",  # Placental polyp (disorder)
        "51495008",  # Cerebral anoxia following anesthesia AND/OR sedation in labor AND/OR delivery (disorder)
        "51920004",  # Precipitate labor (disorder)
        "521000119104",  # Acute cystitis in pregnancy, antepartum (disorder)
        "52327008",  # Fetal disproportion due to fetal myelomeningocele (disorder)
        "52772002",  # Postpartum thyroiditis (disorder)
        "53024001",  # Insufficient weight gain of pregnancy (disorder)
        "53111003",  # Failed attempted abortion with postoperative shock (disorder)
        "53443007",  # Prolonged labor (disorder)
        "54048003",  # Threatened abortion (disorder)
        "54212005",  # Irregular uterine contractions (disorder)
        "54213000",  # Oligohydramnios without rupture of membranes (disorder)
        "54486001",  # Left sacrolateral position (finding)
        "54679003",  # Traumatic injury of urinary bladder during obstetric procedure (disorder)
        "54844002",  # Prolapse of gravid uterus (disorder)
        "55472006",  # Submammary abscess associated with childbirth (disorder)
        "55565007",  # Cardiac failure after obstetrical surgery AND/OR other procedure including delivery (disorder)
        "55581002",  # Meconium in amniotic fluid first noted during labor AND/OR delivery in liveborn infant (disorder)
        "55613002",  # Engorgement of breasts associated with childbirth (disorder)
        "55639004",  # Failed attempted abortion with laceration of vagina (disorder)
        "55704005",  # Abscess of breast, associated with childbirth (disorder)
        "56313000",  # Abnormal placenta affecting management of mother (disorder)
        "56425003",  # Edema of placenta (disorder)
        "56451001",  # Failed attempted abortion with perforation of broad ligament (disorder)
        "56462001",  # Failed attempted abortion with soap embolism (disorder)
        "57220000",  # Obstetrical complication of local anesthesia (disorder)
        "57296000",  # Incarcerated gravid uterus (disorder)
        "5740008",  # Pelvic hematoma during delivery (disorder)
        "57576007",  # Retroversion of gravid uterus (disorder)
        "57759005",  # First degree perineal laceration (disorder)
        "57873008",  # Hypertensive renal disease complicating AND/OR reason for care during puerperium (disorder)
        "58123006",  # Failed attempted abortion with pulmonary embolism (disorder)
        "58261003",  # Sacroposterior position (finding)
        "5852008",  # Acromion right anterior position (finding)
        "58703003",  # Postpartum depression (disorder)
        "58881007",  # Polyp of cervix affecting pregnancy (disorder)
        "58903006",  # Breech presentation, single footling (finding)
        "59136001",  # Thyroid disease in mother complicating pregnancy, childbirth AND/OR puerperium (disorder)
        "5939002",  # Failed attempted abortion complicated by metabolic disorder (disorder)
        "59534005",  # Meconium in amniotic fluid, not clear if noted before OR after onset of labor in liveborn infant (disorder)
        "59566000",  # Oligohydramnios (disorder)
        "5973007",  # Right mentoposterior position (finding)
        "59733002",  # Hypertensive heart disease complicating AND/OR reason for care during childbirth (disorder)
        "59919008",  # Failed attempted abortion with complication (disorder)
        "60574005",  # Twin placenta (disorder)
        "60601008",  # Obstetrical blood clot embolism (disorder)
        "60755004",  # Persistent hymen affecting pregnancy (disorder)
        "60810003",  # Quadruplet pregnancy (finding)
        "60854009",  # Left mentoanterior position (finding)
        "609133009",  # Short cervical length in pregnancy (finding)
        "609447002",  # Induced termination of pregnancy complicated by damage to pelvic organs and/or tissues (disorder)
        "609449004",  # Induced termination of pregnancy complicated by embolism (disorder)
        "609450004",  # Induced termination of pregnancy complicated by genital-pelvic infection (disorder)
        "609451000",  # Induced termination of pregnancy complicated by metabolic disorder (disorder)
        "609452007",  # Induced termination of pregnancy complicated by renal failure (disorder)
        "609453002",  # Induced termination of pregnancy complicated by shock (disorder)
        "609455009",  # Induced termination of pregnancy complicated by acute renal failure (disorder)
        "609457001",  # Induced termination of pregnancy complicated by air embolism (disorder)
        "609458006",  # Induced termination of pregnancy complicated by amniotic fluid embolism (disorder)
        "609459003",  # Induced termination of pregnancy complicated by blood-clot embolism (disorder)
        "609465003",  # Induced termination of pregnancy complicated by fat embolism (disorder)
        "609472002",  # Induced termination of pregnancy complicated by acute renal failure with oliguria (disorder)
        "609479006",  # Induced termination of pregnancy complicated by postoperative shock (disorder)
        "609480009",  # Induced termination of pregnancy complicated by pulmonary embolism (disorder)
        "609486003",  # Induced termination of pregnancy complicated by septic embolism (disorder)
        "609487007",  # Induced termination of pregnancy complicated by septic shock (disorder)
        "609489005",  # Induced termination of pregnancy complicated by soap embolism (disorder)
        "609491002",  # Induced termination of pregnancy complicated by urinary tract infection (disorder)
        "609506003",  # Induced termination of pregnancy complicated by cardiac arrest (disorder)
        "609525000",  # Miscarriage of tubal ectopic pregnancy (disorder)
        "609563008",  # Pre-existing diabetes mellitus in pregnancy (disorder)
        "609564002",  # Pre-existing type 1 diabetes mellitus in pregnancy (disorder)
        "609566000",  # Pregnancy and type 1 diabetes mellitus (disorder)
        "609567009",  # Pre-existing type 2 diabetes mellitus in pregnancy (disorder)
        "6096002",  # Breech presentation (finding)
        "61007003",  # Separation of symphysis pubis during delivery (disorder)
        "61452007",  # Failed attempted abortion with laceration of uterus (disorder)
        "61714007",  # Metabolic disturbance in labor AND/OR delivery (disorder)
        "61951009",  # Failed attempted abortion with laceration of periurethral tissue (disorder)
        "62129004",  # Contraction ring dystocia (disorder)
        "62131008",  # Couvelaire uterus (disorder)
        "6234006",  # Second degree perineal laceration (disorder)
        "62377009",  # Postpartum cardiomyopathy (disorder)
        "62410004",  # Postpartum fibrinolysis with hemorrhage (disorder)
        "62531004",  # Placenta previa marginalis (disorder)
        "62612003",  # Fibrosis of perineum affecting pregnancy (disorder)
        "62657007",  # Cardiac arrest AND/OR failure following anesthesia AND/OR sedation in labor AND/OR delivery (disorder)
        "63287004",  # Benign essential hypertension in obstetric context (disorder)
        "63637002",  # Failed attempted abortion with laceration of broad ligament (disorder)
        "63750008",  # Oblique lie (disorder)
        "6383007",  # Premature labor (finding)
        "64171002",  # Obstetrical cardiac complication of anesthesia AND/OR sedation (disorder)
        "64181003",  # Failed attempted abortion with perforation of vagina (disorder)
        "64229006",  # Traumatic lesion during delivery (disorder)
        "64254006",  # Triplet pregnancy (finding)
        "64433002",  # Left sacroanterior position (finding)
        "64954002",  # Avulsion of inner symphyseal cartilage during delivery (disorder)
        "65147003",  # Twin pregnancy (finding)
        "65377004",  # Polygalactia (disorder)
        "65402008",  # Pre-existing hypertension complicating AND/OR reason for care during pregnancy (disorder)
        "65409004",  # Obstetrical complication of anesthesia (disorder)
        "65483000",  # Placenta of multiple birth higher than twin (finding)
        "6594005",  # Cerebrovascular disorder in the puerperium (disorder)
        "66119008",  # Disruption of perineal laceration repair in the puerperium (disorder)
        "66294006",  # Obstruction by abnormal pelvic soft tissues (disorder)
        "6636004",  # Congenital cardiovascular disorder in mother complicating pregnancy, childbirth AND/OR puerperium (disorder)
        "66709007",  # Hypertensive renal disease complicating AND/OR reason for care during pregnancy (disorder)
        "66844003",  # Generalized infection during labor (disorder)
        "66892003",  # Failed attempted abortion with urinary tract infection (disorder)
        "66958002",  # Isoimmunization from non-ABO, non-Rh blood-group incompatibility affecting pregnancy (disorder)
        "67042008",  # Failed attempted abortion complicated by shock (disorder)
        "67229002",  # Spontaneous uterine inversion (disorder)
        "67359005",  # Pre-eclampsia added to pre-existing hypertension (disorder)
        "67802002",  # Malpresentation other than breech, successfully converted to cephalic presentation (disorder)
        "67881007",  # Annular placenta (disorder)
        "68214002",  # Lymphangitis of breast associated with childbirth (disorder)
        "6825008",  # Perineal laceration involving rectovaginal septum (disorder)
        "68635007",  # Deficiency of placental function (disorder)
        "6891008",  # Uterine incoordination, second degree (disorder)
        "69018001",  # Right mentolateral position (finding)
        "69217004",  # Outlet contraction of pelvis (disorder)
        "698584008",  # Postoperative wound hemorrhage (disorder)
        "698716002",  # Preterm spontaneous labor with preterm delivery (finding)
        "698717006",  # Preterm spontaneous labor with term delivery (finding)
        "69909000",  # Eclampsia added to pre-existing hypertension (disorder)
        "699240001",  # Combined intrauterine and ovarian pregnancy (disorder)
        "6995000",  # Failure of lactation (disorder)
        "699950009",  # Anti-D isoimmunization affecting pregnancy (disorder)
        "70068004",  # Persistent occipitoposterior position (disorder)
        "70129008",  # Placenta accreta (disorder)
        "70137000",  # Deficiency of placental endocrine function (disorder)
        "702711004",  # Mental disorder in mother complicating pregnancy (disorder)
        "71028008",  # Fetal-maternal hemorrhage (disorder)
        "713575004",  # Dizygotic twin pregnancy (finding)
        "713576003",  # Monozygotic twin pregnancy (finding)
        "71473008",  # Amnion nodosum (disorder)
        "71531003",  # Brow right anterior position (finding)
        "71612002",  # Postpartum uterine hypertrophy (disorder)
        "71639005",  # Galactorrhea associated with childbirth (disorder)
        "71874008",  # Benign essential hypertension complicating AND/OR reason for care during childbirth (disorder)
        "71901000",  # Congenital contracted pelvis (disorder)
        "72022006",  # Essential hypertension in obstetric context (disorder)
        "72161000119100",  # Antiphospholipid syndrome in pregnancy (disorder)
        "72271000119100",  # Hyperthyroidism in pregnancy (disorder)
        "72301000119103",  # Asthma in pregnancy (disorder)
        "7245003",  # Fetal dystocia (disorder)
        "7266006",  # Intrapartum hemorrhage due to total placenta previa (disorder)
        "72860003",  # Disorder of amniotic cavity AND/OR membrane (disorder)
        "73030000",  # Hypertensive renal disease in obstetric context (disorder)
        "73161006",  # Transverse lie (disorder)
        "737318003",  # Delayed hemorrhage due to and following miscarriage (disorder)
        "737320000",  # Delayed hemorrhage due to and following molar pregnancy (disorder)
        "737321001",  # Excessive hemorrhage due to and following molar pregnancy (disorder)
        "737322008",  # Delayed hemorrhage due to and following ectopic pregnancy (disorder)
        "737323003",  # Excessive hemorrhage due to and following ectopic pregnancy (disorder)
        "73790007",  # Threatened abortion in first trimester (disorder)
        "73837001",  # Failed attempted abortion with cardiac arrest AND/OR failure (disorder)
        "73972002",  # Postpartum neurosis (disorder)
        "74955002",  # Retraction of nipple associated with childbirth (finding)
        "75022004",  # Gestational diabetes mellitus class A1 (disorder)
        "7504005",  # Trauma to vulva during delivery (disorder)
        "75094005",  # Hydrops of placenta (disorder)
        "75150001",  # Renal disease in pregnancy AND/OR puerperium without hypertension (disorder)
        "75798003",  # Twin dichorionic diamniotic placenta (disorder)
        "75933004",  # Threatened abortion in second trimester (disorder)
        "76037007",  # Rigid cervix uteri affecting pregnancy (disorder)
        "76380008",  # Placenta membranacea (disorder)
        "76751001",  # Diabetes mellitus in mother complicating pregnancy, childbirth AND/OR puerperium (disorder)
        "76771005",  # Parturient hemorrhage associated with hypofibrinogenemia (disorder)
        "76871004",  # Previous surgery to vagina affecting pregnancy (disorder)
        "76889003",  # Failed attempted abortion with cerebral anoxia (disorder)
        "769087009",  # Vomiting during third trimester of pregnancy (disorder)
        "77186001",  # Failed attempted abortion with renal tubular necrosis (disorder)
        "772006002",  # Failed instrumental delivery (situation)
        "77259008",  # Prolonged second stage of labor (disorder)
        "77285007",  # Placental infarct affecting management of mother (disorder)
        "77376005",  # Gestational edema without hypertension (disorder)
        "77563000",  # Obstruction by bony pelvis (disorder)
        "7768008",  # Failure of cervical dilation (disorder)
        "77854008",  # Failed medical induction of labor (disorder)
        "7792000",  # Placenta previa without hemorrhage (disorder)
        "7822001",  # Failed attempted abortion complicated by damage to pelvic organs AND/OR tissues (disorder)
        "78381004",  # Heart disease in mother complicating pregnancy, childbirth AND/OR puerperium (disorder)
        "78408007",  # Complication of obstetrical surgery AND/OR procedure (disorder)
        "785341006",  # Intrapartum hemorrhage due to leiomyoma (disorder)
        "785867009",  # Excessive hemorrhage due to and following induced termination of pregnancy (disorder)
        "785868004",  # Secondary hemorrhage due to and following induced termination of pregnancy (disorder)
        "78697003",  # Nonpurulent mastitis associated with childbirth (disorder)
        "7870007",  # Vascular lesion of cord (disorder)
        "78789000",  # Mature abnormal placenta (disorder)
        "78808002",  # Essential hypertension complicating AND/OR reason for care during pregnancy (disorder)
        "788290007",  # Hemangioma of skin in pregnancy (disorder)
        "79179003",  # Desultory labor (disorder)
        "79255005",  # Mentum presentation of fetus (disorder)
        "79355007",  # Hypertensive heart disease in obstetric context (disorder)
        "79414005",  # Retraction ring dystocia (disorder)
        "79586000",  # Tubal pregnancy (disorder)
        "79643007",  # Right sacroanterior position (finding)
        "79668009",  # Vasa previa (disorder)
        "79748007",  # Maternal dystocia (disorder)
        "79839005",  # Perineal laceration involving vulva (disorder)
        "79884007",  # Brow right posterior position (finding)
        "79888005",  # Sacroanterior position (finding)
        "80002007",  # Malpresentation of fetus (disorder)
        "80113008",  # Complication of the puerperium (disorder)
        "80224003",  # Multiple gestation with one OR more fetal malpresentations (disorder)
        "80256005",  # Intervillous thrombosis (disorder)
        "8076000",  # Postmature abnormal placenta (disorder)
        "80818002",  # Previous surgery to perineum AND/OR vulva affecting pregnancy (disorder)
        "80997009",  # Quintuplet pregnancy (finding)
        "81521003",  # Failed attempted abortion with salpingitis (disorder)
        "81557008",  # Parasitic disease in mother complicating pregnancy, childbirth AND/OR puerperium (disorder)
        "81626002",  # Malignant hypertension in obstetric context (disorder)
        "81677009",  # Lactation tetany (disorder)
        "8218002",  # Chronic hypertension complicating AND/OR reason for care during childbirth (disorder)
        "82661006",  # Abdominal pregnancy (disorder)
        "82664003",  # Placenta succenturiata (disorder)
        "83094001",  # Perineal hematoma during delivery (disorder)
        "83243004",  # Rigid pelvic floor affecting pregnancy (disorder)
        "83741001",  # Placenta spuria (disorder)
        "83787007",  # Twin monochorionic diamniotic placenta (disorder)
        "83916000",  # Thrombophlebitis in puerperium (disorder)
        "8393005",  # Tetanic contractions of uterus (disorder)
        "84007008",  # Shock during AND/OR following labor AND/OR delivery (disorder)
        "84357006",  # Twin monochorionic monoamniotic placenta (disorder)
        "8445003",  # Tumor of vulva affecting pregnancy (disorder)
        "84693004",  # Intervillous hemorrhage of placenta (disorder)
        "85076009",  # Placenta fenestrata (disorder)
        "85542007",  # Perineal laceration involving skin (disorder)
        "86041002",  # Pre-existing hypertension in obstetric context (disorder)
        "86081009",  # Herpes gestationis (disorder)
        "86203003",  # Polyhydramnios (disorder)
        "86356004",  # Unstable lie (disorder)
        "87043009",  # Cerebral anoxia after obstetrical surgery AND/OR other procedure including delivery (disorder)
        "871005",  # Contracted pelvis (disorder)
        "87383005",  # Maternal distress (disorder)
        "8762007",  # Chronic hypertension in obstetric context (disorder)
        "87621000",  # Hyperemesis gravidarum before end of 22 week gestation with dehydration (disorder)
        "87814002",  # Intrapartum hemorrhage due to marginal placenta previa (disorder)
        "87840008",  # Galactocele associated with childbirth (disorder)
        "8884000",  # Fetal ascites causing disproportion (disorder)
        "88887003",  # Maternal hypotension syndrome (disorder)
        "88895004",  # Fatigue during pregnancy (disorder)
        "88992002",  # Left mentoposterior position (finding)
        "89550007",  # Right sacrolateral position (finding)
        "89672000",  # Retromammary mastitis associated with childbirth (disorder)
        "89700002",  # Shoulder girdle dystocia (disorder)
        "90127001",  # Fetus papyraceous (disorder)
        "90188009",  # Failed mechanical induction (disorder)
        "90325002",  # Vomiting of pregnancy (disorder)
        "90532005",  # Central laceration during delivery (disorder)
        "90645002",  # Failed attempted abortion without complication (disorder)
        "90968009",  # Prolonged pregnancy (disorder)
        "9111000119104",  # Musculoskeletal problem in pregnancy (disorder)
        "91162000",  # Necrosis of liver of pregnancy (disorder)
        "9121000119106",  # Low back pain in pregnancy (finding)
        "91217009",  # Megaloblastic anemia due to pregnancy (disorder)
        "91484005",  # Failure of induction of labor by oxytocic drugs (disorder)
        "91948008",  # Asymptomatic human immunodeficiency virus infection in pregnancy (disorder)
        "92297008",  # Benign neoplasm of placenta (disorder)
        "9293002",  # Atony of uterus (disorder)
        "9297001",  # Uterus bicornis affecting pregnancy (disorder)
        "9442009",  # Parturient hemorrhage associated with afibrinogenemia (disorder)
        "95121000119108",  # Postpartum disorder of breast (disorder)
        "95605009",  # Hemolysis-elevated liver enzymes-low platelet count syndrome (disorder)
        "95606005",  # Maternal drug exposure (disorder)
        "95607001",  # Maternal drug use (disorder)
        "95608006",  # Necrosis of placenta (disorder)
        "9720009",  # Cicatrix of cervix affecting pregnancy (disorder)
        "9780006",  # Presentation of prolapsed arm of fetus (disorder)
        "9864005",  # Placenta multipartita (disorder)
        "9899009",  # Ovarian pregnancy (disorder)
        "9901000",  # Essential hypertension complicating AND/OR reason for care during puerperium (disorder)
    }

class ObstetricsVte(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts of diagnoses to identify patients who have venous thromboembolism (VTE) related to pregnancy or obstetrics.

    **Data Element Scope:** This value set may use a model element related to Diagnosis.

    **Inclusion Criteria:** Includes concepts that represent a diagnosis for venous thromboembolism related to pregnancy or obstetrics.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Obstetrics VTE"
    OID = "2.16.840.1.113883.3.117.1.7.1.264"
    DEFINITION_VERSION = "20210220"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "O032",  # Embolism following incomplete spontaneous abortion
        "O0335",  # Other venous complications following incomplete spontaneous abortion
        "O037",  # Embolism following complete or unspecified spontaneous abortion
        "O0385",  # Other venous complications following complete or unspecified spontaneous abortion
        "O047",  # Embolism following (induced) termination of pregnancy
        "O0485",  # Other venous complications following (induced) termination of pregnancy
        "O072",  # Embolism following failed attempted termination of pregnancy
        "O0735",  # Other venous complications following failed attempted termination of pregnancy
        "O082",  # Embolism following ectopic and molar pregnancy
        "O087",  # Other venous complications following an ectopic and molar pregnancy
        "O2230",  # Deep phlebothrombosis in pregnancy, unspecified trimester
        "O2231",  # Deep phlebothrombosis in pregnancy, first trimester
        "O2232",  # Deep phlebothrombosis in pregnancy, second trimester
        "O2233",  # Deep phlebothrombosis in pregnancy, third trimester
        "O2250",  # Cerebral venous thrombosis in pregnancy, unspecified trimester
        "O2251",  # Cerebral venous thrombosis in pregnancy, first trimester
        "O2252",  # Cerebral venous thrombosis in pregnancy, second trimester
        "O2253",  # Cerebral venous thrombosis in pregnancy, third trimester
        "O228X1",  # Other venous complications in pregnancy, first trimester
        "O228X2",  # Other venous complications in pregnancy, second trimester
        "O228X3",  # Other venous complications in pregnancy, third trimester
        "O228X9",  # Other venous complications in pregnancy, unspecified trimester
        "O2290",  # Venous complication in pregnancy, unspecified, unspecified trimester
        "O2291",  # Venous complication in pregnancy, unspecified, first trimester
        "O2292",  # Venous complication in pregnancy, unspecified, second trimester
        "O2293",  # Venous complication in pregnancy, unspecified, third trimester
        "O871",  # Deep phlebothrombosis in the puerperium
        "O873",  # Cerebral venous thrombosis in the puerperium
        "O878",  # Other venous complications in the puerperium
        "O879",  # Venous complication in the puerperium, unspecified
        "O88211",  # Thromboembolism in pregnancy, first trimester
        "O88212",  # Thromboembolism in pregnancy, second trimester
        "O88213",  # Thromboembolism in pregnancy, third trimester
        "O88219",  # Thromboembolism in pregnancy, unspecified trimester
        "O8822",  # Thromboembolism in childbirth
        "O8823",  # Thromboembolism in the puerperium
    }

    SNOMEDCT = {
        "13943000",  # Failed attempted abortion complicated by embolism (disorder)
        "19363005",  # Failed attempted abortion with blood-clot embolism (disorder)
        "198876008",  # Failed medical abortion, complicated by embolism (disorder)
        "200233001",  # Antenatal deep vein thrombosis with antenatal complication (disorder)
        "200284000",  # Obstetric pulmonary embolism (disorder)
        "200299000",  # Obstetric blood-clot pulmonary embolism (disorder)
        "200303005",  # Obstetric blood-clot pulmonary embolism with antenatal complication (disorder)
        "200304004",  # Obstetric blood-clot pulmonary embolism with postnatal complication (disorder)
        "267280004",  # Venous complication of pregnancy and/or puerperium (disorder)
        "43306002",  # Miscarriage complicated by embolism (disorder)
        "49956009",  # Antepartum deep phlebothrombosis (disorder)
        "55976003",  # Miscarriage with blood-clot embolism (disorder)
        "56272000",  # Deep venous thrombosis in puerperium (disorder)
        "56462001",  # Failed attempted abortion with soap embolism (disorder)
        "58123006",  # Failed attempted abortion with pulmonary embolism (disorder)
        "609449004",  # Induced termination of pregnancy complicated by embolism (disorder)
        "609459003",  # Induced termination of pregnancy complicated by blood-clot embolism (disorder)
        "609480009",  # Induced termination of pregnancy complicated by pulmonary embolism (disorder)
        "609497003",  # Venous complication of puerperium (disorder)
        "62583006",  # Phlegmasia alba dolens in puerperium (disorder)
        "82153002",  # Miscarriage with pulmonary embolism (disorder)
    }

class SubcutaneousRoute(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for a medication administered by subcutaneous route.

    **Data Element Scope:** This value set may use a model element related to Medication.

    **Inclusion Criteria:** Includes concepts that identify a medication given subcutaneously.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Subcutaneous route"
    OID = "2.16.840.1.113883.3.117.1.7.1.223"
    DEFINITION_VERSION = "20210220"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "34206005",  # Subcutaneous route (qualifier value)
    }

class ProviderTypes(ValueSet):
    """
    **Clinical Focus:** Provider Types

    **Data Element Scope:** Provider Types

    **Inclusion Criteria:** Provider Types

    **Exclusion Criteria:** na
    """

    VALUE_SET_NAME = "Provider Types"
    OID = "2.16.840.1.113762.1.4.1206.53"
    DEFINITION_VERSION = "20220511"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "158965000",  # Medical practitioner (occupation)
        "224571005",  # Nurse practitioner (occupation)
        "309322005",  # Associate general practitioner (occupation)
        "309324006",  # General practitioner assistant (occupation)
        "309343006",  # Physician (occupation)
        "309394004",  # General practitioner principal (occupation)
        "62247001",  # Family medicine specialist (occupation)
    }

class VteDiagnoses(ValueSet):
    """
    **Clinical Focus:** This value set is used to identify VTE conditions

    **Data Element Scope:** VTE diagnosis codes

    **Inclusion Criteria:** VTE diagnosis codes

    **Exclusion Criteria:** N/A
    """

    VALUE_SET_NAME = "VTE Diagnoses"
    OID = "2.16.840.1.113762.1.4.1206.49"
    DEFINITION_VERSION = "20250205"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "I2601",  # Septic pulmonary embolism with acute cor pulmonale
        "I2602",  # Saddle embolus of pulmonary artery with acute cor pulmonale
        "I2609",  # Other pulmonary embolism with acute cor pulmonale
        "I2690",  # Septic pulmonary embolism without acute cor pulmonale
        "I2692",  # Saddle embolus of pulmonary artery without acute cor pulmonale
        "I2693",  # Single subsegmental thrombotic pulmonary embolism without acute cor pulmonale
        "I2694",  # Multiple subsegmental thrombotic pulmonary emboli without acute cor pulmonale
        "I2699",  # Other pulmonary embolism without acute cor pulmonale
        "I820",  # Budd-Chiari syndrome
        "I82210",  # Acute embolism and thrombosis of superior vena cava
        "I82211",  # Chronic embolism and thrombosis of superior vena cava
        "I82220",  # Acute embolism and thrombosis of inferior vena cava
        "I82221",  # Chronic embolism and thrombosis of inferior vena cava
        "I82290",  # Acute embolism and thrombosis of other thoracic veins
        "I82291",  # Chronic embolism and thrombosis of other thoracic veins
        "I823",  # Embolism and thrombosis of renal vein
        "I82401",  # Acute embolism and thrombosis of unspecified deep veins of right lower extremity
        "I82402",  # Acute embolism and thrombosis of unspecified deep veins of left lower extremity
        "I82403",  # Acute embolism and thrombosis of unspecified deep veins of lower extremity, bilateral
        "I82409",  # Acute embolism and thrombosis of unspecified deep veins of unspecified lower extremity
        "I82411",  # Acute embolism and thrombosis of right femoral vein
        "I82412",  # Acute embolism and thrombosis of left femoral vein
        "I82413",  # Acute embolism and thrombosis of femoral vein, bilateral
        "I82419",  # Acute embolism and thrombosis of unspecified femoral vein
        "I82421",  # Acute embolism and thrombosis of right iliac vein
        "I82422",  # Acute embolism and thrombosis of left iliac vein
        "I82423",  # Acute embolism and thrombosis of iliac vein, bilateral
        "I82429",  # Acute embolism and thrombosis of unspecified iliac vein
        "I82431",  # Acute embolism and thrombosis of right popliteal vein
        "I82432",  # Acute embolism and thrombosis of left popliteal vein
        "I82433",  # Acute embolism and thrombosis of popliteal vein, bilateral
        "I82439",  # Acute embolism and thrombosis of unspecified popliteal vein
        "I82441",  # Acute embolism and thrombosis of right tibial vein
        "I82442",  # Acute embolism and thrombosis of left tibial vein
        "I82443",  # Acute embolism and thrombosis of tibial vein, bilateral
        "I82449",  # Acute embolism and thrombosis of unspecified tibial vein
        "I82451",  # Acute embolism and thrombosis of right peroneal vein
        "I82452",  # Acute embolism and thrombosis of left peroneal vein
        "I82453",  # Acute embolism and thrombosis of peroneal vein, bilateral
        "I82459",  # Acute embolism and thrombosis of unspecified peroneal vein
        "I82461",  # Acute embolism and thrombosis of right calf muscular vein
        "I82462",  # Acute embolism and thrombosis of left calf muscular vein
        "I82463",  # Acute embolism and thrombosis of calf muscular vein, bilateral
        "I82469",  # Acute embolism and thrombosis of unspecified calf muscular vein
        "I82491",  # Acute embolism and thrombosis of other specified deep vein of right lower extremity
        "I82492",  # Acute embolism and thrombosis of other specified deep vein of left lower extremity
        "I82493",  # Acute embolism and thrombosis of other specified deep vein of lower extremity, bilateral
        "I82499",  # Acute embolism and thrombosis of other specified deep vein of unspecified lower extremity
        "I824Y1",  # Acute embolism and thrombosis of unspecified deep veins of right proximal lower extremity
        "I824Y2",  # Acute embolism and thrombosis of unspecified deep veins of left proximal lower extremity
        "I824Y3",  # Acute embolism and thrombosis of unspecified deep veins of proximal lower extremity, bilateral
        "I824Y9",  # Acute embolism and thrombosis of unspecified deep veins of unspecified proximal lower extremity
        "I824Z1",  # Acute embolism and thrombosis of unspecified deep veins of right distal lower extremity
        "I824Z2",  # Acute embolism and thrombosis of unspecified deep veins of left distal lower extremity
        "I824Z3",  # Acute embolism and thrombosis of unspecified deep veins of distal lower extremity, bilateral
        "I824Z9",  # Acute embolism and thrombosis of unspecified deep veins of unspecified distal lower extremity
        "I82501",  # Chronic embolism and thrombosis of unspecified deep veins of right lower extremity
        "I82502",  # Chronic embolism and thrombosis of unspecified deep veins of left lower extremity
        "I82503",  # Chronic embolism and thrombosis of unspecified deep veins of lower extremity, bilateral
        "I82509",  # Chronic embolism and thrombosis of unspecified deep veins of unspecified lower extremity
        "I82511",  # Chronic embolism and thrombosis of right femoral vein
        "I82512",  # Chronic embolism and thrombosis of left femoral vein
        "I82513",  # Chronic embolism and thrombosis of femoral vein, bilateral
        "I82519",  # Chronic embolism and thrombosis of unspecified femoral vein
        "I82521",  # Chronic embolism and thrombosis of right iliac vein
        "I82522",  # Chronic embolism and thrombosis of left iliac vein
        "I82523",  # Chronic embolism and thrombosis of iliac vein, bilateral
        "I82529",  # Chronic embolism and thrombosis of unspecified iliac vein
        "I82531",  # Chronic embolism and thrombosis of right popliteal vein
        "I82532",  # Chronic embolism and thrombosis of left popliteal vein
        "I82533",  # Chronic embolism and thrombosis of popliteal vein, bilateral
        "I82539",  # Chronic embolism and thrombosis of unspecified popliteal vein
        "I82541",  # Chronic embolism and thrombosis of right tibial vein
        "I82542",  # Chronic embolism and thrombosis of left tibial vein
        "I82543",  # Chronic embolism and thrombosis of tibial vein, bilateral
        "I82549",  # Chronic embolism and thrombosis of unspecified tibial vein
        "I82551",  # Chronic embolism and thrombosis of right peroneal vein
        "I82552",  # Chronic embolism and thrombosis of left peroneal vein
        "I82553",  # Chronic embolism and thrombosis of peroneal vein, bilateral
        "I82559",  # Chronic embolism and thrombosis of unspecified peroneal vein
        "I82561",  # Chronic embolism and thrombosis of right calf muscular vein
        "I82562",  # Chronic embolism and thrombosis of left calf muscular vein
        "I82563",  # Chronic embolism and thrombosis of calf muscular vein, bilateral
        "I82569",  # Chronic embolism and thrombosis of unspecified calf muscular vein
        "I82591",  # Chronic embolism and thrombosis of other specified deep vein of right lower extremity
        "I82592",  # Chronic embolism and thrombosis of other specified deep vein of left lower extremity
        "I82593",  # Chronic embolism and thrombosis of other specified deep vein of lower extremity, bilateral
        "I82599",  # Chronic embolism and thrombosis of other specified deep vein of unspecified lower extremity
        "I825Y1",  # Chronic embolism and thrombosis of unspecified deep veins of right proximal lower extremity
        "I825Y2",  # Chronic embolism and thrombosis of unspecified deep veins of left proximal lower extremity
        "I825Y3",  # Chronic embolism and thrombosis of unspecified deep veins of proximal lower extremity, bilateral
        "I825Y9",  # Chronic embolism and thrombosis of unspecified deep veins of unspecified proximal lower extremity
        "I825Z1",  # Chronic embolism and thrombosis of unspecified deep veins of right distal lower extremity
        "I825Z2",  # Chronic embolism and thrombosis of unspecified deep veins of left distal lower extremity
        "I825Z3",  # Chronic embolism and thrombosis of unspecified deep veins of distal lower extremity, bilateral
        "I825Z9",  # Chronic embolism and thrombosis of unspecified deep veins of unspecified distal lower extremity
        "I82811",  # Embolism and thrombosis of superficial veins of right lower extremity
        "I82812",  # Embolism and thrombosis of superficial veins of left lower extremity
        "I82813",  # Embolism and thrombosis of superficial veins of lower extremities, bilateral
        "I82819",  # Embolism and thrombosis of superficial veins of unspecified lower extremity
    }

class VteSymptoms(ValueSet):
    """
    **Clinical Focus:** VTE Symptoms during PCP visit

    **Data Element Scope:** Diagnosis

    **Inclusion Criteria:** Diagnosis SNOMED codes

    **Exclusion Criteria:** na
    """

    VALUE_SET_NAME = "VTE Symptoms"
    OID = "2.16.840.1.113762.1.4.1206.51"
    DEFINITION_VERSION = "20220301"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "102599008",  # Warm skin (finding)
        "10601006",  # Pain in lower limb (finding)
        "247348008",  # Tenderness (finding)
        "248420006",  # Warm extremities (finding)
        "248421005",  # Warm feet (finding)
        "267036007",  # Dyspnea (finding)
        "271594007",  # Syncope (finding)
        "276323006",  # Finding of color of skin (finding)
        "297142003",  # Foot swelling (finding)
        "29857009",  # Chest pain (finding)
        "300954003",  # Pain in calf (finding)
        "301423002",  # Tenderness in lower limb (finding)
        "309537005",  # Numbness of lower limb (finding)
        "309538000",  # Numbness of foot (finding)
        "3424008",  # Tachycardia (finding)
        "404640003",  # Dizziness (finding)
        "429783005",  # Paresthesia of lower extremity (finding)
        "44077006",  # Numbness (finding)
        "449614009",  # Swelling of lower limb (finding)
        "449615005",  # Swelling of lower leg (finding)
        "45007003",  # Low blood pressure (disorder)
        "47933007",  # Foot pain (finding)
        "49727002",  # Cough (finding)
        "62507009",  # Pins and needles (finding)
        "91019004",  # Paresthesia (finding)
    }

class AsaPhysicalStatusClass(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for the American Society of Anesthesiologists (ASA) physical status classes

    **Data Element Scope:** This value set may use a model element related to Observation

    **Inclusion Criteria:** Includes concepts to represent the ASA physical status classes 1 through 6

    **Exclusion Criteria:** N/A
    """

    VALUE_SET_NAME = "ASA physical status class"
    OID = "2.16.840.1.113762.1.4.1248.217"
    DEFINITION_VERSION = "20230512"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "413495001",  # American Society of Anesthesiologists physical status class 1 (finding)
        "413496000",  # American Society of Anesthesiologists physical status class 2 (finding)
        "413497009",  # American Society of Anesthesiologists physical status class 3 (finding)
        "413498004",  # American Society of Anesthesiologists physical status class 4 (finding)
        "413499007",  # American Society of Anesthesiologists physical status class 5 (finding)
        "413500003",  # American Society of Anesthesiologists physical status class 6 (finding)
    }

class AcuteRespiratoryFailure(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for acute respiratory failure

    **Data Element Scope:** This value set may use a model element related to Diagnosis or Condition

    **Inclusion Criteria:** Includes concepts that represent acute respiratory failure

    **Exclusion Criteria:** N/A
    """

    VALUE_SET_NAME = "Acute Respiratory Failure"
    OID = "2.16.840.1.113762.1.4.1248.88"
    DEFINITION_VERSION = "20230426"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "J95821",  # Acute postprocedural respiratory failure
        "J95822",  # Acute and chronic postprocedural respiratory failure
        "J9600",  # Acute respiratory failure, unspecified whether with hypoxia or hypercapnia
        "J9601",  # Acute respiratory failure with hypoxia
        "J9602",  # Acute respiratory failure with hypercapnia
        "J9620",  # Acute and chronic respiratory failure, unspecified whether with hypoxia or hypercapnia
        "J9621",  # Acute and chronic respiratory failure with hypoxia
        "J9622",  # Acute and chronic respiratory failure with hypercapnia
        "J9690",  # Respiratory failure, unspecified, unspecified whether with hypoxia or hypercapnia
        "J9691",  # Respiratory failure, unspecified with hypoxia
        "J9692",  # Respiratory failure, unspecified with hypercapnia
        "Z9911",  # Dependence on respirator [ventilator] status
        "Z9912",  # Encounter for respirator [ventilator] dependence during power failure
    }

class DegenerativeNeurologicalDisorder(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for degenerative neurological disorders

    **Data Element Scope:** This value set may use a model element related to Diagnosis or Condition

    **Inclusion Criteria:** Includes concepts that represent degenerative neurological disorders

    **Exclusion Criteria:** N/A
    """

    VALUE_SET_NAME = "Degenerative Neurological Disorder"
    OID = "2.16.840.1.113762.1.4.1248.241"
    DEFINITION_VERSION = "20230923"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "F01C0",  # Vascular dementia, severe, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F01C11",  # Vascular dementia, severe, with agitation
        "F01C18",  # Vascular dementia, severe, with other behavioral disturbance
        "F01C2",  # Vascular dementia, severe, with psychotic disturbance
        "F01C3",  # Vascular dementia, severe, with mood disturbance
        "F01C4",  # Vascular dementia, severe, with anxiety
        "F02C0",  # Dementia in other diseases classified elsewhere, severe, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F02C11",  # Dementia in other diseases classified elsewhere, severe, with agitation
        "F02C18",  # Dementia in other diseases classified elsewhere, severe, with other behavioral disturbance
        "F02C2",  # Dementia in other diseases classified elsewhere, severe, with psychotic disturbance
        "F02C3",  # Dementia in other diseases classified elsewhere, severe, with mood disturbance
        "F02C4",  # Dementia in other diseases classified elsewhere, severe, with anxiety
        "F03C0",  # Unspecified dementia, severe, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F03C11",  # Unspecified dementia, severe, with agitation
        "F03C18",  # Unspecified dementia, severe, with other behavioral disturbance
        "F03C2",  # Unspecified dementia, severe, with psychotic disturbance
        "F03C3",  # Unspecified dementia, severe, with mood disturbance
        "F03C4",  # Unspecified dementia, severe, with anxiety
        "F04",  # Amnestic disorder due to known physiological condition
        "F05",  # Delirium due to known physiological condition
        "F060",  # Psychotic disorder with hallucinations due to known physiological condition
        "F061",  # Catatonic disorder due to known physiological condition
        "F068",  # Other specified mental disorders due to known physiological condition
        "F070",  # Personality change due to known physiological condition
        "F0789",  # Other personality and behavioral disorders due to known physiological condition
        "F079",  # Unspecified personality and behavioral disorder due to known physiological condition
        "F09",  # Unspecified mental disorder due to known physiological condition
        "F482",  # Pseudobulbar affect
        "G3101",  # Pick's disease
        "G3109",  # Other frontotemporal neurocognitive disorder
        "G311",  # Senile degeneration of brain, not elsewhere classified
        "G3180",  # Leukodystrophy, unspecified
        "G3183",  # Neurocognitive disorder with Lewy bodies
        "G3185",  # Corticobasal degeneration
        "G3186",  # Alexander disease
        "G9382",  # Brain death
    }

    SNOMEDCT = {
        "105451000119102",  # Amnestic disorder associated with general medical condition (disorder)
        "111479008",  # Organic mental disorder (disorder)
        "130121000119104",  # Dementia due to Rett syndrome (disorder)
        "135811000119107",  # Lewy body dementia with behavioral disturbance (disorder)
        "1376001",  # Obsessive compulsive personality disorder (disorder)
        "17262008",  # Non-alcoholic Korsakoff's psychosis (disorder)
        "191447007",  # Organic psychotic condition (disorder)
        "192781003",  # Leukodystrophy (disorder)
        "21921000119103",  # Dementia co-occurrent and due to Pick's disease (disorder)
        "230271008",  # Pick's disease with Pick bodies (disorder)
        "230272001",  # Pick's disease with Pick cells and no Pick bodies (disorder)
        "230802007",  # Brainstem death (disorder)
        "231440006",  # Delirium of mixed origin (disorder)
        "231442003",  # Organic catatonic disorder (disorder)
        "249892007",  # Progressive pseudobulbar palsy (disorder)
        "268612007",  # Senile and presenile organic psychotic conditions (disorder)
        "33449004",  # Personality disorder (disorder)
        "428351000124105",  # Severe dementia (disorder)
        "432776007",  # Pseudobulbar affect (finding)
        "69482004",  # Korsakoff's psychosis (disorder)
        "80098002",  # Diffuse Lewy body disease (disorder)
        "81854007",  # Alexander disease (disorder)
        "82351000119105",  # Altered behavior due to Pick's disease (disorder)
    }

class NeuromuscularDisorder(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for neuromuscular disorders

    **Data Element Scope:** This value set may use a model element related to Diagnosis or Condition

    **Inclusion Criteria:** Includes concepts that represent neuromuscular disorders such as Guillain-Barre syndrome, myasthenia gravis, myasthenia, Lambert-Eaton syndrome, muscular dystrophy, myotonic disorders, myopathies, and myositis

    **Exclusion Criteria:** N/A
    """

    VALUE_SET_NAME = "Neuromuscular Disorder"
    OID = "2.16.840.1.113762.1.4.1248.239"
    DEFINITION_VERSION = "20230923"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "E7402",  # Pompe disease
        "G121",  # Other inherited spinal muscular atrophy
        "G1220",  # Motor neuron disease, unspecified
        "G1221",  # Amyotrophic lateral sclerosis
        "G1222",  # Progressive bulbar palsy
        "G1223",  # Primary lateral sclerosis
        "G1224",  # Familial motor neuron disease
        "G1225",  # Progressive spinal muscle atrophy
        "G1229",  # Other motor neuron disease
        "G128",  # Other spinal muscular atrophies and related syndromes
        "G129",  # Spinal muscular atrophy, unspecified
        "G14",  # Postpolio syndrome
        "G610",  # Guillain-Barre syndrome
        "G7000",  # Myasthenia gravis without (acute) exacerbation
        "G7001",  # Myasthenia gravis with (acute) exacerbation
        "G701",  # Toxic myoneural disorders
        "G702",  # Congenital and developmental myasthenia
        "G7080",  # Lambert-Eaton syndrome, unspecified
        "G7081",  # Lambert-Eaton syndrome in disease classified elsewhere
        "G7089",  # Other specified myoneural disorders
        "G709",  # Myoneural disorder, unspecified
        "G7100",  # Muscular dystrophy, unspecified
        "G7101",  # Duchenne or Becker muscular dystrophy
        "G7102",  # Facioscapulohumeral muscular dystrophy
        "G71031",  # Autosomal dominant limb girdle muscular dystrophy
        "G71032",  # Autosomal recessive limb girdle muscular dystrophy due to calpain-3 dysfunction
        "G71033",  # Limb girdle muscular dystrophy due to dysferlin dysfunction
        "G710340",  # Limb girdle muscular dystrophy due to sarcoglycan dysfunction, unspecified
        "G710341",  # Limb girdle muscular dystrophy due to alpha sarcoglycan dysfunction
        "G710342",  # Limb girdle muscular dystrophy due to beta sarcoglycan dysfunction
        "G710349",  # Limb girdle muscular dystrophy due to other sarcoglycan dysfunction
        "G71035",  # Limb girdle muscular dystrophy due to anoctamin-5 dysfunction
        "G71038",  # Other limb girdle muscular dystrophy
        "G71039",  # Limb girdle muscular dystrophy, unspecified
        "G7109",  # Other specified muscular dystrophies
        "G7111",  # Myotonic muscular dystrophy
        "G7112",  # Myotonia congenita
        "G7113",  # Myotonic chondrodystrophy
        "G7119",  # Other specified myotonic disorders
        "G7120",  # Congenital myopathy, unspecified
        "G7121",  # Nemaline myopathy
        "G71220",  # X-linked myotubular myopathy
        "G71228",  # Other centronuclear myopathy
        "G7129",  # Other congenital myopathy
        "G713",  # Mitochondrial myopathy, not elsewhere classified
        "G718",  # Other primary disorders of muscles
        "G719",  # Primary disorder of muscle, unspecified
        "G720",  # Drug-induced myopathy
        "G721",  # Alcoholic myopathy
        "G722",  # Myopathy due to other toxic agents
        "G723",  # Periodic paralysis
        "G7241",  # Inclusion body myositis [IBM]
        "G7249",  # Other inflammatory and immune myopathies, not elsewhere classified
        "G7281",  # Critical illness myopathy
        "G7289",  # Other specified myopathies
        "G729",  # Myopathy, unspecified
        "G731",  # Lambert-Eaton syndrome in neoplastic disease
        "G733",  # Myasthenic syndromes in other diseases classified elsewhere
        "G737",  # Myopathy in diseases classified elsewhere
        "G800",  # Spastic quadriplegic cerebral palsy
        "G8250",  # Quadriplegia, unspecified
        "G8251",  # Quadriplegia, C1-C4 complete
        "G8252",  # Quadriplegia, C1-C4 incomplete
        "G8253",  # Quadriplegia, C5-C7 complete
        "G8254",  # Quadriplegia, C5-C7 incomplete
        "M0540",  # Rheumatoid myopathy with rheumatoid arthritis of unspecified site
        "M05411",  # Rheumatoid myopathy with rheumatoid arthritis of right shoulder
        "M05412",  # Rheumatoid myopathy with rheumatoid arthritis of left shoulder
        "M05419",  # Rheumatoid myopathy with rheumatoid arthritis of unspecified shoulder
        "M05421",  # Rheumatoid myopathy with rheumatoid arthritis of right elbow
        "M05422",  # Rheumatoid myopathy with rheumatoid arthritis of left elbow
        "M05429",  # Rheumatoid myopathy with rheumatoid arthritis of unspecified elbow
        "M05431",  # Rheumatoid myopathy with rheumatoid arthritis of right wrist
        "M05432",  # Rheumatoid myopathy with rheumatoid arthritis of left wrist
        "M05439",  # Rheumatoid myopathy with rheumatoid arthritis of unspecified wrist
        "M05441",  # Rheumatoid myopathy with rheumatoid arthritis of right hand
        "M05442",  # Rheumatoid myopathy with rheumatoid arthritis of left hand
        "M05449",  # Rheumatoid myopathy with rheumatoid arthritis of unspecified hand
        "M05451",  # Rheumatoid myopathy with rheumatoid arthritis of right hip
        "M05452",  # Rheumatoid myopathy with rheumatoid arthritis of left hip
        "M05459",  # Rheumatoid myopathy with rheumatoid arthritis of unspecified hip
        "M05461",  # Rheumatoid myopathy with rheumatoid arthritis of right knee
        "M05462",  # Rheumatoid myopathy with rheumatoid arthritis of left knee
        "M05469",  # Rheumatoid myopathy with rheumatoid arthritis of unspecified knee
        "M05471",  # Rheumatoid myopathy with rheumatoid arthritis of right ankle and foot
        "M05472",  # Rheumatoid myopathy with rheumatoid arthritis of left ankle and foot
        "M05479",  # Rheumatoid myopathy with rheumatoid arthritis of unspecified ankle and foot
        "M0549",  # Rheumatoid myopathy with rheumatoid arthritis of multiple sites
        "M3301",  # Juvenile dermatomyositis with respiratory involvement
        "M3311",  # Other dermatomyositis with respiratory involvement
        "M3321",  # Polymyositis with respiratory involvement
        "M3391",  # Dermatopolymyositis, unspecified with respiratory involvement
        "M3482",  # Systemic sclerosis with myopathy
        "M3503",  # Sjogren syndrome with myopathy
        "M4140",  # Neuromuscular scoliosis, site unspecified
        "M4141",  # Neuromuscular scoliosis, occipito-atlanto-axial region
        "M4142",  # Neuromuscular scoliosis, cervical region
        "M4143",  # Neuromuscular scoliosis, cervicothoracic region
        "M4144",  # Neuromuscular scoliosis, thoracic region
        "M4145",  # Neuromuscular scoliosis, thoracolumbar region
        "M4146",  # Neuromuscular scoliosis, lumbar region
        "M4147",  # Neuromuscular scoliosis, lumbosacral region
    }

    SNOMEDCT = {
        "1010712009",  # Autosomal dominant Emery-Dreifuss muscular dystrophy (disorder)
        "103851000119100",  # Restrictive lung disease due to amyotrophic lateral sclerosis (disorder)
        "111501005",  # Congenital hereditary muscular dystrophy (disorder)
        "111502003",  # Fukuyama congenital muscular dystrophy (disorder)
        "111503008",  # Merosin deficient congenital muscular dystrophy (disorder)
        "111504002",  # Walker-Warburg congenital muscular dystrophy (disorder)
        "111505001",  # Muscle-eye-brain disease, congenital muscular dystrophy (disorder)
        "111506000",  # Distal muscular dystrophy, Miyoshi type (disorder)
        "111508004",  # Emery-Dreifuss muscular dystrophy (disorder)
        "1144926009",  # Sporadic inclusion body myositis (disorder)
        "11538006",  # Quadriplegia (disorder)
        "1156836006",  # X-linked Emery-Dreifuss muscular dystrophy (disorder)
        "1156848009",  # Autosomal recessive Emery-Dreifuss muscular dystrophy (disorder)
        "1172588008",  # Early-onset progressive encephalopathy, spastic ataxia, distal spinal muscular atrophy syndrome (disorder)
        "1172688004",  # Congenital muscular dystrophy, respiratory failure, skin abnormalities, joint hyperlaxity syndrome (disorder)
        "1172689007",  # Prenatal-onset spinal muscular atrophy with congenital bone fractures (disorder)
        "1172703004",  # Protein O-glucosyltransferase 1-related limb girdle muscular dystrophy R21 (disorder)
        "1177122009",  # Myotonic dystrophy (disorder)
        "1179295004",  # Blood vessel epicardial substance related limb girdle muscular dystrophy (disorder)
        "1179297007",  # LIM zinc finger domain containing 2-related limb girdle muscular dystrophy (disorder)
        "1197152005",  # Distal hereditary motor neuropathy type 5 (disorder)
        "1197153000",  # Typical nemaline myopathy (disorder)
        "1197154006",  # Childhood-onset nemaline myopathy (disorder)
        "1197155007",  # Amish nemaline myopathy (disorder)
        "1197156008",  # Intermediate nemaline myopathy (disorder)
        "1197157004",  # Severe congenital nemaline myopathy (disorder)
        "1197523001",  # Autosomal dominant amyotrophic lateral sclerosis type 1 (disorder)
        "1197524007",  # Autosomal recessive amyotrophic lateral sclerosis type 1 (disorder)
        "1201863001",  # Amyotrophic lateral sclerosis type 1 (disorder)
        "1201947005",  # Juvenile amyotrophic lateral sclerosis type 2 (disorder)
        "1201950008",  # Amyotrophic lateral sclerosis type 3 (disorder)
        "1201961000",  # Juvenile amyotrophic lateral sclerosis type 5 (disorder)
        "1201964008",  # Congenital fiber-type disproportion myopathy due to ZAK mutation (disorder)
        "1202023003",  # Congenital fiber-type disproportion myopathy due to selenoprotein N mutation (disorder)
        "1202024009",  # Autosomal dominant congenital fiber-type disproportion myopathy due to selenoprotein N mutation (disorder)
        "1202025005",  # Autosomal recessive congenital fiber-type disproportion myopathy due to selenoprotein N mutation (disorder)
        "1204334005",  # Amyotrophic lateral sclerosis type 6 (disorder)
        "1204349002",  # Amyotrophic lateral sclerosis type 7 (disorder)
        "1204350002",  # Amyotrophic lateral sclerosis type 8 (disorder)
        "1204351003",  # Amyotrophic lateral sclerosis type 9 (disorder)
        "1208412003",  # Amyotrophic lateral sclerosis type 10 (disorder)
        "1208413008",  # Congenital fiber-type disproportion myopathy due to actin alpha 1, skeletal muscle mutation (disorder)
        "1208414002",  # Autosomal recessive congenital fiber-type disproportion myopathy due to actin alpha 1, skeletal muscle mutation (disorder)
        "1208415001",  # Autosomal dominant congenital fiber-type disproportion myopathy due to actin alpha 1, skeletal muscle mutation (disorder)
        "1208416000",  # Congenital fiber-type disproportion myopathy due to tropomyosin 3 mutation (disorder)
        "1208417009",  # Autosomal recessive congenital fiber-type disproportion myopathy due to tropomyosin 3 mutation (disorder)
        "1208418004",  # Autosomal dominant congenital fiber-type disproportion myopathy due to tropomyosin 3 mutation (disorder)
        "1209168005",  # Congenital fiber-type disproportion myopathy due to myosin heavy chain 7 mutation (disorder)
        "1217655004",  # Disorder of neuromuscular junction due to Lambert-Eaton syndrome (disorder)
        "1230273004",  # Megaconial congenital muscular dystrophy (disorder)
        "1230343006",  # Distal hereditary motor neuropathy type 2 (disorder)
        "1231210003",  # Mechanical strabismus due to disorder of skeletal muscle caused by local anaesthetic (disorder)
        "1231685006",  # Myopathy of extraocular muscle due to disorder of blood vessel (disorder)
        "123391000119106",  # Functional quadriplegia (disorder)
        "1234819007",  # Limb girdle muscular dystrophy due to protein O-mannose kinase deficiency (disorder)
        "1259121008",  # Amyotrophic lateral sclerosis, parkinsonism, dementia complex of West New Guinea (disorder)
        "1259122001",  # Amyotrophic lateral sclerosis with parkinsonism (disorder)
        "1259123006",  # Amyotrophic lateral sclerosis, parkinsonism, dementia complex of Kii Peninsula (disorder)
        "1259124000",  # Amyotrophic lateral sclerosis with frontotemporal dementia (disorder)
        "1259125004",  # Amyotrophic lateral sclerosis with multiple system atrophy (disorder)
        "1259126003",  # Amyotrophic lateral sclerosis with autonomic dysfunction (disorder)
        "1259127007",  # Amyotrophic lateral sclerosis with cerebellar dysfunction (disorder)
        "1259129005",  # Amyotrophic lateral sclerosis with spinocerebellar ataxia (disorder)
        "128212001",  # Spinal muscular atrophy, type II (disorder)
        "129620000",  # Scapuloperoneal muscular dystrophy (disorder)
        "129621001",  # Nemaline myopathy, early onset type (disorder)
        "129622008",  # Nemaline myopathy, late onset type (disorder)
        "17940001",  # Toxic neuromuscular junction disorder (disorder)
        "193209005",  # Myasthenic syndrome due to another disorder (disorder)
        "193212008",  # Myasthenic syndrome due to hypothyroidism (disorder)
        "193213003",  # Myasthenic syndrome due to pernicious anemia (disorder)
        "193214009",  # Myasthenic syndrome due to thyrotoxicosis (disorder)
        "193225000",  # Hereditary progressive muscular dystrophy (disorder)
        "193230001",  # Distal muscular dystrophy with juvenile onset (disorder)
        "193237003",  # Myotonic disorder (disorder)
        "193246009",  # Symptomatic inflammatory myopathy associated with another disorder (disorder)
        "193248005",  # Myopathy due to disseminated lupus erythematosus (disorder)
        "193249002",  # Myopathy due to polyarteritis nodosa (disorder)
        "193250002",  # Myopathy due to rheumatoid arthritis (disorder)
        "193251003",  # Sarcoid myopathy (disorder)
        "193252005",  # Myopathy due to scleroderma (disorder)
        "193253000",  # Myopathy due to Sjogren's disease (disorder)
        "196136009",  # Lung disease co-occurrent with polymyositis (disorder)
        "20305008",  # Congenital myotonia, autosomal recessive form (disorder)
        "203662005",  # Neuromuscular scoliosis (disorder)
        "22881000119100",  # Quadriplegia with quadriparesis (disorder)
        "229221000119103",  # Myopathy due to Cushing's syndrome (disorder)
        "230246005",  # Progressive bulbar palsy of childhood (disorder)
        "230247001",  # Distal spinal muscular atrophy (disorder)
        "230248006",  # Scapuloperoneal spinal muscular atrophy (disorder)
        "230249003",  # Facioscapulohumeral spinal muscular atrophy (disorder)
        "230250003",  # Facioscapulohumeral spinal muscular atrophy with sensory loss (disorder)
        "230251004",  # Scapulohumeral spinal muscular atrophy (disorder)
        "230252006",  # Oculopharyngeal spinal muscular atrophy (disorder)
        "230254007",  # Western Pacific motor neurone disease (disorder)
        "230255008",  # Madras-type motor neurone disease (disorder)
        "230257000",  # Paraneoplastic motor neurone disease (disorder)
        "230258005",  # Amyotrophic lateral sclerosis with dementia (disorder)
        "230274000",  # Frontal lobe degeneration with motor neurone disease (disorder)
        "230672006",  # Congenital myasthenic syndrome (disorder)
        "230685009",  # Myasthenia gravis associated with thymoma (disorder)
        "230687001",  # Myopathy in myasthenia gravis (disorder)
        "240046001",  # Muscular dystrophy with predominantly proximal limb girdle distribution (disorder)
        "240047005",  # X-linked muscular dystrophy with limb girdle distribution (disorder)
        "240048000",  # X-linked muscular dystrophy with abnormal dystrophin (disorder)
        "240049008",  # Intermediate X-linked muscular dystrophy (disorder)
        "240051007",  # X-linked limb girdle muscular dystrophy with normal dystrophin (disorder)
        "240054004",  # Autosomal recessive muscular dystrophy with limb girdle distribution (disorder)
        "240055003",  # Autosomal recessive muscular dystrophy with abnormal dystrophin-associated glycoprotein (disorder)
        "240058001",  # Reunion-Indiana Amish type muscular dystrophy (disorder)
        "240060004",  # Western type of congenital muscular dystrophy (disorder)
        "240061000",  # Congenital muscular dystrophy with arthrogryposis multiplex congenita (disorder)
        "240062007",  # Ullrich congenital muscular dystrophy (disorder)
        "240063002",  # Eichsfeld type congenital muscular dystrophy (disorder)
        "240064008",  # Hutterite type of muscular dystrophy (disorder)
        "240065009",  # Adult onset autosomal recessive muscular dystrophy with normal dystrophin (disorder)
        "240067001",  # Autosomal dominant muscular dystrophy with limb girdle distribution (disorder)
        "240068006",  # Autosomal dominant muscular dystrophy with gene located at 5q31 (disorder)
        "240069003",  # Late onset proximal muscular dystrophy with dysarthria (disorder)
        "240070002",  # Muscular dystrophy not predominantly limb girdle in distribution (disorder)
        "240071003",  # X-linked muscular dystrophy not predominantly limb girdle (disorder)
        "240073000",  # Autosomal recessive muscular dystrophy not predominantly limb girdle (disorder)
        "240074006",  # Scapulohumeral muscular dystrophy (disorder)
        "240075007",  # Autosomal dominant muscular dystrophy not predominantly limb girdle (disorder)
        "240076008",  # Benign scapuloperoneal muscular dystrophy (disorder)
        "240077004",  # Severe scapuloperoneal muscular dystrophy with cardiomyopathy (disorder)
        "240078009",  # Benign congenital muscular dystrophy with finger flexion contractures (disorder)
        "240081004",  # Autosomal recessive centronuclear myopathy (disorder)
        "240100004",  # Myopathy due to snake bite (disorder)
        "240104008",  # Congenital myotonic dystrophy (disorder)
        "24800001000004103",  # Functional quadriplegia due to multiple sclerosis (disorder)
        "24861000119103",  # Symptomatic inflammatory myopathy (disorder)
        "257277002",  # Combined disorder of muscle AND peripheral nerve (disorder)
        "267604001",  # Myasthenic syndrome due to diabetic mellitus (disorder)
        "267607008",  # Familial periodic paralysis (disorder)
        "274864009",  # Glycogen storage disease due to acid maltase deficiency (disorder)
        "275468009",  # Congenital quadriplegia (disorder)
        "29145002",  # Schwartz-Jampel syndrome (disorder)
        "292991000119106",  # Eaton Lambert syndrome without underlying malignancy (disorder)
        "296241000119107",  # Disorder of respiratory system due to dermatomyositis (disorder)
        "304737009",  # Familial hyperkalemic periodic paralysis (disorder)
        "30967002",  # Thyrotoxic periodic paralysis (disorder)
        "31097004",  # Post poliomyelitis syndrome (disorder)
        "311671000119100",  # Juvenile dermatomyositis co-occurrent with respiratory involvement (disorder)
        "314341000119101",  # Neuromuscular scoliosis of cervical spine (disorder)
        "314351000119104",  # Neuromuscular scoliosis of cervicothoracic spine (disorder)
        "314361000119102",  # Neuromuscular scoliosis of lumbar spine (disorder)
        "314371000119108",  # Neuromuscular scoliosis of lumbosacral spine (disorder)
        "314391000119109",  # Neuromuscular scoliosis of thoracic spine (disorder)
        "314401000119106",  # Neuromuscular scoliosis of thoracolumbar spine (disorder)
        "31839002",  # Myasthenia gravis, adult form (disorder)
        "329741000119109",  # Neuromuscular scoliosis of lumbar spine co-occurrent and due to cerebral palsy (disorder)
        "329841000119103",  # Neuromuscular scoliosis due to and following poliomyelitis (disorder)
        "330471000119101",  # Neuromuscular scoliosis co-occurrent and due to cerebral palsy (disorder)
        "330521000119103",  # Neuromuscular scoliosis of thoracolumbar spine co-occurrent and due to cerebral palsy (disorder)
        "3434004",  # Myotonia (finding)
        "37340000",  # Motor neuron disease (disorder)
        "387732009",  # Becker muscular dystrophy (disorder)
        "3971006",  # Duchenne muscular dystrophy carrier detection (procedure)
        "398102009",  # Acute poliomyelitis (disorder)
        "399091004",  # Facioscapulohumeral muscular dystrophy (disorder)
        "40381009",  # Familial normokalemic periodic paralysis (disorder)
        "40956001",  # Guillain-Barre syndrome (disorder)
        "422348008",  # Andersen Tawil syndrome (disorder)
        "441705005",  # Complete quadriplegia due to spinal cord lesion between first and fourth cervical vertebra (disorder)
        "441980007",  # Complete quadriplegia due to spinal cord lesion between fifth and seventh cervical vertebra (disorder)
        "443819006",  # Critical illness myopathy (disorder)
        "46804001",  # Severe X-linked myotubular myopathy (disorder)
        "48721008",  # Quadriplegic cerebral palsy (disorder)
        "49793008",  # Hereditary motor neuron disease (disorder)
        "5262007",  # Spinal muscular atrophy (disorder)
        "54280009",  # Kugelberg-Welander disease (disorder)
        "54304004",  # Progressive bulbar palsy (disorder)
        "56989000",  # Eaton-Lambert syndrome (disorder)
        "57938005",  # Congenital myotonia, autosomal dominant form (disorder)
        "58795000",  # Distal muscular dystrophy (disorder)
        "608874000",  # Eaton Lambert syndrome with underlying malignancy (disorder)
        "64383006",  # Werdnig-Hoffmann disease (disorder)
        "68437005",  # Thyrotoxic myopathy (disorder)
        "698741009",  # Acute complete quadriplegia due to spinal cord lesion between first and fourth cervical vertebra (disorder)
        "698743007",  # Acute complete quadriplegia due to spinal cord lesion between fifth and seventh cervical vertebra (disorder)
        "698846009",  # Tibial muscular dystrophy (disorder)
        "699866005",  # Progressive bulbar palsy with sensorineural deafness (disorder)
        "702343002",  # Early onset myopathy with fatal cardiomyopathy (disorder)
        "702349003",  # Actin accumulation myopathy (disorder)
        "702380008",  # Idiopathic inflammatory myopathy (disorder)
        "702424003",  # Dilated cardiomyopathy 3B (disorder)
        "703524005",  # Spinal muscular atrophy with progressive myoclonic epilepsy (disorder)
        "703544004",  # Inclusion body myopathy with early-onset Paget disease and frontotemporal dementia (disorder)
        "711406009",  # Autosomal recessive axonal neuropathy with neuromyotonia (disorder)
        "711483003",  # Spinal muscular atrophy with respiratory distress type 1 (disorder)
        "715317001",  # Proximal myotonic myopathy (disorder)
        "715340002",  # Autosomal recessive limb girdle muscular dystrophy type 2D (disorder)
        "715341003",  # Autosomal recessive limb girdle muscular dystrophy type 2A (disorder)
        "715429006",  # Congenital muscular dystrophy with infantile cataract and hypogonadism syndrome (disorder)
        "715788001",  # Myotonia fluctuans (disorder)
        "715789009",  # Myotonia permanens (disorder)
        "715793003",  # Acetazolamide responsive myotonia (disorder)
        "715863001",  # Autoimmune necrotizing myopathy (disorder)
        "716696006",  # Autosomal dominant centronuclear myopathy (disorder)
        "716722005",  # Acute motor sensory axonal Guillain-Barre syndrome (disorder)
        "716723000",  # Guillain-Barre syndrome acute inflammatory demyelinating polyradiculoneuropathic form (disorder)
        "718176005",  # Autosomal recessive limb girdle muscular dystrophy type 2C (disorder)
        "718177001",  # Autosomal recessive limb girdle muscular dystrophy type 2F (disorder)
        "718179003",  # Autosomal recessive limb girdle muscular dystrophy type 2B (disorder)
        "718180000",  # Autosomal recessive limb girdle muscular dystrophy type 2I (disorder)
        "718555006",  # Juvenile amyotrophic lateral sclerosis (disorder)
        "718850008",  # Autosomal recessive limb girdle muscular dystrophy type 2E (disorder)
        "719836007",  # X-linked distal arthrogryposis multiplex congenita (disorder)
        "719985001",  # Autosomal dominant limb girdle muscular dystrophy type 1A (disorder)
        "719987009",  # Autosomal dominant limb girdle muscular dystrophy type 1D (disorder)
        "719988004",  # Autosomal dominant limb girdle muscular dystrophy type 1E (disorder)
        "719989007",  # Autosomal dominant limb girdle muscular dystrophy type 1F (disorder)
        "719990003",  # Autosomal dominant limb girdle muscular dystrophy type 1G (disorder)
        "720522001",  # Autosomal recessive limb girdle muscular dystrophy type 2G (disorder)
        "720523006",  # Autosomal recessive limb girdle muscular dystrophy type 2K (disorder)
        "721190004",  # Myopathy due to magnesium deficiency (disorder)
        "722060007",  # Oculogastrointestinal muscular dystrophy (disorder)
        "722302009",  # Glycogen storage disease due to acid maltase deficiency, infantile onset (disorder)
        "722343009",  # Glycogen storage disease due to acid maltase deficiency, late-onset (disorder)
        "722987009",  # Amyotrophic lateral sclerosis plus syndrome (disorder)
        "72315009",  # Inclusion body myositis (disorder)
        "723308003",  # Epidermolysis bullosa simplex with muscular dystrophy (disorder)
        "723407009",  # Muscular dystrophy Selcen type (disorder)
        "723612001",  # Spinal muscular atrophy, Dandy-Walker malformation, cataract syndrome (disorder)
        "724095006",  # Myopathy due to calsequestrin and sarcoplasmic/endoplasmic reticulum calcium ATPase 1 protein overload (disorder)
        "724559006",  # Myopathy co-occurrent and due to hypercalcemia (disorder)
        "725042001",  # Autosomal recessive limb girdle muscular dystrophy type 2J (disorder)
        "725043006",  # Autosomal recessive limb girdle muscular dystrophy type 2O (disorder)
        "725420009",  # Congenital muscular dystrophy Paradas type (disorder)
        "725907002",  # Autosomal recessive limb girdle muscular dystrophy type 2Y (disorder)
        "726051002",  # Myotonia congenita (disorder)
        "726614009",  # Autosomal recessive limb girdle muscular dystrophy type 2P (disorder)
        "726615005",  # Autosomal recessive limb girdle muscular dystrophy type 2Q (disorder)
        "726616006",  # Autosomal recessive limb girdle muscular dystrophy type 2L (disorder)
        "726617002",  # Autosomal recessive limb girdle muscular dystrophy type 2N (disorder)
        "726618007",  # Autosomal recessive limb girdle muscular dystrophy type 2M (disorder)
        "732929002",  # Autosomal recessive limb girdle muscular dystrophy type 2S (disorder)
        "732930007",  # Autosomal recessive limb girdle muscular dystrophy type 2T (disorder)
        "73297009",  # Muscular dystrophy (disorder)
        "7409003",  # Secondary periodic paralysis (disorder)
        "74116004",  # Nutritional muscular degeneration (disorder)
        "75072002",  # Nemaline myopathy (disorder)
        "763067000",  # Autosomal dominant congenital benign spinal muscular atrophy (disorder)
        "763314009",  # Congenital muscular dystrophy with hyperlaxity (disorder)
        "763315005",  # Congenital myopathy with myasthenic-like onset (disorder)
        "763533003",  # Distal hereditary motor neuropathy Jerash type (disorder)
        "764944006",  # Congenital muscular dystrophy type 1B (disorder)
        "764945007",  # Congenital myopathy with internal nuclei and atypical cores (disorder)
        "76670001",  # Duchenne muscular dystrophy (disorder)
        "766706007",  # Inflammatory myopathy with abundant macrophages (disorder)
        "766715000",  # Metabolic myopathy due to lactate transporter defect (disorder)
        "766722008",  # Paraparetic variant of Guillain-Barre syndrome (disorder)
        "766764008",  # X-linked distal spinal muscular atrophy type 3 (disorder)
        "770430000",  # Autosomal recessive distal spinal muscular atrophy type 3 (disorder)
        "770630005",  # Distal hereditary motor neuropathy type 1 (disorder)
        "770727008",  # Spinal muscular atrophy with respiratory distress type 2 (disorder)
        "770792007",  # Adult-onset distal myopathy due to valosin containing protein mutation (disorder)
        "77097004",  # Oculopharyngeal muscular dystrophy (disorder)
        "771081007",  # Distal hereditary motor neuropathy type 7 (disorder)
        "771267003",  # Congenital muscular dystrophy with integrin alpha-7 deficiency (disorder)
        "771272007",  # Congenital muscular dystrophy due to lamin A/C mutation (disorder)
        "771302009",  # Autosomal recessive lower motor neuron disease with childhood onset (disorder)
        "771334000",  # Autosomal dominant limb-girdle muscular dystrophy type 1H (disorder)
        "771475006",  # Young adult-onset distal hereditary motor neuropathy (disorder)
        "772129007",  # Autosomal dominant childhood-onset proximal spinal muscular atrophy (disorder)
        "774153002",  # Periodic paralysis with transient compartment-like syndrome (disorder)
        "774154008",  # Periodic paralysis with later-onset distal motor neuropathy (disorder)
        "77461000119109",  # Myasthenia gravis with exacerbation (disorder)
        "77471000119103",  # Myasthenia gravis without exacerbation (disorder)
        "77956009",  # Steinert myotonic dystrophy syndrome (disorder)
        "782772000",  # Congenital muscular dystrophy with intellectual disability and severe epilepsy (disorder)
        "782941005",  # Richieri Costa-da Silva syndrome (disorder)
        "783010003",  # Pharyngeal-cervical-brachial variant of Guillain-Barre syndrome (disorder)
        "783166000",  # Distal anoctaminopathy (disorder)
        "783174004",  # Congenital muscular dystrophy with intellectual disability (disorder)
        "783175003",  # Congenital muscular dystrophy without intellectual disability (disorder)
        "783176002",  # Congenital muscular dystrophy with cerebellar involvement (disorder)
        "783554002",  # Autosomal recessive limb girdle muscular dystrophy type 2U (disorder)
        "784341001",  # Amyotrophic lateral sclerosis type 4 (disorder)
        "784352007",  # X-linked scapuloperoneal muscular dystrophy (disorder)
        "784391002",  # Autosomal dominant adult-onset proximal spinal muscular atrophy (disorder)
        "787037000",  # Congenital muscular dystrophy type 1A (disorder)
        "80976008",  # Myasthenic crisis (disorder)
        "81211007",  # Primary lateral sclerosis (disorder)
        "82077006",  # Myotubular myopathy (disorder)
        "82732003",  # Familial hypokalemic periodic paralysis (disorder)
        "838276009",  # Amyotrophic lateral sclerosis, parkinsonism, dementia complex (disorder)
        "84590007",  # Lower motor neuron disease (disorder)
        "85034001",  # Myotonia acquisita (disorder)
        "85505000",  # Adult spinal muscular atrophy (disorder)
        "86044005",  # Amyotrophic lateral sclerosis (disorder)
        "866051002",  # Motor neuron disease due to lead intoxication (disorder)
        "866103007",  # Interstitial lung disease due to juvenile polymyositis (disorder)
        "870297003",  # Myopathy due to chronic alcoholism (disorder)
        "870299000",  # Myopathy due to calcium deficiency (disorder)
        "890368007",  # Congenital muscular dystrophy type 1C due to fukutin related protein gene mutation (disorder)
        "890395002",  # Congenital muscular dystrophy type 1D large gene mutation (disorder)
        "8960007",  # Myotonia levior (disorder)
        "91637004",  # Myasthenia gravis (disorder)
        "95647008",  # Upper motor neuron disease (disorder)
    }

class ProceduralHospitalLocations(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for these procedural hospital locations: operating room/suite, cardiac catheterization suite, interventional radiology, and endoscopy suite

    **Data Element Scope:** This value set may use a model element related to facility location

    **Inclusion Criteria:** Includes concepts for concepts for these hospital locations: operating room/suite, cardiac catheterization suite, interventional radiology, and endoscopy suite

    **Exclusion Criteria:** Excludes any other hospital or facility locations
    """

    VALUE_SET_NAME = "Procedural Hospital Locations"
    OID = "2.16.840.1.113762.1.4.1248.216"
    DEFINITION_VERSION = "20230512"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    HSLOC = {
        "1005-8",  # Cardiac Catheterization Room/Suite
        "1007-4",  # Endoscopy Suite
        "1096-7",  # Operating Room/Suite
        "1203-9",  # Interventional Radiology
    }

class SmokingStatus(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for smoking status

    **Data Element Scope:** This value set may use a model element related to Observation or Assessment

    **Inclusion Criteria:** Includes concepts to represent smoking status

    **Exclusion Criteria:** N/A
    """

    VALUE_SET_NAME = "Smoking status"
    OID = "2.16.840.1.113762.1.4.1248.220"
    DEFINITION_VERSION = "20240112"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "105539002",  # Non-smoker for personal reasons (finding)
        "105540000",  # Non-smoker for religious reasons (finding)
        "105541001",  # Non-smoker for medical reasons (finding)
        "160603005",  # Light cigarette smoker (1-9 cigs/day) (finding)
        "160604004",  # Moderate cigarette smoker (10-19 cigs/day) (finding)
        "160605003",  # Heavy cigarette smoker (20-39 cigs/day) (finding)
        "160606002",  # Very heavy cigarette smoker (40+ cigs/day) (finding)
        "160620009",  # Ex-pipe smoker (finding)
        "160621008",  # Ex-cigar smoker (finding)
        "230059006",  # Occasional cigarette smoker (finding)
        "230060001",  # Light cigarette smoker (finding)
        "230062009",  # Moderate cigarette smoker (finding)
        "230063004",  # Heavy cigarette smoker (finding)
        "230064005",  # Very heavy cigarette smoker (finding)
        "230065006",  # Chain smoker (finding)
        "266920004",  # Trivial cigarette smoker (less than one cigarette/day) (finding)
        "266921000",  # Ex-trivial cigarette smoker (<1/day) (finding)
        "266922007",  # Ex-light cigarette smoker (1-9/day) (finding)
        "266923002",  # Ex-moderate cigarette smoker (10-19/day) (finding)
        "266924008",  # Ex-heavy cigarette smoker (20-39/day) (finding)
        "266925009",  # Ex-very heavy cigarette smoker (40+/day) (finding)
        "266928006",  # Ex-cigarette smoker amount unknown (finding)
        "281018007",  # Ex-cigarette smoker (finding)
        "360890004",  # Intolerant ex-smoker (finding)
        "360900008",  # Aggressive ex-smoker (finding)
        "360918006",  # Aggressive non-smoker (finding)
        "360929005",  # Intolerant non-smoker (finding)
        "405746006",  # Current non smoker but past smoking history unknown (finding)
        "428041000124106",  # Occasional tobacco smoker (finding)
        "428061000124105",  # Light tobacco smoker (finding)
        "428071000124103",  # Heavy tobacco smoker (finding)
        "428081000124100",  # Former heavy tobacco smoker (finding)
        "428091000124102",  # Former light tobacco smoker (finding)
        "43381005",  # Passive smoker (finding)
        "449868002",  # Smokes tobacco daily (finding)
        "450811000124104",  # Cigarette smoker (5-9 cigarettes/day) (finding)
        "450821000124107",  # Cigarette smoker (1-4 cigarettes/day) (finding)
        "48031000119106",  # Ex-smoker for more than 1 year (finding)
        "53896009",  # Tolerant ex-smoker (finding)
        "56578002",  # Moderate smoker (20 or less per day) (finding)
        "56771006",  # Heavy smoker (over 20 per day) (finding)
        "59978006",  # Cigar smoker (finding)
        "65568007",  # Cigarette smoker (finding)
        "698289004",  # Hookah pipe smoker (finding)
        "735128000",  # Ex-smoker for less than 1 year (finding)
        "77176002",  # Smoker (finding)
        "82302008",  # Pipe smoker (finding)
        "8392000",  # Non-smoker (finding)
        "8517006",  # Ex-smoker (finding)
        "87739003",  # Tolerant non-smoker (finding)
    }

class TracheostomyDiagnoses(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for tracheostomy diagnoses

    **Data Element Scope:** This value set may use a model element related to Diagnosis or Condition

    **Inclusion Criteria:** Includes concepts that represent tracheostomy diagnoses

    **Exclusion Criteria:** N/A
    """

    VALUE_SET_NAME = "Tracheostomy Diagnoses"
    OID = "2.16.840.1.113762.1.4.1248.89"
    DEFINITION_VERSION = "20220719"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "J9500",  # Unspecified tracheostomy complication
        "J9501",  # Hemorrhage from tracheostomy stoma
        "J9502",  # Infection of tracheostomy stoma
        "J9503",  # Malfunction of tracheostomy stoma
        "J9504",  # Tracheo-esophageal fistula following tracheostomy
        "J9509",  # Other tracheostomy complication
        "Z430",  # Encounter for attention to tracheostomy
        "Z930",  # Tracheostomy status
    }

class AdmitInpatient(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts of an assessment result of decision to admit to inpatient hospitalization.

    **Data Element Scope:** The value set may use a model element related to Assessment.

    **Inclusion Criteria:** Includes concepts that represent an assessment that resulted in a decision to admit to an inpatient hospital setting.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Admit Inpatient"
    OID = "2.16.840.1.113762.1.4.1111.164"
    DEFINITION_VERSION = "20210220"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "434081000124108",  # Patient requires hospitalization (finding)
        "452541000124103",  # Transition of care from emergency department to acute care (finding)
        "707852009",  # Inpatient management required (finding)
    }

class EmergencyDepartmentLocation(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for emergency department locations.

    **Data Element Scope:** This value set may use the data element Encounter.

    **Inclusion Criteria:** Includes concepts that represent a location for emergency department.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Emergency Department Location"
    OID = "2.16.840.1.113762.1.4.1046.284"
    DEFINITION_VERSION = "20240418"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    HSLOC = {
        "1108-0",  # Emergency Department
        "1109-8",  # Pediatric Emergency Department
    }

    SNOMEDCT = {
        "225728007",  # Accident and Emergency department (environment)
        "310203004",  # Pediatric Accident and Emergency department (environment)
        "73770003",  # Hospital-based outpatient emergency care center (environment)
        "74018000",  # Free-standing emergency care center (environment)
    }

class EmergencyDepartmentTreatmentLocation(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for ED treatment locations

    **Data Element Scope:** This value set may use the data element Encounter.

    **Inclusion Criteria:** Includes concepts that represent a location for treatment in the emergency department.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Emergency Department Treatment Location"
    OID = "2.16.840.1.113762.1.4.1046.278"
    DEFINITION_VERSION = "20250212"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    HSLOC = {
        "1025-6",  # Trauma Critical Care
        "1027-2",  # Medical Critical Care
        "1029-8",  # Medical-Surgical Critical Care
        "1160-1",  # Urgent Care Center
        "1162-7",  # 24-Hour Observation Area
        "1209-6",  # Treatment Room
        "1210-4",  # Adult Mixed Acuity Unit
        "1212-0",  # Mixed Age Mixed Acuity Unit
        "1272-4",  # Onsite Overflow Critical Care
    }

class MentalHealthDiagnosisWithoutSubstanceUseDisorders(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group concepts of mental health diagnoses.

    **Data Element Scope:** This value set may use a model element related to Diagnosis.

    **Inclusion Criteria:** Includes concepts that represent a diagnosis of a mental health disorder.

    **Exclusion Criteria:** Excludes substance use disorders.
    """

    VALUE_SET_NAME = "Mental Health Diagnosis without Substance Use Disorders"
    OID = "2.16.840.1.113762.1.4.1046.285"
    DEFINITION_VERSION = "20240418"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "F0150",  # Vascular dementia, unspecified severity, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F01511",  # Vascular dementia, unspecified severity, with agitation
        "F01518",  # Vascular dementia, unspecified severity, with other behavioral disturbance
        "F0152",  # Vascular dementia, unspecified severity, with psychotic disturbance
        "F0153",  # Vascular dementia, unspecified severity, with mood disturbance
        "F0154",  # Vascular dementia, unspecified severity, with anxiety
        "F01A0",  # Vascular dementia, mild, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F01A11",  # Vascular dementia, mild, with agitation
        "F01A18",  # Vascular dementia, mild, with other behavioral disturbance
        "F01A2",  # Vascular dementia, mild, with psychotic disturbance
        "F01A3",  # Vascular dementia, mild, with mood disturbance
        "F01A4",  # Vascular dementia, mild, with anxiety
        "F01B0",  # Vascular dementia, moderate, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F01B11",  # Vascular dementia, moderate, with agitation
        "F01B18",  # Vascular dementia, moderate, with other behavioral disturbance
        "F01B2",  # Vascular dementia, moderate, with psychotic disturbance
        "F01B3",  # Vascular dementia, moderate, with mood disturbance
        "F01B4",  # Vascular dementia, moderate, with anxiety
        "F01C0",  # Vascular dementia, severe, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F01C11",  # Vascular dementia, severe, with agitation
        "F01C18",  # Vascular dementia, severe, with other behavioral disturbance
        "F01C2",  # Vascular dementia, severe, with psychotic disturbance
        "F01C3",  # Vascular dementia, severe, with mood disturbance
        "F01C4",  # Vascular dementia, severe, with anxiety
        "F0390",  # Unspecified dementia, unspecified severity, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F03911",  # Unspecified dementia, unspecified severity, with agitation
        "F03918",  # Unspecified dementia, unspecified severity, with other behavioral disturbance
        "F0392",  # Unspecified dementia, unspecified severity, with psychotic disturbance
        "F0393",  # Unspecified dementia, unspecified severity, with mood disturbance
        "F0394",  # Unspecified dementia, unspecified severity, with anxiety
        "F03A0",  # Unspecified dementia, mild, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F03A11",  # Unspecified dementia, mild, with agitation
        "F03A18",  # Unspecified dementia, mild, with other behavioral disturbance
        "F03A2",  # Unspecified dementia, mild, with psychotic disturbance
        "F03A3",  # Unspecified dementia, mild, with mood disturbance
        "F03A4",  # Unspecified dementia, mild, with anxiety
        "F03B0",  # Unspecified dementia, moderate, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F03B11",  # Unspecified dementia, moderate, with agitation
        "F03B18",  # Unspecified dementia, moderate, with other behavioral disturbance
        "F03B2",  # Unspecified dementia, moderate, with psychotic disturbance
        "F03B3",  # Unspecified dementia, moderate, with mood disturbance
        "F03B4",  # Unspecified dementia, moderate, with anxiety
        "F03C0",  # Unspecified dementia, severe, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F03C11",  # Unspecified dementia, severe, with agitation
        "F03C18",  # Unspecified dementia, severe, with other behavioral disturbance
        "F03C2",  # Unspecified dementia, severe, with psychotic disturbance
        "F03C3",  # Unspecified dementia, severe, with mood disturbance
        "F03C4",  # Unspecified dementia, severe, with anxiety
        "F04",  # Amnestic disorder due to known physiological condition
        "F060",  # Psychotic disorder with hallucinations due to known physiological condition
        "F061",  # Catatonic disorder due to known physiological condition
        "F062",  # Psychotic disorder with delusions due to known physiological condition
        "F0630",  # Mood disorder due to known physiological condition, unspecified
        "F0631",  # Mood disorder due to known physiological condition with depressive features
        "F0632",  # Mood disorder due to known physiological condition with major depressive-like episode
        "F0633",  # Mood disorder due to known physiological condition with manic features
        "F0634",  # Mood disorder due to known physiological condition with mixed features
        "F064",  # Anxiety disorder due to known physiological condition
        "F0670",  # Mild neurocognitive disorder due to known physiological condition without behavioral disturbance
        "F0671",  # Mild neurocognitive disorder due to known physiological condition with behavioral disturbance
        "F068",  # Other specified mental disorders due to known physiological condition
        "F070",  # Personality change due to known physiological condition
        "F0781",  # Postconcussional syndrome
        "F0789",  # Other personality and behavioral disorders due to known physiological condition
        "F079",  # Unspecified personality and behavioral disorder due to known physiological condition
        "F09",  # Unspecified mental disorder due to known physiological condition
        "F200",  # Paranoid schizophrenia
        "F201",  # Disorganized schizophrenia
        "F202",  # Catatonic schizophrenia
        "F203",  # Undifferentiated schizophrenia
        "F205",  # Residual schizophrenia
        "F2081",  # Schizophreniform disorder
        "F2089",  # Other schizophrenia
        "F209",  # Schizophrenia, unspecified
        "F21",  # Schizotypal disorder
        "F22",  # Delusional disorders
        "F23",  # Brief psychotic disorder
        "F24",  # Shared psychotic disorder
        "F250",  # Schizoaffective disorder, bipolar type
        "F251",  # Schizoaffective disorder, depressive type
        "F258",  # Other schizoaffective disorders
        "F259",  # Schizoaffective disorder, unspecified
        "F28",  # Other psychotic disorder not due to a substance or known physiological condition
        "F29",  # Unspecified psychosis not due to a substance or known physiological condition
        "F3010",  # Manic episode without psychotic symptoms, unspecified
        "F3011",  # Manic episode without psychotic symptoms, mild
        "F3012",  # Manic episode without psychotic symptoms, moderate
        "F3013",  # Manic episode, severe, without psychotic symptoms
        "F302",  # Manic episode, severe with psychotic symptoms
        "F303",  # Manic episode in partial remission
        "F304",  # Manic episode in full remission
        "F308",  # Other manic episodes
        "F309",  # Manic episode, unspecified
        "F310",  # Bipolar disorder, current episode hypomanic
        "F3110",  # Bipolar disorder, current episode manic without psychotic features, unspecified
        "F3111",  # Bipolar disorder, current episode manic without psychotic features, mild
        "F3112",  # Bipolar disorder, current episode manic without psychotic features, moderate
        "F3113",  # Bipolar disorder, current episode manic without psychotic features, severe
        "F312",  # Bipolar disorder, current episode manic severe with psychotic features
        "F3130",  # Bipolar disorder, current episode depressed, mild or moderate severity, unspecified
        "F3131",  # Bipolar disorder, current episode depressed, mild
        "F3132",  # Bipolar disorder, current episode depressed, moderate
        "F314",  # Bipolar disorder, current episode depressed, severe, without psychotic features
        "F315",  # Bipolar disorder, current episode depressed, severe, with psychotic features
        "F3160",  # Bipolar disorder, current episode mixed, unspecified
        "F3161",  # Bipolar disorder, current episode mixed, mild
        "F3162",  # Bipolar disorder, current episode mixed, moderate
        "F3163",  # Bipolar disorder, current episode mixed, severe, without psychotic features
        "F3164",  # Bipolar disorder, current episode mixed, severe, with psychotic features
        "F3170",  # Bipolar disorder, currently in remission, most recent episode unspecified
        "F3171",  # Bipolar disorder, in partial remission, most recent episode hypomanic
        "F3172",  # Bipolar disorder, in full remission, most recent episode hypomanic
        "F3173",  # Bipolar disorder, in partial remission, most recent episode manic
        "F3174",  # Bipolar disorder, in full remission, most recent episode manic
        "F3175",  # Bipolar disorder, in partial remission, most recent episode depressed
        "F3176",  # Bipolar disorder, in full remission, most recent episode depressed
        "F3177",  # Bipolar disorder, in partial remission, most recent episode mixed
        "F3178",  # Bipolar disorder, in full remission, most recent episode mixed
        "F3181",  # Bipolar II disorder
        "F3189",  # Other bipolar disorder
        "F319",  # Bipolar disorder, unspecified
        "F320",  # Major depressive disorder, single episode, mild
        "F321",  # Major depressive disorder, single episode, moderate
        "F322",  # Major depressive disorder, single episode, severe without psychotic features
        "F323",  # Major depressive disorder, single episode, severe with psychotic features
        "F324",  # Major depressive disorder, single episode, in partial remission
        "F325",  # Major depressive disorder, single episode, in full remission
        "F3281",  # Premenstrual dysphoric disorder
        "F3289",  # Other specified depressive episodes
        "F329",  # Major depressive disorder, single episode, unspecified
        "F32A",  # Depression, unspecified
        "F330",  # Major depressive disorder, recurrent, mild
        "F331",  # Major depressive disorder, recurrent, moderate
        "F332",  # Major depressive disorder, recurrent severe without psychotic features
        "F333",  # Major depressive disorder, recurrent, severe with psychotic symptoms
        "F3340",  # Major depressive disorder, recurrent, in remission, unspecified
        "F3341",  # Major depressive disorder, recurrent, in partial remission
        "F3342",  # Major depressive disorder, recurrent, in full remission
        "F338",  # Other recurrent depressive disorders
        "F339",  # Major depressive disorder, recurrent, unspecified
        "F340",  # Cyclothymic disorder
        "F341",  # Dysthymic disorder
        "F3481",  # Disruptive mood dysregulation disorder
        "F3489",  # Other specified persistent mood disorders
        "F349",  # Persistent mood [affective] disorder, unspecified
        "F39",  # Unspecified mood [affective] disorder
        "F4000",  # Agoraphobia, unspecified
        "F4001",  # Agoraphobia with panic disorder
        "F4002",  # Agoraphobia without panic disorder
        "F4010",  # Social phobia, unspecified
        "F4011",  # Social phobia, generalized
        "F40210",  # Arachnophobia
        "F40218",  # Other animal type phobia
        "F40220",  # Fear of thunderstorms
        "F40228",  # Other natural environment type phobia
        "F40230",  # Fear of blood
        "F40231",  # Fear of injections and transfusions
        "F40232",  # Fear of other medical care
        "F40233",  # Fear of injury
        "F40240",  # Claustrophobia
        "F40241",  # Acrophobia
        "F40242",  # Fear of bridges
        "F40243",  # Fear of flying
        "F40248",  # Other situational type phobia
        "F40290",  # Androphobia
        "F40291",  # Gynephobia
        "F40298",  # Other specified phobia
        "F408",  # Other phobic anxiety disorders
        "F409",  # Phobic anxiety disorder, unspecified
        "F410",  # Panic disorder [episodic paroxysmal anxiety]
        "F411",  # Generalized anxiety disorder
        "F413",  # Other mixed anxiety disorders
        "F418",  # Other specified anxiety disorders
        "F419",  # Anxiety disorder, unspecified
        "F422",  # Mixed obsessional thoughts and acts
        "F423",  # Hoarding disorder
        "F424",  # Excoriation (skin-picking) disorder
        "F428",  # Other obsessive-compulsive disorder
        "F429",  # Obsessive-compulsive disorder, unspecified
        "F430",  # Acute stress reaction
        "F4310",  # Post-traumatic stress disorder, unspecified
        "F4311",  # Post-traumatic stress disorder, acute
        "F4312",  # Post-traumatic stress disorder, chronic
        "F4320",  # Adjustment disorder, unspecified
        "F4321",  # Adjustment disorder with depressed mood
        "F4322",  # Adjustment disorder with anxiety
        "F4323",  # Adjustment disorder with mixed anxiety and depressed mood
        "F4324",  # Adjustment disorder with disturbance of conduct
        "F4325",  # Adjustment disorder with mixed disturbance of emotions and conduct
        "F4329",  # Adjustment disorder with other symptoms
        "F4381",  # Prolonged grief disorder
        "F4389",  # Other reactions to severe stress
        "F439",  # Reaction to severe stress, unspecified
        "F440",  # Dissociative amnesia
        "F441",  # Dissociative fugue
        "F442",  # Dissociative stupor
        "F444",  # Conversion disorder with motor symptom or deficit
        "F445",  # Conversion disorder with seizures or convulsions
        "F446",  # Conversion disorder with sensory symptom or deficit
        "F447",  # Conversion disorder with mixed symptom presentation
        "F4481",  # Dissociative identity disorder
        "F4489",  # Other dissociative and conversion disorders
        "F449",  # Dissociative and conversion disorder, unspecified
        "F450",  # Somatization disorder
        "F451",  # Undifferentiated somatoform disorder
        "F4520",  # Hypochondriacal disorder, unspecified
        "F4521",  # Hypochondriasis
        "F4522",  # Body dysmorphic disorder
        "F4529",  # Other hypochondriacal disorders
        "F4541",  # Pain disorder exclusively related to psychological factors
        "F4542",  # Pain disorder with related psychological factors
        "F458",  # Other somatoform disorders
        "F459",  # Somatoform disorder, unspecified
        "F481",  # Depersonalization-derealization syndrome
        "F482",  # Pseudobulbar affect
        "F488",  # Other specified nonpsychotic mental disorders
        "F489",  # Nonpsychotic mental disorder, unspecified
        "F5000",  # Anorexia nervosa, unspecified
        "F50010",  # Anorexia nervosa, restricting type, mild
        "F50011",  # Anorexia nervosa, restricting type, moderate
        "F50012",  # Anorexia nervosa, restricting type, severe
        "F50013",  # Anorexia nervosa, restricting type, extreme
        "F50014",  # Anorexia nervosa, restricting type, in remission
        "F50019",  # Anorexia nervosa, restricting type, unspecified
        "F50020",  # Anorexia nervosa, binge eating/purging type, mild
        "F50021",  # Anorexia nervosa, binge eating/purging type, moderate
        "F50022",  # Anorexia nervosa, binge eating/purging type, severe
        "F50023",  # Anorexia nervosa, binge eating/purging type, extreme
        "F50024",  # Anorexia nervosa, binge eating/purging type, in remission
        "F50029",  # Anorexia nervosa, binge eating/purging type, unspecified
        "F5020",  # Bulimia nervosa, unspecified
        "F5021",  # Bulimia nervosa, mild
        "F5022",  # Bulimia nervosa, moderate
        "F5023",  # Bulimia nervosa, severe
        "F5024",  # Bulimia nervosa, extreme
        "F5025",  # Bulimia nervosa, in remission
        "F50810",  # Binge eating disorder, mild
        "F50811",  # Binge eating disorder, moderate
        "F50812",  # Binge eating disorder, severe
        "F50813",  # Binge eating disorder, extreme
        "F50814",  # Binge eating disorder, in remission
        "F50819",  # Binge eating disorder, unspecified
        "F5082",  # Avoidant/restrictive food intake disorder
        "F5083",  # Pica in adults
        "F5084",  # Rumination disorder in adults
        "F5089",  # Other specified eating disorder
        "F509",  # Eating disorder, unspecified
        "F5101",  # Primary insomnia
        "F5102",  # Adjustment insomnia
        "F5103",  # Paradoxical insomnia
        "F5104",  # Psychophysiologic insomnia
        "F5105",  # Insomnia due to other mental disorder
        "F5109",  # Other insomnia not due to a substance or known physiological condition
        "F5111",  # Primary hypersomnia
        "F5112",  # Insufficient sleep syndrome
        "F5113",  # Hypersomnia due to other mental disorder
        "F5119",  # Other hypersomnia not due to a substance or known physiological condition
        "F513",  # Sleepwalking [somnambulism]
        "F514",  # Sleep terrors [night terrors]
        "F515",  # Nightmare disorder
        "F518",  # Other sleep disorders not due to a substance or known physiological condition
        "F519",  # Sleep disorder not due to a substance or known physiological condition, unspecified
        "F520",  # Hypoactive sexual desire disorder
        "F521",  # Sexual aversion disorder
        "F5221",  # Male erectile disorder
        "F5222",  # Female sexual arousal disorder
        "F5231",  # Female orgasmic disorder
        "F5232",  # Male orgasmic disorder
        "F524",  # Premature ejaculation
        "F525",  # Vaginismus not due to a substance or known physiological condition
        "F526",  # Dyspareunia not due to a substance or known physiological condition
        "F528",  # Other sexual dysfunction not due to a substance or known physiological condition
        "F529",  # Unspecified sexual dysfunction not due to a substance or known physiological condition
        "F530",  # Postpartum depression
        "F531",  # Puerperal psychosis
        "F550",  # Abuse of antacids
        "F551",  # Abuse of herbal or folk remedies
        "F552",  # Abuse of laxatives
        "F553",  # Abuse of steroids or hormones
        "F554",  # Abuse of vitamins
        "F558",  # Abuse of other non-psychoactive substances
        "F59",  # Unspecified behavioral syndromes associated with physiological disturbances and physical factors
        "F600",  # Paranoid personality disorder
        "F601",  # Schizoid personality disorder
        "F602",  # Antisocial personality disorder
        "F603",  # Borderline personality disorder
        "F604",  # Histrionic personality disorder
        "F605",  # Obsessive-compulsive personality disorder
        "F606",  # Avoidant personality disorder
        "F607",  # Dependent personality disorder
        "F6081",  # Narcissistic personality disorder
        "F6089",  # Other specific personality disorders
        "F609",  # Personality disorder, unspecified
        "F630",  # Pathological gambling
        "F631",  # Pyromania
        "F632",  # Kleptomania
        "F633",  # Trichotillomania
        "F6381",  # Intermittent explosive disorder
        "F6389",  # Other impulse disorders
        "F639",  # Impulse disorder, unspecified
        "F640",  # Transsexualism
        "F641",  # Dual role transvestism
        "F642",  # Gender identity disorder of childhood
        "F648",  # Other gender identity disorders
        "F649",  # Gender identity disorder, unspecified
        "F650",  # Fetishism
        "F651",  # Transvestic fetishism
        "F652",  # Exhibitionism
        "F653",  # Voyeurism
        "F654",  # Pedophilia
        "F6550",  # Sadomasochism, unspecified
        "F6551",  # Sexual masochism
        "F6552",  # Sexual sadism
        "F6581",  # Frotteurism
        "F6589",  # Other paraphilias
        "F659",  # Paraphilia, unspecified
        "F66",  # Other sexual disorders
        "F6810",  # Factitious disorder imposed on self, unspecified
        "F6811",  # Factitious disorder imposed on self, with predominantly psychological signs and symptoms
        "F6812",  # Factitious disorder imposed on self, with predominantly physical signs and symptoms
        "F6813",  # Factitious disorder imposed on self, with combined psychological and physical signs and symptoms
        "F688",  # Other specified disorders of adult personality and behavior
        "F68A",  # Factitious disorder imposed on another
        "F69",  # Unspecified disorder of adult personality and behavior
        "F78A1",  # SYNGAP1-related intellectual disability
        "F800",  # Phonological disorder
        "F801",  # Expressive language disorder
        "F802",  # Mixed receptive-expressive language disorder
        "F804",  # Speech and language development delay due to hearing loss
        "F8081",  # Childhood onset fluency disorder
        "F8082",  # Social pragmatic communication disorder
        "F8089",  # Other developmental disorders of speech and language
        "F809",  # Developmental disorder of speech and language, unspecified
        "F810",  # Specific reading disorder
        "F812",  # Mathematics disorder
        "F8181",  # Disorder of written expression
        "F8189",  # Other developmental disorders of scholastic skills
        "F819",  # Developmental disorder of scholastic skills, unspecified
        "F82",  # Specific developmental disorder of motor function
        "F840",  # Autistic disorder
        "F842",  # Rett's syndrome
        "F843",  # Other childhood disintegrative disorder
        "F845",  # Asperger's syndrome
        "F848",  # Other pervasive developmental disorders
        "F849",  # Pervasive developmental disorder, unspecified
        "F88",  # Other disorders of psychological development
        "F89",  # Unspecified disorder of psychological development
        "F900",  # Attention-deficit hyperactivity disorder, predominantly inattentive type
        "F901",  # Attention-deficit hyperactivity disorder, predominantly hyperactive type
        "F902",  # Attention-deficit hyperactivity disorder, combined type
        "F908",  # Attention-deficit hyperactivity disorder, other type
        "F909",  # Attention-deficit hyperactivity disorder, unspecified type
        "F910",  # Conduct disorder confined to family context
        "F911",  # Conduct disorder, childhood-onset type
        "F912",  # Conduct disorder, adolescent-onset type
        "F913",  # Oppositional defiant disorder
        "F918",  # Other conduct disorders
        "F919",  # Conduct disorder, unspecified
        "F930",  # Separation anxiety disorder of childhood
        "F938",  # Other childhood emotional disorders
        "F939",  # Childhood emotional disorder, unspecified
        "F940",  # Selective mutism
        "F941",  # Reactive attachment disorder of childhood
        "F942",  # Disinhibited attachment disorder of childhood
        "F948",  # Other childhood disorders of social functioning
        "F949",  # Childhood disorder of social functioning, unspecified
        "F950",  # Transient tic disorder
        "F951",  # Chronic motor or vocal tic disorder
        "F952",  # Tourette's disorder
        "F958",  # Other tic disorders
        "F959",  # Tic disorder, unspecified
        "F980",  # Enuresis not due to a substance or known physiological condition
        "F981",  # Encopresis not due to a substance or known physiological condition
        "F9821",  # Rumination disorder of infancy and childhood
        "F9829",  # Other feeding disorders of infancy and early childhood
        "F983",  # Pica of infancy and childhood
        "F984",  # Stereotyped movement disorders
        "F985",  # Adult onset fluency disorder
        "F988",  # Other specified behavioral and emotional disorders with onset usually occurring in childhood and adolescence
        "F989",  # Unspecified behavioral and emotional disorders with onset usually occurring in childhood and adolescence
        "F99",  # Mental disorder, not otherwise specified
        "R410",  # Disorientation, unspecified
        "R411",  # Anterograde amnesia
        "R412",  # Retrograde amnesia
        "R413",  # Other amnesia
        "R4185",  # Anosognosia
        "R4189",  # Other symptoms and signs involving cognitive functions and awareness
        "R440",  # Auditory hallucinations
        "R441",  # Visual hallucinations
        "R442",  # Other hallucinations
        "R443",  # Hallucinations, unspecified
        "R448",  # Other symptoms and signs involving general sensations and perceptions
        "R450",  # Nervousness
        "R451",  # Restlessness and agitation
        "R452",  # Unhappiness
        "R453",  # Demoralization and apathy
        "R454",  # Irritability and anger
        "R455",  # Hostility
        "R456",  # Violent behavior
        "R457",  # State of emotional shock and stress, unspecified
        "R4581",  # Low self-esteem
        "R4582",  # Worries
        "R4583",  # Excessive crying of child, adolescent or adult
        "R4584",  # Anhedonia
        "R45850",  # Homicidal ideations
        "R45851",  # Suicidal ideations
        "R4587",  # Impulsiveness
        "R4589",  # Other symptoms and signs involving emotional state
        "R461",  # Bizarre personal appearance
        "R462",  # Strange and inexplicable behavior
        "R463",  # Overactivity
        "R465",  # Suspiciousness and marked evasiveness
        "R466",  # Undue concern and preoccupation with stressful events
        "R467",  # Verbosity and circumstantial detail obscuring reason for contact
        "R4681",  # Obsessive-compulsive behavior
        "R4689",  # Other symptoms and signs involving appearance and behavior
        "T360X2A",  # Poisoning by penicillins, intentional self-harm, initial encounter
        "T360X2D",  # Poisoning by penicillins, intentional self-harm, subsequent encounter
        "T360X2S",  # Poisoning by penicillins, intentional self-harm, sequela
        "T361X2A",  # Poisoning by cephalosporins and other beta-lactam antibiotics, intentional self-harm, initial encounter
        "T361X2D",  # Poisoning by cephalosporins and other beta-lactam antibiotics, intentional self-harm, subsequent encounter
        "T361X2S",  # Poisoning by cephalosporins and other beta-lactam antibiotics, intentional self-harm, sequela
        "T362X2A",  # Poisoning by chloramphenicol group, intentional self-harm, initial encounter
        "T362X2D",  # Poisoning by chloramphenicol group, intentional self-harm, subsequent encounter
        "T362X2S",  # Poisoning by chloramphenicol group, intentional self-harm, sequela
        "T363X2A",  # Poisoning by macrolides, intentional self-harm, initial encounter
        "T363X2D",  # Poisoning by macrolides, intentional self-harm, subsequent encounter
        "T363X2S",  # Poisoning by macrolides, intentional self-harm, sequela
        "T364X2A",  # Poisoning by tetracyclines, intentional self-harm, initial encounter
        "T364X2D",  # Poisoning by tetracyclines, intentional self-harm, subsequent encounter
        "T364X2S",  # Poisoning by tetracyclines, intentional self-harm, sequela
        "T365X2A",  # Poisoning by aminoglycosides, intentional self-harm, initial encounter
        "T365X2D",  # Poisoning by aminoglycosides, intentional self-harm, subsequent encounter
        "T365X2S",  # Poisoning by aminoglycosides, intentional self-harm, sequela
        "T366X2A",  # Poisoning by rifampicins, intentional self-harm, initial encounter
        "T366X2D",  # Poisoning by rifampicins, intentional self-harm, subsequent encounter
        "T366X2S",  # Poisoning by rifampicins, intentional self-harm, sequela
        "T367X2A",  # Poisoning by antifungal antibiotics, systemically used, intentional self-harm, initial encounter
        "T367X2D",  # Poisoning by antifungal antibiotics, systemically used, intentional self-harm, subsequent encounter
        "T367X2S",  # Poisoning by antifungal antibiotics, systemically used, intentional self-harm, sequela
        "T368X2A",  # Poisoning by other systemic antibiotics, intentional self-harm, initial encounter
        "T368X2D",  # Poisoning by other systemic antibiotics, intentional self-harm, subsequent encounter
        "T368X2S",  # Poisoning by other systemic antibiotics, intentional self-harm, sequela
        "T3692XA",  # Poisoning by unspecified systemic antibiotic, intentional self-harm, initial encounter
        "T3692XD",  # Poisoning by unspecified systemic antibiotic, intentional self-harm, subsequent encounter
        "T3692XS",  # Poisoning by unspecified systemic antibiotic, intentional self-harm, sequela
        "T370X2A",  # Poisoning by sulfonamides, intentional self-harm, initial encounter
        "T370X2D",  # Poisoning by sulfonamides, intentional self-harm, subsequent encounter
        "T370X2S",  # Poisoning by sulfonamides, intentional self-harm, sequela
        "T371X2A",  # Poisoning by antimycobacterial drugs, intentional self-harm, initial encounter
        "T371X2D",  # Poisoning by antimycobacterial drugs, intentional self-harm, subsequent encounter
        "T371X2S",  # Poisoning by antimycobacterial drugs, intentional self-harm, sequela
        "T372X2A",  # Poisoning by antimalarials and drugs acting on other blood protozoa, intentional self-harm, initial encounter
        "T372X2D",  # Poisoning by antimalarials and drugs acting on other blood protozoa, intentional self-harm, subsequent encounter
        "T372X2S",  # Poisoning by antimalarials and drugs acting on other blood protozoa, intentional self-harm, sequela
        "T373X2A",  # Poisoning by other antiprotozoal drugs, intentional self-harm, initial encounter
        "T373X2D",  # Poisoning by other antiprotozoal drugs, intentional self-harm, subsequent encounter
        "T373X2S",  # Poisoning by other antiprotozoal drugs, intentional self-harm, sequela
        "T374X2A",  # Poisoning by anthelminthics, intentional self-harm, initial encounter
        "T374X2D",  # Poisoning by anthelminthics, intentional self-harm, subsequent encounter
        "T374X2S",  # Poisoning by anthelminthics, intentional self-harm, sequela
        "T375X2A",  # Poisoning by antiviral drugs, intentional self-harm, initial encounter
        "T375X2D",  # Poisoning by antiviral drugs, intentional self-harm, subsequent encounter
        "T375X2S",  # Poisoning by antiviral drugs, intentional self-harm, sequela
        "T378X2A",  # Poisoning by other specified systemic anti-infectives and antiparasitics, intentional self-harm, initial encounter
        "T378X2D",  # Poisoning by other specified systemic anti-infectives and antiparasitics, intentional self-harm, subsequent encounter
        "T378X2S",  # Poisoning by other specified systemic anti-infectives and antiparasitics, intentional self-harm, sequela
        "T3792XA",  # Poisoning by unspecified systemic anti-infective and antiparasitics, intentional self-harm, initial encounter
        "T3792XD",  # Poisoning by unspecified systemic anti-infective and antiparasitics, intentional self-harm, subsequent encounter
        "T3792XS",  # Poisoning by unspecified systemic anti-infective and antiparasitics, intentional self-harm, sequela
        "T380X2A",  # Poisoning by glucocorticoids and synthetic analogues, intentional self-harm, initial encounter
        "T380X2D",  # Poisoning by glucocorticoids and synthetic analogues, intentional self-harm, subsequent encounter
        "T380X2S",  # Poisoning by glucocorticoids and synthetic analogues, intentional self-harm, sequela
        "T381X2A",  # Poisoning by thyroid hormones and substitutes, intentional self-harm, initial encounter
        "T381X2D",  # Poisoning by thyroid hormones and substitutes, intentional self-harm, subsequent encounter
        "T381X2S",  # Poisoning by thyroid hormones and substitutes, intentional self-harm, sequela
        "T382X2A",  # Poisoning by antithyroid drugs, intentional self-harm, initial encounter
        "T382X2D",  # Poisoning by antithyroid drugs, intentional self-harm, subsequent encounter
        "T382X2S",  # Poisoning by antithyroid drugs, intentional self-harm, sequela
        "T383X2A",  # Poisoning by insulin and oral hypoglycemic [antidiabetic] drugs, intentional self-harm, initial encounter
        "T383X2D",  # Poisoning by insulin and oral hypoglycemic [antidiabetic] drugs, intentional self-harm, subsequent encounter
        "T383X2S",  # Poisoning by insulin and oral hypoglycemic [antidiabetic] drugs, intentional self-harm, sequela
        "T384X2A",  # Poisoning by oral contraceptives, intentional self-harm, initial encounter
        "T384X2D",  # Poisoning by oral contraceptives, intentional self-harm, subsequent encounter
        "T384X2S",  # Poisoning by oral contraceptives, intentional self-harm, sequela
        "T385X2A",  # Poisoning by other estrogens and progestogens, intentional self-harm, initial encounter
        "T385X2D",  # Poisoning by other estrogens and progestogens, intentional self-harm, subsequent encounter
        "T385X2S",  # Poisoning by other estrogens and progestogens, intentional self-harm, sequela
        "T386X2A",  # Poisoning by antigonadotrophins, antiestrogens, antiandrogens, not elsewhere classified, intentional self-harm, initial encounter
        "T386X2D",  # Poisoning by antigonadotrophins, antiestrogens, antiandrogens, not elsewhere classified, intentional self-harm, subsequent encounter
        "T386X2S",  # Poisoning by antigonadotrophins, antiestrogens, antiandrogens, not elsewhere classified, intentional self-harm, sequela
        "T387X2A",  # Poisoning by androgens and anabolic congeners, intentional self-harm, initial encounter
        "T387X2D",  # Poisoning by androgens and anabolic congeners, intentional self-harm, subsequent encounter
        "T387X2S",  # Poisoning by androgens and anabolic congeners, intentional self-harm, sequela
        "T38802A",  # Poisoning by unspecified hormones and synthetic substitutes, intentional self-harm, initial encounter
        "T38802D",  # Poisoning by unspecified hormones and synthetic substitutes, intentional self-harm, subsequent encounter
        "T38802S",  # Poisoning by unspecified hormones and synthetic substitutes, intentional self-harm, sequela
        "T38812A",  # Poisoning by anterior pituitary [adenohypophyseal] hormones, intentional self-harm, initial encounter
        "T38812D",  # Poisoning by anterior pituitary [adenohypophyseal] hormones, intentional self-harm, subsequent encounter
        "T38812S",  # Poisoning by anterior pituitary [adenohypophyseal] hormones, intentional self-harm, sequela
        "T38892A",  # Poisoning by other hormones and synthetic substitutes, intentional self-harm, initial encounter
        "T38892D",  # Poisoning by other hormones and synthetic substitutes, intentional self-harm, subsequent encounter
        "T38892S",  # Poisoning by other hormones and synthetic substitutes, intentional self-harm, sequela
        "T38902A",  # Poisoning by unspecified hormone antagonists, intentional self-harm, initial encounter
        "T38902D",  # Poisoning by unspecified hormone antagonists, intentional self-harm, subsequent encounter
        "T38902S",  # Poisoning by unspecified hormone antagonists, intentional self-harm, sequela
        "T38992A",  # Poisoning by other hormone antagonists, intentional self-harm, initial encounter
        "T38992D",  # Poisoning by other hormone antagonists, intentional self-harm, subsequent encounter
        "T38992S",  # Poisoning by other hormone antagonists, intentional self-harm, sequela
        "T39012A",  # Poisoning by aspirin, intentional self-harm, initial encounter
        "T39012D",  # Poisoning by aspirin, intentional self-harm, subsequent encounter
        "T39012S",  # Poisoning by aspirin, intentional self-harm, sequela
        "T39092A",  # Poisoning by salicylates, intentional self-harm, initial encounter
        "T39092D",  # Poisoning by salicylates, intentional self-harm, subsequent encounter
        "T39092S",  # Poisoning by salicylates, intentional self-harm, sequela
        "T391X2A",  # Poisoning by 4-Aminophenol derivatives, intentional self-harm, initial encounter
        "T391X2D",  # Poisoning by 4-Aminophenol derivatives, intentional self-harm, subsequent encounter
        "T391X2S",  # Poisoning by 4-Aminophenol derivatives, intentional self-harm, sequela
        "T392X2A",  # Poisoning by pyrazolone derivatives, intentional self-harm, initial encounter
        "T392X2D",  # Poisoning by pyrazolone derivatives, intentional self-harm, subsequent encounter
        "T392X2S",  # Poisoning by pyrazolone derivatives, intentional self-harm, sequela
        "T39312A",  # Poisoning by propionic acid derivatives, intentional self-harm, initial encounter
        "T39312D",  # Poisoning by propionic acid derivatives, intentional self-harm, subsequent encounter
        "T39312S",  # Poisoning by propionic acid derivatives, intentional self-harm, sequela
        "T39392A",  # Poisoning by other nonsteroidal anti-inflammatory drugs [NSAID], intentional self-harm, initial encounter
        "T39392D",  # Poisoning by other nonsteroidal anti-inflammatory drugs [NSAID], intentional self-harm, subsequent encounter
        "T39392S",  # Poisoning by other nonsteroidal anti-inflammatory drugs [NSAID], intentional self-harm, sequela
        "T394X2A",  # Poisoning by antirheumatics, not elsewhere classified, intentional self-harm, initial encounter
        "T394X2D",  # Poisoning by antirheumatics, not elsewhere classified, intentional self-harm, subsequent encounter
        "T394X2S",  # Poisoning by antirheumatics, not elsewhere classified, intentional self-harm, sequela
        "T398X2A",  # Poisoning by other nonopioid analgesics and antipyretics, not elsewhere classified, intentional self-harm, initial encounter
        "T398X2D",  # Poisoning by other nonopioid analgesics and antipyretics, not elsewhere classified, intentional self-harm, subsequent encounter
        "T398X2S",  # Poisoning by other nonopioid analgesics and antipyretics, not elsewhere classified, intentional self-harm, sequela
        "T3992XA",  # Poisoning by unspecified nonopioid analgesic, antipyretic and antirheumatic, intentional self-harm, initial encounter
        "T3992XD",  # Poisoning by unspecified nonopioid analgesic, antipyretic and antirheumatic, intentional self-harm, subsequent encounter
        "T3992XS",  # Poisoning by unspecified nonopioid analgesic, antipyretic and antirheumatic, intentional self-harm, sequela
        "T400X2A",  # Poisoning by opium, intentional self-harm, initial encounter
        "T400X2D",  # Poisoning by opium, intentional self-harm, subsequent encounter
        "T400X2S",  # Poisoning by opium, intentional self-harm, sequela
        "T401X2A",  # Poisoning by heroin, intentional self-harm, initial encounter
        "T401X2D",  # Poisoning by heroin, intentional self-harm, subsequent encounter
        "T401X2S",  # Poisoning by heroin, intentional self-harm, sequela
        "T402X2A",  # Poisoning by other opioids, intentional self-harm, initial encounter
        "T402X2D",  # Poisoning by other opioids, intentional self-harm, subsequent encounter
        "T402X2S",  # Poisoning by other opioids, intentional self-harm, sequela
        "T403X2A",  # Poisoning by methadone, intentional self-harm, initial encounter
        "T403X2D",  # Poisoning by methadone, intentional self-harm, subsequent encounter
        "T403X2S",  # Poisoning by methadone, intentional self-harm, sequela
        "T40412A",  # Poisoning by fentanyl or fentanyl analogs, intentional self-harm, initial encounter
        "T40412D",  # Poisoning by fentanyl or fentanyl analogs, intentional self-harm, subsequent encounter
        "T40412S",  # Poisoning by fentanyl or fentanyl analogs, intentional self-harm, sequela
        "T40422A",  # Poisoning by tramadol, intentional self-harm, initial encounter
        "T40422D",  # Poisoning by tramadol, intentional self-harm, subsequent encounter
        "T40422S",  # Poisoning by tramadol, intentional self-harm, sequela
        "T40492A",  # Poisoning by other synthetic narcotics, intentional self-harm, initial encounter
        "T40492D",  # Poisoning by other synthetic narcotics, intentional self-harm, subsequent encounter
        "T40492S",  # Poisoning by other synthetic narcotics, intentional self-harm, sequela
        "T405X2A",  # Poisoning by cocaine, intentional self-harm, initial encounter
        "T405X2D",  # Poisoning by cocaine, intentional self-harm, subsequent encounter
        "T405X2S",  # Poisoning by cocaine, intentional self-harm, sequela
        "T40602A",  # Poisoning by unspecified narcotics, intentional self-harm, initial encounter
        "T40602D",  # Poisoning by unspecified narcotics, intentional self-harm, subsequent encounter
        "T40602S",  # Poisoning by unspecified narcotics, intentional self-harm, sequela
        "T40692A",  # Poisoning by other narcotics, intentional self-harm, initial encounter
        "T40692D",  # Poisoning by other narcotics, intentional self-harm, subsequent encounter
        "T40692S",  # Poisoning by other narcotics, intentional self-harm, sequela
        "T40712A",  # Poisoning by cannabis, intentional self-harm, initial encounter
        "T40712D",  # Poisoning by cannabis, intentional self-harm, subsequent encounter
        "T40712S",  # Poisoning by cannabis, intentional self-harm, sequela
        "T40722A",  # Poisoning by synthetic cannabinoids, intentional self-harm, initial encounter
        "T40722D",  # Poisoning by synthetic cannabinoids, intentional self-harm, subsequent encounter
        "T40722S",  # Poisoning by synthetic cannabinoids, intentional self-harm, sequela
        "T408X2A",  # Poisoning by lysergide [LSD], intentional self-harm, initial encounter
        "T408X2D",  # Poisoning by lysergide [LSD], intentional self-harm, subsequent encounter
        "T408X2S",  # Poisoning by lysergide [LSD], intentional self-harm, sequela
        "T40902A",  # Poisoning by unspecified psychodysleptics [hallucinogens], intentional self-harm, initial encounter
        "T40902D",  # Poisoning by unspecified psychodysleptics [hallucinogens], intentional self-harm, subsequent encounter
        "T40902S",  # Poisoning by unspecified psychodysleptics [hallucinogens], intentional self-harm, sequela
        "T40992A",  # Poisoning by other psychodysleptics [hallucinogens], intentional self-harm, initial encounter
        "T40992D",  # Poisoning by other psychodysleptics [hallucinogens], intentional self-harm, subsequent encounter
        "T40992S",  # Poisoning by other psychodysleptics [hallucinogens], intentional self-harm, sequela
        "T410X2A",  # Poisoning by inhaled anesthetics, intentional self-harm, initial encounter
        "T410X2D",  # Poisoning by inhaled anesthetics, intentional self-harm, subsequent encounter
        "T410X2S",  # Poisoning by inhaled anesthetics, intentional self-harm, sequela
        "T411X2A",  # Poisoning by intravenous anesthetics, intentional self-harm, initial encounter
        "T411X2D",  # Poisoning by intravenous anesthetics, intentional self-harm, subsequent encounter
        "T411X2S",  # Poisoning by intravenous anesthetics, intentional self-harm, sequela
        "T41202A",  # Poisoning by unspecified general anesthetics, intentional self-harm, initial encounter
        "T41202D",  # Poisoning by unspecified general anesthetics, intentional self-harm, subsequent encounter
        "T41202S",  # Poisoning by unspecified general anesthetics, intentional self-harm, sequela
        "T41292A",  # Poisoning by other general anesthetics, intentional self-harm, initial encounter
        "T41292D",  # Poisoning by other general anesthetics, intentional self-harm, subsequent encounter
        "T41292S",  # Poisoning by other general anesthetics, intentional self-harm, sequela
        "T413X2A",  # Poisoning by local anesthetics, intentional self-harm, initial encounter
        "T413X2D",  # Poisoning by local anesthetics, intentional self-harm, subsequent encounter
        "T413X2S",  # Poisoning by local anesthetics, intentional self-harm, sequela
        "T4142XA",  # Poisoning by unspecified anesthetic, intentional self-harm, initial encounter
        "T4142XD",  # Poisoning by unspecified anesthetic, intentional self-harm, subsequent encounter
        "T4142XS",  # Poisoning by unspecified anesthetic, intentional self-harm, sequela
        "T415X2A",  # Poisoning by therapeutic gases, intentional self-harm, initial encounter
        "T415X2D",  # Poisoning by therapeutic gases, intentional self-harm, subsequent encounter
        "T415X2S",  # Poisoning by therapeutic gases, intentional self-harm, sequela
        "T420X2A",  # Poisoning by hydantoin derivatives, intentional self-harm, initial encounter
        "T420X2D",  # Poisoning by hydantoin derivatives, intentional self-harm, subsequent encounter
        "T420X2S",  # Poisoning by hydantoin derivatives, intentional self-harm, sequela
        "T421X2A",  # Poisoning by iminostilbenes, intentional self-harm, initial encounter
        "T421X2D",  # Poisoning by iminostilbenes, intentional self-harm, subsequent encounter
        "T421X2S",  # Poisoning by iminostilbenes, intentional self-harm, sequela
        "T422X2A",  # Poisoning by succinimides and oxazolidinediones, intentional self-harm, initial encounter
        "T422X2D",  # Poisoning by succinimides and oxazolidinediones, intentional self-harm, subsequent encounter
        "T422X2S",  # Poisoning by succinimides and oxazolidinediones, intentional self-harm, sequela
        "T423X2A",  # Poisoning by barbiturates, intentional self-harm, initial encounter
        "T423X2D",  # Poisoning by barbiturates, intentional self-harm, subsequent encounter
        "T423X2S",  # Poisoning by barbiturates, intentional self-harm, sequela
        "T424X2A",  # Poisoning by benzodiazepines, intentional self-harm, initial encounter
        "T424X2D",  # Poisoning by benzodiazepines, intentional self-harm, subsequent encounter
        "T424X2S",  # Poisoning by benzodiazepines, intentional self-harm, sequela
        "T425X2A",  # Poisoning by mixed antiepileptics, intentional self-harm, initial encounter
        "T425X2D",  # Poisoning by mixed antiepileptics, intentional self-harm, subsequent encounter
        "T425X2S",  # Poisoning by mixed antiepileptics, intentional self-harm, sequela
        "T426X2A",  # Poisoning by other antiepileptic and sedative-hypnotic drugs, intentional self-harm, initial encounter
        "T426X2D",  # Poisoning by other antiepileptic and sedative-hypnotic drugs, intentional self-harm, subsequent encounter
        "T426X2S",  # Poisoning by other antiepileptic and sedative-hypnotic drugs, intentional self-harm, sequela
        "T4272XA",  # Poisoning by unspecified antiepileptic and sedative-hypnotic drugs, intentional self-harm, initial encounter
        "T4272XD",  # Poisoning by unspecified antiepileptic and sedative-hypnotic drugs, intentional self-harm, subsequent encounter
        "T4272XS",  # Poisoning by unspecified antiepileptic and sedative-hypnotic drugs, intentional self-harm, sequela
        "T428X2A",  # Poisoning by antiparkinsonism drugs and other central muscle-tone depressants, intentional self-harm, initial encounter
        "T428X2D",  # Poisoning by antiparkinsonism drugs and other central muscle-tone depressants, intentional self-harm, subsequent encounter
        "T428X2S",  # Poisoning by antiparkinsonism drugs and other central muscle-tone depressants, intentional self-harm, sequela
        "T43012A",  # Poisoning by tricyclic antidepressants, intentional self-harm, initial encounter
        "T43012D",  # Poisoning by tricyclic antidepressants, intentional self-harm, subsequent encounter
        "T43012S",  # Poisoning by tricyclic antidepressants, intentional self-harm, sequela
        "T43022A",  # Poisoning by tetracyclic antidepressants, intentional self-harm, initial encounter
        "T43022D",  # Poisoning by tetracyclic antidepressants, intentional self-harm, subsequent encounter
        "T43022S",  # Poisoning by tetracyclic antidepressants, intentional self-harm, sequela
        "T431X2A",  # Poisoning by monoamine-oxidase-inhibitor antidepressants, intentional self-harm, initial encounter
        "T431X2D",  # Poisoning by monoamine-oxidase-inhibitor antidepressants, intentional self-harm, subsequent encounter
        "T431X2S",  # Poisoning by monoamine-oxidase-inhibitor antidepressants, intentional self-harm, sequela
        "T43202A",  # Poisoning by unspecified antidepressants, intentional self-harm, initial encounter
        "T43202D",  # Poisoning by unspecified antidepressants, intentional self-harm, subsequent encounter
        "T43202S",  # Poisoning by unspecified antidepressants, intentional self-harm, sequela
        "T43212A",  # Poisoning by selective serotonin and norepinephrine reuptake inhibitors, intentional self-harm, initial encounter
        "T43212D",  # Poisoning by selective serotonin and norepinephrine reuptake inhibitors, intentional self-harm, subsequent encounter
        "T43212S",  # Poisoning by selective serotonin and norepinephrine reuptake inhibitors, intentional self-harm, sequela
        "T43222A",  # Poisoning by selective serotonin reuptake inhibitors, intentional self-harm, initial encounter
        "T43222D",  # Poisoning by selective serotonin reuptake inhibitors, intentional self-harm, subsequent encounter
        "T43222S",  # Poisoning by selective serotonin reuptake inhibitors, intentional self-harm, sequela
        "T43292A",  # Poisoning by other antidepressants, intentional self-harm, initial encounter
        "T43292D",  # Poisoning by other antidepressants, intentional self-harm, subsequent encounter
        "T43292S",  # Poisoning by other antidepressants, intentional self-harm, sequela
        "T433X2A",  # Poisoning by phenothiazine antipsychotics and neuroleptics, intentional self-harm, initial encounter
        "T433X2D",  # Poisoning by phenothiazine antipsychotics and neuroleptics, intentional self-harm, subsequent encounter
        "T433X2S",  # Poisoning by phenothiazine antipsychotics and neuroleptics, intentional self-harm, sequela
        "T434X2A",  # Poisoning by butyrophenone and thiothixene neuroleptics, intentional self-harm, initial encounter
        "T434X2D",  # Poisoning by butyrophenone and thiothixene neuroleptics, intentional self-harm, subsequent encounter
        "T434X2S",  # Poisoning by butyrophenone and thiothixene neuroleptics, intentional self-harm, sequela
        "T43502A",  # Poisoning by unspecified antipsychotics and neuroleptics, intentional self-harm, initial encounter
        "T43502D",  # Poisoning by unspecified antipsychotics and neuroleptics, intentional self-harm, subsequent encounter
        "T43502S",  # Poisoning by unspecified antipsychotics and neuroleptics, intentional self-harm, sequela
        "T43592A",  # Poisoning by other antipsychotics and neuroleptics, intentional self-harm, initial encounter
        "T43592D",  # Poisoning by other antipsychotics and neuroleptics, intentional self-harm, subsequent encounter
        "T43592S",  # Poisoning by other antipsychotics and neuroleptics, intentional self-harm, sequela
        "T43602A",  # Poisoning by unspecified psychostimulants, intentional self-harm, initial encounter
        "T43602D",  # Poisoning by unspecified psychostimulants, intentional self-harm, subsequent encounter
        "T43602S",  # Poisoning by unspecified psychostimulants, intentional self-harm, sequela
        "T43612A",  # Poisoning by caffeine, intentional self-harm, initial encounter
        "T43612D",  # Poisoning by caffeine, intentional self-harm, subsequent encounter
        "T43612S",  # Poisoning by caffeine, intentional self-harm, sequela
        "T43622A",  # Poisoning by amphetamines, intentional self-harm, initial encounter
        "T43622D",  # Poisoning by amphetamines, intentional self-harm, subsequent encounter
        "T43622S",  # Poisoning by amphetamines, intentional self-harm, sequela
        "T43632A",  # Poisoning by methylphenidate, intentional self-harm, initial encounter
        "T43632D",  # Poisoning by methylphenidate, intentional self-harm, subsequent encounter
        "T43632S",  # Poisoning by methylphenidate, intentional self-harm, sequela
        "T43642A",  # Poisoning by ecstasy, intentional self-harm, initial encounter
        "T43642D",  # Poisoning by ecstasy, intentional self-harm, subsequent encounter
        "T43642S",  # Poisoning by ecstasy, intentional self-harm, sequela
        "T43652A",  # Poisoning by methamphetamines intentional self-harm, initial encounter
        "T43652D",  # Poisoning by methamphetamines intentional self-harm, subsequent encounter
        "T43652S",  # Poisoning by methamphetamines intentional self-harm, sequela
        "T43692A",  # Poisoning by other psychostimulants, intentional self-harm, initial encounter
        "T43692D",  # Poisoning by other psychostimulants, intentional self-harm, subsequent encounter
        "T43692S",  # Poisoning by other psychostimulants, intentional self-harm, sequela
        "T438X2A",  # Poisoning by other psychotropic drugs, intentional self-harm, initial encounter
        "T438X2D",  # Poisoning by other psychotropic drugs, intentional self-harm, subsequent encounter
        "T438X2S",  # Poisoning by other psychotropic drugs, intentional self-harm, sequela
        "T4392XA",  # Poisoning by unspecified psychotropic drug, intentional self-harm, initial encounter
        "T4392XD",  # Poisoning by unspecified psychotropic drug, intentional self-harm, subsequent encounter
        "T4392XS",  # Poisoning by unspecified psychotropic drug, intentional self-harm, sequela
        "T440X2A",  # Poisoning by anticholinesterase agents, intentional self-harm, initial encounter
        "T440X2D",  # Poisoning by anticholinesterase agents, intentional self-harm, subsequent encounter
        "T440X2S",  # Poisoning by anticholinesterase agents, intentional self-harm, sequela
        "T441X2A",  # Poisoning by other parasympathomimetics [cholinergics], intentional self-harm, initial encounter
        "T441X2D",  # Poisoning by other parasympathomimetics [cholinergics], intentional self-harm, subsequent encounter
        "T441X2S",  # Poisoning by other parasympathomimetics [cholinergics], intentional self-harm, sequela
        "T442X2A",  # Poisoning by ganglionic blocking drugs, intentional self-harm, initial encounter
        "T442X2D",  # Poisoning by ganglionic blocking drugs, intentional self-harm, subsequent encounter
        "T442X2S",  # Poisoning by ganglionic blocking drugs, intentional self-harm, sequela
        "T443X2A",  # Poisoning by other parasympatholytics [anticholinergics and antimuscarinics] and spasmolytics, intentional self-harm, initial encounter
        "T443X2D",  # Poisoning by other parasympatholytics [anticholinergics and antimuscarinics] and spasmolytics, intentional self-harm, subsequent encounter
        "T443X2S",  # Poisoning by other parasympatholytics [anticholinergics and antimuscarinics] and spasmolytics, intentional self-harm, sequela
        "T444X2A",  # Poisoning by predominantly alpha-adrenoreceptor agonists, intentional self-harm, initial encounter
        "T444X2D",  # Poisoning by predominantly alpha-adrenoreceptor agonists, intentional self-harm, subsequent encounter
        "T444X2S",  # Poisoning by predominantly alpha-adrenoreceptor agonists, intentional self-harm, sequela
        "T445X2A",  # Poisoning by predominantly beta-adrenoreceptor agonists, intentional self-harm, initial encounter
        "T445X2D",  # Poisoning by predominantly beta-adrenoreceptor agonists, intentional self-harm, subsequent encounter
        "T445X2S",  # Poisoning by predominantly beta-adrenoreceptor agonists, intentional self-harm, sequela
        "T446X2A",  # Poisoning by alpha-adrenoreceptor antagonists, intentional self-harm, initial encounter
        "T446X2D",  # Poisoning by alpha-adrenoreceptor antagonists, intentional self-harm, subsequent encounter
        "T446X2S",  # Poisoning by alpha-adrenoreceptor antagonists, intentional self-harm, sequela
        "T447X2A",  # Poisoning by beta-adrenoreceptor antagonists, intentional self-harm, initial encounter
        "T447X2D",  # Poisoning by beta-adrenoreceptor antagonists, intentional self-harm, subsequent encounter
        "T447X2S",  # Poisoning by beta-adrenoreceptor antagonists, intentional self-harm, sequela
        "T448X2A",  # Poisoning by centrally-acting and adrenergic-neuron-blocking agents, intentional self-harm, initial encounter
        "T448X2D",  # Poisoning by centrally-acting and adrenergic-neuron-blocking agents, intentional self-harm, subsequent encounter
        "T448X2S",  # Poisoning by centrally-acting and adrenergic-neuron-blocking agents, intentional self-harm, sequela
        "T44902A",  # Poisoning by unspecified drugs primarily affecting the autonomic nervous system, intentional self-harm, initial encounter
        "T44902D",  # Poisoning by unspecified drugs primarily affecting the autonomic nervous system, intentional self-harm, subsequent encounter
        "T44902S",  # Poisoning by unspecified drugs primarily affecting the autonomic nervous system, intentional self-harm, sequela
        "T44992A",  # Poisoning by other drug primarily affecting the autonomic nervous system, intentional self-harm, initial encounter
        "T44992D",  # Poisoning by other drug primarily affecting the autonomic nervous system, intentional self-harm, subsequent encounter
        "T44992S",  # Poisoning by other drug primarily affecting the autonomic nervous system, intentional self-harm, sequela
        "T450X2A",  # Poisoning by antiallergic and antiemetic drugs, intentional self-harm, initial encounter
        "T450X2D",  # Poisoning by antiallergic and antiemetic drugs, intentional self-harm, subsequent encounter
        "T450X2S",  # Poisoning by antiallergic and antiemetic drugs, intentional self-harm, sequela
        "T451X2A",  # Poisoning by antineoplastic and immunosuppressive drugs, intentional self-harm, initial encounter
        "T451X2D",  # Poisoning by antineoplastic and immunosuppressive drugs, intentional self-harm, subsequent encounter
        "T451X2S",  # Poisoning by antineoplastic and immunosuppressive drugs, intentional self-harm, sequela
        "T452X2A",  # Poisoning by vitamins, intentional self-harm, initial encounter
        "T452X2D",  # Poisoning by vitamins, intentional self-harm, subsequent encounter
        "T452X2S",  # Poisoning by vitamins, intentional self-harm, sequela
        "T453X2A",  # Poisoning by enzymes, intentional self-harm, initial encounter
        "T453X2D",  # Poisoning by enzymes, intentional self-harm, subsequent encounter
        "T453X2S",  # Poisoning by enzymes, intentional self-harm, sequela
        "T454X2A",  # Poisoning by iron and its compounds, intentional self-harm, initial encounter
        "T454X2D",  # Poisoning by iron and its compounds, intentional self-harm, subsequent encounter
        "T454X2S",  # Poisoning by iron and its compounds, intentional self-harm, sequela
        "T45512A",  # Poisoning by anticoagulants, intentional self-harm, initial encounter
        "T45512D",  # Poisoning by anticoagulants, intentional self-harm, subsequent encounter
        "T45512S",  # Poisoning by anticoagulants, intentional self-harm, sequela
        "T45522A",  # Poisoning by antithrombotic drugs, intentional self-harm, initial encounter
        "T45522D",  # Poisoning by antithrombotic drugs, intentional self-harm, subsequent encounter
        "T45522S",  # Poisoning by antithrombotic drugs, intentional self-harm, sequela
        "T45602A",  # Poisoning by unspecified fibrinolysis-affecting drugs, intentional self-harm, initial encounter
        "T45602D",  # Poisoning by unspecified fibrinolysis-affecting drugs, intentional self-harm, subsequent encounter
        "T45602S",  # Poisoning by unspecified fibrinolysis-affecting drugs, intentional self-harm, sequela
        "T45612A",  # Poisoning by thrombolytic drug, intentional self-harm, initial encounter
        "T45612D",  # Poisoning by thrombolytic drug, intentional self-harm, subsequent encounter
        "T45612S",  # Poisoning by thrombolytic drug, intentional self-harm, sequela
        "T45622A",  # Poisoning by hemostatic drug, intentional self-harm, initial encounter
        "T45622D",  # Poisoning by hemostatic drug, intentional self-harm, subsequent encounter
        "T45622S",  # Poisoning by hemostatic drug, intentional self-harm, sequela
        "T45692A",  # Poisoning by other fibrinolysis-affecting drugs, intentional self-harm, initial encounter
        "T45692D",  # Poisoning by other fibrinolysis-affecting drugs, intentional self-harm, subsequent encounter
        "T45692S",  # Poisoning by other fibrinolysis-affecting drugs, intentional self-harm, sequela
        "T457X2A",  # Poisoning by anticoagulant antagonists, vitamin K and other coagulants, intentional self-harm, initial encounter
        "T457X2D",  # Poisoning by anticoagulant antagonists, vitamin K and other coagulants, intentional self-harm, subsequent encounter
        "T457X2S",  # Poisoning by anticoagulant antagonists, vitamin K and other coagulants, intentional self-harm, sequela
        "T458X2A",  # Poisoning by other primarily systemic and hematological agents, intentional self-harm, initial encounter
        "T458X2D",  # Poisoning by other primarily systemic and hematological agents, intentional self-harm, subsequent encounter
        "T458X2S",  # Poisoning by other primarily systemic and hematological agents, intentional self-harm, sequela
        "T4592XA",  # Poisoning by unspecified primarily systemic and hematological agent, intentional self-harm, initial encounter
        "T4592XD",  # Poisoning by unspecified primarily systemic and hematological agent, intentional self-harm, subsequent encounter
        "T4592XS",  # Poisoning by unspecified primarily systemic and hematological agent, intentional self-harm, sequela
        "T45AX2A",  # Poisoning by immune checkpoint inhibitors and immunostimulant drugs, intentional self-harm, initial encounter
        "T45AX2D",  # Poisoning by immune checkpoint inhibitors and immunostimulant drugs, intentional self-harm, subsequent encounter
        "T45AX2S",  # Poisoning by immune checkpoint inhibitors and immunostimulant drugs, intentional self-harm, sequela
        "T460X2A",  # Poisoning by cardiac-stimulant glycosides and drugs of similar action, intentional self-harm, initial encounter
        "T460X2D",  # Poisoning by cardiac-stimulant glycosides and drugs of similar action, intentional self-harm, subsequent encounter
        "T460X2S",  # Poisoning by cardiac-stimulant glycosides and drugs of similar action, intentional self-harm, sequela
        "T461X2A",  # Poisoning by calcium-channel blockers, intentional self-harm, initial encounter
        "T461X2D",  # Poisoning by calcium-channel blockers, intentional self-harm, subsequent encounter
        "T461X2S",  # Poisoning by calcium-channel blockers, intentional self-harm, sequela
        "T462X2A",  # Poisoning by other antidysrhythmic drugs, intentional self-harm, initial encounter
        "T462X2D",  # Poisoning by other antidysrhythmic drugs, intentional self-harm, subsequent encounter
        "T462X2S",  # Poisoning by other antidysrhythmic drugs, intentional self-harm, sequela
        "T463X2A",  # Poisoning by coronary vasodilators, intentional self-harm, initial encounter
        "T463X2D",  # Poisoning by coronary vasodilators, intentional self-harm, subsequent encounter
        "T463X2S",  # Poisoning by coronary vasodilators, intentional self-harm, sequela
        "T464X2A",  # Poisoning by angiotensin-converting-enzyme inhibitors, intentional self-harm, initial encounter
        "T464X2D",  # Poisoning by angiotensin-converting-enzyme inhibitors, intentional self-harm, subsequent encounter
        "T464X2S",  # Poisoning by angiotensin-converting-enzyme inhibitors, intentional self-harm, sequela
        "T465X2A",  # Poisoning by other antihypertensive drugs, intentional self-harm, initial encounter
        "T465X2D",  # Poisoning by other antihypertensive drugs, intentional self-harm, subsequent encounter
        "T465X2S",  # Poisoning by other antihypertensive drugs, intentional self-harm, sequela
        "T466X2A",  # Poisoning by antihyperlipidemic and antiarteriosclerotic drugs, intentional self-harm, initial encounter
        "T466X2D",  # Poisoning by antihyperlipidemic and antiarteriosclerotic drugs, intentional self-harm, subsequent encounter
        "T466X2S",  # Poisoning by antihyperlipidemic and antiarteriosclerotic drugs, intentional self-harm, sequela
        "T467X2A",  # Poisoning by peripheral vasodilators, intentional self-harm, initial encounter
        "T467X2D",  # Poisoning by peripheral vasodilators, intentional self-harm, subsequent encounter
        "T467X2S",  # Poisoning by peripheral vasodilators, intentional self-harm, sequela
        "T468X2A",  # Poisoning by antivaricose drugs, including sclerosing agents, intentional self-harm, initial encounter
        "T468X2D",  # Poisoning by antivaricose drugs, including sclerosing agents, intentional self-harm, subsequent encounter
        "T468X2S",  # Poisoning by antivaricose drugs, including sclerosing agents, intentional self-harm, sequela
        "T46902A",  # Poisoning by unspecified agents primarily affecting the cardiovascular system, intentional self-harm, initial encounter
        "T46902D",  # Poisoning by unspecified agents primarily affecting the cardiovascular system, intentional self-harm, subsequent encounter
        "T46902S",  # Poisoning by unspecified agents primarily affecting the cardiovascular system, intentional self-harm, sequela
        "T46992A",  # Poisoning by other agents primarily affecting the cardiovascular system, intentional self-harm, initial encounter
        "T46992D",  # Poisoning by other agents primarily affecting the cardiovascular system, intentional self-harm, subsequent encounter
        "T46992S",  # Poisoning by other agents primarily affecting the cardiovascular system, intentional self-harm, sequela
        "T470X2A",  # Poisoning by histamine H2-receptor blockers, intentional self-harm, initial encounter
        "T470X2D",  # Poisoning by histamine H2-receptor blockers, intentional self-harm, subsequent encounter
        "T470X2S",  # Poisoning by histamine H2-receptor blockers, intentional self-harm, sequela
        "T471X2A",  # Poisoning by other antacids and anti-gastric-secretion drugs, intentional self-harm, initial encounter
        "T471X2D",  # Poisoning by other antacids and anti-gastric-secretion drugs, intentional self-harm, subsequent encounter
        "T471X2S",  # Poisoning by other antacids and anti-gastric-secretion drugs, intentional self-harm, sequela
        "T472X2A",  # Poisoning by stimulant laxatives, intentional self-harm, initial encounter
        "T472X2D",  # Poisoning by stimulant laxatives, intentional self-harm, subsequent encounter
        "T472X2S",  # Poisoning by stimulant laxatives, intentional self-harm, sequela
        "T473X2A",  # Poisoning by saline and osmotic laxatives, intentional self-harm, initial encounter
        "T473X2D",  # Poisoning by saline and osmotic laxatives, intentional self-harm, subsequent encounter
        "T473X2S",  # Poisoning by saline and osmotic laxatives, intentional self-harm, sequela
        "T474X2A",  # Poisoning by other laxatives, intentional self-harm, initial encounter
        "T474X2D",  # Poisoning by other laxatives, intentional self-harm, subsequent encounter
        "T474X2S",  # Poisoning by other laxatives, intentional self-harm, sequela
        "T475X2A",  # Poisoning by digestants, intentional self-harm, initial encounter
        "T475X2D",  # Poisoning by digestants, intentional self-harm, subsequent encounter
        "T475X2S",  # Poisoning by digestants, intentional self-harm, sequela
        "T476X2A",  # Poisoning by antidiarrheal drugs, intentional self-harm, initial encounter
        "T476X2D",  # Poisoning by antidiarrheal drugs, intentional self-harm, subsequent encounter
        "T476X2S",  # Poisoning by antidiarrheal drugs, intentional self-harm, sequela
        "T477X2A",  # Poisoning by emetics, intentional self-harm, initial encounter
        "T477X2D",  # Poisoning by emetics, intentional self-harm, subsequent encounter
        "T477X2S",  # Poisoning by emetics, intentional self-harm, sequela
        "T478X2A",  # Poisoning by other agents primarily affecting gastrointestinal system, intentional self-harm, initial encounter
        "T478X2D",  # Poisoning by other agents primarily affecting gastrointestinal system, intentional self-harm, subsequent encounter
        "T478X2S",  # Poisoning by other agents primarily affecting gastrointestinal system, intentional self-harm, sequela
        "T4792XA",  # Poisoning by unspecified agents primarily affecting the gastrointestinal system, intentional self-harm, initial encounter
        "T4792XD",  # Poisoning by unspecified agents primarily affecting the gastrointestinal system, intentional self-harm, subsequent encounter
        "T4792XS",  # Poisoning by unspecified agents primarily affecting the gastrointestinal system, intentional self-harm, sequela
        "T480X2A",  # Poisoning by oxytocic drugs, intentional self-harm, initial encounter
        "T480X2D",  # Poisoning by oxytocic drugs, intentional self-harm, subsequent encounter
        "T480X2S",  # Poisoning by oxytocic drugs, intentional self-harm, sequela
        "T481X2A",  # Poisoning by skeletal muscle relaxants [neuromuscular blocking agents], intentional self-harm, initial encounter
        "T481X2D",  # Poisoning by skeletal muscle relaxants [neuromuscular blocking agents], intentional self-harm, subsequent encounter
        "T481X2S",  # Poisoning by skeletal muscle relaxants [neuromuscular blocking agents], intentional self-harm, sequela
        "T48202A",  # Poisoning by unspecified drugs acting on muscles, intentional self-harm, initial encounter
        "T48202D",  # Poisoning by unspecified drugs acting on muscles, intentional self-harm, subsequent encounter
        "T48202S",  # Poisoning by unspecified drugs acting on muscles, intentional self-harm, sequela
        "T48292A",  # Poisoning by other drugs acting on muscles, intentional self-harm, initial encounter
        "T48292D",  # Poisoning by other drugs acting on muscles, intentional self-harm, subsequent encounter
        "T48292S",  # Poisoning by other drugs acting on muscles, intentional self-harm, sequela
        "T483X2A",  # Poisoning by antitussives, intentional self-harm, initial encounter
        "T483X2D",  # Poisoning by antitussives, intentional self-harm, subsequent encounter
        "T483X2S",  # Poisoning by antitussives, intentional self-harm, sequela
        "T484X2A",  # Poisoning by expectorants, intentional self-harm, initial encounter
        "T484X2D",  # Poisoning by expectorants, intentional self-harm, subsequent encounter
        "T484X2S",  # Poisoning by expectorants, intentional self-harm, sequela
        "T485X2A",  # Poisoning by other anti-common-cold drugs, intentional self-harm, initial encounter
        "T485X2D",  # Poisoning by other anti-common-cold drugs, intentional self-harm, subsequent encounter
        "T485X2S",  # Poisoning by other anti-common-cold drugs, intentional self-harm, sequela
        "T486X2A",  # Poisoning by antiasthmatics, intentional self-harm, initial encounter
        "T486X2D",  # Poisoning by antiasthmatics, intentional self-harm, subsequent encounter
        "T486X2S",  # Poisoning by antiasthmatics, intentional self-harm, sequela
        "T48902A",  # Poisoning by unspecified agents primarily acting on the respiratory system, intentional self-harm, initial encounter
        "T48902D",  # Poisoning by unspecified agents primarily acting on the respiratory system, intentional self-harm, subsequent encounter
        "T48902S",  # Poisoning by unspecified agents primarily acting on the respiratory system, intentional self-harm, sequela
        "T48992A",  # Poisoning by other agents primarily acting on the respiratory system, intentional self-harm, initial encounter
        "T48992D",  # Poisoning by other agents primarily acting on the respiratory system, intentional self-harm, subsequent encounter
        "T48992S",  # Poisoning by other agents primarily acting on the respiratory system, intentional self-harm, sequela
        "T490X2A",  # Poisoning by local antifungal, anti-infective and anti-inflammatory drugs, intentional self-harm, initial encounter
        "T490X2D",  # Poisoning by local antifungal, anti-infective and anti-inflammatory drugs, intentional self-harm, subsequent encounter
        "T490X2S",  # Poisoning by local antifungal, anti-infective and anti-inflammatory drugs, intentional self-harm, sequela
        "T491X2A",  # Poisoning by antipruritics, intentional self-harm, initial encounter
        "T491X2D",  # Poisoning by antipruritics, intentional self-harm, subsequent encounter
        "T491X2S",  # Poisoning by antipruritics, intentional self-harm, sequela
        "T492X2A",  # Poisoning by local astringents and local detergents, intentional self-harm, initial encounter
        "T492X2D",  # Poisoning by local astringents and local detergents, intentional self-harm, subsequent encounter
        "T492X2S",  # Poisoning by local astringents and local detergents, intentional self-harm, sequela
        "T493X2A",  # Poisoning by emollients, demulcents and protectants, intentional self-harm, initial encounter
        "T493X2D",  # Poisoning by emollients, demulcents and protectants, intentional self-harm, subsequent encounter
        "T493X2S",  # Poisoning by emollients, demulcents and protectants, intentional self-harm, sequela
        "T494X2A",  # Poisoning by keratolytics, keratoplastics, and other hair treatment drugs and preparations, intentional self-harm, initial encounter
        "T494X2D",  # Poisoning by keratolytics, keratoplastics, and other hair treatment drugs and preparations, intentional self-harm, subsequent encounter
        "T494X2S",  # Poisoning by keratolytics, keratoplastics, and other hair treatment drugs and preparations, intentional self-harm, sequela
        "T495X2A",  # Poisoning by ophthalmological drugs and preparations, intentional self-harm, initial encounter
        "T495X2D",  # Poisoning by ophthalmological drugs and preparations, intentional self-harm, subsequent encounter
        "T495X2S",  # Poisoning by ophthalmological drugs and preparations, intentional self-harm, sequela
        "T496X2A",  # Poisoning by otorhinolaryngological drugs and preparations, intentional self-harm, initial encounter
        "T496X2D",  # Poisoning by otorhinolaryngological drugs and preparations, intentional self-harm, subsequent encounter
        "T496X2S",  # Poisoning by otorhinolaryngological drugs and preparations, intentional self-harm, sequela
        "T497X2A",  # Poisoning by dental drugs, topically applied, intentional self-harm, initial encounter
        "T497X2D",  # Poisoning by dental drugs, topically applied, intentional self-harm, subsequent encounter
        "T497X2S",  # Poisoning by dental drugs, topically applied, intentional self-harm, sequela
        "T498X2A",  # Poisoning by other topical agents, intentional self-harm, initial encounter
        "T498X2D",  # Poisoning by other topical agents, intentional self-harm, subsequent encounter
        "T498X2S",  # Poisoning by other topical agents, intentional self-harm, sequela
        "T4992XA",  # Poisoning by unspecified topical agent, intentional self-harm, initial encounter
        "T4992XD",  # Poisoning by unspecified topical agent, intentional self-harm, subsequent encounter
        "T4992XS",  # Poisoning by unspecified topical agent, intentional self-harm, sequela
        "T500X2A",  # Poisoning by mineralocorticoids and their antagonists, intentional self-harm, initial encounter
        "T500X2D",  # Poisoning by mineralocorticoids and their antagonists, intentional self-harm, subsequent encounter
        "T500X2S",  # Poisoning by mineralocorticoids and their antagonists, intentional self-harm, sequela
        "T501X2A",  # Poisoning by loop [high-ceiling] diuretics, intentional self-harm, initial encounter
        "T501X2D",  # Poisoning by loop [high-ceiling] diuretics, intentional self-harm, subsequent encounter
        "T501X2S",  # Poisoning by loop [high-ceiling] diuretics, intentional self-harm, sequela
        "T502X2A",  # Poisoning by carbonic-anhydrase inhibitors, benzothiadiazides and other diuretics, intentional self-harm, initial encounter
        "T502X2D",  # Poisoning by carbonic-anhydrase inhibitors, benzothiadiazides and other diuretics, intentional self-harm, subsequent encounter
        "T502X2S",  # Poisoning by carbonic-anhydrase inhibitors, benzothiadiazides and other diuretics, intentional self-harm, sequela
        "T503X2A",  # Poisoning by electrolytic, caloric and water-balance agents, intentional self-harm, initial encounter
        "T503X2D",  # Poisoning by electrolytic, caloric and water-balance agents, intentional self-harm, subsequent encounter
        "T503X2S",  # Poisoning by electrolytic, caloric and water-balance agents, intentional self-harm, sequela
        "T504X2A",  # Poisoning by drugs affecting uric acid metabolism, intentional self-harm, initial encounter
        "T504X2D",  # Poisoning by drugs affecting uric acid metabolism, intentional self-harm, subsequent encounter
        "T504X2S",  # Poisoning by drugs affecting uric acid metabolism, intentional self-harm, sequela
        "T505X2A",  # Poisoning by appetite depressants, intentional self-harm, initial encounter
        "T505X2D",  # Poisoning by appetite depressants, intentional self-harm, subsequent encounter
        "T505X2S",  # Poisoning by appetite depressants, intentional self-harm, sequela
        "T506X2A",  # Poisoning by antidotes and chelating agents, intentional self-harm, initial encounter
        "T506X2D",  # Poisoning by antidotes and chelating agents, intentional self-harm, subsequent encounter
        "T506X2S",  # Poisoning by antidotes and chelating agents, intentional self-harm, sequela
        "T507X2A",  # Poisoning by analeptics and opioid receptor antagonists, intentional self-harm, initial encounter
        "T507X2D",  # Poisoning by analeptics and opioid receptor antagonists, intentional self-harm, subsequent encounter
        "T507X2S",  # Poisoning by analeptics and opioid receptor antagonists, intentional self-harm, sequela
        "T508X2A",  # Poisoning by diagnostic agents, intentional self-harm, initial encounter
        "T508X2D",  # Poisoning by diagnostic agents, intentional self-harm, subsequent encounter
        "T508X2S",  # Poisoning by diagnostic agents, intentional self-harm, sequela
        "T50902A",  # Poisoning by unspecified drugs, medicaments and biological substances, intentional self-harm, initial encounter
        "T50902D",  # Poisoning by unspecified drugs, medicaments and biological substances, intentional self-harm, subsequent encounter
        "T50902S",  # Poisoning by unspecified drugs, medicaments and biological substances, intentional self-harm, sequela
        "T50912A",  # Poisoning by multiple unspecified drugs, medicaments and biological substances, intentional self-harm, initial encounter
        "T50912D",  # Poisoning by multiple unspecified drugs, medicaments and biological substances, intentional self-harm, subsequent encounter
        "T50912S",  # Poisoning by multiple unspecified drugs, medicaments and biological substances, intentional self-harm, sequela
        "T50992A",  # Poisoning by other drugs, medicaments and biological substances, intentional self-harm, initial encounter
        "T50992D",  # Poisoning by other drugs, medicaments and biological substances, intentional self-harm, subsequent encounter
        "T50992S",  # Poisoning by other drugs, medicaments and biological substances, intentional self-harm, sequela
        "T50A12A",  # Poisoning by pertussis vaccine, including combinations with a pertussis component, intentional self-harm, initial encounter
        "T50A12D",  # Poisoning by pertussis vaccine, including combinations with a pertussis component, intentional self-harm, subsequent encounter
        "T50A12S",  # Poisoning by pertussis vaccine, including combinations with a pertussis component, intentional self-harm, sequela
        "T50A22A",  # Poisoning by mixed bacterial vaccines without a pertussis component, intentional self-harm, initial encounter
        "T50A22D",  # Poisoning by mixed bacterial vaccines without a pertussis component, intentional self-harm, subsequent encounter
        "T50A22S",  # Poisoning by mixed bacterial vaccines without a pertussis component, intentional self-harm, sequela
        "T50A92A",  # Poisoning by other bacterial vaccines, intentional self-harm, initial encounter
        "T50A92D",  # Poisoning by other bacterial vaccines, intentional self-harm, subsequent encounter
        "T50A92S",  # Poisoning by other bacterial vaccines, intentional self-harm, sequela
        "T50B12A",  # Poisoning by smallpox vaccines, intentional self-harm, initial encounter
        "T50B12D",  # Poisoning by smallpox vaccines, intentional self-harm, subsequent encounter
        "T50B12S",  # Poisoning by smallpox vaccines, intentional self-harm, sequela
        "T50B92A",  # Poisoning by other viral vaccines, intentional self-harm, initial encounter
        "T50B92D",  # Poisoning by other viral vaccines, intentional self-harm, subsequent encounter
        "T50B92S",  # Poisoning by other viral vaccines, intentional self-harm, sequela
        "T50Z12A",  # Poisoning by immunoglobulin, intentional self-harm, initial encounter
        "T50Z12D",  # Poisoning by immunoglobulin, intentional self-harm, subsequent encounter
        "T50Z12S",  # Poisoning by immunoglobulin, intentional self-harm, sequela
        "T50Z92A",  # Poisoning by other vaccines and biological substances, intentional self-harm, initial encounter
        "T50Z92D",  # Poisoning by other vaccines and biological substances, intentional self-harm, subsequent encounter
        "T50Z92S",  # Poisoning by other vaccines and biological substances, intentional self-harm, sequela
        "T510X2A",  # Toxic effect of ethanol, intentional self-harm, initial encounter
        "T510X2D",  # Toxic effect of ethanol, intentional self-harm, subsequent encounter
        "T510X2S",  # Toxic effect of ethanol, intentional self-harm, sequela
        "T511X2A",  # Toxic effect of methanol, intentional self-harm, initial encounter
        "T511X2D",  # Toxic effect of methanol, intentional self-harm, subsequent encounter
        "T511X2S",  # Toxic effect of methanol, intentional self-harm, sequela
        "T512X2A",  # Toxic effect of 2-Propanol, intentional self-harm, initial encounter
        "T512X2D",  # Toxic effect of 2-Propanol, intentional self-harm, subsequent encounter
        "T512X2S",  # Toxic effect of 2-Propanol, intentional self-harm, sequela
        "T513X2A",  # Toxic effect of fusel oil, intentional self-harm, initial encounter
        "T513X2D",  # Toxic effect of fusel oil, intentional self-harm, subsequent encounter
        "T513X2S",  # Toxic effect of fusel oil, intentional self-harm, sequela
        "T518X2A",  # Toxic effect of other alcohols, intentional self-harm, initial encounter
        "T518X2D",  # Toxic effect of other alcohols, intentional self-harm, subsequent encounter
        "T518X2S",  # Toxic effect of other alcohols, intentional self-harm, sequela
        "T5192XA",  # Toxic effect of unspecified alcohol, intentional self-harm, initial encounter
        "T5192XD",  # Toxic effect of unspecified alcohol, intentional self-harm, subsequent encounter
        "T5192XS",  # Toxic effect of unspecified alcohol, intentional self-harm, sequela
        "T520X2A",  # Toxic effect of petroleum products, intentional self-harm, initial encounter
        "T520X2D",  # Toxic effect of petroleum products, intentional self-harm, subsequent encounter
        "T520X2S",  # Toxic effect of petroleum products, intentional self-harm, sequela
        "T521X2A",  # Toxic effect of benzene, intentional self-harm, initial encounter
        "T521X2D",  # Toxic effect of benzene, intentional self-harm, subsequent encounter
        "T521X2S",  # Toxic effect of benzene, intentional self-harm, sequela
        "T522X2A",  # Toxic effect of homologues of benzene, intentional self-harm, initial encounter
        "T522X2D",  # Toxic effect of homologues of benzene, intentional self-harm, subsequent encounter
        "T522X2S",  # Toxic effect of homologues of benzene, intentional self-harm, sequela
        "T523X2A",  # Toxic effect of glycols, intentional self-harm, initial encounter
        "T523X2D",  # Toxic effect of glycols, intentional self-harm, subsequent encounter
        "T523X2S",  # Toxic effect of glycols, intentional self-harm, sequela
        "T524X2A",  # Toxic effect of ketones, intentional self-harm, initial encounter
        "T524X2D",  # Toxic effect of ketones, intentional self-harm, subsequent encounter
        "T524X2S",  # Toxic effect of ketones, intentional self-harm, sequela
        "T528X2A",  # Toxic effect of other organic solvents, intentional self-harm, initial encounter
        "T528X2D",  # Toxic effect of other organic solvents, intentional self-harm, subsequent encounter
        "T528X2S",  # Toxic effect of other organic solvents, intentional self-harm, sequela
        "T5292XA",  # Toxic effect of unspecified organic solvent, intentional self-harm, initial encounter
        "T5292XD",  # Toxic effect of unspecified organic solvent, intentional self-harm, subsequent encounter
        "T5292XS",  # Toxic effect of unspecified organic solvent, intentional self-harm, sequela
        "T530X2A",  # Toxic effect of carbon tetrachloride, intentional self-harm, initial encounter
        "T530X2D",  # Toxic effect of carbon tetrachloride, intentional self-harm, subsequent encounter
        "T530X2S",  # Toxic effect of carbon tetrachloride, intentional self-harm, sequela
        "T531X2A",  # Toxic effect of chloroform, intentional self-harm, initial encounter
        "T531X2D",  # Toxic effect of chloroform, intentional self-harm, subsequent encounter
        "T531X2S",  # Toxic effect of chloroform, intentional self-harm, sequela
        "T532X2A",  # Toxic effect of trichloroethylene, intentional self-harm, initial encounter
        "T532X2D",  # Toxic effect of trichloroethylene, intentional self-harm, subsequent encounter
        "T532X2S",  # Toxic effect of trichloroethylene, intentional self-harm, sequela
        "T533X2A",  # Toxic effect of tetrachloroethylene, intentional self-harm, initial encounter
        "T533X2D",  # Toxic effect of tetrachloroethylene, intentional self-harm, subsequent encounter
        "T533X2S",  # Toxic effect of tetrachloroethylene, intentional self-harm, sequela
        "T534X2A",  # Toxic effect of dichloromethane, intentional self-harm, initial encounter
        "T534X2D",  # Toxic effect of dichloromethane, intentional self-harm, subsequent encounter
        "T534X2S",  # Toxic effect of dichloromethane, intentional self-harm, sequela
        "T535X2A",  # Toxic effect of chlorofluorocarbons, intentional self-harm, initial encounter
        "T535X2D",  # Toxic effect of chlorofluorocarbons, intentional self-harm, subsequent encounter
        "T535X2S",  # Toxic effect of chlorofluorocarbons, intentional self-harm, sequela
        "T536X2A",  # Toxic effect of other halogen derivatives of aliphatic hydrocarbons, intentional self-harm, initial encounter
        "T536X2D",  # Toxic effect of other halogen derivatives of aliphatic hydrocarbons, intentional self-harm, subsequent encounter
        "T536X2S",  # Toxic effect of other halogen derivatives of aliphatic hydrocarbons, intentional self-harm, sequela
        "T537X2A",  # Toxic effect of other halogen derivatives of aromatic hydrocarbons, intentional self-harm, initial encounter
        "T537X2D",  # Toxic effect of other halogen derivatives of aromatic hydrocarbons, intentional self-harm, subsequent encounter
        "T537X2S",  # Toxic effect of other halogen derivatives of aromatic hydrocarbons, intentional self-harm, sequela
        "T5392XA",  # Toxic effect of unspecified halogen derivatives of aliphatic and aromatic hydrocarbons, intentional self-harm, initial encounter
        "T5392XD",  # Toxic effect of unspecified halogen derivatives of aliphatic and aromatic hydrocarbons, intentional self-harm, subsequent encounter
        "T5392XS",  # Toxic effect of unspecified halogen derivatives of aliphatic and aromatic hydrocarbons, intentional self-harm, sequela
        "T540X2A",  # Toxic effect of phenol and phenol homologues, intentional self-harm, initial encounter
        "T540X2D",  # Toxic effect of phenol and phenol homologues, intentional self-harm, subsequent encounter
        "T540X2S",  # Toxic effect of phenol and phenol homologues, intentional self-harm, sequela
        "T541X2A",  # Toxic effect of other corrosive organic compounds, intentional self-harm, initial encounter
        "T541X2D",  # Toxic effect of other corrosive organic compounds, intentional self-harm, subsequent encounter
        "T541X2S",  # Toxic effect of other corrosive organic compounds, intentional self-harm, sequela
        "T542X2A",  # Toxic effect of corrosive acids and acid-like substances, intentional self-harm, initial encounter
        "T542X2D",  # Toxic effect of corrosive acids and acid-like substances, intentional self-harm, subsequent encounter
        "T542X2S",  # Toxic effect of corrosive acids and acid-like substances, intentional self-harm, sequela
        "T543X2A",  # Toxic effect of corrosive alkalis and alkali-like substances, intentional self-harm, initial encounter
        "T543X2D",  # Toxic effect of corrosive alkalis and alkali-like substances, intentional self-harm, subsequent encounter
        "T543X2S",  # Toxic effect of corrosive alkalis and alkali-like substances, intentional self-harm, sequela
        "T5492XA",  # Toxic effect of unspecified corrosive substance, intentional self-harm, initial encounter
        "T5492XD",  # Toxic effect of unspecified corrosive substance, intentional self-harm, subsequent encounter
        "T5492XS",  # Toxic effect of unspecified corrosive substance, intentional self-harm, sequela
        "T550X2A",  # Toxic effect of soaps, intentional self-harm, initial encounter
        "T550X2D",  # Toxic effect of soaps, intentional self-harm, subsequent encounter
        "T550X2S",  # Toxic effect of soaps, intentional self-harm, sequela
        "T551X2A",  # Toxic effect of detergents, intentional self-harm, initial encounter
        "T551X2D",  # Toxic effect of detergents, intentional self-harm, subsequent encounter
        "T551X2S",  # Toxic effect of detergents, intentional self-harm, sequela
        "T560X2A",  # Toxic effect of lead and its compounds, intentional self-harm, initial encounter
        "T560X2D",  # Toxic effect of lead and its compounds, intentional self-harm, subsequent encounter
        "T560X2S",  # Toxic effect of lead and its compounds, intentional self-harm, sequela
        "T561X2A",  # Toxic effect of mercury and its compounds, intentional self-harm, initial encounter
        "T561X2D",  # Toxic effect of mercury and its compounds, intentional self-harm, subsequent encounter
        "T561X2S",  # Toxic effect of mercury and its compounds, intentional self-harm, sequela
        "T562X2A",  # Toxic effect of chromium and its compounds, intentional self-harm, initial encounter
        "T562X2D",  # Toxic effect of chromium and its compounds, intentional self-harm, subsequent encounter
        "T562X2S",  # Toxic effect of chromium and its compounds, intentional self-harm, sequela
        "T563X2A",  # Toxic effect of cadmium and its compounds, intentional self-harm, initial encounter
        "T563X2D",  # Toxic effect of cadmium and its compounds, intentional self-harm, subsequent encounter
        "T563X2S",  # Toxic effect of cadmium and its compounds, intentional self-harm, sequela
        "T564X2A",  # Toxic effect of copper and its compounds, intentional self-harm, initial encounter
        "T564X2D",  # Toxic effect of copper and its compounds, intentional self-harm, subsequent encounter
        "T564X2S",  # Toxic effect of copper and its compounds, intentional self-harm, sequela
        "T565X2A",  # Toxic effect of zinc and its compounds, intentional self-harm, initial encounter
        "T565X2D",  # Toxic effect of zinc and its compounds, intentional self-harm, subsequent encounter
        "T565X2S",  # Toxic effect of zinc and its compounds, intentional self-harm, sequela
        "T566X2A",  # Toxic effect of tin and its compounds, intentional self-harm, initial encounter
        "T566X2D",  # Toxic effect of tin and its compounds, intentional self-harm, subsequent encounter
        "T566X2S",  # Toxic effect of tin and its compounds, intentional self-harm, sequela
        "T567X2A",  # Toxic effect of beryllium and its compounds, intentional self-harm, initial encounter
        "T567X2D",  # Toxic effect of beryllium and its compounds, intentional self-harm, subsequent encounter
        "T567X2S",  # Toxic effect of beryllium and its compounds, intentional self-harm, sequela
        "T56812A",  # Toxic effect of thallium, intentional self-harm, initial encounter
        "T56812D",  # Toxic effect of thallium, intentional self-harm, subsequent encounter
        "T56812S",  # Toxic effect of thallium, intentional self-harm, sequela
        "T56822A",  # Toxic effect of gadolinium, intentional self-harm, initial encounter
        "T56822D",  # Toxic effect of gadolinium, intentional self-harm, subsequent encounter
        "T56822S",  # Toxic effect of gadolinium, intentional self-harm, sequela
        "T56892A",  # Toxic effect of other metals, intentional self-harm, initial encounter
        "T56892D",  # Toxic effect of other metals, intentional self-harm, subsequent encounter
        "T56892S",  # Toxic effect of other metals, intentional self-harm, sequela
        "T5692XA",  # Toxic effect of unspecified metal, intentional self-harm, initial encounter
        "T5692XD",  # Toxic effect of unspecified metal, intentional self-harm, subsequent encounter
        "T5692XS",  # Toxic effect of unspecified metal, intentional self-harm, sequela
        "T570X2A",  # Toxic effect of arsenic and its compounds, intentional self-harm, initial encounter
        "T570X2D",  # Toxic effect of arsenic and its compounds, intentional self-harm, subsequent encounter
        "T570X2S",  # Toxic effect of arsenic and its compounds, intentional self-harm, sequela
        "T571X2A",  # Toxic effect of phosphorus and its compounds, intentional self-harm, initial encounter
        "T571X2D",  # Toxic effect of phosphorus and its compounds, intentional self-harm, subsequent encounter
        "T571X2S",  # Toxic effect of phosphorus and its compounds, intentional self-harm, sequela
        "T572X2A",  # Toxic effect of manganese and its compounds, intentional self-harm, initial encounter
        "T572X2D",  # Toxic effect of manganese and its compounds, intentional self-harm, subsequent encounter
        "T572X2S",  # Toxic effect of manganese and its compounds, intentional self-harm, sequela
        "T573X2A",  # Toxic effect of hydrogen cyanide, intentional self-harm, initial encounter
        "T573X2D",  # Toxic effect of hydrogen cyanide, intentional self-harm, subsequent encounter
        "T573X2S",  # Toxic effect of hydrogen cyanide, intentional self-harm, sequela
        "T578X2A",  # Toxic effect of other specified inorganic substances, intentional self-harm, initial encounter
        "T578X2D",  # Toxic effect of other specified inorganic substances, intentional self-harm, subsequent encounter
        "T578X2S",  # Toxic effect of other specified inorganic substances, intentional self-harm, sequela
        "T5792XA",  # Toxic effect of unspecified inorganic substance, intentional self-harm, initial encounter
        "T5792XD",  # Toxic effect of unspecified inorganic substance, intentional self-harm, subsequent encounter
        "T5792XS",  # Toxic effect of unspecified inorganic substance, intentional self-harm, sequela
        "T5802XA",  # Toxic effect of carbon monoxide from motor vehicle exhaust, intentional self-harm, initial encounter
        "T5802XD",  # Toxic effect of carbon monoxide from motor vehicle exhaust, intentional self-harm, subsequent encounter
        "T5802XS",  # Toxic effect of carbon monoxide from motor vehicle exhaust, intentional self-harm, sequela
        "T5812XA",  # Toxic effect of carbon monoxide from utility gas, intentional self-harm, initial encounter
        "T5812XD",  # Toxic effect of carbon monoxide from utility gas, intentional self-harm, subsequent encounter
        "T5812XS",  # Toxic effect of carbon monoxide from utility gas, intentional self-harm, sequela
        "T582X2A",  # Toxic effect of carbon monoxide from incomplete combustion of other domestic fuels, intentional self-harm, initial encounter
        "T582X2D",  # Toxic effect of carbon monoxide from incomplete combustion of other domestic fuels, intentional self-harm, subsequent encounter
        "T582X2S",  # Toxic effect of carbon monoxide from incomplete combustion of other domestic fuels, intentional self-harm, sequela
        "T588X2A",  # Toxic effect of carbon monoxide from other source, intentional self-harm, initial encounter
        "T588X2D",  # Toxic effect of carbon monoxide from other source, intentional self-harm, subsequent encounter
        "T588X2S",  # Toxic effect of carbon monoxide from other source, intentional self-harm, sequela
        "T5892XA",  # Toxic effect of carbon monoxide from unspecified source, intentional self-harm, initial encounter
        "T5892XD",  # Toxic effect of carbon monoxide from unspecified source, intentional self-harm, subsequent encounter
        "T5892XS",  # Toxic effect of carbon monoxide from unspecified source, intentional self-harm, sequela
        "T590X2A",  # Toxic effect of nitrogen oxides, intentional self-harm, initial encounter
        "T590X2D",  # Toxic effect of nitrogen oxides, intentional self-harm, subsequent encounter
        "T590X2S",  # Toxic effect of nitrogen oxides, intentional self-harm, sequela
        "T591X2A",  # Toxic effect of sulfur dioxide, intentional self-harm, initial encounter
        "T591X2D",  # Toxic effect of sulfur dioxide, intentional self-harm, subsequent encounter
        "T591X2S",  # Toxic effect of sulfur dioxide, intentional self-harm, sequela
        "T592X2A",  # Toxic effect of formaldehyde, intentional self-harm, initial encounter
        "T592X2D",  # Toxic effect of formaldehyde, intentional self-harm, subsequent encounter
        "T592X2S",  # Toxic effect of formaldehyde, intentional self-harm, sequela
        "T593X2A",  # Toxic effect of lacrimogenic gas, intentional self-harm, initial encounter
        "T593X2D",  # Toxic effect of lacrimogenic gas, intentional self-harm, subsequent encounter
        "T593X2S",  # Toxic effect of lacrimogenic gas, intentional self-harm, sequela
        "T594X2A",  # Toxic effect of chlorine gas, intentional self-harm, initial encounter
        "T594X2D",  # Toxic effect of chlorine gas, intentional self-harm, subsequent encounter
        "T594X2S",  # Toxic effect of chlorine gas, intentional self-harm, sequela
        "T595X2A",  # Toxic effect of fluorine gas and hydrogen fluoride, intentional self-harm, initial encounter
        "T595X2D",  # Toxic effect of fluorine gas and hydrogen fluoride, intentional self-harm, subsequent encounter
        "T595X2S",  # Toxic effect of fluorine gas and hydrogen fluoride, intentional self-harm, sequela
        "T596X2A",  # Toxic effect of hydrogen sulfide, intentional self-harm, initial encounter
        "T596X2D",  # Toxic effect of hydrogen sulfide, intentional self-harm, subsequent encounter
        "T596X2S",  # Toxic effect of hydrogen sulfide, intentional self-harm, sequela
        "T597X2A",  # Toxic effect of carbon dioxide, intentional self-harm, initial encounter
        "T597X2D",  # Toxic effect of carbon dioxide, intentional self-harm, subsequent encounter
        "T597X2S",  # Toxic effect of carbon dioxide, intentional self-harm, sequela
        "T59812A",  # Toxic effect of smoke, intentional self-harm, initial encounter
        "T59812D",  # Toxic effect of smoke, intentional self-harm, subsequent encounter
        "T59812S",  # Toxic effect of smoke, intentional self-harm, sequela
        "T59892A",  # Toxic effect of other specified gases, fumes and vapors, intentional self-harm, initial encounter
        "T59892D",  # Toxic effect of other specified gases, fumes and vapors, intentional self-harm, subsequent encounter
        "T59892S",  # Toxic effect of other specified gases, fumes and vapors, intentional self-harm, sequela
        "T5992XA",  # Toxic effect of unspecified gases, fumes and vapors, intentional self-harm, initial encounter
        "T5992XD",  # Toxic effect of unspecified gases, fumes and vapors, intentional self-harm, subsequent encounter
        "T5992XS",  # Toxic effect of unspecified gases, fumes and vapors, intentional self-harm, sequela
        "T600X2A",  # Toxic effect of organophosphate and carbamate insecticides, intentional self-harm, initial encounter
        "T600X2D",  # Toxic effect of organophosphate and carbamate insecticides, intentional self-harm, subsequent encounter
        "T600X2S",  # Toxic effect of organophosphate and carbamate insecticides, intentional self-harm, sequela
        "T601X2A",  # Toxic effect of halogenated insecticides, intentional self-harm, initial encounter
        "T601X2D",  # Toxic effect of halogenated insecticides, intentional self-harm, subsequent encounter
        "T601X2S",  # Toxic effect of halogenated insecticides, intentional self-harm, sequela
        "T602X2A",  # Toxic effect of other insecticides, intentional self-harm, initial encounter
        "T602X2D",  # Toxic effect of other insecticides, intentional self-harm, subsequent encounter
        "T602X2S",  # Toxic effect of other insecticides, intentional self-harm, sequela
        "T603X2A",  # Toxic effect of herbicides and fungicides, intentional self-harm, initial encounter
        "T603X2D",  # Toxic effect of herbicides and fungicides, intentional self-harm, subsequent encounter
        "T603X2S",  # Toxic effect of herbicides and fungicides, intentional self-harm, sequela
        "T604X2A",  # Toxic effect of rodenticides, intentional self-harm, initial encounter
        "T604X2D",  # Toxic effect of rodenticides, intentional self-harm, subsequent encounter
        "T604X2S",  # Toxic effect of rodenticides, intentional self-harm, sequela
        "T608X2A",  # Toxic effect of other pesticides, intentional self-harm, initial encounter
        "T608X2D",  # Toxic effect of other pesticides, intentional self-harm, subsequent encounter
        "T608X2S",  # Toxic effect of other pesticides, intentional self-harm, sequela
        "T6092XA",  # Toxic effect of unspecified pesticide, intentional self-harm, initial encounter
        "T6092XD",  # Toxic effect of unspecified pesticide, intentional self-harm, subsequent encounter
        "T6092XS",  # Toxic effect of unspecified pesticide, intentional self-harm, sequela
        "T6102XA",  # Ciguatera fish poisoning, intentional self-harm, initial encounter
        "T6102XD",  # Ciguatera fish poisoning, intentional self-harm, subsequent encounter
        "T6102XS",  # Ciguatera fish poisoning, intentional self-harm, sequela
        "T6112XA",  # Scombroid fish poisoning, intentional self-harm, initial encounter
        "T6112XD",  # Scombroid fish poisoning, intentional self-harm, subsequent encounter
        "T6112XS",  # Scombroid fish poisoning, intentional self-harm, sequela
        "T61772A",  # Other fish poisoning, intentional self-harm, initial encounter
        "T61772D",  # Other fish poisoning, intentional self-harm, subsequent encounter
        "T61772S",  # Other fish poisoning, intentional self-harm, sequela
        "T61782A",  # Other shellfish poisoning, intentional self-harm, initial encounter
        "T61782D",  # Other shellfish poisoning, intentional self-harm, subsequent encounter
        "T61782S",  # Other shellfish poisoning, intentional self-harm, sequela
        "T618X2A",  # Toxic effect of other seafood, intentional self-harm, initial encounter
        "T618X2D",  # Toxic effect of other seafood, intentional self-harm, subsequent encounter
        "T618X2S",  # Toxic effect of other seafood, intentional self-harm, sequela
        "T6192XA",  # Toxic effect of unspecified seafood, intentional self-harm, initial encounter
        "T6192XD",  # Toxic effect of unspecified seafood, intentional self-harm, subsequent encounter
        "T6192XS",  # Toxic effect of unspecified seafood, intentional self-harm, sequela
        "T620X2A",  # Toxic effect of ingested mushrooms, intentional self-harm, initial encounter
        "T620X2D",  # Toxic effect of ingested mushrooms, intentional self-harm, subsequent encounter
        "T620X2S",  # Toxic effect of ingested mushrooms, intentional self-harm, sequela
        "T621X2A",  # Toxic effect of ingested berries, intentional self-harm, initial encounter
        "T621X2D",  # Toxic effect of ingested berries, intentional self-harm, subsequent encounter
        "T621X2S",  # Toxic effect of ingested berries, intentional self-harm, sequela
        "T622X2A",  # Toxic effect of other ingested (parts of) plant(s), intentional self-harm, initial encounter
        "T622X2D",  # Toxic effect of other ingested (parts of) plant(s), intentional self-harm, subsequent encounter
        "T622X2S",  # Toxic effect of other ingested (parts of) plant(s), intentional self-harm, sequela
        "T628X2A",  # Toxic effect of other specified noxious substances eaten as food, intentional self-harm, initial encounter
        "T628X2D",  # Toxic effect of other specified noxious substances eaten as food, intentional self-harm, subsequent encounter
        "T628X2S",  # Toxic effect of other specified noxious substances eaten as food, intentional self-harm, sequela
        "T6292XA",  # Toxic effect of unspecified noxious substance eaten as food, intentional self-harm, initial encounter
        "T6292XD",  # Toxic effect of unspecified noxious substance eaten as food, intentional self-harm, subsequent encounter
        "T6292XS",  # Toxic effect of unspecified noxious substance eaten as food, intentional self-harm, sequela
        "T63002A",  # Toxic effect of unspecified snake venom, intentional self-harm, initial encounter
        "T63002D",  # Toxic effect of unspecified snake venom, intentional self-harm, subsequent encounter
        "T63002S",  # Toxic effect of unspecified snake venom, intentional self-harm, sequela
        "T63012A",  # Toxic effect of rattlesnake venom, intentional self-harm, initial encounter
        "T63012D",  # Toxic effect of rattlesnake venom, intentional self-harm, subsequent encounter
        "T63012S",  # Toxic effect of rattlesnake venom, intentional self-harm, sequela
        "T63022A",  # Toxic effect of coral snake venom, intentional self-harm, initial encounter
        "T63022D",  # Toxic effect of coral snake venom, intentional self-harm, subsequent encounter
        "T63022S",  # Toxic effect of coral snake venom, intentional self-harm, sequela
        "T63032A",  # Toxic effect of taipan venom, intentional self-harm, initial encounter
        "T63032D",  # Toxic effect of taipan venom, intentional self-harm, subsequent encounter
        "T63032S",  # Toxic effect of taipan venom, intentional self-harm, sequela
        "T63042A",  # Toxic effect of cobra venom, intentional self-harm, initial encounter
        "T63042D",  # Toxic effect of cobra venom, intentional self-harm, subsequent encounter
        "T63042S",  # Toxic effect of cobra venom, intentional self-harm, sequela
        "T63062A",  # Toxic effect of venom of other North and South American snake, intentional self-harm, initial encounter
        "T63062D",  # Toxic effect of venom of other North and South American snake, intentional self-harm, subsequent encounter
        "T63062S",  # Toxic effect of venom of other North and South American snake, intentional self-harm, sequela
        "T63072A",  # Toxic effect of venom of other Australian snake, intentional self-harm, initial encounter
        "T63072D",  # Toxic effect of venom of other Australian snake, intentional self-harm, subsequent encounter
        "T63072S",  # Toxic effect of venom of other Australian snake, intentional self-harm, sequela
        "T63082A",  # Toxic effect of venom of other African and Asian snake, intentional self-harm, initial encounter
        "T63082D",  # Toxic effect of venom of other African and Asian snake, intentional self-harm, subsequent encounter
        "T63082S",  # Toxic effect of venom of other African and Asian snake, intentional self-harm, sequela
        "T63092A",  # Toxic effect of venom of other snake, intentional self-harm, initial encounter
        "T63092D",  # Toxic effect of venom of other snake, intentional self-harm, subsequent encounter
        "T63092S",  # Toxic effect of venom of other snake, intentional self-harm, sequela
        "T63112A",  # Toxic effect of venom of gila monster, intentional self-harm, initial encounter
        "T63112D",  # Toxic effect of venom of gila monster, intentional self-harm, subsequent encounter
        "T63112S",  # Toxic effect of venom of gila monster, intentional self-harm, sequela
        "T63122A",  # Toxic effect of venom of other venomous lizard, intentional self-harm, initial encounter
        "T63122D",  # Toxic effect of venom of other venomous lizard, intentional self-harm, subsequent encounter
        "T63122S",  # Toxic effect of venom of other venomous lizard, intentional self-harm, sequela
        "T63192A",  # Toxic effect of venom of other reptiles, intentional self-harm, initial encounter
        "T63192D",  # Toxic effect of venom of other reptiles, intentional self-harm, subsequent encounter
        "T63192S",  # Toxic effect of venom of other reptiles, intentional self-harm, sequela
        "T632X2A",  # Toxic effect of venom of scorpion, intentional self-harm, initial encounter
        "T632X2D",  # Toxic effect of venom of scorpion, intentional self-harm, subsequent encounter
        "T632X2S",  # Toxic effect of venom of scorpion, intentional self-harm, sequela
        "T63302A",  # Toxic effect of unspecified spider venom, intentional self-harm, initial encounter
        "T63302D",  # Toxic effect of unspecified spider venom, intentional self-harm, subsequent encounter
        "T63302S",  # Toxic effect of unspecified spider venom, intentional self-harm, sequela
        "T63312A",  # Toxic effect of venom of black widow spider, intentional self-harm, initial encounter
        "T63312D",  # Toxic effect of venom of black widow spider, intentional self-harm, subsequent encounter
        "T63312S",  # Toxic effect of venom of black widow spider, intentional self-harm, sequela
        "T63322A",  # Toxic effect of venom of tarantula, intentional self-harm, initial encounter
        "T63322D",  # Toxic effect of venom of tarantula, intentional self-harm, subsequent encounter
        "T63322S",  # Toxic effect of venom of tarantula, intentional self-harm, sequela
        "T63332A",  # Toxic effect of venom of brown recluse spider, intentional self-harm, initial encounter
        "T63332D",  # Toxic effect of venom of brown recluse spider, intentional self-harm, subsequent encounter
        "T63332S",  # Toxic effect of venom of brown recluse spider, intentional self-harm, sequela
        "T63392A",  # Toxic effect of venom of other spider, intentional self-harm, initial encounter
        "T63392D",  # Toxic effect of venom of other spider, intentional self-harm, subsequent encounter
        "T63392S",  # Toxic effect of venom of other spider, intentional self-harm, sequela
        "T63412A",  # Toxic effect of venom of centipedes and venomous millipedes, intentional self-harm, initial encounter
        "T63412D",  # Toxic effect of venom of centipedes and venomous millipedes, intentional self-harm, subsequent encounter
        "T63412S",  # Toxic effect of venom of centipedes and venomous millipedes, intentional self-harm, sequela
        "T63422A",  # Toxic effect of venom of ants, intentional self-harm, initial encounter
        "T63422D",  # Toxic effect of venom of ants, intentional self-harm, subsequent encounter
        "T63422S",  # Toxic effect of venom of ants, intentional self-harm, sequela
        "T63432A",  # Toxic effect of venom of caterpillars, intentional self-harm, initial encounter
        "T63432D",  # Toxic effect of venom of caterpillars, intentional self-harm, subsequent encounter
        "T63432S",  # Toxic effect of venom of caterpillars, intentional self-harm, sequela
        "T63442A",  # Toxic effect of venom of bees, intentional self-harm, initial encounter
        "T63442D",  # Toxic effect of venom of bees, intentional self-harm, subsequent encounter
        "T63442S",  # Toxic effect of venom of bees, intentional self-harm, sequela
        "T63452A",  # Toxic effect of venom of hornets, intentional self-harm, initial encounter
        "T63452D",  # Toxic effect of venom of hornets, intentional self-harm, subsequent encounter
        "T63452S",  # Toxic effect of venom of hornets, intentional self-harm, sequela
        "T63462A",  # Toxic effect of venom of wasps, intentional self-harm, initial encounter
        "T63462D",  # Toxic effect of venom of wasps, intentional self-harm, subsequent encounter
        "T63462S",  # Toxic effect of venom of wasps, intentional self-harm, sequela
        "T63482A",  # Toxic effect of venom of other arthropod, intentional self-harm, initial encounter
        "T63482D",  # Toxic effect of venom of other arthropod, intentional self-harm, subsequent encounter
        "T63482S",  # Toxic effect of venom of other arthropod, intentional self-harm, sequela
        "T63512A",  # Toxic effect of contact with stingray, intentional self-harm, initial encounter
        "T63512D",  # Toxic effect of contact with stingray, intentional self-harm, subsequent encounter
        "T63512S",  # Toxic effect of contact with stingray, intentional self-harm, sequela
        "T63592A",  # Toxic effect of contact with other venomous fish, intentional self-harm, initial encounter
        "T63592D",  # Toxic effect of contact with other venomous fish, intentional self-harm, subsequent encounter
        "T63592S",  # Toxic effect of contact with other venomous fish, intentional self-harm, sequela
        "T63612A",  # Toxic effect of contact with Portuguese Man-o-war, intentional self-harm, initial encounter
        "T63612D",  # Toxic effect of contact with Portuguese Man-o-war, intentional self-harm, subsequent encounter
        "T63612S",  # Toxic effect of contact with Portuguese Man-o-war, intentional self-harm, sequela
        "T63622A",  # Toxic effect of contact with other jellyfish, intentional self-harm, initial encounter
        "T63622D",  # Toxic effect of contact with other jellyfish, intentional self-harm, subsequent encounter
        "T63622S",  # Toxic effect of contact with other jellyfish, intentional self-harm, sequela
        "T63632A",  # Toxic effect of contact with sea anemone, intentional self-harm, initial encounter
        "T63632D",  # Toxic effect of contact with sea anemone, intentional self-harm, subsequent encounter
        "T63632S",  # Toxic effect of contact with sea anemone, intentional self-harm, sequela
        "T63692A",  # Toxic effect of contact with other venomous marine animals, intentional self-harm, initial encounter
        "T63692D",  # Toxic effect of contact with other venomous marine animals, intentional self-harm, subsequent encounter
        "T63692S",  # Toxic effect of contact with other venomous marine animals, intentional self-harm, sequela
        "T63712A",  # Toxic effect of contact with venomous marine plant, intentional self-harm, initial encounter
        "T63712D",  # Toxic effect of contact with venomous marine plant, intentional self-harm, subsequent encounter
        "T63712S",  # Toxic effect of contact with venomous marine plant, intentional self-harm, sequela
        "T63792A",  # Toxic effect of contact with other venomous plant, intentional self-harm, initial encounter
        "T63792D",  # Toxic effect of contact with other venomous plant, intentional self-harm, subsequent encounter
        "T63792S",  # Toxic effect of contact with other venomous plant, intentional self-harm, sequela
        "T63812A",  # Toxic effect of contact with venomous frog, intentional self-harm, initial encounter
        "T63812D",  # Toxic effect of contact with venomous frog, intentional self-harm, subsequent encounter
        "T63812S",  # Toxic effect of contact with venomous frog, intentional self-harm, sequela
        "T63822A",  # Toxic effect of contact with venomous toad, intentional self-harm, initial encounter
        "T63822D",  # Toxic effect of contact with venomous toad, intentional self-harm, subsequent encounter
        "T63822S",  # Toxic effect of contact with venomous toad, intentional self-harm, sequela
        "T63832A",  # Toxic effect of contact with other venomous amphibian, intentional self-harm, initial encounter
        "T63832D",  # Toxic effect of contact with other venomous amphibian, intentional self-harm, subsequent encounter
        "T63832S",  # Toxic effect of contact with other venomous amphibian, intentional self-harm, sequela
        "T63892A",  # Toxic effect of contact with other venomous animals, intentional self-harm, initial encounter
        "T63892D",  # Toxic effect of contact with other venomous animals, intentional self-harm, subsequent encounter
        "T63892S",  # Toxic effect of contact with other venomous animals, intentional self-harm, sequela
        "T6392XA",  # Toxic effect of contact with unspecified venomous animal, intentional self-harm, initial encounter
        "T6392XD",  # Toxic effect of contact with unspecified venomous animal, intentional self-harm, subsequent encounter
        "T6392XS",  # Toxic effect of contact with unspecified venomous animal, intentional self-harm, sequela
        "T6402XA",  # Toxic effect of aflatoxin, intentional self-harm, initial encounter
        "T6402XD",  # Toxic effect of aflatoxin, intentional self-harm, subsequent encounter
        "T6402XS",  # Toxic effect of aflatoxin, intentional self-harm, sequela
        "T6482XA",  # Toxic effect of other mycotoxin food contaminants, intentional self-harm, initial encounter
        "T6482XD",  # Toxic effect of other mycotoxin food contaminants, intentional self-harm, subsequent encounter
        "T6482XS",  # Toxic effect of other mycotoxin food contaminants, intentional self-harm, sequela
        "T650X2A",  # Toxic effect of cyanides, intentional self-harm, initial encounter
        "T650X2D",  # Toxic effect of cyanides, intentional self-harm, subsequent encounter
        "T650X2S",  # Toxic effect of cyanides, intentional self-harm, sequela
        "T651X2A",  # Toxic effect of strychnine and its salts, intentional self-harm, initial encounter
        "T651X2D",  # Toxic effect of strychnine and its salts, intentional self-harm, subsequent encounter
        "T651X2S",  # Toxic effect of strychnine and its salts, intentional self-harm, sequela
        "T65212A",  # Toxic effect of chewing tobacco, intentional self-harm, initial encounter
        "T65212D",  # Toxic effect of chewing tobacco, intentional self-harm, subsequent encounter
        "T65212S",  # Toxic effect of chewing tobacco, intentional self-harm, sequela
        "T65222A",  # Toxic effect of tobacco cigarettes, intentional self-harm, initial encounter
        "T65222D",  # Toxic effect of tobacco cigarettes, intentional self-harm, subsequent encounter
        "T65222S",  # Toxic effect of tobacco cigarettes, intentional self-harm, sequela
        "T65292A",  # Toxic effect of other tobacco and nicotine, intentional self-harm, initial encounter
        "T65292D",  # Toxic effect of other tobacco and nicotine, intentional self-harm, subsequent encounter
        "T65292S",  # Toxic effect of other tobacco and nicotine, intentional self-harm, sequela
        "T653X2A",  # Toxic effect of nitroderivatives and aminoderivatives of benzene and its homologues, intentional self-harm, initial encounter
        "T653X2D",  # Toxic effect of nitroderivatives and aminoderivatives of benzene and its homologues, intentional self-harm, subsequent encounter
        "T653X2S",  # Toxic effect of nitroderivatives and aminoderivatives of benzene and its homologues, intentional self-harm, sequela
        "T654X2A",  # Toxic effect of carbon disulfide, intentional self-harm, initial encounter
        "T654X2D",  # Toxic effect of carbon disulfide, intentional self-harm, subsequent encounter
        "T654X2S",  # Toxic effect of carbon disulfide, intentional self-harm, sequela
        "T655X2A",  # Toxic effect of nitroglycerin and other nitric acids and esters, intentional self-harm, initial encounter
        "T655X2D",  # Toxic effect of nitroglycerin and other nitric acids and esters, intentional self-harm, subsequent encounter
        "T655X2S",  # Toxic effect of nitroglycerin and other nitric acids and esters, intentional self-harm, sequela
        "T656X2A",  # Toxic effect of paints and dyes, not elsewhere classified, intentional self-harm, initial encounter
        "T656X2D",  # Toxic effect of paints and dyes, not elsewhere classified, intentional self-harm, subsequent encounter
        "T656X2S",  # Toxic effect of paints and dyes, not elsewhere classified, intentional self-harm, sequela
        "T65812A",  # Toxic effect of latex, intentional self-harm, initial encounter
        "T65812D",  # Toxic effect of latex, intentional self-harm, subsequent encounter
        "T65812S",  # Toxic effect of latex, intentional self-harm, sequela
        "T65822A",  # Toxic effect of harmful algae and algae toxins, intentional self-harm, initial encounter
        "T65822D",  # Toxic effect of harmful algae and algae toxins, intentional self-harm, subsequent encounter
        "T65822S",  # Toxic effect of harmful algae and algae toxins, intentional self-harm, sequela
        "T65832A",  # Toxic effect of fiberglass, intentional self-harm, initial encounter
        "T65832D",  # Toxic effect of fiberglass, intentional self-harm, subsequent encounter
        "T65832S",  # Toxic effect of fiberglass, intentional self-harm, sequela
        "T65892A",  # Toxic effect of other specified substances, intentional self-harm, initial encounter
        "T65892D",  # Toxic effect of other specified substances, intentional self-harm, subsequent encounter
        "T65892S",  # Toxic effect of other specified substances, intentional self-harm, sequela
        "T6592XA",  # Toxic effect of unspecified substance, intentional self-harm, initial encounter
        "T6592XD",  # Toxic effect of unspecified substance, intentional self-harm, subsequent encounter
        "T6592XS",  # Toxic effect of unspecified substance, intentional self-harm, sequela
        "T71112A",  # Asphyxiation due to smothering under pillow, intentional self-harm, initial encounter
        "T71112D",  # Asphyxiation due to smothering under pillow, intentional self-harm, subsequent encounter
        "T71112S",  # Asphyxiation due to smothering under pillow, intentional self-harm, sequela
        "T71122A",  # Asphyxiation due to plastic bag, intentional self-harm, initial encounter
        "T71122D",  # Asphyxiation due to plastic bag, intentional self-harm, subsequent encounter
        "T71122S",  # Asphyxiation due to plastic bag, intentional self-harm, sequela
        "T71132A",  # Asphyxiation due to being trapped in bed linens, intentional self-harm, initial encounter
        "T71132D",  # Asphyxiation due to being trapped in bed linens, intentional self-harm, subsequent encounter
        "T71132S",  # Asphyxiation due to being trapped in bed linens, intentional self-harm, sequela
        "T71152A",  # Asphyxiation due to smothering in furniture, intentional self-harm, initial encounter
        "T71152D",  # Asphyxiation due to smothering in furniture, intentional self-harm, subsequent encounter
        "T71152S",  # Asphyxiation due to smothering in furniture, intentional self-harm, sequela
        "T71162A",  # Asphyxiation due to hanging, intentional self-harm, initial encounter
        "T71162D",  # Asphyxiation due to hanging, intentional self-harm, subsequent encounter
        "T71162S",  # Asphyxiation due to hanging, intentional self-harm, sequela
        "T71192A",  # Asphyxiation due to mechanical threat to breathing due to other causes, intentional self-harm, initial encounter
        "T71192D",  # Asphyxiation due to mechanical threat to breathing due to other causes, intentional self-harm, subsequent encounter
        "T71192S",  # Asphyxiation due to mechanical threat to breathing due to other causes, intentional self-harm, sequela
        "T71222A",  # Asphyxiation due to being trapped in a car trunk, intentional self-harm, initial encounter
        "T71222D",  # Asphyxiation due to being trapped in a car trunk, intentional self-harm, subsequent encounter
        "T71222S",  # Asphyxiation due to being trapped in a car trunk, intentional self-harm, sequela
        "T71232A",  # Asphyxiation due to being trapped in a (discarded) refrigerator, intentional self-harm, initial encounter
        "T71232D",  # Asphyxiation due to being trapped in a (discarded) refrigerator, intentional self-harm, subsequent encounter
        "T71232S",  # Asphyxiation due to being trapped in a (discarded) refrigerator, intentional self-harm, sequela
        "X710XXA",  # Intentional self-harm by drowning and submersion while in bathtub, initial encounter
        "X710XXD",  # Intentional self-harm by drowning and submersion while in bathtub, subsequent encounter
        "X710XXS",  # Intentional self-harm by drowning and submersion while in bathtub, sequela
        "X711XXA",  # Intentional self-harm by drowning and submersion while in swimming pool, initial encounter
        "X711XXD",  # Intentional self-harm by drowning and submersion while in swimming pool, subsequent encounter
        "X711XXS",  # Intentional self-harm by drowning and submersion while in swimming pool, sequela
        "X712XXA",  # Intentional self-harm by drowning and submersion after jump into swimming pool, initial encounter
        "X712XXD",  # Intentional self-harm by drowning and submersion after jump into swimming pool, subsequent encounter
        "X712XXS",  # Intentional self-harm by drowning and submersion after jump into swimming pool, sequela
        "X713XXA",  # Intentional self-harm by drowning and submersion in natural water, initial encounter
        "X713XXD",  # Intentional self-harm by drowning and submersion in natural water, subsequent encounter
        "X713XXS",  # Intentional self-harm by drowning and submersion in natural water, sequela
        "X718XXA",  # Other intentional self-harm by drowning and submersion, initial encounter
        "X718XXD",  # Other intentional self-harm by drowning and submersion, subsequent encounter
        "X718XXS",  # Other intentional self-harm by drowning and submersion, sequela
        "X719XXA",  # Intentional self-harm by drowning and submersion, unspecified, initial encounter
        "X719XXD",  # Intentional self-harm by drowning and submersion, unspecified, subsequent encounter
        "X719XXS",  # Intentional self-harm by drowning and submersion, unspecified, sequela
        "X72XXXA",  # Intentional self-harm by handgun discharge, initial encounter
        "X72XXXD",  # Intentional self-harm by handgun discharge, subsequent encounter
        "X72XXXS",  # Intentional self-harm by handgun discharge, sequela
        "X730XXA",  # Intentional self-harm by shotgun discharge, initial encounter
        "X730XXD",  # Intentional self-harm by shotgun discharge, subsequent encounter
        "X730XXS",  # Intentional self-harm by shotgun discharge, sequela
        "X731XXA",  # Intentional self-harm by hunting rifle discharge, initial encounter
        "X731XXD",  # Intentional self-harm by hunting rifle discharge, subsequent encounter
        "X731XXS",  # Intentional self-harm by hunting rifle discharge, sequela
        "X732XXA",  # Intentional self-harm by machine gun discharge, initial encounter
        "X732XXD",  # Intentional self-harm by machine gun discharge, subsequent encounter
        "X732XXS",  # Intentional self-harm by machine gun discharge, sequela
        "X738XXA",  # Intentional self-harm by other larger firearm discharge, initial encounter
        "X738XXD",  # Intentional self-harm by other larger firearm discharge, subsequent encounter
        "X738XXS",  # Intentional self-harm by other larger firearm discharge, sequela
        "X739XXA",  # Intentional self-harm by unspecified larger firearm discharge, initial encounter
        "X739XXD",  # Intentional self-harm by unspecified larger firearm discharge, subsequent encounter
        "X739XXS",  # Intentional self-harm by unspecified larger firearm discharge, sequela
        "X7401XA",  # Intentional self-harm by airgun, initial encounter
        "X7401XD",  # Intentional self-harm by airgun, subsequent encounter
        "X7401XS",  # Intentional self-harm by airgun, sequela
        "X7402XA",  # Intentional self-harm by paintball gun, initial encounter
        "X7402XD",  # Intentional self-harm by paintball gun, subsequent encounter
        "X7402XS",  # Intentional self-harm by paintball gun, sequela
        "X7409XA",  # Intentional self-harm by other gas, air or spring-operated gun, initial encounter
        "X7409XD",  # Intentional self-harm by other gas, air or spring-operated gun, subsequent encounter
        "X7409XS",  # Intentional self-harm by other gas, air or spring-operated gun, sequela
        "X748XXA",  # Intentional self-harm by other firearm discharge, initial encounter
        "X748XXD",  # Intentional self-harm by other firearm discharge, subsequent encounter
        "X748XXS",  # Intentional self-harm by other firearm discharge, sequela
        "X749XXA",  # Intentional self-harm by unspecified firearm discharge, initial encounter
        "X749XXD",  # Intentional self-harm by unspecified firearm discharge, subsequent encounter
        "X749XXS",  # Intentional self-harm by unspecified firearm discharge, sequela
        "X75XXXA",  # Intentional self-harm by explosive material, initial encounter
        "X75XXXD",  # Intentional self-harm by explosive material, subsequent encounter
        "X75XXXS",  # Intentional self-harm by explosive material, sequela
        "X76XXXA",  # Intentional self-harm by smoke, fire and flames, initial encounter
        "X76XXXD",  # Intentional self-harm by smoke, fire and flames, subsequent encounter
        "X76XXXS",  # Intentional self-harm by smoke, fire and flames, sequela
        "X770XXA",  # Intentional self-harm by steam or hot vapors, initial encounter
        "X770XXD",  # Intentional self-harm by steam or hot vapors, subsequent encounter
        "X770XXS",  # Intentional self-harm by steam or hot vapors, sequela
        "X771XXA",  # Intentional self-harm by hot tap water, initial encounter
        "X771XXD",  # Intentional self-harm by hot tap water, subsequent encounter
        "X771XXS",  # Intentional self-harm by hot tap water, sequela
        "X772XXA",  # Intentional self-harm by other hot fluids, initial encounter
        "X772XXD",  # Intentional self-harm by other hot fluids, subsequent encounter
        "X772XXS",  # Intentional self-harm by other hot fluids, sequela
        "X773XXA",  # Intentional self-harm by hot household appliances, initial encounter
        "X773XXD",  # Intentional self-harm by hot household appliances, subsequent encounter
        "X773XXS",  # Intentional self-harm by hot household appliances, sequela
        "X778XXA",  # Intentional self-harm by other hot objects, initial encounter
        "X778XXD",  # Intentional self-harm by other hot objects, subsequent encounter
        "X778XXS",  # Intentional self-harm by other hot objects, sequela
        "X779XXA",  # Intentional self-harm by unspecified hot objects, initial encounter
        "X779XXD",  # Intentional self-harm by unspecified hot objects, subsequent encounter
        "X779XXS",  # Intentional self-harm by unspecified hot objects, sequela
        "X780XXA",  # Intentional self-harm by sharp glass, initial encounter
        "X780XXD",  # Intentional self-harm by sharp glass, subsequent encounter
        "X780XXS",  # Intentional self-harm by sharp glass, sequela
        "X781XXA",  # Intentional self-harm by knife, initial encounter
        "X781XXD",  # Intentional self-harm by knife, subsequent encounter
        "X781XXS",  # Intentional self-harm by knife, sequela
        "X782XXA",  # Intentional self-harm by sword or dagger, initial encounter
        "X782XXD",  # Intentional self-harm by sword or dagger, subsequent encounter
        "X782XXS",  # Intentional self-harm by sword or dagger, sequela
        "X788XXA",  # Intentional self-harm by other sharp object, initial encounter
        "X788XXD",  # Intentional self-harm by other sharp object, subsequent encounter
        "X788XXS",  # Intentional self-harm by other sharp object, sequela
        "X789XXA",  # Intentional self-harm by unspecified sharp object, initial encounter
        "X789XXD",  # Intentional self-harm by unspecified sharp object, subsequent encounter
        "X789XXS",  # Intentional self-harm by unspecified sharp object, sequela
        "X79XXXA",  # Intentional self-harm by blunt object, initial encounter
        "X79XXXD",  # Intentional self-harm by blunt object, subsequent encounter
        "X79XXXS",  # Intentional self-harm by blunt object, sequela
        "X80XXXA",  # Intentional self-harm by jumping from a high place, initial encounter
        "X80XXXD",  # Intentional self-harm by jumping from a high place, subsequent encounter
        "X80XXXS",  # Intentional self-harm by jumping from a high place, sequela
        "X810XXA",  # Intentional self-harm by jumping or lying in front of motor vehicle, initial encounter
        "X810XXD",  # Intentional self-harm by jumping or lying in front of motor vehicle, subsequent encounter
        "X810XXS",  # Intentional self-harm by jumping or lying in front of motor vehicle, sequela
        "X811XXA",  # Intentional self-harm by jumping or lying in front of (subway) train, initial encounter
        "X811XXD",  # Intentional self-harm by jumping or lying in front of (subway) train, subsequent encounter
        "X811XXS",  # Intentional self-harm by jumping or lying in front of (subway) train, sequela
        "X818XXA",  # Intentional self-harm by jumping or lying in front of other moving object, initial encounter
        "X818XXD",  # Intentional self-harm by jumping or lying in front of other moving object, subsequent encounter
        "X818XXS",  # Intentional self-harm by jumping or lying in front of other moving object, sequela
        "X828XXA",  # Other intentional self-harm by crashing of motor vehicle, initial encounter
        "X828XXD",  # Other intentional self-harm by crashing of motor vehicle, subsequent encounter
        "X828XXS",  # Other intentional self-harm by crashing of motor vehicle, sequela
        "X830XXA",  # Intentional self-harm by crashing of aircraft, initial encounter
        "X830XXD",  # Intentional self-harm by crashing of aircraft, subsequent encounter
        "X830XXS",  # Intentional self-harm by crashing of aircraft, sequela
        "X831XXA",  # Intentional self-harm by electrocution, initial encounter
        "X831XXD",  # Intentional self-harm by electrocution, subsequent encounter
        "X831XXS",  # Intentional self-harm by electrocution, sequela
        "X832XXA",  # Intentional self-harm by exposure to extremes of cold, initial encounter
        "X832XXD",  # Intentional self-harm by exposure to extremes of cold, subsequent encounter
        "X832XXS",  # Intentional self-harm by exposure to extremes of cold, sequela
        "X838XXA",  # Intentional self-harm by other specified means, initial encounter
        "X838XXD",  # Intentional self-harm by other specified means, subsequent encounter
        "X838XXS",  # Intentional self-harm by other specified means, sequela
        "Z554",  # Educational maladjustment and discord with teachers and classmates
        "Z563",  # Stressful work schedule
        "Z564",  # Discord with boss and workmates
        "Z592",  # Discord with neighbors, lodgers and landlord
        "Z600",  # Problems of adjustment to life-cycle transitions
        "Z603",  # Acculturation difficulty
        "Z604",  # Social exclusion and rejection
        "Z605",  # Target of (perceived) adverse discrimination and persecution
        "Z620",  # Inadequate parental supervision and control
        "Z621",  # Parental overprotection
        "Z6222",  # Institutional upbringing
        "Z6229",  # Other upbringing away from parents
        "Z623",  # Hostility towards and scapegoating of child
        "Z626",  # Inappropriate (excessive) parental pressure
        "Z62810",  # Personal history of physical and sexual abuse in childhood
        "Z62811",  # Personal history of psychological abuse in childhood
        "Z62812",  # Personal history of neglect in childhood
        "Z62813",  # Personal history of forced labor or sexual exploitation in childhood
        "Z62819",  # Personal history of unspecified abuse in childhood
        "Z62820",  # Parent-biological child conflict
        "Z62821",  # Parent-adopted child conflict
        "Z62822",  # Parent-foster child conflict
        "Z62890",  # Parent-child estrangement NEC
        "Z62891",  # Sibling rivalry
        "Z62898",  # Other specified problems related to upbringing
        "Z629",  # Problem related to upbringing, unspecified
        "Z630",  # Problems in relationship with spouse or partner
        "Z631",  # Problems in relationship with in-laws
        "Z634",  # Disappearance and death of family member
        "Z635",  # Disruption of family by separation and divorce
        "Z6371",  # Stress on family due to return of family member from military deployment
        "Z6379",  # Other stressful life events affecting family and household
        "Z638",  # Other specified problems related to primary support group
        "Z644",  # Discord with counselors
        "Z658",  # Other specified problems related to psychosocial circumstances
        "Z69010",  # Encounter for mental health services for victim of parental child abuse
        "Z69011",  # Encounter for mental health services for perpetrator of parental child abuse
        "Z69020",  # Encounter for mental health services for victim of non-parental child abuse
        "Z69021",  # Encounter for mental health services for perpetrator of non-parental child abuse
        "Z6911",  # Encounter for mental health services for victim of spousal or partner abuse
        "Z6912",  # Encounter for mental health services for perpetrator of spousal or partner abuse
        "Z6981",  # Encounter for mental health services for victim of other abuse
        "Z6982",  # Encounter for mental health services for perpetrator of other abuse
        "Z700",  # Counseling related to sexual attitude
        "Z701",  # Counseling related to patient's sexual behavior and orientation
        "Z702",  # Counseling related to sexual behavior and orientation of third party
        "Z703",  # Counseling related to combined concerns regarding sexual attitude, behavior and orientation
        "Z708",  # Other sex counseling
        "Z709",  # Sex counseling, unspecified
        "Z726",  # Gambling and betting
        "Z72810",  # Child and adolescent antisocial behavior
        "Z72811",  # Adult antisocial behavior
        "Z730",  # Burn-out
        "Z731",  # Type A behavior pattern
        "Z733",  # Stress, not elsewhere classified
        "Z734",  # Inadequate social skills, not elsewhere classified
        "Z735",  # Social role conflict, not elsewhere classified
        "Z73810",  # Behavioral insomnia of childhood, sleep-onset association type
        "Z73811",  # Behavioral insomnia of childhood, limit setting type
        "Z73812",  # Behavioral insomnia of childhood, combined type
        "Z73819",  # Behavioral insomnia of childhood, unspecified type
        "Z7389",  # Other problems related to life management difficulty
        "Z8651",  # Personal history of combat and operational stress reaction
        "Z8659",  # Personal history of other mental and behavioral disorders
        "Z91410",  # Personal history of adult physical and sexual abuse
        "Z91411",  # Personal history of adult psychological abuse
        "Z91412",  # Personal history of adult neglect
        "Z91419",  # Personal history of unspecified adult abuse
        "Z9142",  # Personal history of forced labor or sexual exploitation
        "Z9149",  # Other personal history of psychological trauma, not elsewhere classified
    }

    SNOMEDCT = {
        "101421000119107",  # Dementia due to Parkinson's disease (disorder)
        "10171000132106",  # Behavioral and psychological symptoms of dementia (finding)
        "10349009",  # Multi-infarct dementia with delirium (disorder)
        "10532003",  # Primary degenerative dementia of the Alzheimer type, presenile onset, with depression (disorder)
        "105491000119107",  # Primary hyposomnia (disorder)
        "106021000119105",  # Multi-infarct dementia due to atherosclerosis (disorder)
        "109006",  # Anxiety disorder of childhood OR adolescence (disorder)
        "109805003",  # Factitious cheilitis (disorder)
        "109899002",  # Indication for modification of patient emotional status (disorder)
        "11003002",  # Nervous diarrhea (disorder)
        "111475002",  # Neurosis (disorder)
        "111477005",  # Reactive attachment disorder of infancy OR early childhood, disinhibited type (disorder)
        "111479008",  # Organic mental disorder (disorder)
        "111480006",  # Psychoactive substance-induced organic dementia (disorder)
        "111482003",  # Subchronic schizophrenia with acute exacerbations (disorder)
        "111483008",  # Catatonic schizophrenia in remission (disorder)
        "111484002",  # Undifferentiated schizophrenia (disorder)
        "111485001",  # Mixed bipolar I disorder in full remission (disorder)
        "111487009",  # Dream anxiety disorder (disorder)
        "111490003",  # Panic disorder with agoraphobia, agoraphobic avoidance in partial remission AND severe panic attacks (disorder)
        "111491004",  # Panic disorder with agoraphobia, agoraphobic avoidance in full remission AND panic attacks in partial remission (disorder)
        "111492006",  # Conversion disorder, single episode (disorder)
        "1144368001",  # Intentional warfarin overdose (disorder)
        "1144776001",  # Intentional levothyroxine poisoning (disorder)
        "1144817005",  # Intentional protamine poisoning (disorder)
        "1144822005",  # Intentional thiopental poisoning (disorder)
        "1144826008",  # Intentional tolazoline poisoning (disorder)
        "1144830006",  # Intentional triclofos poisoning (disorder)
        "1144834002",  # Intentional poisoning caused by valproate (disorder)
        "1144838004",  # Intentional warfarin poisoning (disorder)
        "1145003",  # Developmental speech disorder (disorder)
        "1145046005",  # Intentional thiopental overdose (disorder)
        "1145056009",  # Intentional clorazepate overdose (disorder)
        "1145065002",  # Intentional triclofos overdose (disorder)
        "1145075004",  # Intentional clorazepate poisoning (disorder)
        "1145160009",  # Intentional piperazine and/or piperazine derivative poisoning (disorder)
        "1145548001",  # Intentional poisoning by nicotinic acid (disorder)
        "1148516004",  # Intentional bile acid and/or bile acid derivative poisoning (disorder)
        "1148533006",  # Intentional bile acid and/or bile acid derivative overdose (disorder)
        "1148542004",  # Intentional nicotinic acid overdose (disorder)
        "1148569003",  # Intentional amfetamine and/or amfetamine derivative poisoning (disorder)
        "1148647001",  # Intentional opioid receptor agonist poisoning (disorder)
        "1148653001",  # Intentional parathyroid hormone and/or parathyroid hormone derivative poisoning (disorder)
        "1148673006",  # Intentional amfetamine and/or amfetamine derivative overdose (disorder)
        "1148742001",  # Intentional event (event)
        "1148746003",  # Intentional dextropropoxyphene and/or paracetamol poisoning (disorder)
        "1148748002",  # Intentional sulfamethoxazole and/or trimethoprim poisoning (disorder)
        "1148751009",  # Intentional estrogen and/or progestogen poisoning (disorder)
        "1148924004",  # Dementia due to deficiency of folic acid (disorder)
        "1149134001",  # Intentional ferric iron compound poisoning (disorder)
        "1149148001",  # Intentional deoxycortone poisoning (disorder)
        "1149224003",  # Intentional overdose (disorder)
        "1149236009",  # Intentional poisoning caused by corticosteroid and/or corticosteroid derivative (disorder)
        "1149241001",  # Intentional overdose by lysergic acid diethylamide (disorder)
        "1149373009",  # Intentional sulfamethoxazole and/or trimethoprim overdose (disorder)
        "1149376001",  # Intentional dextropropoxyphene and/or paracetamol overdose (disorder)
        "1149407007",  # Intentional protamine overdose (disorder)
        "1149412008",  # Intentional diethyl ether overdose (disorder)
        "1149470008",  # Intentional somatropin poisoning (disorder)
        "1153530002",  # Intentional poisoning caused by substance with ether structure (disorder)
        "1153540004",  # Intentional fluoroquinolone poisoning (disorder)
        "1153575004",  # Persistent depressive disorder (disorder)
        "1156507003",  # Intentional overdose of opioid receptor agonist (disorder)
        "1156518003",  # Intentional quinolone antibacterial overdose (disorder)
        "1162806001",  # Intentional valproate overdose (disorder)
        "1162819002",  # Intentional lithium and/or lithium compound overdose (disorder)
        "1162822000",  # Intentional vitamin K and/or vitamin K derivative overdose (disorder)
        "1162825003",  # Intentional vitamin D and/or vitamin D derivative overdose (disorder)
        "11806006",  # Separation anxiety disorder of childhood (disorder)
        "1186877003",  # Dementia due to vitamin E deficiency (disorder)
        "1186879000",  # Dementia due to thiamine deficiency (disorder)
        "1186880002",  # Dementia due to cobalamin deficiency (disorder)
        "1186881003",  # Dementia due to niacin deficiency (disorder)
        "1186883000",  # Dementia due to nutritional deficiency disorder (disorder)
        "1186887004",  # Dementia caused by manganese and/or manganese compound (disorder)
        "11941006",  # Panic disorder with agoraphobia, agoraphobic avoidance in full remission AND panic attacks in full remission (disorder)
        "1196001",  # Chronic bipolar II disorder, most recent episode major depressive (disorder)
        "1204434006",  # Intentional poisoning caused by detergent (disorder)
        "12348006",  # Presenile dementia (disorder)
        "1259066002",  # Disorder of autonomic nervous system due to senile dementia of Lewy body type (disorder)
        "1259121008",  # Amyotrophic lateral sclerosis, parkinsonism, dementia complex of West New Guinea (disorder)
        "1259123006",  # Amyotrophic lateral sclerosis, parkinsonism, dementia complex of Kii Peninsula (disorder)
        "1259124000",  # Amyotrophic lateral sclerosis with frontotemporal dementia (disorder)
        "1259465009",  # Dementia due to hepatic failure (disorder)
        "1259467001",  # Dementia due to hypercalcemia (disorder)
        "1259469003",  # Dementia due to Gerstmann Straussler Scheinker syndrome (disorder)
        "1259471003",  # Dementia due to Hashimoto encephalopathy (disorder)
        "1259473000",  # Dementia due to fragile X syndrome (disorder)
        "1259476008",  # Dementia due to genetic disease (disorder)
        "1259478009",  # Dementia due to familial Creutzfeldt-Jakob disease (disorder)
        "1259480003",  # Dementia due to fatal familial insomnia (disorder)
        "1259485008",  # Dementia due to cerebral vasculitis (disorder)
        "1259488005",  # Dementia due to cerebral amyloid angiopathy (disorder)
        "1259492003",  # Dementia due to metastatic malignant neoplasm to brain (disorder)
        "1259494002",  # Dementia due to leukodystrophy (disorder)
        "1259496000",  # Dementia due to Lyme disease (disorder)
        "1259499007",  # Dementia due to hemorrhagic cerebral infarction due to hypertension (disorder)
        "1259501004",  # Dementia due to kuru (disorder)
        "1259503001",  # Dementia due to iatrogenic Creutzfeldt-Jakob disease (disorder)
        "1259511006",  # Dementia due to Wilson disease (disorder)
        "1259513009",  # Dementia due to Whipple disease (disorder)
        "1259517005",  # Dementia due to systemic lupus erythematosus (disorder)
        "1259519008",  # Dementia due to subacute sclerosing panencephalitis (disorder)
        "1259522005",  # Dementia due to variant Creutzfeldt-Jakob disease (disorder)
        "1259524006",  # Dementia due to trypanosomiasis (disorder)
        "1259529001",  # Dementia due to sporadic Creutzfeldt-Jakob disease (disorder)
        "1259531005",  # Dementia due to hypertensive encephalopathy (disorder)
        "1259579003",  # Dementia due to Behcet syndrome (disorder)
        "1259581001",  # Dementia due to celiac disease (disorder)
        "1259584009",  # Dementia due to and following dialysis (disorder)
        "1259586006",  # Dementia due to autoimmune encephalitis (disorder)
        "1259591007",  # Dementia due to acquired hypothyroidism (disorder)
        "1259656006",  # Dementia due to renal failure (disorder)
        "1259661008",  # Dementia due to inflammatory disorder of musculoskeletal system (disorder)
        "1259663006",  # Dementia due to polyarteritis nodosa (disorder)
        "1259665004",  # Dementia due to progressive subcortical gliosis (disorder)
        "1259667007",  # Dementia due to paraneoplastic encephalitis (disorder)
        "1259673008",  # Dementia due to neurofilament inclusion body disease (disorder)
        "1259675001",  # Dementia due to obstructive hydrocephalus (disorder)
        "1259677009",  # Dementia due to multiple system atrophy (disorder)
        "1259679007",  # Dementia due to atypical pantothenate kinase associated neurodegeneration (disorder)
        "1259990004",  # Dementia due to classical pantothenate kinase associated neurodegeneration (disorder)
        "1260352009",  # Frontotemporal dementia due to TARDBP mutation (disorder)
        "1260353004",  # Frontotemporal dementia due to VCP mutation (disorder)
        "1260354005",  # Frontotemporal dementia due to C9orf72 mutation (disorder)
        "1260355006",  # Frontotemporal dementia due to FUS mutation (disorder)
        "1263512007",  # Myoclonic disorder due to dementia (disorder)
        "126943008",  # Separation anxiety (disorder)
        "128293007",  # Chronic mental disorder (disorder)
        "129104009",  # Developmental mental disorder (disorder)
        "12939007",  # Chronic disorganized schizophrenia (disorder)
        "129562004",  # Psychogenic skin disease (disorder)
        "129602009",  # Symbiotic infantile psychosis (disorder)
        "129604005",  # Delusion of heart disease syndrome (disorder)
        "12969000",  # Severe bipolar II disorder, most recent episode major depressive, in full remission (disorder)
        "130121000119104",  # Dementia due to Rett syndrome (disorder)
        "1303408008",  # Persistent perceptual disturbance due to and following hallucinogen intoxication (disorder)
        "1303411009",  # Flashback due to and following trauma (finding)
        "13313007",  # Mild bipolar disorder (disorder)
        "1339031006",  # Dementia caused by ionizing radiation (disorder)
        "13438001",  # Overanxious disorder of childhood (disorder)
        "135811000119107",  # Lewy body dementia with behavioral disturbance (disorder)
        "13601005",  # Paranoid personality disorder (disorder)
        "13746004",  # Bipolar disorder (disorder)
        "1376001",  # Obsessive compulsive personality disorder (disorder)
        "14070001",  # Multi-infarct dementia with depression (disorder)
        "14077003",  # Pica (disorder)
        "14183003",  # Chronic major depressive disorder, single episode (disorder)
        "14291003",  # Subchronic disorganized schizophrenia with acute exacerbations (disorder)
        "14495005",  # Severe bipolar I disorder, single manic episode without psychotic features (disorder)
        "1499003",  # Bipolar I disorder, single manic episode with postpartum onset (disorder)
        "15193003",  # Severe recurrent major depression with psychotic features, mood-incongruent (disorder)
        "15639000",  # Moderate major depression, single episode (disorder)
        "15662003",  # Senile dementia (disorder)
        "1581000119101",  # Dementia of the Alzheimer type with behavioral disturbance (disorder)
        "1591000119103",  # Dementia with behavioral disturbance (disorder)
        "15977008",  # Adjustment disorder with academic inhibition (disorder)
        "160325007",  # Family history: Senile dementia (situation)
        "160822004",  # Relationship problem (finding)
        "161465002",  # History of dementia (situation)
        "162004",  # Severe manic bipolar I disorder without psychotic features (disorder)
        "16219201000119101",  # Behavioral disturbance co-occurrent and due to late onset Alzheimer dementia (disorder)
        "162204000",  # Late insomnia (disorder)
        "16276361000119109",  # Vascular dementia without behavioral disturbance (disorder)
        "16295005",  # Bipolar II disorder, most recent episode major depressive (disorder)
        "16506000",  # Mixed bipolar I disorder (disorder)
        "165320004",  # Dementia test (procedure)
        "165321000",  # Ten item dementia test (procedure)
        "165322007",  # Thirty-seven item dementia test (procedure)
        "16805009",  # Cluster A personality disorder (disorder)
        "16966009",  # Factitious hypoglycemia (disorder)
        "16990005",  # Subchronic schizophrenia (disorder)
        "17226007",  # Adjustment disorder (disorder)
        "17496003",  # Organic anxiety disorder (disorder)
        "17782008",  # Bipolar I disorder, most recent episode manic with catatonic features (disorder)
        "17961008",  # Conduct disorder, childhood-onset type (disorder)
        "18003009",  # Gender identity disorder of adulthood (disorder)
        "18085000",  # Compulsive gambling (disorder)
        "1816003",  # Panic disorder with agoraphobia, severe agoraphobic avoidance AND mild panic attacks (disorder)
        "18260003",  # Postpartum psychosis (disorder)
        "18478005",  # Adjustment disorder with physical complaints (disorder)
        "18541000119100",  # Borderline cognitive developmental delay (disorder)
        "18818009",  # Moderate recurrent major depression (disorder)
        "18941000",  # Oppositional defiant disorder (disorder)
        "191447007",  # Organic psychotic condition (disorder)
        "191449005",  # Uncomplicated senile dementia (disorder)
        "191451009",  # Uncomplicated presenile dementia (disorder)
        "191452002",  # Presenile dementia with delirium (disorder)
        "191454001",  # Presenile dementia with paranoia (disorder)
        "191455000",  # Presenile dementia with depression (disorder)
        "191457008",  # Senile dementia with depressive or paranoid features (disorder)
        "191458003",  # Senile dementia with paranoia (disorder)
        "191459006",  # Senile dementia with depression (disorder)
        "191461002",  # Senile dementia with delirium (disorder)
        "191463004",  # Uncomplicated arteriosclerotic dementia (disorder)
        "191464005",  # Arteriosclerotic dementia with delirium (disorder)
        "191465006",  # Arteriosclerotic dementia with paranoia (disorder)
        "191466007",  # Arteriosclerotic dementia with depression (disorder)
        "191493005",  # Dementia caused by drug (disorder)
        "191499009",  # Transient organic psychoses (disorder)
        "191501001",  # Acute confusional state, post-traumatic (disorder)
        "191507002",  # Subacute delirium (disorder)
        "191508007",  # Subacute confusional state, post-traumatic (disorder)
        "191519005",  # Dementia associated with another disease (disorder)
        "191525009",  # Non-organic psychosis (disorder)
        "191526005",  # Schizophrenic disorders (disorder)
        "191527001",  # Simple schizophrenia (disorder)
        "191531007",  # Acute exacerbation of chronic schizophrenia (disorder)
        "191542003",  # Catatonic schizophrenia (disorder)
        "191547009",  # Acute exacerbation of subchronic catatonic schizophrenia (disorder)
        "191548004",  # Acute exacerbation of chronic catatonic schizophrenia (disorder)
        "191554003",  # Acute exacerbation of subchronic paranoid schizophrenia (disorder)
        "191555002",  # Acute exacerbation of chronic paranoid schizophrenia (disorder)
        "191559008",  # Latent schizophrenia (disorder)
        "191567000",  # Schizoaffective schizophrenia (disorder)
        "191569002",  # Subchronic schizoaffective schizophrenia (disorder)
        "191570001",  # Chronic schizoaffective schizophrenia (disorder)
        "191571002",  # Acute exacerbation of subchronic schizoaffective schizophrenia (disorder)
        "191572009",  # Acute exacerbation of chronic schizoaffective schizophrenia (disorder)
        "191574005",  # Schizoaffective schizophrenia in remission (disorder)
        "191577003",  # Cenesthopathic schizophrenia (disorder)
        "191583000",  # Single manic episode, mild (disorder)
        "191584006",  # Single manic episode, moderate (disorder)
        "191586008",  # Single manic episode, severe, with psychosis (disorder)
        "191588009",  # Single manic episode in full remission (disorder)
        "191590005",  # Recurrent manic episodes (disorder)
        "191592002",  # Recurrent manic episodes, mild (disorder)
        "191593007",  # Recurrent manic episodes, moderate (disorder)
        "191595000",  # Recurrent manic episodes, severe, with psychosis (disorder)
        "191597008",  # Recurrent manic episodes, in full remission (disorder)
        "191604000",  # Single major depressive episode, severe, with psychosis (disorder)
        "191610000",  # Recurrent major depressive episodes, mild (disorder)
        "191611001",  # Recurrent major depressive episodes, moderate (disorder)
        "191613003",  # Recurrent major depressive episodes, severe, with psychosis (disorder)
        "191616006",  # Recurrent depression (disorder)
        "191618007",  # Bipolar affective disorder, current episode manic (disorder)
        "191620005",  # Bipolar affective disorder, currently manic, mild (disorder)
        "191621009",  # Bipolar affective disorder, currently manic, moderate (disorder)
        "191623007",  # Bipolar affective disorder, currently manic, severe, with psychosis (disorder)
        "191627008",  # Bipolar affective disorder, current episode depression (disorder)
        "191629006",  # Bipolar affective disorder, currently depressed, mild (disorder)
        "191630001",  # Bipolar affective disorder, currently depressed, moderate (disorder)
        "191636007",  # Mixed bipolar affective disorder (disorder)
        "191638008",  # Mixed bipolar affective disorder, mild (disorder)
        "191639000",  # Mixed bipolar affective disorder, moderate (disorder)
        "191641004",  # Mixed bipolar affective disorder, severe, with psychosis (disorder)
        "191643001",  # Mixed bipolar affective disorder, in full remission (disorder)
        "191658009",  # Atypical manic disorder (disorder)
        "191659001",  # Atypical depressive disorder (disorder)
        "191668004",  # Simple paranoid state (disorder)
        "191672000",  # Paranoia querulans (disorder)
        "191676002",  # Reactive depressive psychosis (disorder)
        "191677006",  # Acute hysterical psychosis (disorder)
        "191680007",  # Psychogenic paranoid psychosis (disorder)
        "191683009",  # Psychogenic stupor (disorder)
        "191687005",  # Psychosis with origin in childhood (disorder)
        "191692007",  # Active disintegrative psychoses (disorder)
        "191693002",  # Residual disintegrative psychoses (disorder)
        "191696005",  # Atypical childhood psychoses (disorder)
        "191697001",  # Borderline psychosis of childhood (disorder)
        "191714002",  # Dissociative convulsions (disorder)
        "191722009",  # Agoraphobia with panic attacks (disorder)
        "191724005",  # Social phobia, fear of eating in public (disorder)
        "191725006",  # Social phobia, fear of public speaking (disorder)
        "191726007",  # Social phobia, fear of public washing (disorder)
        "191736004",  # Obsessive-compulsive disorder (disorder)
        "191746002",  # Psychasthenic neurosis (disorder)
        "191753006",  # Hypomanic personality disorder (disorder)
        "191765005",  # Emotionally unstable personality disorder (disorder)
        "191772006",  # Eccentric personality disorder (disorder)
        "191773001",  # Immature personality disorder (disorder)
        "191774007",  # Masochistic personality disorder (disorder)
        "191887008",  # Tobacco dependence, continuous (disorder)
        "191888003",  # Tobacco dependence, episodic (disorder)
        "191889006",  # Tobacco dependence in remission (disorder)
        "191952007",  # Somatoform autonomic dysfunction - respiratory tract (disorder)
        "191965003",  # Psychogenic skin symptoms (disorder)
        "191970005",  # Psychogenic cyclical vomiting (disorder)
        "191972002",  # Psychogenic dyspepsia (disorder)
        "191973007",  # Psychogenic constipation (disorder)
        "191980009",  # Psychogenic endocrine malfunction (disorder)
        "191990001",  # Transient childhood tic (disorder)
        "191997003",  # Persistent insomnia (disorder)
        "192003008",  # Sleep drunkenness (disorder)
        "192016008",  # Non-organic infant feeding disturbance (disorder)
        "192029008",  # Psychogenic backache (disorder)
        "192037000",  # Acute panic state due to acute stress reaction (disorder)
        "192038005",  # Acute fugue state due to acute stress reaction (disorder)
        "192041001",  # Acute situational disturbance (disorder)
        "192042008",  # Acute post-trauma stress state (disorder)
        "192044009",  # Stress reaction causing mixed disturbance of emotion and conduct (disorder)
        "192046006",  # Brief depressive adjustment reaction (disorder)
        "192049004",  # Prolonged depressive adjustment reaction (disorder)
        "192051000",  # Adolescent emancipation disorder (disorder)
        "192056005",  # Adjustment reaction with aggression (disorder)
        "192057001",  # Adjustment reaction with antisocial behavior (disorder)
        "192058006",  # Adjustment reaction with destructiveness (disorder)
        "192063005",  # Adjustment reaction with physical symptoms (disorder)
        "192064004",  # Elective mutism due to an adjustment reaction (disorder)
        "192072002",  # Organic memory impairment (disorder)
        "192073007",  # Change in personality (disorder)
        "192080009",  # Chronic depression (disorder)
        "192082001",  # Aggressive unsocial conduct disorder (disorder)
        "192097003",  # Isolated explosive disorder (disorder)
        "192099000",  # Childhood disorder of conduct and emotion (disorder)
        "192100008",  # Neurotic delinquency (disorder)
        "192108001",  # Disturbance of anxiety and fearfulness in childhood and adolescence (disorder)
        "192110004",  # Childhood and adolescent fearfulness disturbance (disorder)
        "192123006",  # Academic underachievement disorder (disorder)
        "192127007",  # Child attention deficit disorder (disorder)
        "192138007",  # Developmental dyslexia (disorder)
        "192147004",  # Mixed disorder of psychological development (disorder)
        "192362008",  # Bipolar affective disorder, current episode mixed (disorder)
        "192527004",  # Elaboration of physical symptoms for psychological reasons (disorder)
        "192562009",  # Disorder of psychological development (disorder)
        "192575009",  # Mixed disorder of scholastic skills (disorder)
        "192611004",  # Childhood phobic anxiety disorder (disorder)
        "192616009",  # Childhood or adolescent disorder of social functioning (disorder)
        "192630004",  # Psychogenic feeding disorder of infancy and childhood (disorder)
        "192631000",  # Pica of infancy and childhood (disorder)
        "19300006",  # Severe bipolar II disorder, most recent episode major depressive with psychotic features, mood-congruent (disorder)
        "193462001",  # Insomnia (disorder)
        "193756007",  # Charles Bonnet syndrome (disorder)
        "197480006",  # Anxiety disorder (disorder)
        "19766004",  # Panic disorder with agoraphobia, mild agoraphobic avoidance AND severe panic attacks (disorder)
        "19922006",  # Compulsive sexual sadism (disorder)
        "199257008",  # Mental disorders during pregnancy, childbirth and the puerperium (disorder)
        "20010003",  # Borderline personality disorder (disorder)
        "20250007",  # Severe major depression, single episode, with psychotic features, mood-incongruent (disorder)
        "20960007",  # Severe bipolar II disorder, most recent episode major depressive with psychotic features, mood-incongruent (disorder)
        "21586000",  # Munchausen's syndrome (disorder)
        "21897009",  # Generalized anxiety disorder (disorder)
        "21900002",  # Bipolar I disorder, most recent episode depressed with catatonic features (disorder)
        "21921000119103",  # Dementia co-occurrent and due to Pick's disease (disorder)
        "22121000",  # Depressed bipolar I disorder in full remission (disorder)
        "22230001",  # Panic disorder with agoraphobia, agoraphobic avoidance in partial remission AND panic attacks in full remission (disorder)
        "22381000119105",  # Primary degenerative dementia (disorder)
        "22407005",  # Bipolar II disorder, most recent episode major depressive with catatonic features (disorder)
        "22419002",  # Mood disorder with mixed features due to general medical condition (disorder)
        "229621000",  # Disorder of fluency (disorder)
        "229623002",  # Developmental dysfluency (disorder)
        "229629003",  # Idiopathic stammering (disorder)
        "229630008",  # Psychogenic stammering (disorder)
        "229632000",  # Neurogenic stammering (disorder)
        "229672009",  # Language disorder of dementia (disorder)
        "229683000",  # Motor speech disorder (disorder)
        "229699006",  # Immature articulatory praxis (disorder)
        "229700007",  # Developmental motor speech disorder (disorder)
        "229715008",  # Deficits in attention motor control and perception (disorder)
        "229733002",  # Expressive language disorder (disorder)
        "229734008",  # Expressive language delay (disorder)
        "229736005",  # Receptive language delay (disorder)
        "229740001",  # Delayed pre-verbal development (disorder)
        "229744005",  # Developmental syntactic impairment (disorder)
        "229745006",  # Developmental semantic impairment (disorder)
        "229750000",  # Lexical syntactic disorder (disorder)
        "229751001",  # Semantic-pragmatic disorder (disorder)
        "230258005",  # Amyotrophic lateral sclerosis with dementia (disorder)
        "230270009",  # Frontotemporal dementia (disorder)
        "230282000",  # Post-traumatic dementia (disorder)
        "230285003",  # Vascular dementia of acute onset (disorder)
        "230286002",  # Subcortical vascular dementia (disorder)
        "230287006",  # Mixed cortical and subcortical vascular dementia (disorder)
        "230288001",  # Semantic dementia (disorder)
        "230289009",  # Patchy dementia (disorder)
        "230335009",  # Facial tic disorder (disorder)
        "230338006",  # Gestural tic disorder (disorder)
        "230488004",  # Hypersomnia of non-organic origin (disorder)
        "230497000",  # Sleep-related head banging (disorder)
        "2312009",  # Reactive attachment disorder of infancy OR early childhood, inhibited type (disorder)
        "231437006",  # Reactive psychoses (disorder)
        "231438001",  # Presbyophrenic psychosis (disorder)
        "231439009",  # Toxic confusional state (disorder)
        "231440006",  # Delirium of mixed origin (disorder)
        "231442003",  # Organic catatonic disorder (disorder)
        "231444002",  # Organic bipolar disorder (disorder)
        "231445001",  # Organic dissociative disorder (disorder)
        "231446000",  # Organic emotionally labile disorder (disorder)
        "231449007",  # Epileptic psychosis (disorder)
        "231452004",  # Limbic epilepsy personality syndrome (disorder)
        "231454003",  # Organic pseudopsychopathic personality (disorder)
        "231485007",  # Post-schizophrenic depression (disorder)
        "231487004",  # Persistent delusional disorder (disorder)
        "231489001",  # Acute transient psychotic disorder (disorder)
        "231494001",  # Mania (disorder)
        "231495000",  # Manic stupor (disorder)
        "231496004",  # Hypomania (disorder)
        "231500002",  # Masked depression (disorder)
        "231504006",  # Mixed anxiety and depressive disorder (disorder)
        "231517009",  # Somatoform autonomic dysfunction (disorder)
        "231519007",  # Depersonalization-derealization syndrome (disorder)
        "231520001",  # Behavioral syndrome associated with physiological disturbance and physical factors (disorder)
        "231522009",  # Atypical anorexia nervosa (disorder)
        "231523004",  # Atypical bulimia nervosa (disorder)
        "231524005",  # Interictal behavior disorder (disorder)
        "231525006",  # Manipulative personality disorder (disorder)
        "231526007",  # Fanatic personality (disorder)
        "231527003",  # Explosive personality disorder (disorder)
        "231528008",  # Anxious personality disorder (disorder)
        "231532002",  # Sexual disorder (disorder)
        "231536004",  # Atypical autism (disorder)
        "231538003",  # Behavioral and emotional disorder with onset in childhood (disorder)
        "231539006",  # Adolescent - emotional problem (disorder)
        "231540008",  # Conduct disorder - in family context (disorder)
        "231541007",  # Conduct disorder - unsocialized (disorder)
        "231542000",  # Depressive conduct disorder (disorder)
        "233690008",  # Factitious asthma (disorder)
        "23560001",  # Asperger's disorder (disorder)
        "23645006",  # Organic mood disorder (disorder)
        "237349002",  # Mild postnatal depression (disorder)
        "237351003",  # Mild postnatal psychosis (disorder)
        "237352005",  # Severe postnatal psychosis (disorder)
        "23772009",  # Dysphonia of Gilles de la Tourette's syndrome (disorder)
        "238959007",  # Disorders of cutaneous image and perception (disorder)
        "238961003",  # Trichophobia (disorder)
        "238967004",  # Psychogenic sensory disturbance of skin (disorder)
        "238972008",  # Cutaneous monosymptomatic delusional psychosis (disorder)
        "238973003",  # Delusions of parasitosis (disorder)
        "238974009",  # Delusions of infestation (disorder)
        "238977002",  # Delusional hyperhidrosis (disorder)
        "238979004",  # Hyposchemazia (disorder)
        "24121004",  # Insomnia disorder related to another mental disorder (disorder)
        "24125008",  # Mental disorder in infancy (disorder)
        "2421000119107",  # Hallucinations co-occurrent and due to late onset dementia (disorder)
        "242823008",  # Intentional non-opiate analgesic overdose (disorder)
        "242824002",  # Intentional paracetamol overdose (disorder)
        "242825001",  # Intentional aspirin overdose (disorder)
        "242829007",  # Intentional diamorphine overdose (disorder)
        "242830002",  # Intentional dihydrocodeine overdose (disorder)
        "242831003",  # Intentional methadone overdose (disorder)
        "242832005",  # Intentional benzodiazepine overdose (disorder)
        "242833000",  # Intentional diazepam overdose (disorder)
        "242834006",  # Intentional chlordiazepoxide overdose (disorder)
        "242835007",  # Intentional temazepam overdose (disorder)
        "24315006",  # Factitious disorder with combined physical AND psychological symptoms (disorder)
        "247444006",  # Excoriation of skin (disorder)
        "247803002",  # Seasonal affective disorder (disorder)
        "247804008",  # Schizophrenic prodrome (disorder)
        "24781009",  # Panic disorder with agoraphobia, mild agoraphobic avoidance AND panic attacks in full remission (disorder)
        "248118000",  # Self-induced purging to lose weight (disorder)
        "248290002",  # Developmental delay (disorder)
        "249520001",  # Self-induced purging (disorder)
        "25501002",  # Social phobia (disorder)
        "25766007",  # Mixed receptive-expressive language disorder (disorder)
        "25772007",  # Multi-infarct dementia with delusions (disorder)
        "25922000",  # Major depressive disorder, single episode with postpartum onset (disorder)
        "25971005",  # Pedophilia, exclusive type (disorder)
        "26025008",  # Residual schizophrenia (disorder)
        "2618002",  # Chronic recurrent major depressive disorder (disorder)
        "26203008",  # Severe depressed bipolar I disorder with psychotic features, mood-incongruent (disorder)
        "26453000",  # Mental disorder in adolescence (disorder)
        "26516009",  # Severe mood disorder with psychotic features (disorder)
        "26665006",  # Antisocial personality disorder (disorder)
        "26852004",  # Primary degenerative dementia of the Alzheimer type, senile onset, with depression (disorder)
        "268612007",  # Senile and presenile organic psychotic conditions (disorder)
        "268617001",  # Acute schizophrenic episode (disorder)
        "268619003",  # Manic disorder, single episode (disorder)
        "268621008",  # Recurrent major depressive episodes (disorder)
        "268622001",  # Chronic paranoid psychosis (disorder)
        "268624000",  # Acute paranoid reaction (disorder)
        "268633003",  # Introverted personality disorder (disorder)
        "268650001",  # Somatoform autonomic dysfunction - gastrointestinal tract (disorder)
        "268651002",  # Psychogenic diarrhea (disorder)
        "268652009",  # Transient insomnia (disorder)
        "268661009",  # Nonaggressive unsocial conduct disorder (disorder)
        "268664001",  # Childhood emotional disorder (disorder)
        "268666004",  # Childhood and adolescent disturbance with sensitivity (disorder)
        "268667008",  # Childhood and adolescent disturbance with shyness (disorder)
        "268668003",  # Childhood and adolescent disturbance with introversion (disorder)
        "268669006",  # Childhood and adolescent disturbance with elective mutism (disorder)
        "268672004",  # Disorder of speech and language development (disorder)
        "268715000",  # Dissociative motor disorder (disorder)
        "268734000",  # Developmental expressive language disorder (disorder)
        "268957000",  # Neurotic condition, insight present (disorder)
        "270901009",  # Schizoaffective disorder, mixed type (disorder)
        "270903007",  # Lack or loss of sexual desire (disorder)
        "270905000",  # Childhood disinhibited attachment disorder (disorder)
        "271428004",  # Schizoaffective disorder, manic type (disorder)
        "271952001",  # Stress and adjustment reaction (disorder)
        "271982007",  # Intentional self poisoning (disorder)
        "273280001",  # Arizona battery for communication disorders of dementia (assessment scale)
        "273323004",  # Blessed dementia rating scale (assessment scale)
        "273367002",  # Clinical dementia rating scale (assessment scale)
        "273549005",  # Kendrick battery for detection of dementia in the elderly (assessment scale)
        "27387000",  # Subchronic disorganized schizophrenia (disorder)
        "274948002",  # Endogenous depression - recurrent (disorder)
        "274953007",  # Acute polymorphic psychotic disorder (disorder)
        "27544004",  # Developmental coordination disorder (disorder)
        "275474009",  # Psychogenic overeating (disorder)
        "276300008",  # Dissociative stupor (disorder)
        "277131000",  # Intentional non-steroidal anti-inflammatory agent overdose (disorder)
        "2776000",  # Delirium (disorder)
        "278506006",  # Involutional paranoid state (disorder)
        "278508007",  # Delusional dysmorphophobia (disorder)
        "278852008",  # Paranoid-hallucinatory epileptic psychosis (disorder)
        "278853003",  # Acute schizophrenia-like psychotic disorder (disorder)
        "278857002",  # Dementia of frontal lobe type (disorder)
        "278919001",  # Communication disorder (disorder)
        "279982005",  # Cerebral degeneration presenting primarily with dementia (disorder)
        "280032002",  # Developmental language disorder (disorder)
        "280994000",  # Chronic confusional state (disorder)
        "281004",  # Dementia associated with alcoholism (disorder)
        "2815001",  # Sexual pyromania (disorder)
        "28357009",  # Transitory postpartum mood disturbance (disorder)
        "28475009",  # Severe recurrent major depression with psychotic features (disorder)
        "28663008",  # Severe manic bipolar I disorder with psychotic features (disorder)
        "28676002",  # Mood disorder with manic features due to general medical condition (disorder)
        "286933003",  # Confusional state (disorder)
        "288081000119106",  # Behavioral insomnia of childhood, combined type (disorder)
        "288091000119109",  # Behavioral insomnia of childhood, limit setting type (disorder)
        "288101000119104",  # Behavioral insomnia of childhood, sleep onset association type (disorder)
        "288631000119104",  # Vascular dementia with behavioral disturbance (disorder)
        "28884001",  # Moderate bipolar I disorder, single manic episode (disorder)
        "290135001",  # Intentional paracetamol poisoning (disorder)
        "290145004",  # Intentional aspirin poisoning (disorder)
        "290148002",  # Intentional salicylic acid salt poisoning (disorder)
        "290151009",  # Intentional pentazocine poisoning (disorder)
        "290155000",  # Intentional phenazocine poisoning (disorder)
        "290160001",  # Intentional dextromoramide poisoning (disorder)
        "290164005",  # Intentional dextropropoxyphene poisoning (disorder)
        "290168008",  # Intentional dipipanone poisoning (disorder)
        "290171000",  # Intentional methadone poisoning (disorder)
        "290176005",  # Intentional buprenorphine poisoning (disorder)
        "290179003",  # Intentional poisoning caused by codeine (disorder)
        "290182008",  # Intentional heroin poisoning (disorder)
        "290185005",  # Intentional poisoning caused by dihydrocodeine (disorder)
        "290190008",  # Intentional nalbuphine poisoning (disorder)
        "290193005",  # Intentional morphine poisoning (disorder)
        "290199009",  # Intentional alfentanil poisoning (disorder)
        "290203009",  # Intentional fentanyl poisoning (disorder)
        "290206001",  # Intentional pethidine poisoning (disorder)
        "290210003",  # Intentional phenoperidine poisoning (disorder)
        "290214007",  # Intentional meptazinol poisoning (disorder)
        "290218005",  # Intentional levorphanol poisoning (disorder)
        "290228001",  # Intentional acemetacin poisoning (disorder)
        "290232007",  # Intentional azapropazone poisoning (disorder)
        "290236005",  # Intentional diclofenac poisoning (disorder)
        "290240001",  # Intentional etodolac poisoning (disorder)
        "290244005",  # Intentional felbinac poisoning (disorder)
        "290249000",  # Intentional fenbufen poisoning (disorder)
        "290253003",  # Intentional fenoprofen poisoning (disorder)
        "290257002",  # Intentional flurbiprofen poisoning (disorder)
        "290260009",  # Intentional ibuprofen poisoning (disorder)
        "290263006",  # Intentional indomethacin poisoning (disorder)
        "290267007",  # Intentional ketoprofen poisoning (disorder)
        "290271005",  # Intentional ketorolac poisoning (disorder)
        "290275001",  # Intentional mefenamic acid poisoning (disorder)
        "290279007",  # Intentional nabumetone poisoning (disorder)
        "290282002",  # Intentional naproxen poisoning (disorder)
        "290286004",  # Intentional nefopam poisoning (disorder)
        "290290002",  # Intentional oxyphenbutazone poisoning (disorder)
        "290293000",  # Intentional phenylbutazone poisoning (disorder)
        "290298009",  # Intentional piroxicam poisoning (disorder)
        "290302001",  # Intentional sulindac poisoning (disorder)
        "290306003",  # Intentional tenoxicam poisoning (disorder)
        "290310000",  # Intentional tiaprofenic acid poisoning (disorder)
        "290314009",  # Intentional tolmetin poisoning (disorder)
        "290319004",  # Intentional radiopharmaceutical poisoning (disorder)
        "290331002",  # Intentional magnetic resonance imaging contrast media poisoning (disorder)
        "290343001",  # Intentional bismuth compound poisoning (disorder)
        "290347000",  # Intentional sucralfate poisoning (disorder)
        "290351003",  # Intentional misoprostol poisoning (disorder)
        "290355007",  # Intentional cimetidine poisoning (disorder)
        "290359001",  # Intentional famotidine poisoning (disorder)
        "290363008",  # Intentional nizatidine poisoning (disorder)
        "290367009",  # Intentional ranitidine poisoning (disorder)
        "290372000",  # Intentional omeprazole poisoning (disorder)
        "290376002",  # Intentional lansoprazole poisoning (disorder)
        "290380007",  # Intentional carbenoxolone poisoning (disorder)
        "290384003",  # Intentional pirenzepine poisoning (disorder)
        "290388000",  # Intentional 5-aminosalicylic acid poisoning (disorder)
        "290391000",  # Intentional aluminum hydroxide poisoning (disorder)
        "290394008",  # Intentional magnesium trisilicate poisoning (disorder)
        "290398006",  # Intentional loperamide poisoning (disorder)
        "290401009",  # Intentional kaolin poisoning (disorder)
        "290404001",  # Intentional pectin poisoning (disorder)
        "290409006",  # Intentional cisapride poisoning (disorder)
        "290414005",  # Intentional nabilone poisoning (disorder)
        "290418008",  # Intentional domperidone poisoning (disorder)
        "290422003",  # Intentional metoclopramide poisoning (disorder)
        "290426000",  # Intentional 5-HT3-receptor antagonist poisoning (disorder)
        "290430002",  # Intentional bisacodyl poisoning (disorder)
        "290434006",  # Intentional danthron poisoning (disorder)
        "290438009",  # Intentional sodium picosulfate poisoning (disorder)
        "290443002",  # Intentional lactulose poisoning (disorder)
        "290446005",  # Intentional magnesium sulfate poisoning (disorder)
        "290455008",  # Intentional cascara poisoning (disorder)
        "290459002",  # Intentional senna poisoning (disorder)
        "290463009",  # Intentional docusate poisoning (disorder)
        "290466001",  # Intentional castor oil poisoning (disorder)
        "290469008",  # Intentional phenolphthalein poisoning (disorder)
        "290476003",  # Intentional antispasmodic poisoning (disorder)
        "290484004",  # Intentional nitrous oxide poisoning (disorder)
        "290489009",  # Intentional etomidate poisoning (disorder)
        "290492008",  # Intentional ketamine poisoning (disorder)
        "290496006",  # Intentional propofol poisoning (disorder)
        "290503005",  # Intentional methohexitone poisoning (disorder)
        "290508001",  # Intentional enflurane poisoning (disorder)
        "290511000",  # Intentional ether poisoning (disorder)
        "290514008",  # Intentional halothane poisoning (disorder)
        "290518006",  # Intentional isoflurane poisoning (disorder)
        "290522001",  # Intentional trichloroethylene poisoning (disorder)
        "290526003",  # Intentional desflurane poisoning (disorder)
        "290530000",  # Intentional bupivacaine poisoning (disorder)
        "290534009",  # Intentional cinchocaine poisoning (disorder)
        "290538007",  # Intentional prilocaine poisoning (disorder)
        "290541003",  # Intentional lignocaine poisoning (disorder)
        "290544006",  # Intentional cocaine poisoning (disorder)
        "290548009",  # Intentional benzocaine poisoning (disorder)
        "290552009",  # Intentional oxybuprocaine poisoning (disorder)
        "290555006",  # Intentional procaine poisoning (disorder)
        "290559000",  # Intentional proxymetacaine poisoning (disorder)
        "290568003",  # Intentional tetracaine poisoning (disorder)
        "290582003",  # Intentional mitobronitol poisoning (disorder)
        "290585001",  # Intentional busulfan poisoning (disorder)
        "290589007",  # Intentional treosulfan poisoning (disorder)
        "290592006",  # Intentional triethylene thiophosphoramide poisoning (disorder)
        "290596009",  # Intentional chlorambucil poisoning (disorder)
        "290599002",  # Intentional cyclophosphamide poisoning (disorder)
        "290604008",  # Intentional ethoglucid poisoning (disorder)
        "290608006",  # Intentional ifosfamide poisoning (disorder)
        "290612000",  # Intentional melphalan poisoning (disorder)
        "290616002",  # Intentional estramustine poisoning (disorder)
        "290620003",  # Intentional mustine poisoning (disorder)
        "290625008",  # Intentional carmustine poisoning (disorder)
        "290629002",  # Intentional lomustine poisoning (disorder)
        "290634003",  # Intentional dacarbazine poisoning (disorder)
        "290638000",  # Intentional dactinomycin poisoning (disorder)
        "290641009",  # Intentional bleomycin poisoning (disorder)
        "290644001",  # Intentional mitomycin poisoning (disorder)
        "290648003",  # Intentional plicamycin poisoning (disorder)
        "290654002",  # Intentional aclarubicin poisoning (disorder)
        "290658004",  # Intentional mitozantrone poisoning (disorder)
        "290662005",  # Intentional doxorubicin poisoning (disorder)
        "290666008",  # Intentional epirubicin poisoning (disorder)
        "290670000",  # Intentional idarubicin poisoning (disorder)
        "290673003",  # Intentional daunorubicin poisoning (disorder)
        "290678007",  # Intentional mercuric oxide poisoning (disorder)
        "290682009",  # Intentional methotrexate poisoning (disorder)
        "290685006",  # Intentional mercaptopurine poisoning (disorder)
        "290689000",  # Intentional thioguanine poisoning (disorder)
        "290694000",  # Intentional pentostatin poisoning (disorder)
        "290697007",  # Intentional cytarabine poisoning (disorder)
        "290700006",  # Intentional fluorouracil poisoning (disorder)
        "290705001",  # Intentional etoposide poisoning (disorder)
        "290709007",  # Intentional amsacrine poisoning (disorder)
        "290713000",  # Intentional carboplatin poisoning (disorder)
        "290717004",  # Intentional cisplatin poisoning (disorder)
        "290721006",  # Intentional hydroxyurea poisoning (disorder)
        "290725002",  # Intentional procarbazine poisoning (disorder)
        "290729008",  # Intentional razoxane poisoning (disorder)
        "290733001",  # Intentional crisantaspase poisoning (disorder)
        "290737000",  # Intentional paclitaxel poisoning (disorder)
        "290741001",  # Intentional fludarabine poisoning (disorder)
        "290745005",  # Intentional aminoglutethimide poisoning (disorder)
        "290750004",  # Intentional trilostane poisoning (disorder)
        "290754008",  # Intentional tamoxifen poisoning (disorder)
        "290758006",  # Intentional formestane poisoning (disorder)
        "290763005",  # Intentional vinblastine poisoning (disorder)
        "290767006",  # Intentional vincristine poisoning (disorder)
        "290771009",  # Intentional vindesine poisoning (disorder)
        "290776004",  # Intentional cyclosporin poisoning (disorder)
        "290779006",  # Intentional azathioprine poisoning (disorder)
        "290786003",  # Intentional levodopa poisoning (disorder)
        "290789005",  # Intentional amantadine poisoning (disorder)
        "290793004",  # Intentional lysuride poisoning (disorder)
        "290797003",  # Intentional bromocriptine poisoning (disorder)
        "290800001",  # Intentional ethopropazine poisoning (disorder)
        "290804005",  # Intentional lithium poisoning (disorder)
        "290808008",  # Intentional amitriptyline poisoning (disorder)
        "290812002",  # Intentional amoxapine poisoning (disorder)
        "290816004",  # Intentional butriptyline poisoning (disorder)
        "290820000",  # Intentional clomipramine poisoning (disorder)
        "290824009",  # Intentional desipramine poisoning (disorder)
        "290828007",  # Intentional dothiepin poisoning (disorder)
        "290832001",  # Intentional doxepin poisoning (disorder)
        "290835004",  # Intentional imipramine poisoning (disorder)
        "290839005",  # Intentional iprindole poisoning (disorder)
        "290843009",  # Intentional lofepramine poisoning (disorder)
        "290847005",  # Intentional nortriptyline poisoning (disorder)
        "290851007",  # Intentional protriptyline poisoning (disorder)
        "290855003",  # Intentional trimipramine poisoning (disorder)
        "290862007",  # Intentional phenelzine poisoning (disorder)
        "290866005",  # Intentional iproniazid poisoning (disorder)
        "290870002",  # Intentional isocarboxazid poisoning (disorder)
        "290874006",  # Intentional tranylcypromine poisoning (disorder)
        "290878009",  # Intentional moclobemide poisoning (disorder)
        "290882006",  # Intentional tryptophan poisoning (disorder)
        "290886009",  # Intentional venlafaxine poisoning (disorder)
        "290891005",  # Intentional sertraline poisoning (disorder)
        "290895001",  # Intentional paroxetine poisoning (disorder)
        "290899007",  # Intentional nefazodone poisoning (disorder)
        "290903000",  # Intentional citalopram poisoning (disorder)
        "290908009",  # Intentional fluoxetine poisoning (disorder)
        "290912003",  # Intentional fluvoxamine poisoning (disorder)
        "290917009",  # Intentional maprotiline poisoning (disorder)
        "290921002",  # Intentional mianserin poisoning (disorder)
        "290925006",  # Intentional trazodone poisoning (disorder)
        "290929000",  # Intentional viloxazine poisoning (disorder)
        "290933007",  # Intentional beclamide poisoning (disorder)
        "290937008",  # Intentional lamotrigine poisoning (disorder)
        "290941007",  # Intentional piracetam poisoning (disorder)
        "290945003",  # Intentional gabapentin poisoning (disorder)
        "290953006",  # Intentional methylphenobarbitone poisoning (disorder)
        "290956003",  # Intentional phenobarbitone poisoning (disorder)
        "290959005",  # Intentional primidone poisoning (disorder)
        "290962008",  # Intentional poisoning caused by carbamazepine (disorder)
        "290966006",  # Intentional vigabatrin poisoning (disorder)
        "290969004",  # Intentional phenytoin poisoning (disorder)
        "290972006",  # Intentional succinimide poisoning (disorder)
        "290975008",  # Intentional ethosuximide poisoning (disorder)
        "290978005",  # Intentional phensuximide poisoning (disorder)
        "290982007",  # Intentional clonazepam poisoning (disorder)
        "290987001",  # Intentional zopiclone poisoning (disorder)
        "290991006",  # Intentional zolpidem poisoning (disorder)
        "290996001",  # Intentional chlormezanone poisoning (disorder)
        "291000007",  # Intentional methyprylone poisoning (disorder)
        "291003009",  # Intentional paraldehyde poisoning (disorder)
        "291006001",  # Intentional amylobarbitone poisoning (disorder)
        "291010003",  # Intentional butabarbitone poisoning (disorder)
        "291017000",  # Intentional cyclobarbitone poisoning (disorder)
        "291020008",  # Intentional quinalbarbitone poisoning (disorder)
        "291023005",  # Intentional barbitone poisoning (disorder)
        "291026002",  # Intentional pentobarbitone poisoning (disorder)
        "291030004",  # Intentional flunitrazepam poisoning (disorder)
        "291033002",  # Intentional flurazepam poisoning (disorder)
        "291037001",  # Intentional loprazolam poisoning (disorder)
        "291041002",  # Intentional lormetazepam poisoning (disorder)
        "291044005",  # Intentional nitrazepam poisoning (disorder)
        "291048008",  # Intentional triazolam poisoning (disorder)
        "291052008",  # Intentional alprazolam poisoning (disorder)
        "291056006",  # Intentional bromazepam poisoning (disorder)
        "291059004",  # Intentional chlordiazepoxide poisoning (disorder)
        "291063006",  # Intentional clobazam poisoning (disorder)
        "291071005",  # Intentional ketazolam poisoning (disorder)
        "291074002",  # Intentional medazepam poisoning (disorder)
        "291078004",  # Intentional oxazepam poisoning (disorder)
        "291082002",  # Intentional prazepam poisoning (disorder)
        "291086004",  # Intentional midazolam poisoning (disorder)
        "291089006",  # Intentional diazepam poisoning (disorder)
        "291092005",  # Intentional lorazepam poisoning (disorder)
        "291095007",  # Intentional poisoning caused by temazepam (disorder)
        "291098009",  # Intentional meprobamate poisoning (disorder)
        "291102001",  # Intentional chloral hydrate poisoning (disorder)
        "291106003",  # Intentional dichloralphenazone poisoning (disorder)
        "291115005",  # Intentional buspirone poisoning (disorder)
        "291119004",  # Intentional chlormethiazole poisoning (disorder)
        "291124001",  # Intentional sulpiride poisoning (disorder)
        "291128003",  # Intentional loxapine poisoning (disorder)
        "291132009",  # Intentional clozapine poisoning (disorder)
        "291136007",  # Intentional risperidone poisoning (disorder)
        "291140003",  # Intentional tetrabenazine poisoning (disorder)
        "291144007",  # Intentional benperidol poisoning (disorder)
        "291147000",  # Intentional trifluperidol poisoning (disorder)
        "291150002",  # Intentional haloperidol poisoning (disorder)
        "291154006",  # Intentional droperidol poisoning (disorder)
        "291159001",  # Intentional pimozide poisoning (disorder)
        "291163008",  # Intentional fluspirilene poisoning (disorder)
        "291167009",  # Intentional methotrimeprazine poisoning (disorder)
        "291171007",  # Intentional pericyazine poisoning (disorder)
        "291174004",  # Intentional fluphenazine poisoning (disorder)
        "291178001",  # Intentional thiethylperazine poisoning (disorder)
        "291181006",  # Intentional chlorpromazine poisoning (disorder)
        "291185002",  # Intentional pipothiazine poisoning (disorder)
        "291188000",  # Intentional promazine poisoning (disorder)
        "291192007",  # Intentional thioridazine poisoning (disorder)
        "291196005",  # Intentional perphenazine poisoning (disorder)
        "291199003",  # Intentional prochlorperazine poisoning (disorder)
        "291203003",  # Intentional trifluoperazine poisoning (disorder)
        "291208007",  # Intentional chlorprothixene poisoning (disorder)
        "291213006",  # Intentional flupenthixol decanoate poisoning (disorder)
        "291217007",  # Intentional zuclopenthixol decanoate poisoning (disorder)
        "291221000",  # Intentional zuclopenthixol poisoning (disorder)
        "291225009",  # Intentional flupenthixol poisoning (disorder)
        "291229003",  # Intentional oxypertine poisoning (disorder)
        "291233005",  # Intentional remoxipride poisoning (disorder)
        "291238001",  # Intentional selegiline poisoning (disorder)
        "291247009",  # Intentional cannabis poisoning (disorder)
        "291250007",  # Intentional poisoning by lysergic acid (disorder)
        "291253009",  # Intentional psilocybin poisoning (disorder)
        "291256001",  # Intentional mescaline poisoning (disorder)
        "291263001",  # Intentional poisoning caused by crack cocaine (disorder)
        "291266009",  # Intentional caffeine poisoning (disorder)
        "291270001",  # Intentional atenolol poisoning (disorder)
        "291273004",  # Intentional propranolol poisoning (disorder)
        "291276007",  # Intentional practolol poisoning (disorder)
        "291282005",  # Intentional phenoxybenzamine poisoning (disorder)
        "291285007",  # Intentional nicotine poisoning (disorder)
        "291288009",  # Intentional poisoning caused by calcium-channel blocker (disorder)
        "291291009",  # Intentional pilocarpine poisoning (disorder)
        "291294001",  # Intentional acetylcholine poisoning (disorder)
        "291297008",  # Intentional anticholinesterase poisoning (disorder)
        "291301004",  # Intentional metaraminol poisoning (disorder)
        "291306009",  # Intentional salbutamol poisoning (disorder)
        "291309002",  # Intentional orciprenaline poisoning (disorder)
        "291314003",  # Intentional clonidine poisoning (disorder)
        "291317005",  # Intentional adrenalin poisoning (disorder)
        "291320002",  # Intentional norepinephrine poisoning (disorder)
        "291323000",  # Intentional hyoscine poisoning (disorder)
        "291326008",  # Intentional atropine poisoning (disorder)
        "291329001",  # Intentional homatropine poisoning (disorder)
        "291332003",  # Intentional acetylcysteine poisoning (disorder)
        "291336000",  # Intentional nikethamide poisoning (disorder)
        "291340009",  # Intentional chlorpheniramine poisoning (disorder)
        "291343006",  # Intentional diphenhydramine poisoning (disorder)
        "291346003",  # Intentional diphenylpyraline poisoning (disorder)
        "291349005",  # Intentional dextromethorphan poisoning (disorder)
        "291352002",  # Intentional guaifenesin poisoning (disorder)
        "291355000",  # Intentional terpin hydrate poisoning (disorder)
        "291361002",  # Intentional aminophylline poisoning (disorder)
        "291364005",  # Intentional theophylline poisoning (disorder)
        "291379003",  # Intentional hair treatment poisoning (disorder)
        "291383003",  # Intentional allopurinol poisoning (disorder)
        "291386006",  # Intentional colchicine poisoning (disorder)
        "291389004",  # Intentional probenecid poisoning (disorder)
        "291392000",  # Intentional gold salt poisoning (disorder)
        "291395003",  # Intentional antirheumatic poisoning (disorder)
        "291399009",  # Intentional prostaglandin poisoning (disorder)
        "291403000",  # Intentional naloxone poisoning (disorder)
        "291406008",  # Intentional levallorphan poisoning (disorder)
        "291409001",  # Intentional nalorphine poisoning (disorder)
        "291420001",  # Intentional alternative medicine poisoning (navigational concept)
        "291421002",  # Alternative medicine poisoning of undetermined intent (navigational concept)
        "291424005",  # Intentional flucytosine poisoning (disorder)
        "291427003",  # Intentional griseofulvin poisoning (disorder)
        "291430005",  # Intentional amphotericin B poisoning (disorder)
        "291433007",  # Intentional nystatin poisoning (disorder)
        "291436004",  # Intentional trichomycin poisoning (disorder)
        "291439006",  # Intentional idoxuridine poisoning (disorder)
        "291442000",  # Intentional pyrimethamine poisoning (disorder)
        "291445003",  # Intentional chloroquine poisoning (disorder)
        "291448001",  # Intentional primaquine poisoning (disorder)
        "291452001",  # Intentional quinine poisoning (disorder)
        "291456003",  # Intentional mefloquine poisoning (disorder)
        "291459005",  # Intentional proguanil poisoning (disorder)
        "291462008",  # Intentional cycloguanil poisoning (disorder)
        "291468007",  # Intentional thiabendazole poisoning (disorder)
        "291471004",  # Intentional hexylresorcinol poisoning (disorder)
        "291475008",  # Intentional kanamycin poisoning (disorder)
        "291478005",  # Intentional streptomycin poisoning (disorder)
        "291482007",  # Intentional gentamicin poisoning (disorder)
        "291486005",  # Intentional tobramycin poisoning (disorder)
        "291490007",  # Intentional netilmicin poisoning (disorder)
        "291493009",  # Intentional erythromycin poisoning (disorder)
        "291497005",  # Intentional azithromycin poisoning (disorder)
        "291501000",  # Intentional clarithromycin poisoning (disorder)
        "291504008",  # Intentional oleandomycin poisoning (disorder)
        "291507001",  # Intentional spiramycin poisoning (disorder)
        "291516002",  # Intentional spectinomycin poisoning (disorder)
        "291520003",  # Intentional vancomycin poisoning (disorder)
        "291524007",  # Intentional trimethoprim poisoning (disorder)
        "291527000",  # Intentional nitrofuran derivative poisoning (disorder)
        "291531006",  # Intentional fusidic acid poisoning (disorder)
        "291538000",  # Intentional ampicillin poisoning (disorder)
        "291541009",  # Intentional cloxacillin poisoning (disorder)
        "291544001",  # Intentional carbenicillin poisoning (disorder)
        "291547008",  # Intentional penicillin G poisoning (disorder)
        "291551005",  # Intentional flucloxacillin poisoning (disorder)
        "291555001",  # Intentional piperacillin poisoning (disorder)
        "291560002",  # Intentional cefadroxil poisoning (disorder)
        "291563000",  # Intentional cephalexin poisoning (disorder)
        "291566008",  # Intentional cephalothin poisoning (disorder)
        "291570000",  # Intentional cephazolin poisoning (disorder)
        "291574009",  # Intentional cephradine poisoning (disorder)
        "291578007",  # Intentional latamoxef poisoning (disorder)
        "291583004",  # Intentional cefaclor poisoning (disorder)
        "291587003",  # Intentional cefuroxime poisoning (disorder)
        "291591008",  # Intentional cephamandole poisoning (disorder)
        "291596003",  # Intentional cefotaxime poisoning (disorder)
        "291600008",  # Intentional ceftazidime poisoning (disorder)
        "291604004",  # Intentional ceftizoxime poisoning (disorder)
        "291608001",  # Intentional cefixime poisoning (disorder)
        "291613002",  # Intentional cefodizime poisoning (disorder)
        "291617001",  # Intentional cefpodoxime poisoning (disorder)
        "291621008",  # Intentional ceftriaxone poisoning (disorder)
        "291625004",  # Intentional ceftibuten poisoning (disorder)
        "291629005",  # Intentional cefsulodin poisoning (disorder)
        "291634009",  # Intentional cefpirome poisoning (disorder)
        "291637002",  # Intentional cephaloridine poisoning (disorder)
        "291640002",  # Intentional sulfadiazine poisoning (disorder)
        "291643000",  # Intentional sulfafurazole poisoning (disorder)
        "291646008",  # Intentional sulfamethoxazole poisoning (disorder)
        "291649001",  # Intentional doxycycline poisoning (disorder)
        "291652009",  # Intentional minocycline poisoning (disorder)
        "291655006",  # Intentional oxytetracycline poisoning (disorder)
        "291658008",  # Intentional tetracycline poisoning (disorder)
        "291662002",  # Intentional chloramphenicol poisoning (disorder)
        "291671006",  # Intentional hydroxyquinoline poisoning (disorder)
        "291674003",  # Intentional diiodohydroxyquinoline poisoning (disorder)
        "291677005",  # Intentional rifampin poisoning (disorder)
        "291680006",  # Intentional isoniazid poisoning (disorder)
        "291683008",  # Intentional ethambutol poisoning (disorder)
        "291686000",  # Intentional cycloserine poisoning (disorder)
        "291693001",  # Intentional ethionamide poisoning (disorder)
        "291696009",  # Intentional para-aminosalicylic acid poisoning (disorder)
        "291699002",  # Intentional sulfone poisoning (disorder)
        "291703004",  # Intentional pesticide product poisoning (disorder)
        "291783001",  # Intentional thiouracil poisoning (disorder)
        "291787000",  # Intentional carbimazole poisoning (disorder)
        "291797009",  # Intentional fluorinated corticosteroid poisoning (disorder)
        "291800006",  # Intentional glucagon poisoning (disorder)
        "291803008",  # Intentional insulin poisoning (disorder)
        "291807009",  # Intentional acetohexamide poisoning (disorder)
        "291810002",  # Intentional chlorpropamide poisoning (disorder)
        "291813000",  # Intentional tolbutamide poisoning (disorder)
        "291817004",  # Intentional poisoning caused by glibenclamide (disorder)
        "291820007",  # Intentional poisoning caused by metformin (disorder)
        "291823009",  # Intentional phenformin poisoning (disorder)
        "291827005",  # Intentional progestogen poisoning (disorder)
        "291833001",  # Intentional estrogen poisoning (disorder)
        "291840000",  # Intentional testosterone poisoning (disorder)
        "291844009",  # Intentional nandrolone poisoning (disorder)
        "291847002",  # Intentional oxymetholone poisoning (disorder)
        "291850004",  # Intentional methandriol poisoning (disorder)
        "291853002",  # Intentional liothyronine poisoning (disorder)
        "291856005",  # Intentional thyroxin poisoning (disorder)
        "291862000",  # Intentional thyroglobulin poisoning (disorder)
        "291866002",  # Intentional corticotrophin poisoning (disorder)
        "291869009",  # Intentional gonadotrophin poisoning (disorder)
        "291872002",  # Intentional oxytocin poisoning (disorder)
        "291879006",  # Intentional thyrotrophic hormone poisoning (disorder)
        "291882001",  # Intentional vasopressin poisoning (disorder)
        "291888002",  # Intentional macromolecular blood substitute poisoning (disorder)
        "291891002",  # Intentional blood plasma poisoning (disorder)
        "291894005",  # Intentional human fibrinogen poisoning (disorder)
        "291900005",  # Intentional coumarin poisoning (disorder)
        "291903007",  # Intentional heparin poisoning (disorder)
        "291906004",  # Intentional phenindione poisoning (disorder)
        "291909006",  # Intentional aminocaproic acid poisoning (disorder)
        "291913004",  # Intentional ferrous sulfate poisoning (disorder)
        "291920006",  # Intentional iodide poisoning (disorder)
        "291923008",  # Intentional vitamin A poisoning (disorder)
        "291926000",  # Intentional vitamin D poisoning (disorder)
        "291929007",  # Intentional vitamin K poisoning (disorder)
        "291933000",  # Intentional folic acid poisoning (disorder)
        "291939001",  # Intentional electrolyte agent poisoning (disorder)
        "291942007",  # Intentional clofibrate poisoning (disorder)
        "291946005",  # Intentional disopyramide poisoning (disorder)
        "291949003",  # Intentional quinidine poisoning (disorder)
        "291952006",  # Intentional procainamide poisoning (disorder)
        "291956009",  # Intentional amiodarone poisoning (disorder)
        "291961006",  # Intentional bendrofluazide poisoning (disorder)
        "291964003",  # Intentional chlorothiazide poisoning (disorder)
        "291971008",  # Intentional furosemide poisoning (disorder)
        "291982000",  # Intentional acetazolamide poisoning (disorder)
        "291986002",  # Intentional guanethidine poisoning (disorder)
        "291989009",  # Intentional poisoning caused by angiotensin-converting enzyme inhibitor (disorder)
        "291993003",  # Intentional digoxin poisoning (disorder)
        "291997002",  # Intentional phosphodiesterase inhibitor poisoning (disorder)
        "292001009",  # Intentional ergot alkaloid poisoning (disorder)
        "292005000",  # Intentional diazoxide poisoning (disorder)
        "292009006",  # Intentional hydralazine poisoning (disorder)
        "292012009",  # Intentional dipyridamole poisoning (disorder)
        "292015006",  # Intentional nitrate poisoning (disorder)
        "292020006",  # Intentional nitrite poisoning (disorder)
        "292024002",  # Intentional streptodornase poisoning (disorder)
        "292027009",  # Intentional streptokinase poisoning (disorder)
        "292030002",  # Intentional urokinase poisoning (disorder)
        "292033000",  # Intentional penicillinase poisoning (disorder)
        "292036008",  # Intentional spermicide poisoning (disorder)
        "293671000119109",  # Behavioral disturbance due to multi-infarct dementia (disorder)
        "295142004",  # Intentional pentazocine overdose (disorder)
        "295146001",  # Intentional phenazocine overdose (disorder)
        "295151007",  # Intentional dextromoramide overdose (disorder)
        "295155003",  # Intentional dextropropoxyphene overdose (disorder)
        "295159009",  # Intentional dipipanone overdose (disorder)
        "295168006",  # Intentional buprenorphine overdose (disorder)
        "295172005",  # Intentional overdose by codeine (disorder)
        "295182006",  # Intentional nalbuphine overdose (disorder)
        "295186009",  # Intentional morphine overdose (disorder)
        "295191005",  # Intentional alfentanil overdose (disorder)
        "295195001",  # Intentional fentanyl overdose (disorder)
        "295199007",  # Intentional pethidine overdose (disorder)
        "295203007",  # Intentional phenoperidine overdose (disorder)
        "295207008",  # Intentional meptazinol overdose (disorder)
        "295211002",  # Intentional levorphanol overdose (disorder)
        "295220006",  # Intentional acemetacin overdose (disorder)
        "295224002",  # Intentional azapropazone overdose (disorder)
        "295228004",  # Intentional diclofenac overdose (disorder)
        "295232005",  # Intentional etodolac overdose (disorder)
        "295236008",  # Intentional felbinac overdose (disorder)
        "295240004",  # Intentional fenbufen overdose (disorder)
        "295244008",  # Intentional fenoprofen overdose (disorder)
        "295248006",  # Intentional flurbiprofen overdose (disorder)
        "295252006",  # Intentional ibuprofen overdose (disorder)
        "295256009",  # Intentional indomethacin overdose (disorder)
        "295260007",  # Intentional ketoprofen overdose (disorder)
        "295265002",  # Intentional ketorolac overdose (disorder)
        "295269008",  # Intentional mefenamic acid overdose (disorder)
        "295273006",  # Intentional nabumetone overdose (disorder)
        "295277007",  # Intentional naproxen overdose (disorder)
        "295281007",  # Intentional nefopam overdose (disorder)
        "295285003",  # Intentional oxyphenbutazone overdose (disorder)
        "295289009",  # Intentional phenylbutazone overdose (disorder)
        "295293003",  # Intentional piroxicam overdose (disorder)
        "295297002",  # Intentional sulindac overdose (disorder)
        "295301006",  # Intentional tenoxicam overdose (disorder)
        "295305002",  # Intentional tiaprofenic acid overdose (disorder)
        "295309008",  # Intentional tolmetin overdose (disorder)
        "295317000",  # Intentional radiopharmaceutical overdose (disorder)
        "295322000",  # Intentional X-ray diagnostic contrast media overdose (disorder)
        "295330004",  # Intentional magnetic resonance imaging contrast media overdose (disorder)
        "295336005",  # Intentional bismuth compound overdose (disorder)
        "295340001",  # Intentional sucralfate overdose (disorder)
        "295344005",  # Intentional liquorice overdose (disorder)
        "295348008",  # Intentional misoprostol overdose (disorder)
        "295353003",  # Intentional cimetidine overdose (disorder)
        "295357002",  # Intentional famotidine overdose (disorder)
        "295362001",  # Intentional nizatidine overdose (disorder)
        "295367007",  # Intentional ranitidine overdose (disorder)
        "295369005",  # Intentional overdose of H2 antagonist (disorder)
        "295374002",  # Intentional omeprazole overdose (disorder)
        "295378004",  # Intentional lansoprazole overdose (disorder)
        "295382002",  # Intentional carbenoxolone overdose (disorder)
        "295386004",  # Intentional pirenzepine overdose (disorder)
        "295390002",  # Intentional 5-aminosalicylic acid overdose (disorder)
        "295395007",  # Intentional aluminum hydroxide overdose (disorder)
        "295399001",  # Intentional magnesium trisilicate overdose (disorder)
        "295403005",  # Intentional loperamide overdose (disorder)
        "295407006",  # Intentional kaolin overdose (disorder)
        "295412007",  # Intentional cisapride overdose (disorder)
        "295417001",  # Intentional nabilone overdose (disorder)
        "295421008",  # Intentional domperidone overdose (disorder)
        "295425004",  # Intentional metoclopramide overdose (disorder)
        "295429005",  # Intentional 5-hydroxytryptamine-3-receptor antagonist overdose (disorder)
        "295434009",  # Intentional bisacodyl overdose (disorder)
        "295438007",  # Intentional danthron overdose (disorder)
        "295442005",  # Intentional sodium picosulfate overdose (disorder)
        "295446008",  # Intentional lactulose overdose (disorder)
        "295450001",  # Intentional magnesium sulfate overdose (disorder)
        "295454005",  # Intentional bulk-forming laxative overdose (disorder)
        "295458008",  # Intentional anthraquinone laxative overdose (disorder)
        "295462002",  # Intentional cascara overdose (disorder)
        "295466004",  # Intentional senna overdose (disorder)
        "295471006",  # Intentional docusate overdose (disorder)
        "295476001",  # Intentional castor oil overdose (disorder)
        "295480006",  # Intentional phenolphthalein overdose (disorder)
        "295489007",  # Intentional antispasmodic overdose (disorder)
        "295499002",  # Intentional nitrous oxide overdose (disorder)
        "295505001",  # Intentional etomidate overdose (disorder)
        "295510002",  # Intentional ketamine overdose (disorder)
        "295514006",  # Intentional propofol overdose (disorder)
        "295522004",  # Intentional methohexitone overdose (disorder)
        "295527005",  # Intentional enflurane overdose (disorder)
        "295535008",  # Intentional halothane overdose (disorder)
        "295539002",  # Intentional isoflurane overdose (disorder)
        "295543003",  # Intentional trichloroethylene overdose (disorder)
        "295547002",  # Intentional desflurane overdose (disorder)
        "295552007",  # Intentional bupivacaine overdose (disorder)
        "295556005",  # Intentional cinchocaine overdose (disorder)
        "295560008",  # Intentional prilocaine overdose (disorder)
        "295564004",  # Intentional lignocaine overdose (disorder)
        "295573007",  # Intentional benzocaine overdose (disorder)
        "295577008",  # Intentional oxybuprocaine overdose (disorder)
        "295581008",  # Intentional procaine overdose (disorder)
        "295585004",  # Intentional proxymetacaine overdose (disorder)
        "295595006",  # Intentional immunostimulant overdose (disorder)
        "295601003",  # Intentional mitobronitol overdose (disorder)
        "295605007",  # Intentional busulfan overdose (disorder)
        "295609001",  # Intentional treosulfan overdose (disorder)
        "295613008",  # Intentional thiotepa overdose (disorder)
        "295618004",  # Intentional chlorambucil overdose (disorder)
        "295622009",  # Intentional cyclophosphamide overdose (disorder)
        "295626007",  # Intentional ethoglucid overdose (disorder)
        "295630005",  # Intentional ifosfamide overdose (disorder)
        "295634001",  # Intentional melphalan overdose (disorder)
        "295638003",  # Intentional estramustine overdose (disorder)
        "295642000",  # Intentional mustine overdose (disorder)
        "295647006",  # Intentional carmustine overdose (disorder)
        "295651008",  # Intentional lomustine overdose (disorder)
        "295656003",  # Intentional dacarbazine overdose (disorder)
        "295661001",  # Intentional dactinomycin overdose (disorder)
        "295665005",  # Intentional bleomycin overdose (disorder)
        "295669004",  # Intentional mitomycin overdose (disorder)
        "295674007",  # Intentional plicamycin overdose (disorder)
        "295678005",  # Intentional aclarubicin overdose (disorder)
        "295682007",  # Intentional mitozantrone overdose (disorder)
        "295686005",  # Intentional doxorubicin overdose (disorder)
        "295690007",  # Intentional epirubicin overdose (disorder)
        "295694003",  # Intentional idarubicin overdose (disorder)
        "295699008",  # Intentional mercuric oxide overdose (disorder)
        "295703006",  # Intentional methotrexate overdose (disorder)
        "295707007",  # Intentional mercaptopurine overdose (disorder)
        "295711001",  # Intentional thioguanine overdose (disorder)
        "295715005",  # Intentional pentostatin overdose (disorder)
        "295720005",  # Intentional cytarabine overdose (disorder)
        "295725000",  # Intentional fluorouracil overdose (disorder)
        "295729006",  # Intentional etoposide overdose (disorder)
        "295733004",  # Intentional amsacrine overdose (disorder)
        "295737003",  # Intentional carboplatin overdose (disorder)
        "295741004",  # Intentional cisplatin overdose (disorder)
        "295745008",  # Intentional hydroxyurea overdose (disorder)
        "295749002",  # Intentional procarbazine overdose (disorder)
        "295753000",  # Intentional razoxane overdose (disorder)
        "295757004",  # Intentional crisantaspase overdose (disorder)
        "295762003",  # Intentional paclitaxel overdose (disorder)
        "295766000",  # Intentional fludarabine overdose (disorder)
        "295770008",  # Intentional aminoglutethimide overdose (disorder)
        "295776002",  # Intentional trilostane overdose (disorder)
        "295780007",  # Intentional tamoxifen overdose (disorder)
        "295784003",  # Intentional formestane overdose (disorder)
        "295789008",  # Intentional vinblastine overdose (disorder)
        "295793002",  # Intentional vincristine overdose (disorder)
        "295797001",  # Intentional vindesine overdose (disorder)
        "295802007",  # Intentional cyclosporin overdose (disorder)
        "295806005",  # Intentional azathioprine overdose (disorder)
        "295811007",  # Intentional central appetite depressant overdose (disorder)
        "295816002",  # Intentional levodopa overdose (disorder)
        "295820003",  # Intentional amantadine overdose (disorder)
        "295824007",  # Intentional lysuride overdose (disorder)
        "295828005",  # Intentional bromocriptine overdose (disorder)
        "295837005",  # Intentional amitriptyline overdose (disorder)
        "295841009",  # Intentional amoxapine overdose (disorder)
        "295845000",  # Intentional butriptyline overdose (disorder)
        "295849006",  # Intentional clomipramine overdose (disorder)
        "295854002",  # Intentional desipramine overdose (disorder)
        "295858004",  # Intentional dothiepin overdose (disorder)
        "295862005",  # Intentional doxepin overdose (disorder)
        "295866008",  # Intentional imipramine overdose (disorder)
        "295870000",  # Intentional iprindole overdose (disorder)
        "295874009",  # Intentional lofepramine overdose (disorder)
        "295879004",  # Intentional nortriptyline overdose (disorder)
        "295883004",  # Intentional protriptyline overdose (disorder)
        "295887003",  # Intentional trimipramine overdose (disorder)
        "295892001",  # Intentional phenelzine overdose (disorder)
        "295896003",  # Intentional iproniazid overdose (disorder)
        "295900000",  # Intentional isocarboxazid overdose (disorder)
        "295904009",  # Intentional tranylcypromine overdose (disorder)
        "295908007",  # Intentional moclobemide overdose (disorder)
        "295912001",  # Intentional tryptophan overdose (disorder)
        "295916003",  # Intentional venlafaxine overdose (disorder)
        "295921000",  # Intentional sertraline overdose (disorder)
        "295925009",  # Intentional paroxetine overdose (disorder)
        "295929003",  # Intentional nefazodone overdose (disorder)
        "295933005",  # Intentional citalopram overdose (disorder)
        "295937006",  # Intentional fluoxetine overdose (disorder)
        "295941005",  # Intentional fluvoxamine overdose (disorder)
        "295946000",  # Intentional maprotiline overdose (disorder)
        "295950007",  # Intentional mianserin overdose (disorder)
        "295954003",  # Intentional trazodone overdose (disorder)
        "295958000",  # Intentional viloxazine overdose (disorder)
        "295963001",  # Intentional beclamide overdose (disorder)
        "295967000",  # Intentional lamotrigine overdose (disorder)
        "295971002",  # Intentional piracetam overdose (disorder)
        "295975006",  # Intentional gabapentin overdose (disorder)
        "295985007",  # Intentional methylphenobarbitone overdose (disorder)
        "295989001",  # Intentional phenobarbitone overdose (disorder)
        "29599000",  # Chronic undifferentiated schizophrenia (disorder)
        "295993007",  # Intentional primidone overdose (disorder)
        "295997008",  # Intentional overdose by carbamazepine (disorder)
        "296001007",  # Intentional vigabatrin overdose (disorder)
        "296004004",  # Intentional phenytoin overdose (disorder)
        "296008001",  # Intentional ethosuximide overdose (disorder)
        "296012007",  # Intentional clonazepam overdose (disorder)
        "296018006",  # Intentional zopiclone overdose (disorder)
        "296022001",  # Intentional zolpidem overdose (disorder)
        "296026003",  # Intentional chlormezanone overdose (disorder)
        "296030000",  # Intentional methyprylone overdose (disorder)
        "296034009",  # Intentional paraldehyde overdose (disorder)
        "296039004",  # Intentional amylobarbitone overdose (disorder)
        "296043000",  # Intentional butabarbitone overdose (disorder)
        "296047004",  # Intentional cyclobarbitone overdose (disorder)
        "296051002",  # Intentional quinalbarbitone overdose (disorder)
        "296056007",  # Intentional flunitrazepam overdose (disorder)
        "296060005",  # Intentional flurazepam overdose (disorder)
        "296064001",  # Intentional loprazolam overdose (disorder)
        "296068003",  # Intentional lormetazepam overdose (disorder)
        "296072004",  # Intentional nitrazepam overdose (disorder)
        "296076001",  # Intentional triazolam overdose (disorder)
        "296081005",  # Intentional alprazolam overdose (disorder)
        "296085001",  # Intentional bromazepam overdose (disorder)
        "296092006",  # Intentional clobazam overdose (disorder)
        "296100005",  # Intentional ketazolam overdose (disorder)
        "296104001",  # Intentional medazepam overdose (disorder)
        "296108003",  # Intentional oxazepam overdose (disorder)
        "296112009",  # Intentional prazepam overdose (disorder)
        "296116007",  # Intentional midazolam overdose (disorder)
        "296123008",  # Intentional lorazepam overdose (disorder)
        "296133000",  # Intentional meprobamate overdose (disorder)
        "296138009",  # Intentional chloral hydrate overdose (disorder)
        "296142007",  # Intentional dichloralphenazone overdose (disorder)
        "296150003",  # Intentional buspirone overdose (disorder)
        "296154007",  # Intentional chlormethiazole overdose (disorder)
        "296159002",  # Intentional sulpiride overdose (disorder)
        "296163009",  # Intentional loxapine overdose (disorder)
        "296167005",  # Intentional clozapine overdose (disorder)
        "296171008",  # Intentional risperidone overdose (disorder)
        "296175004",  # Intentional tetrabenazine overdose (disorder)
        "296181007",  # Intentional benperidol overdose (disorder)
        "296185003",  # Intentional trifluperidol overdose (disorder)
        "296189009",  # Intentional haloperidol overdose (disorder)
        "296193003",  # Intentional droperidol overdose (disorder)
        "296198007",  # Intentional pimozide overdose (disorder)
        "296202009",  # Intentional fluspirilene overdose (disorder)
        "296207003",  # Intentional methotrimeprazine overdose (disorder)
        "296211009",  # Intentional pericyazine overdose (disorder)
        "296215000",  # Intentional fluphenazine decanoate overdose (disorder)
        "296219006",  # Intentional fluphenazine enanthate overdose (disorder)
        "296223003",  # Intentional thiethylperazine overdose (disorder)
        "296227002",  # Intentional chlorpromazine overdose (disorder)
        "296231008",  # Intentional pipothiazine overdose (disorder)
        "296235004",  # Intentional promazine overdose (disorder)
        "296239005",  # Intentional thioridazine overdose (disorder)
        "296243009",  # Intentional perphenazine overdose (disorder)
        "296247005",  # Intentional prochlorperazine overdose (disorder)
        "296251007",  # Intentional trifluoperazine overdose (disorder)
        "296260004",  # Intentional flupenthixol decanoate overdose (disorder)
        "296264008",  # Intentional zuclopenthixol decanoate overdose (disorder)
        "296272005",  # Intentional flupenthixol overdose (disorder)
        "296276008",  # Intentional oxypertine overdose (disorder)
        "296281004",  # Intentional remoxipride overdose (disorder)
        "296288005",  # Intentional selegiline overdose (disorder)
        "296303002",  # Intentional cannabis overdose (disorder)
        "296311007",  # Intentional psilocybin overdose (disorder)
        "296315003",  # Intentional mescaline overdose (disorder)
        "296323001",  # Intentional overdose by cocaine (disorder)
        "296327000",  # Intentional overdose by crack cocaine (disorder)
        "296331006",  # Intentional caffeine overdose (disorder)
        "296338000",  # Intentional atenolol overdose (disorder)
        "296342002",  # Intentional propranolol overdose (disorder)
        "296344001",  # Intentional overdose of beta-adrenergic blocking drug (disorder)
        "296349006",  # Intentional phenoxybenzamine overdose (disorder)
        "296353008",  # Intentional nicotine overdose (disorder)
        "296357009",  # Intentional overdose by calcium-channel blocker (disorder)
        "296362005",  # Intentional pilocarpine overdose (disorder)
        "296366008",  # Intentional acetylcholine overdose (disorder)
        "296370000",  # Intentional anticholinesterase overdose (disorder)
        "296377002",  # Intentional metaraminol overdose (disorder)
        "296382009",  # Intentional salbutamol overdose (disorder)
        "296386007",  # Intentional overdose of isoprenaline (disorder)
        "296391008",  # Intentional clonidine overdose (disorder)
        "296396003",  # Intentional hyoscine overdose (disorder)
        "296400003",  # Intentional atropine overdose (disorder)
        "296405008",  # Intentional acetylcysteine overdose (disorder)
        "296410007",  # Intentional nikethamide overdose (disorder)
        "296415002",  # Intentional chlorpheniramine overdose (disorder)
        "296419008",  # Intentional diphenhydramine overdose (disorder)
        "296423000",  # Intentional diphenylpyraline overdose (disorder)
        "296427004",  # Intentional thonzylamine overdose (disorder)
        "296431005",  # Intentional tripelennamine overdose (disorder)
        "296435001",  # Intentional hydroxyzine overdose (disorder)
        "296440009",  # Intentional aminophylline overdose (disorder)
        "296444000",  # Intentional theophylline overdose (disorder)
        "296448002",  # Intentional bronchodilator preparations overdose (disorder)
        "296454001",  # Intentional dithranol overdose (disorder)
        "296459006",  # Intentional gamolenic acid overdose (disorder)
        "296464005",  # Intentional etretinate overdose (disorder)
        "296468008",  # Intentional acitretin overdose (disorder)
        "296472007",  # Intentional tretinoin overdose (disorder)
        "296476005",  # Intentional isotretinoin overdose (disorder)
        "296482008",  # Intentional allopurinol overdose (disorder)
        "296487002",  # Intentional colchicine overdose (disorder)
        "296493005",  # Intentional baclofen overdose (disorder)
        "296497006",  # Intentional methocarbamol overdose (disorder)
        "296501001",  # Intentional gold salt overdose (disorder)
        "296506006",  # Intentional papaverine overdose (disorder)
        "296511008",  # Intentional prostaglandin overdose (disorder)
        "296518002",  # Intentional naloxone overdose (disorder)
        "296527001",  # Intentional alternative medicine overdose (navigational concept)
        "296528006",  # Alternative medicine overdose of undetermined intent (navigational concept)
        "296533005",  # Intentional flucytosine overdose (disorder)
        "296537006",  # Intentional griseofulvin overdose (disorder)
        "296541005",  # Intentional amphotericin B overdose (disorder)
        "296545001",  # Intentional nystatin overdose (disorder)
        "296550007",  # Intentional idoxuridine overdose (disorder)
        "296555002",  # Intentional pyrimethamine overdose (disorder)
        "296559008",  # Intentional chloroquine overdose (disorder)
        "296563001",  # Intentional primaquine overdose (disorder)
        "296567000",  # Intentional quinine overdose (disorder)
        "296571002",  # Intentional mefloquine overdose (disorder)
        "296575006",  # Intentional proguanil overdose (disorder)
        "296580002",  # Intentional piperazine overdose (disorder)
        "296584006",  # Intentional thiabendazole overdose (disorder)
        "296591009",  # Intentional kanamycin overdose (disorder)
        "296595000",  # Intentional streptomycin overdose (disorder)
        "296599006",  # Intentional gentamicin overdose (disorder)
        "296603006",  # Intentional tobramycin overdose (disorder)
        "296607007",  # Intentional netilmicin overdose (disorder)
        "296612008",  # Intentional erythromycin overdose (disorder)
        "296616006",  # Intentional azithromycin overdose (disorder)
        "296620005",  # Intentional clarithromycin overdose (disorder)
        "296628003",  # Intentional spectinomycin overdose (disorder)
        "296632009",  # Intentional vancomycin overdose (disorder)
        "296636007",  # Intentional trimethoprim overdose (disorder)
        "296640003",  # Intentional nitrofuran derivative overdose (disorder)
        "296644007",  # Intentional fusidic acid overdose (disorder)
        "296653000",  # Intentional ampicillin overdose (disorder)
        "296658009",  # Intentional cloxacillin overdose (disorder)
        "296662003",  # Intentional carbenicillin overdose (disorder)
        "296666000",  # Intentional flucloxacillin overdose (disorder)
        "296672000",  # Intentional cefadroxil overdose (disorder)
        "296676002",  # Intentional cephalexin overdose (disorder)
        "296680007",  # Intentional cephalothin overdose (disorder)
        "296684003",  # Intentional cephazolin overdose (disorder)
        "296689008",  # Intentional cephradine overdose (disorder)
        "296693002",  # Intentional latamoxef overdose (disorder)
        "296698006",  # Intentional cefaclor overdose (disorder)
        "296702005",  # Intentional cefuroxime overdose (disorder)
        "296706008",  # Intentional cephamandole overdose (disorder)
        "296711005",  # Intentional cefotaxime overdose (disorder)
        "296715001",  # Intentional ceftazidime overdose (disorder)
        "296719007",  # Intentional ceftizoxime overdose (disorder)
        "296723004",  # Intentional cefixime overdose (disorder)
        "296727003",  # Intentional cefodizime overdose (disorder)
        "296731009",  # Intentional cefpodoxime overdose (disorder)
        "296735000",  # Intentional ceftriaxone overdose (disorder)
        "296741007",  # Intentional ceftibuten overdose (disorder)
        "296745003",  # Intentional cefsulodin overdose (disorder)
        "296750009",  # Intentional cefpirome overdose (disorder)
        "296756003",  # Intentional doxycycline overdose (disorder)
        "296760000",  # Intentional minocycline overdose (disorder)
        "296764009",  # Intentional oxytetracycline overdose (disorder)
        "296768007",  # Intentional tetracycline overdose (disorder)
        "296772006",  # Intentional chloramphenicol overdose (disorder)
        "296782007",  # Intentional antimony compound overdose (disorder)
        "296786005",  # Intentional hydroxyquinoline overdose (disorder)
        "296793009",  # Intentional rifampin overdose (disorder)
        "296797005",  # Intentional isoniazid overdose (disorder)
        "296801006",  # Intentional ethambutol overdose (disorder)
        "296805002",  # Intentional antileprotic drug overdose (disorder)
        "296834008",  # Intentional carbimazole overdose (disorder)
        "296838006",  # Intentional thiouracil overdose (disorder)
        "296843004",  # Intentional prednisone overdose (disorder)
        "296847003",  # Intentional dexamethasone overdose (disorder)
        "296851001",  # Intentional insulin overdose (disorder)
        "296857002",  # Intentional acetohexamide overdose (disorder)
        "296861008",  # Intentional chlorpropamide overdose (disorder)
        "296865004",  # Intentional overdose by glibenclamide (disorder)
        "296870006",  # Intentional tolbutamide overdose (disorder)
        "296875001",  # Intentional overdose by metformin (disorder)
        "296880005",  # Intentional progestogen overdose (disorder)
        "296885000",  # Intentional nandrolone overdose (disorder)
        "296889006",  # Intentional oxymetholone overdose (disorder)
        "296894006",  # Intentional methandriol overdose (disorder)
        "296898009",  # Intentional oral contraceptive overdose (disorder)
        "296903008",  # Intentional testosterone overdose (disorder)
        "296907009",  # Intentional estrogen overdose (disorder)
        "296912005",  # Intentional liothyronine overdose (disorder)
        "296916008",  # Intentional thyroxin overdose (disorder)
        "296928000",  # Intentional heparin overdose (disorder)
        "296932006",  # Intentional coumarin overdose (disorder)
        "296941001",  # Intentional ferrous sulfate overdose (disorder)
        "296946006",  # Intentional iodide overdose (disorder)
        "296951000",  # Intentional vitamin A overdose (disorder)
        "296968001",  # Intentional folic acid overdose (disorder)
        "296972002",  # Intentional potassium overdose (disorder)
        "296978003",  # Intentional clofibrate overdose (disorder)
        "296984000",  # Intentional disopyramide overdose (disorder)
        "296988002",  # Intentional quinidine overdose (disorder)
        "296993004",  # Intentional procainamide overdose (disorder)
        "296998008",  # Intentional bretylium overdose (disorder)
        "297003000",  # Intentional amiodarone overdose (disorder)
        "297010006",  # Intentional bendrofluazide overdose (disorder)
        "297014002",  # Intentional chlorothiazide overdose (disorder)
        "297019007",  # Intentional furosemide overdose (disorder)
        "297023004",  # Intentional bumetanide overdose (disorder)
        "297027003",  # Intentional ethacrynic acid overdose (disorder)
        "297031009",  # Intentional potassium sparing diuretic overdose (disorder)
        "297035000",  # Intentional osmotic diuretic overdose (disorder)
        "297040008",  # Intentional mersalyl overdose (disorder)
        "297045003",  # Intentional acetazolamide overdose (disorder)
        "297051008",  # Intentional guanethidine overdose (disorder)
        "297055004",  # Intentional overdose by angiotensin-converting enzyme inhibitor (disorder)
        "297058002",  # Intentional antihypertensive overdose (disorder)
        "297063003",  # Intentional digoxin overdose (disorder)
        "297067002",  # Intentional phosphodiesterase inhibitor overdose (disorder)
        "297072006",  # Intentional ergot alkaloid overdose (disorder)
        "297077000",  # Intentional diazoxide overdose (disorder)
        "297081000",  # Intentional hydralazine overdose (disorder)
        "297085009",  # Intentional dipyridamole overdose (disorder)
        "297097005",  # Intentional streptokinase overdose (disorder)
        "297101001",  # Intentional urokinase overdose (disorder)
        "297201008",  # Intentional overdose of tricyclic antidepressant (disorder)
        "29929003",  # Bipolar I disorder, most recent episode depressed with atypical features (disorder)
        "30059008",  # Panic disorder with agoraphobia, severe agoraphobic avoidance AND moderate panic attacks (disorder)
        "300706003",  # Endogenous depression (disorder)
        "30077003",  # Somatoform pain disorder (disorder)
        "30169000",  # Psychogenic deafness (disorder)
        "30336007",  # Chronic residual schizophrenia with acute exacerbations (disorder)
        "304594002",  # Suicidal intent (finding)
        "30520009",  # Severe bipolar II disorder, most recent episode major depressive with psychotic features (disorder)
        "30605009",  # Major depression in partial remission (disorder)
        "30687003",  # Bipolar II disorder, most recent episode major depressive with postpartum onset (disorder)
        "307417003",  # Cycloid psychosis (disorder)
        "30935000",  # Manic bipolar I disorder in full remission (disorder)
        "31027006",  # Schizotypal personality disorder (disorder)
        "310495003",  # Mild depression (disorder)
        "310496002",  # Moderate depression (disorder)
        "310497006",  # Severe depression (disorder)
        "31081000119101",  # Presenile dementia with delusions (disorder)
        "3109008",  # Secondary dysthymia early onset (disorder)
        "31177006",  # Attention deficit hyperactivity disorder, combined type (disorder)
        "312991009",  # Senile dementia of the Lewy body type (disorder)
        "313182004",  # Chronic post-traumatic stress disorder (disorder)
        "31373002",  # Disorganized schizophrenia in remission (disorder)
        "31446002",  # Bipolar I disorder, most recent episode hypomanic (disorder)
        "3158007",  # Panic disorder with agoraphobia, agoraphobic avoidance in partial remission AND panic attacks in partial remission (disorder)
        "31611000",  # Multiple personality disorder (disorder)
        "31658008",  # Chronic paranoid schizophrenia (disorder)
        "31781004",  # Panic disorder with agoraphobia, agoraphobic avoidance in partial remission AND mild panic attacks (disorder)
        "317816007",  # Stockholm syndrome (disorder)
        "318784009",  # Posttraumatic stress disorder, delayed onset (disorder)
        "319768000",  # Recurrent major depressive disorder with melancholic features (disorder)
        "320751009",  # Major depression, melancholic type (disorder)
        "321717001",  # Involutional depression (disorder)
        "32388005",  # Panic disorder with agoraphobia, agoraphobic avoidance in partial remission AND moderate panic attacks (disorder)
        "32721004",  # Bulimia nervosa, purging type (disorder)
        "32875003",  # Inhalant-induced persisting dementia (disorder)
        "3298001",  # Amnestic disorder (disorder)
        "33078009",  # Severe recurrent major depression with psychotic features, mood-congruent (disorder)
        "33135002",  # Recurrent major depression in partial remission (disorder)
        "33323008",  # Somatic delusion disorder (disorder)
        "33380008",  # Severe manic bipolar I disorder with psychotic features, mood-incongruent (disorder)
        "33449004",  # Personality disorder (disorder)
        "33736005",  # Severe major depression with psychotic features, mood-congruent (disorder)
        "34116005",  # Panic disorder with agoraphobia, agoraphobic avoidance in full remission AND severe panic attacks (disorder)
        "34315001",  # Bipolar II disorder, most recent episode major depressive with melancholic features (disorder)
        "35218008",  # Chronic disorganized schizophrenia with acute exacerbation (disorder)
        "35252006",  # Disorganized schizophrenia (disorder)
        "35253001",  # Attention deficit hyperactivity disorder, predominantly inattentive type (disorder)
        "35481005",  # Mixed bipolar I disorder in remission (disorder)
        "35489007",  # Depressive disorder (disorder)
        "35607004",  # Panic disorder with agoraphobia (disorder)
        "35722002",  # Severe bipolar II disorder, most recent episode major depressive, in remission (disorder)
        "35827000",  # Recurrent conversion disorder (disorder)
        "35846004",  # Moderate bipolar II disorder, most recent episode major depressive (disorder)
        "35919005",  # Pervasive developmental disorder (disorder)
        "36124002",  # Primary hypersomnia (disorder)
        "36158005",  # Schizophreniform disorder with good prognostic features (disorder)
        "36170009",  # Secondary dysthymia late onset (disorder)
        "36217008",  # Organic personality disorder (disorder)
        "36474008",  # Severe recurrent major depression without psychotic features (disorder)
        "36583000",  # Mixed bipolar I disorder in partial remission (disorder)
        "36622002",  # Mild mood disorder (disorder)
        "367515004",  # Receptive language disorder (disorder)
        "36923009",  # Major depression, single episode (disorder)
        "370143000",  # Major depressive disorder (disorder)
        "371024007",  # Senile dementia with delusion (disorder)
        "371026009",  # Senile dementia with psychosis (disorder)
        "371596008",  # Bipolar I disorder (disorder)
        "371599001",  # Severe bipolar I disorder (disorder)
        "371600003",  # Severe bipolar disorder (disorder)
        "371604007",  # Severe bipolar II disorder (disorder)
        "371631005",  # Panic disorder (disorder)
        "37224001",  # Psychogenic vomiting (disorder)
        "373618009",  # Autistic spectrum disorder with isolated skills (disorder)
        "37739004",  # Mood disorder due to a general medical condition (disorder)
        "37746008",  # Avoidant personality disorder (disorder)
        "37868008",  # Anxiety disorder of adolescence (disorder)
        "37872007",  # Avoidant disorder of childhood OR adolescence (disorder)
        "37941009",  # Rumination disorder (disorder)
        "38328002",  # Panic disorder with agoraphobia, severe agoraphobic avoidance AND panic attacks in full remission (disorder)
        "38368003",  # Schizoaffective disorder, bipolar type (disorder)
        "38451003",  # Primary dysthymia early onset (disorder)
        "38547003",  # Mood disorder in full remission (disorder)
        "386257007",  # Dementia management (regime/therapy)
        "386537007",  # Psychogenic pylorospasm (disorder)
        "386805003",  # Mild neurocognitive disorder (disorder)
        "386810004",  # Phobic disorder (disorder)
        "386821008",  # Adjustment reaction in infancy (disorder)
        "386822001",  # Adjustment reaction of adolescence (disorder)
        "386823006",  # Adjustment reaction of adult life (disorder)
        "386824000",  # Adjustment reaction of childhood (disorder)
        "386825004",  # Adjustment reaction of late life (disorder)
        "38694004",  # Recurrent major depressive disorder with atypical features (disorder)
        "3914008",  # Mental disorder in childhood (disorder)
        "39465007",  # Emotional deprivation syndrome (disorder)
        "3972004",  # Primary insomnia (disorder)
        "397923000",  # Somatization disorder (disorder)
        "39809009",  # Recurrent major depressive disorder with catatonic features (disorder)
        "40083003",  # Stereotypic movement disorder with self-injurious behavior (disorder)
        "401230005",  # Plans for deliberate self harm without intent (finding)
        "401231009",  # Intent of deliberate self harm with detailed plans (finding)
        "402732001",  # Habit tic (disorder)
        "402733006",  # Habit tic affecting skin (disorder)
        "402735004",  # Habit tic affecting hair (disorder)
        "402736003",  # Factitious skin disease (disorder)
        "402737007",  # Artefactual skin disease (disorder)
        "403474003",  # Self-inflicted trauma involving penis (disorder)
        "403582001",  # Self-inflicted caustic burn (disorder)
        "403583006",  # Deliberate self-cutting (disorder)
        "403586003",  # Cutaneous Munchausen syndrome (disorder)
        "403590001",  # Factitious skin disorder imposed on another (disorder)
        "403593004",  # Phobic fear of skin cancer (disorder)
        "403594005",  # Psychogenic formication (disorder)
        "40379007",  # Mild recurrent major depression (disorder)
        "40568001",  # Recurrent brief depressive disorder (disorder)
        "406165004",  # Dementia management: bathing (regime/therapy)
        "406506008",  # Attention deficit hyperactivity disorder (disorder)
        "407628009",  # Global deterioration scale finding for assessment of primary degenerative dementia (finding)
        "408858002",  # Infantile psychosis (disorder)
        "40926005",  # Moderate mixed bipolar I disorder (disorder)
        "40987004",  # Intermittent explosive disorder (disorder)
        "410061008",  # Intentional poisoning (disorder)
        "41524005",  # Flagellantism (disorder)
        "41526007",  # Reactive attachment disorder (disorder)
        "41552001",  # Mild bipolar I disorder, single manic episode (disorder)
        "416340002",  # Late onset schizophrenia (disorder)
        "416780008",  # Primary degenerative dementia of the Alzheimer type, presenile onset (disorder)
        "416975007",  # Primary degenerative dementia of the Alzheimer type, senile onset (disorder)
        "41836007",  # Bipolar disorder in full remission (disorder)
        "420614009",  # Organic dementia with acquired immunodeficiency syndrome (disorder)
        "421023003",  # Presenile dementia with acquired immunodeficiency syndrome (disorder)
        "421529006",  # Dementia with acquired immunodeficiency syndrome (disorder)
        "425390006",  # Dementia associated with Parkinson's Disease (disorder)
        "425476007",  # Non-organic parasomnia (disorder)
        "425499006",  # Non-organic communication disorder (disorder)
        "425832009",  # Psychophysiologic insomnia (disorder)
        "425914008",  # Adjustment reaction to medical therapy (disorder)
        "425919003",  # Chronic organic mental disorder (disorder)
        "42594001",  # Organic mood disorder of depressed type (disorder)
        "426174008",  # Chronic stress disorder (disorder)
        "426299001",  # Intentional X-ray contrast media poisoning (disorder)
        "426450003",  # Intentional chlorprothixene overdose (disorder)
        "428051000124108",  # Mild dementia (disorder)
        "428351000124105",  # Severe dementia (disorder)
        "42868002",  # Subchronic catatonic schizophrenia (disorder)
        "428687006",  # Nightmares associated with chronic post-traumatic stress disorder (disorder)
        "428703001",  # Transient organic mental disorder (disorder)
        "429161000124103",  # Primary degenerative dementia of the Alzheimer type, senile onset, with behavioral disturbance (disorder)
        "42925002",  # Major depressive disorder, single episode with atypical features (disorder)
        "429458009",  # Dementia due to Creutzfeldt Jakob disease (disorder)
        "429571005",  # Sleep-related dissociative disorder (disorder)
        "429961000",  # Family history of dementia (situation)
        "429998004",  # Vascular dementia (disorder)
        "4306003",  # Cluster B personality disorder (disorder)
        "430744005",  # Factitious disorder with predominantly physical signs and symptoms (disorder)
        "430751001",  # Factitious disorder with predominantly psychological signs and symptoms (disorder)
        "430771000124100",  # Moderate dementia (disorder)
        "430852001",  # Severe major depression, single episode, with psychotic features (disorder)
        "430881000124107",  # Referral for safety counseling associated with dementia (procedure)
        "430909002",  # Conduct disorder (disorder)
        "431271000124101",  # Counseling about dementia (procedure)
        "431307001",  # Intentional poisoning caused by drug (disorder)
        "43150009",  # Panic disorder without agoraphobia with severe panic attacks (disorder)
        "433278001",  # Family history of presenile dementia (situation)
        "434871000124103",  # Dementia-related safety counseling (procedure)
        "43568002",  # Bipolar II disorder, most recent episode major depressive with atypical features (disorder)
        "43614003",  # Autistic disorder of childhood onset (disorder)
        "43769008",  # Mild mixed bipolar I disorder (disorder)
        "439011002",  # Self-administered intentional poisoning caused by analgesic (disorder)
        "439960005",  # Binge eating disorder (disorder)
        "44124003",  # Reactive attachment disorder of early childhood (disorder)
        "441704009",  # Affective psychosis (disorder)
        "441711008",  # Chronic psychogenic pain (disorder)
        "441716003",  # Residual childhood psychosis (disorder)
        "441833000",  # Lethal catatonia (disorder)
        "442057004",  # Chronic depressive personality disorder (disorder)
        "442059001",  # Mixed developmental disorder (disorder)
        "442243005",  # Psychosexual dysfunction associated with inhibited libido (disorder)
        "442245003",  # Chronic hypomanic personality disorder (disorder)
        "442344002",  # Dementia due to Huntington chorea (disorder)
        "443265004",  # Cognitive disorder (disorder)
        "443735008",  # Nonverbal learning disorder (disorder)
        "44376007",  # Dissociative disorder (disorder)
        "443919007",  # Complex posttraumatic stress disorder (disorder)
        "4441000",  # Severe bipolar disorder with psychotic features (disorder)
        "44433009",  # Recurrent transient tic disorder (disorder)
        "444613000",  # Adult attention deficit hyperactivity disorder (disorder)
        "446175003",  # Acute posttraumatic stress disorder following military combat (disorder)
        "446180007",  # Delayed posttraumatic stress disorder following military combat (disorder)
        "44966003",  # Passive aggressive personality disorder (disorder)
        "45479006",  # Manic bipolar I disorder in remission (disorder)
        "45677003",  # Developmental expressive writing disorder (disorder)
        "45912004",  # Organic hallucinosis (disorder)
        "45924006",  # Necrophilia (disorder)
        "459431000124103",  # Dementia severity rating scale (assessment scale)
        "459441000124108",  # Dementia severity rating scale score (observable entity)
        "459451000124105",  # Assessment using dementia severity rating scale (procedure)
        "459471000124100",  # Eight-item Informant Interview to Differentiate Aging and Dementia screening score (observable entity)
        "459671000124102",  # Assessment using Eight-item Informant Interview to Differentiate Aging and Dementia (procedure)
        "46023009",  # Pedophilia, same AND opposite sex (disorder)
        "461061000124108",  # Intentional psychostimulant overdose (disorder)
        "461071000124101",  # Intentional barbiturate overdose (disorder)
        "461171000124100",  # Intentional poisoning by ethyl alcohol (disorder)
        "46206005",  # Mood disorder (disorder)
        "46229002",  # Severe mixed bipolar I disorder without psychotic features (disorder)
        "46244001",  # Recurrent major depression in full remission (disorder)
        "46372006",  # Female sexual arousal disorder (disorder)
        "46432001",  # Lecherism (disorder)
        "46762006",  # Sexual desire disorder (disorder)
        "472981000",  # Fetishistic transvestism (disorder)
        "473203000",  # Assessment of dementia (procedure)
        "473456000",  # Compulsive personality disorder (disorder)
        "47372000",  # Adjustment disorder with anxious mood (disorder)
        "47447001",  # Grandiose delusion disorder (disorder)
        "47505003",  # Posttraumatic stress disorder (disorder)
        "47916000",  # Developmental arithmetic disorder (disorder)
        "4817008",  # Primary degenerative dementia of the Alzheimer type, senile onset, with delirium (disorder)
        "48309007",  # Pedophilia, nonexclusive type (disorder)
        "48500005",  # Delusional disorder (disorder)
        "48589009",  # Minor depressive disorder (disorder)
        "48826008",  # Conduct disorder, adolescent-onset type (disorder)
        "48937005",  # Bipolar II disorder, most recent episode hypomanic (disorder)
        "4926007",  # Schizophrenia in remission (disorder)
        "4932002",  # Panic disorder with agoraphobia, moderate agoraphobic avoidance AND mild panic attacks (disorder)
        "49468007",  # Depressed bipolar I disorder (disorder)
        "49512000",  # Depressed bipolar I disorder in partial remission (disorder)
        "49564006",  # Panic disorder with agoraphobia, mild agoraphobic avoidance AND moderate panic attacks (disorder)
        "50299009",  # Paraphilia (disorder)
        "50705009",  # Factitious disorder (disorder)
        "5095008",  # Gender identity disorder of childhood (disorder)
        "50983008",  # Panic disorder with agoraphobia, mild agoraphobic avoidance AND panic attacks in partial remission (disorder)
        "51133006",  # Residual schizophrenia in remission (disorder)
        "5158005",  # Gilles de la Tourette's syndrome (disorder)
        "51637008",  # Chronic bipolar I disorder, most recent episode depressed (disorder)
        "52448006",  # Dementia (disorder)
        "52910006",  # Anxiety disorder due to a general medical condition (disorder)
        "52954000",  # Schizoid personality disorder (disorder)
        "53049002",  # Severe bipolar disorder without psychotic features (disorder)
        "53333005",  # Akinetic mutism (disorder)
        "53467004",  # Anxiety disorder of childhood (disorder)
        "53607008",  # Depressed bipolar I disorder in remission (disorder)
        "53956006",  # Panic disorder without agoraphobia with panic attacks in partial remission (disorder)
        "54319003",  # Disruptive behavior disorder (disorder)
        "54502004",  # Primary degenerative dementia of the Alzheimer type, presenile onset, with delusions (disorder)
        "54587008",  # Simple phobia (disorder)
        "5464005",  # Brief reactive psychosis (disorder)
        "54761006",  # Severe depressed bipolar I disorder with psychotic features, mood-congruent (disorder)
        "55009008",  # Primary degenerative dementia of the Alzheimer type, senile onset, with delusions (disorder)
        "5509004",  # Panic disorder with agoraphobia AND severe panic attacks (disorder)
        "5510009",  # Organic delusional disorder (disorder)
        "55341008",  # Histrionic personality disorder (disorder)
        "55516002",  # Bipolar I disorder, most recent episode manic with postpartum onset (disorder)
        "55668003",  # Adjustment disorder with mixed emotional features (disorder)
        "55728007",  # Sexual aversion disorder (disorder)
        "55736003",  # Schizophreniform disorder without good prognostic features (disorder)
        "56034001",  # Compulsive exhibitionism (disorder)
        "56267009",  # Multi-infarct dementia (disorder)
        "56573006",  # Transient tic disorder (disorder)
        "56576003",  # Panic disorder without agoraphobia (disorder)
        "56627002",  # Psychosexual disorder (disorder)
        "5664002",  # Situational hypoactive sexual desire disorder (disorder)
        "568005",  # Tic disorder (disorder)
        "56882008",  # Anorexia nervosa (disorder)
        "5703000",  # Bipolar disorder in partial remission (disorder)
        "57194009",  # Adjustment disorder with depressed mood (disorder)
        "57715001",  # Gender identity disorder of adolescence (disorder)
        "58214004",  # Schizophrenia (disorder)
        "58329000",  # Organic mood disorder of manic type (disorder)
        "58535001",  # Physical AND emotional exhaustion state (disorder)
        "58647003",  # Severe mood disorder with psychotic features, mood-congruent (disorder)
        "58703003",  # Postpartum depression (disorder)
        "59174009",  # Fetishism (disorder)
        "59252009",  # de Barsey syndrome (disorder)
        "596004",  # Premenstrual dysphoric disorder (disorder)
        "59617007",  # Severe depressed bipolar I disorder with psychotic features (disorder)
        "59645001",  # Bulimia nervosa, nonpurging type (disorder)
        "59651006",  # Sedative, hypnotic AND/OR anxiolytic-induced persisting dementia (disorder)
        "59923000",  # Panic disorder with agoraphobia AND panic attacks in full remission (disorder)
        "600009",  # Pyromania (disorder)
        "60099002",  # Severe major depression with psychotic features, mood-incongruent (disorder)
        "60103007",  # Inhibited female orgasm (disorder)
        "60123008",  # Delusional disorder, mixed type (disorder)
        "609225004",  # Developmental regression (disorder)
        "61212007",  # Panic disorder with agoraphobia, severe agoraphobic avoidance AND severe panic attacks (disorder)
        "61403008",  # Severe depressed bipolar I disorder without psychotic features (disorder)
        "61901004",  # Conduct disorder, undifferentiated type (disorder)
        "62351001",  # Generalized social phobia (disorder)
        "62491004",  # Frotteurism (disorder)
        "62792007",  # Urophilia (disorder)
        "63181006",  # Paranoid schizophrenia in remission (disorder)
        "63249007",  # Manic bipolar I disorder in partial remission (disorder)
        "63393005",  # Anorexia nervosa, binge-eating purging type (disorder)
        "63701002",  # Panic disorder with agoraphobia, mild agoraphobic avoidance AND mild panic attacks (disorder)
        "63778009",  # Major depressive disorder, single episode with melancholic features (disorder)
        "63835008",  # Voyeurism (disorder)
        "63909006",  # Panic disorder with agoraphobia AND panic attacks in partial remission (disorder)
        "64060000",  # Panic disorder with agoraphobia, moderate agoraphobic avoidance AND panic attacks in full remission (disorder)
        "64165008",  # Avoidant disorder of childhood (disorder)
        "64731001",  # Severe mixed bipolar I disorder with psychotic features, mood-congruent (disorder)
        "6475002",  # Primary degenerative dementia of the Alzheimer type, presenile onset, uncomplicated (disorder)
        "64905009",  # Paranoid schizophrenia (disorder)
        "65064003",  # Panic disorder without agoraphobia with moderate panic attacks (disorder)
        "65096006",  # Primary degenerative dementia of the Alzheimer type, presenile onset, with delirium (disorder)
        "65410009",  # Compulsive sexual masochism (disorder)
        "66108005",  # Primary degenerative dementia of the Alzheimer type, senile onset, uncomplicated (disorder)
        "66307007",  # Conduct disorder, group type (disorder)
        "66344007",  # Recurrent major depression (disorder)
        "66347000",  # Impulse control disorder (disorder)
        "66381006",  # Adjustment disorder with mixed disturbance of emotions AND conduct (disorder)
        "66631006",  # Moderate depressed bipolar I disorder (disorder)
        "66936004",  # Identity disorder (disorder)
        "67002003",  # Severe bipolar II disorder, most recent episode major depressive, in partial remission (disorder)
        "67227000",  # Pedophilia, same sex (disorder)
        "67698009",  # Obsessional thoughts (finding)
        "67711008",  # Primary dysthymia late onset (disorder)
        "68019004",  # Recurrent major depression in remission (disorder)
        "68569003",  # Manic bipolar I disorder (disorder)
        "68890003",  # Schizoaffective disorder (disorder)
        "68995007",  # Chronic catatonic schizophrenia (disorder)
        "69322001",  # Psychotic disorder (disorder)
        "69392006",  # Major depressive disorder, single episode with catatonic features (disorder)
        "69479009",  # Anxiety hyperventilation (disorder)
        "698464007",  # At increased risk of dementia (finding)
        "698624003",  # Dementia associated with cerebral lipidosis (disorder)
        "698625002",  # Dementia associated with normal pressure hydrocephalus (disorder)
        "698626001",  # Dementia associated with multiple sclerosis (disorder)
        "698687007",  # Post-traumatic dementia with behavioral change (disorder)
        "698700004",  # Borderline personality disorder in remission (disorder)
        "698725008",  # Dementia associated with neurosyphilis (disorder)
        "698726009",  # Dementia associated with viral encephalitis (disorder)
        "698781002",  # Dementia associated with cerebral anoxia (disorder)
        "698948009",  # Vascular dementia in remission (disorder)
        "698949001",  # Dementia in remission (disorder)
        "698954005",  # Primary degenerative dementia of the Alzheimer type, senile onset in remission (disorder)
        "698955006",  # Primary degenerative dementia of the Alzheimer type, presenile onset in remission (disorder)
        "698958008",  # Delirium in remission (disorder)
        "700214004",  # Antipsychotic drug therapy for dementia (procedure)
        "70043001",  # Severe mood disorder with psychotic features, mood-incongruent (disorder)
        "700464008",  # Assessment of psychotic and behavioral symptoms of dementia (procedure)
        "702393003",  # Frontotemporal dementia with gene located on 3p11 (disorder)
        "702426001",  # GRN-related frontotemporal dementia (disorder)
        "702429008",  # Frontotemporal dementia with parkinsonism-17 (disorder)
        "7025000",  # Subchronic undifferentiated schizophrenia with acute exacerbations (disorder)
        "703544004",  # Inclusion body myopathy with early-onset Paget disease and frontotemporal dementia (disorder)
        "70546001",  # Severe bipolar disorder with psychotic features, mood-congruent (disorder)
        "70691001",  # Agoraphobia (disorder)
        "70747007",  # Major depression single episode, in partial remission (disorder)
        "70764005",  # Depersonalization disorder (disorder)
        "70814008",  # Subchronic residual schizophrenia with acute exacerbations (disorder)
        "708728007",  # Traumatic brain injury of unknown intent (disorder)
        "70922000",  # Compulsive pedophilia (disorder)
        "70936005",  # Multi-infarct dementia, uncomplicated (disorder)
        "71103003",  # Chronic residual schizophrenia (disorder)
        "711538001",  # Intentional drug overdose by tablet (disorder)
        "711539009",  # Intentional drug overdose by injectable substance (disorder)
        "7121000122100",  # Pain Assessment in Advanced Dementia Scale (assessment scale)
        "71294008",  # Mild bipolar II disorder, most recent episode major depressive (disorder)
        "71336009",  # Recurrent major depressive disorder with postpartum onset (disorder)
        "713488003",  # Presenile dementia co-occurrent with human immunodeficiency virus infection (disorder)
        "713844000",  # Dementia co-occurrent with human immunodeficiency virus infection (disorder)
        "715269009",  # Intentional disulfiram poisoning (disorder)
        "715284000",  # Dementia leaflet given (situation)
        "715302000",  # Intentional disulfiram overdose (disorder)
        "715454006",  # Assessment using Revised Kendrick Battery for detection of dementia in the elderly (procedure)
        "715737004",  # Parkinsonism co-occurrent with dementia of Guadeloupe (disorder)
        "715924009",  # Disruptive mood dysregulation disorder (disorder)
        "716175000",  # Arizona Battery for Communication Disorders of Dementia score (observable entity)
        "716610001",  # Revised Kendrick Battery for detection of dementia in the elderly score (observable entity)
        "716667005",  # Right temporal atrophy variant frontotemporal dementia (disorder)
        "716727004",  # Assessment using Arizona Battery for Communication Disorders of Dementia (procedure)
        "716994006",  # Behavioral variant of frontotemporal dementia (disorder)
        "717679002",  # Revised Kendrick Battery for detection of dementia in the elderly (assessment scale)
        "718372000",  # Assessment using Clinical Dementia Rating (procedure)
        "71959007",  # Elective mutism (disorder)
        "71961003",  # Childhood disintegrative disorder (disorder)
        "719787003",  # Shared care prescribing of drug for dementia (finding)
        "71984005",  # Mild manic bipolar I disorder (disorder)
        "720021000",  # Shared care prescribing protocol of drugs for dementia (regime/therapy)
        "720022007",  # Shared care prescribing of drugs for dementia declined (situation)
        "720204003",  # Clinical Dementia Rating score (observable entity)
        "722977005",  # Dementia co-occurrent and due to neurocysticercosis (disorder)
        "722978000",  # Toxic dementia (disorder)
        "722979008",  # Dementia due to metabolic abnormality (disorder)
        "722980006",  # Dementia due to chromosomal anomaly (disorder)
        "723123001",  # Ischemic vascular dementia (disorder)
        "723390000",  # Rapidly progressive dementia (disorder)
        "72366004",  # Eating disorder (disorder)
        "723916001",  # Bodily distress disorder (disorder)
        "724776007",  # Dementia due to disorder of central nervous system (disorder)
        "724777003",  # Dementia due to infectious disease (disorder)
        "724992007",  # Epilepsy co-occurrent and due to dementia (disorder)
        "725898002",  # Delirium co-occurrent with dementia (disorder)
        "72861004",  # Panic disorder without agoraphobia with mild panic attacks (disorder)
        "7291006",  # Reactive attachment disorder of infancy (disorder)
        "733184002",  # Dementia caused by heavy metal exposure (disorder)
        "733190003",  # Dementia due to primary malignant neoplasm of brain (disorder)
        "733191004",  # Dementia due to chronic subdural hematoma (disorder)
        "733192006",  # Dementia due to herpes encephalitis (disorder)
        "733193001",  # Dementia co-occurrent and due to progressive multifocal leukoencephalopathy (disorder)
        "733194007",  # Dementia co-occurrent and due to Down syndrome (disorder)
        "73462009",  # Chronic vocal tic disorder (disorder)
        "735141001",  # On anti-dementia drug therapy (finding)
        "736371006",  # Dementia care plan (record artifact)
        "73867007",  # Severe major depression with psychotic features (disorder)
        "7397008",  # Aggressor identification syndrome (disorder)
        "73972002",  # Postpartum neurosis (disorder)
        "74007000",  # Sexual arousal disorder (disorder)
        "74010007",  # Panic disorder with agoraphobia, severe agoraphobic avoidance AND panic attacks in partial remission (disorder)
        "74266001",  # Mood disorder in partial remission (disorder)
        "7461003",  # Attention deficit hyperactivity disorder, predominantly hyperactive impulsive type (disorder)
        "74686005",  # Mild depressed bipolar I disorder (disorder)
        "74732009",  # Mental disorder (disorder)
        "74791000",  # Pedophilia, limited to incest (disorder)
        "74850006",  # Conduct disorder, solitary aggressive type (disorder)
        "75084000",  # Severe major depression without psychotic features (disorder)
        "75360000",  # Bipolar I disorder, single manic episode, in remission (disorder)
        "75752004",  # Bipolar I disorder, most recent episode depressed with melancholic features (disorder)
        "75837004",  # Mood disorder with depressive features due to general medical condition (disorder)
        "762350007",  # Dementia due to prion disease (disorder)
        "762351006",  # Dementia due to and following injury of head (disorder)
        "76236006",  # Atypical tic disorder (disorder)
        "762707000",  # Subcortical dementia (disorder)
        "76441001",  # Severe major depression, single episode, without psychotic features (disorder)
        "765176007",  # Psychosis and severe depression co-occurrent and due to bipolar affective disorder (disorder)
        "76566000",  # Subchronic residual schizophrenia (disorder)
        "76812003",  # Panic disorder with agoraphobia, moderate agoraphobic avoidance AND panic attacks in partial remission (disorder)
        "76868007",  # Panic disorder with agoraphobia, agoraphobic avoidance in full remission AND mild panic attacks (disorder)
        "774069007",  # Protein kinase cAMP-dependent type I regulatory subunit beta-related neurodegenerative dementia with intermediate filaments (disorder)
        "77475008",  # Jealous delusion disorder (disorder)
        "77486005",  # Mood disorder with major depressive-like episode due to general medical condition (disorder)
        "77675002",  # Anorexia nervosa, restricting type (disorder)
        "77911002",  # Severe major depression, single episode, with psychotic features, mood-congruent (disorder)
        "7794004",  # Chronic motor tic disorder (disorder)
        "78004001",  # Bulimia nervosa (disorder)
        "78269000",  # Bipolar I disorder, single manic episode, in partial remission (disorder)
        "783161005",  # Familial dementia British type (disorder)
        "783258000",  # Familial dementia Danish type (disorder)
        "78640000",  # Severe manic bipolar I disorder with psychotic features, mood-congruent (disorder)
        "78667006",  # Dysthymia (disorder)
        "78689005",  # Chronic brain syndrome (disorder)
        "788861009",  # Aggression due to dementia (finding)
        "788862002",  # Agitation due to dementia (finding)
        "788866004",  # Anxiety due to dementia (finding)
        "788867008",  # Apathetic behavior due to dementia (finding)
        "788898005",  # Dementia caused by volatile inhalant (disorder)
        "788899002",  # Dementia due to pellagra (disorder)
        "789011007",  # Psychological symptom due to dementia (finding)
        "789062005",  # Wandering due to dementia (finding)
        "789170003",  # Disinhibited behavior due to dementia (disorder)
        "79204003",  # Chronic undifferentiated schizophrenia with acute exacerbations (disorder)
        "79298009",  # Mild major depression, single episode (disorder)
        "79341000119107",  # Mixed dementia (disorder)
        "79584002",  # Moderate bipolar disorder (disorder)
        "79842004",  # Stuporous depression (disorder)
        "79866005",  # Subchronic paranoid schizophrenia (disorder)
        "80711002",  # Narcissistic personality disorder (disorder)
        "81319007",  # Severe bipolar II disorder, most recent episode major depressive without psychotic features (disorder)
        "8185002",  # Panic disorder with agoraphobia AND moderate panic attacks (disorder)
        "81903006",  # Inhibited male orgasm (disorder)
        "82361000119107",  # Altered behavior in dementia due to Huntington chorea (disorder)
        "82371000119101",  # Dementia due to multiple sclerosis with altered behavior (disorder)
        "82381000119103",  # Epileptic dementia with behavioral disturbance (disorder)
        "82494000",  # Panic disorder without agoraphobia with panic attacks in full remission (disorder)
        "82636008",  # Orgasm disorder (disorder)
        "82738004",  # Panic disorder with agoraphobia, moderate agoraphobic avoidance AND moderate panic attacks (disorder)
        "82959004",  # Dementia paralytica juvenilis (disorder)
        "82998009",  # Moderate manic bipolar I disorder (disorder)
        "83176005",  # Primary dysthymia (disorder)
        "83225003",  # Bipolar II disorder (disorder)
        "833326008",  # Cortical vascular dementia (disorder)
        "83458005",  # Agitated depression (disorder)
        "83501007",  # Organic mood disorder of mixed type (disorder)
        "83631006",  # Panic disorder with agoraphobia, moderate agoraphobic avoidance AND severe panic attacks (disorder)
        "83746006",  # Chronic schizophrenia (disorder)
        "838276009",  # Amyotrophic lateral sclerosis, parkinsonism, dementia complex (disorder)
        "838521001",  # Intentional overdose of methylenedioxymethamphetamine (disorder)
        "838526006",  # Intentional poisoning caused by methylenedioxymethamphetamine (disorder)
        "83890006",  # Cluster C personality disorder (disorder)
        "84002002",  # Pedophilia (disorder)
        "840464007",  # Dementia due to carbon monoxide poisoning (disorder)
        "840465008",  # Dementia due to iron deficiency (disorder)
        "84209002",  # Psychogenic amnesia (disorder)
        "84466009",  # Dependent personality disorder (disorder)
        "84760002",  # Schizoaffective disorder, depressive type (disorder)
        "84788008",  # Menopausal depression (disorder)
        "84984002",  # Adjustment disorder with disturbance of conduct (disorder)
        "85061001",  # Separation anxiety disorder of childhood, early onset (disorder)
        "85080004",  # Secondary dysthymia (disorder)
        "8511007",  # Transient tic disorder, single episode (disorder)
        "85248005",  # Bipolar disorder in remission (disorder)
        "85821003",  # Acute non-psychotic brain syndrome (disorder)
        "85861002",  # Subchronic undifferentiated schizophrenia (disorder)
        "86110000",  # Rumination - thoughts (finding)
        "87203005",  # Bipolar I disorder, most recent episode depressed with postpartum onset (disorder)
        "87414006",  # Reactive depression (situational) (disorder)
        "87798009",  # Panic disorder with agoraphobia, agoraphobic avoidance in full remission AND moderate panic attacks (disorder)
        "87950005",  # Bipolar I disorder, single manic episode with catatonic features (disorder)
        "87991007",  # Gender identity disorder (disorder)
        "88845000",  # Explosive type organic personality disorder (disorder)
        "88939009",  # Severe mood disorder without psychotic features (disorder)
        "88975006",  # Schizophreniform disorder (disorder)
        "89415002",  # Hypersomnia disorder related to another mental disorder (disorder)
        "89618007",  # Persecutory delusion disorder (disorder)
        "89948007",  # Panic disorder with agoraphobia AND mild panic attacks (disorder)
        "90361000119105",  # Behavioral insomnia of childhood (disorder)
        "90790003",  # Avoidant disorder of adolescence (disorder)
        "9083002",  # Pedophilia, opposite sex (disorder)
        "9167000",  # Moderate mood disorder (disorder)
        "92501000119101",  # Stress reaction with psychomotor agitation (disorder)
        "9340000",  # Bipolar I disorder, single manic episode (disorder)
        "9345005",  # Dialysis dementia (disorder)
        "93461009",  # Gender dysphoria (disorder)
        "95636001",  # Sadomasochism (disorder)
        "95637005",  # Factitious disorder imposed on another (disorder)
        "9674006",  # Adjustment disorder with withdrawal (disorder)
    }

class AutonomousEyeExamResultOrFinding(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for an Autonomous Eye Exam Result or Finding.

    **Data Element Scope:** This value set was intended to identify patients who had a Autonomous Eye Exam Result or Finding.

    **Inclusion Criteria:** Includes codes that identify an Autonomous Eye Exam Result or Findings.

    **Exclusion Criteria:** Exclude order only codes and code that indicate narrative reports.
    """

    VALUE_SET_NAME = "Autonomous Eye Exam Result or Finding"
    OID = "2.16.840.1.113883.3.464.1004.2616"
    DEFINITION_VERSION = "20250130"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    LOINC = {
        "LA34398-0",  # ETDRS Level 20 or lower, without macular edema
        "LA34399-8",  # ETDRS Level 35 or higher, with or without macular edema
    }

class DiabeticRetinopathySeverityLevel(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for Diabetic Retinopathy Severity Level.

    **Data Element Scope:** This value set may use a model element related to Diabetic Retinopathy Severity Level.

    **Inclusion Criteria:** Includes concepts that represent severe, mild, moderate or no (non) proliferative retinopathy.

    **Exclusion Criteria:** none
    """

    VALUE_SET_NAME = "Diabetic Retinopathy Severity Level"
    OID = "2.16.840.1.113883.3.464.1003.1266"
    DEFINITION_VERSION = "20250109"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    LOINC = {
        "LA18643-9",  # No apparent retinopathy
        "LA18644-7",  # Mild non-proliferative retinopathy
        "LA18645-4",  # Moderate non-proliferative retinopathy
        "LA18646-2",  # Severe non-proliferative retinopathy
        "LA18648-8",  # Proliferative retinopathy
    }

class VisualAcuity2040OrBetter(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts of a physical exam with visual acuity findings that are 20/40 or better.

    **Data Element Scope:** This value set may use a model element Physical Exam.

    **Inclusion Criteria:** Includes concepts that represent a physical exam with a result of distance vision findings of 20/40 or better.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Visual Acuity 20/40 or Better"
    OID = "2.16.840.1.113883.3.526.3.1483"
    DEFINITION_VERSION = "20210214"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "422497000",  # Distance vision 20/20 (finding)
        "423059004",  # Distance vision 20/40 (finding)
        "423364005",  # Distance vision 20/25 (finding)
        "423862000",  # Distance vision 20/15 (finding)
        "424703005",  # Distance vision 20/30 (finding)
    }

class MedicalReason(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for medical reasons for not receiving a therapy or service.

    **Data Element Scope:** This value set may use a model element related to Negation Rationale.

    **Inclusion Criteria:** Includes concepts that describe a medical reason for not receiving a therapy or service.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Medical Reason"
    OID = "2.16.840.1.113883.3.526.3.1007"
    DEFINITION_VERSION = "20170504"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "183932001",  # Procedure contraindicated (situation)
        "183964008",  # Treatment not indicated (situation)
        "183966005",  # Drug treatment not indicated (situation)
        "266721009",  # Absent response to treatment (situation)
        "269191009",  # Late effect of medical and surgical care complication (disorder)
        "31438003",  # Drug resistance (disorder)
        "35688006",  # Complication of medical care (disorder)
        "407563006",  # Treatment not tolerated (situation)
        "410534003",  # Not indicated (qualifier value)
        "410536001",  # Contraindicated (qualifier value)
        "416098002",  # Allergy to drug (finding)
        "428119001",  # Procedure not indicated (situation)
        "59037007",  # Intolerance to drug (finding)
        "62014003",  # Adverse reaction caused by drug (disorder)
        "79899007",  # Drug interaction (finding)
    }

class ModerateOrSevere(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts of severe and moderate levels of severity.

    **Data Element Scope:** This value set may use a model element related to Severity.

    **Inclusion Criteria:** Includes concepts that represent a Allergy/Intolerance, Adverse Event, Diagnosis, or Symptom with a severity of severe and moderate levels.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Moderate or Severe"
    OID = "2.16.840.1.113883.3.526.3.1092"
    DEFINITION_VERSION = "20170504"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "24484000",  # Severe (severity modifier) (qualifier value)
        "6736007",  # Moderate (severity modifier) (qualifier value)
    }

class PatientReason(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for patient-specific reasons for not receiving a therapy or service.

    **Data Element Scope:** This value set may use a model element related to Negation Rationale.

    **Inclusion Criteria:** Includes concepts that represent a patient-specific reason for not receiving a therapy or service.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Patient Reason"
    OID = "2.16.840.1.113883.3.526.3.1008"
    DEFINITION_VERSION = "20170504"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "1296859006",  # Procedure declined (situation)
        "160932005",  # Financial problem (finding)
        "160934006",  # Financial circumstances change (finding)
        "182890002",  # Patient requests alternative treatment (finding)
        "182895007",  # Drug declined by patient (situation)
        "182897004",  # Drug declined by patient - side effects (situation)
        "182900006",  # Drug declined by patient - patient beliefs (situation)
        "182902003",  # Drug declined by patient - cannot pay script (situation)
        "183945002",  # Procedure declined for religious reason (situation)
        "184081006",  # Patient has moved away (finding)
        "185479006",  # Patient dissatisfied with result (finding)
        "185481008",  # Dissatisfied with doctor (finding)
        "224187001",  # Variable income (finding)
        "225928004",  # Patient self-discharge against medical advice (procedure)
        "266710000",  # Drugs not taken/completed (situation)
        "266966009",  # Family illness (situation)
        "275694009",  # Patient defaulted from follow-up (finding)
        "275936005",  # Patient noncompliance - general (situation)
        "31021000119100",  # Screening declined (situation)
        "310343007",  # Further opinion sought (finding)
        "373787003",  # Treatment delay - patient choice (finding)
        "406149000",  # Medication declined (situation)
        "408367005",  # Patient forgets to take medication (finding)
        "413311005",  # Patient non-compliant - declined intervention / support (situation)
        "416432009",  # Procedure not wanted (situation)
        "423656007",  # Income insufficient to buy necessities (finding)
        "424739004",  # Income sufficient to buy only necessities (finding)
        "443390004",  # Refused (qualifier value)
        "713247000",  # Procedure discontinued by patient (situation)
    }

class PatientReasonForAceInhibitorOrArbDecline(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for communication of a patient reason for declining angiotensin-converting enzyme (ACE) inhibitor or angiotensin ii receptor blocker (ARB) therapy.

    **Data Element Scope:** This value set may use a model element related to Communication.

    **Inclusion Criteria:** Includes concepts that represent a communication of declining angiotensin-converting enzyme (ACE) inhibitor or angiotensin ii receptor blocker (ARB) therapy.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Patient Reason for ACE Inhibitor or ARB Decline"
    OID = "2.16.840.1.113883.3.526.3.1140"
    DEFINITION_VERSION = "20170504"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "134397009",  # Angiotensin converting enzyme inhibitor declined (situation)
        "401084003",  # Angiotensin II receptor antagonist declined (situation)
    }

class Ambulatory(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for encounters in an ambulatory setting.

    **Data Element Scope:** This value set may use a model element related to Encounter.

    **Inclusion Criteria:** Includes concepts that represent an ambulatory setting.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Ambulatory"
    OID = "2.16.840.1.113883.3.464.1003.122.12.1003"
    DEFINITION_VERSION = "20170504"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "35971002",  # Ambulatory care site (environment)
        "440655000",  # Outpatient environment (environment)
        "722171005",  # Diagnostic institution (environment)
    }

class MentalBehavioralAndNeurodevelopmentalDisorders(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for a diagnosis of a mental, behavioral or neurodevelopmental disorder.

    **Data Element Scope:** This value set may use a model element related to Diagnosis.

    **Inclusion Criteria:** Includes concepts that represent a diagnosis of mental health or substance abuse.

    **Exclusion Criteria:** Excludes concepts that represent a diagnosis of mental, behavioral or neurodevelopmental disorder in remission.
    """

    VALUE_SET_NAME = "Mental Behavioral and Neurodevelopmental Disorders"
    OID = "2.16.840.1.113883.3.464.1003.105.12.1203"
    DEFINITION_VERSION = "20210224"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "F0150",  # Vascular dementia, unspecified severity, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F01511",  # Vascular dementia, unspecified severity, with agitation
        "F01518",  # Vascular dementia, unspecified severity, with other behavioral disturbance
        "F0152",  # Vascular dementia, unspecified severity, with psychotic disturbance
        "F0153",  # Vascular dementia, unspecified severity, with mood disturbance
        "F0154",  # Vascular dementia, unspecified severity, with anxiety
        "F01A0",  # Vascular dementia, mild, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F01A11",  # Vascular dementia, mild, with agitation
        "F01A18",  # Vascular dementia, mild, with other behavioral disturbance
        "F01A2",  # Vascular dementia, mild, with psychotic disturbance
        "F01A3",  # Vascular dementia, mild, with mood disturbance
        "F01A4",  # Vascular dementia, mild, with anxiety
        "F01B0",  # Vascular dementia, moderate, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F01B11",  # Vascular dementia, moderate, with agitation
        "F01B18",  # Vascular dementia, moderate, with other behavioral disturbance
        "F01B2",  # Vascular dementia, moderate, with psychotic disturbance
        "F01B3",  # Vascular dementia, moderate, with mood disturbance
        "F01B4",  # Vascular dementia, moderate, with anxiety
        "F01C0",  # Vascular dementia, severe, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F01C11",  # Vascular dementia, severe, with agitation
        "F01C18",  # Vascular dementia, severe, with other behavioral disturbance
        "F01C2",  # Vascular dementia, severe, with psychotic disturbance
        "F01C3",  # Vascular dementia, severe, with mood disturbance
        "F01C4",  # Vascular dementia, severe, with anxiety
        "F0280",  # Dementia in other diseases classified elsewhere, unspecified severity, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F02811",  # Dementia in other diseases classified elsewhere, unspecified severity, with agitation
        "F02818",  # Dementia in other diseases classified elsewhere, unspecified severity, with other behavioral disturbance
        "F0282",  # Dementia in other diseases classified elsewhere, unspecified severity, with psychotic disturbance
        "F0283",  # Dementia in other diseases classified elsewhere, unspecified severity, with mood disturbance
        "F0284",  # Dementia in other diseases classified elsewhere, unspecified severity, with anxiety
        "F02A0",  # Dementia in other diseases classified elsewhere, mild, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F02A11",  # Dementia in other diseases classified elsewhere, mild, with agitation
        "F02A18",  # Dementia in other diseases classified elsewhere, mild, with other behavioral disturbance
        "F02A2",  # Dementia in other diseases classified elsewhere, mild, with psychotic disturbance
        "F02A3",  # Dementia in other diseases classified elsewhere, mild, with mood disturbance
        "F02A4",  # Dementia in other diseases classified elsewhere, mild, with anxiety
        "F02B0",  # Dementia in other diseases classified elsewhere, moderate, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F02B11",  # Dementia in other diseases classified elsewhere, moderate, with agitation
        "F02B18",  # Dementia in other diseases classified elsewhere, moderate, with other behavioral disturbance
        "F02B2",  # Dementia in other diseases classified elsewhere, moderate, with psychotic disturbance
        "F02B3",  # Dementia in other diseases classified elsewhere, moderate, with mood disturbance
        "F02B4",  # Dementia in other diseases classified elsewhere, moderate, with anxiety
        "F02C0",  # Dementia in other diseases classified elsewhere, severe, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F02C11",  # Dementia in other diseases classified elsewhere, severe, with agitation
        "F02C18",  # Dementia in other diseases classified elsewhere, severe, with other behavioral disturbance
        "F02C2",  # Dementia in other diseases classified elsewhere, severe, with psychotic disturbance
        "F02C3",  # Dementia in other diseases classified elsewhere, severe, with mood disturbance
        "F02C4",  # Dementia in other diseases classified elsewhere, severe, with anxiety
        "F0390",  # Unspecified dementia, unspecified severity, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F03911",  # Unspecified dementia, unspecified severity, with agitation
        "F03918",  # Unspecified dementia, unspecified severity, with other behavioral disturbance
        "F0392",  # Unspecified dementia, unspecified severity, with psychotic disturbance
        "F0393",  # Unspecified dementia, unspecified severity, with mood disturbance
        "F0394",  # Unspecified dementia, unspecified severity, with anxiety
        "F03A0",  # Unspecified dementia, mild, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F03A11",  # Unspecified dementia, mild, with agitation
        "F03A18",  # Unspecified dementia, mild, with other behavioral disturbance
        "F03A2",  # Unspecified dementia, mild, with psychotic disturbance
        "F03A3",  # Unspecified dementia, mild, with mood disturbance
        "F03A4",  # Unspecified dementia, mild, with anxiety
        "F03B0",  # Unspecified dementia, moderate, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F03B11",  # Unspecified dementia, moderate, with agitation
        "F03B18",  # Unspecified dementia, moderate, with other behavioral disturbance
        "F03B2",  # Unspecified dementia, moderate, with psychotic disturbance
        "F03B3",  # Unspecified dementia, moderate, with mood disturbance
        "F03B4",  # Unspecified dementia, moderate, with anxiety
        "F03C0",  # Unspecified dementia, severe, without behavioral disturbance, psychotic disturbance, mood disturbance, and anxiety
        "F03C11",  # Unspecified dementia, severe, with agitation
        "F03C18",  # Unspecified dementia, severe, with other behavioral disturbance
        "F03C2",  # Unspecified dementia, severe, with psychotic disturbance
        "F03C3",  # Unspecified dementia, severe, with mood disturbance
        "F03C4",  # Unspecified dementia, severe, with anxiety
        "F04",  # Amnestic disorder due to known physiological condition
        "F05",  # Delirium due to known physiological condition
        "F060",  # Psychotic disorder with hallucinations due to known physiological condition
        "F061",  # Catatonic disorder due to known physiological condition
        "F062",  # Psychotic disorder with delusions due to known physiological condition
        "F0630",  # Mood disorder due to known physiological condition, unspecified
        "F0631",  # Mood disorder due to known physiological condition with depressive features
        "F0632",  # Mood disorder due to known physiological condition with major depressive-like episode
        "F0633",  # Mood disorder due to known physiological condition with manic features
        "F0634",  # Mood disorder due to known physiological condition with mixed features
        "F064",  # Anxiety disorder due to known physiological condition
        "F0670",  # Mild neurocognitive disorder due to known physiological condition without behavioral disturbance
        "F0671",  # Mild neurocognitive disorder due to known physiological condition with behavioral disturbance
        "F068",  # Other specified mental disorders due to known physiological condition
        "F070",  # Personality change due to known physiological condition
        "F0781",  # Postconcussional syndrome
        "F0789",  # Other personality and behavioral disorders due to known physiological condition
        "F079",  # Unspecified personality and behavioral disorder due to known physiological condition
        "F09",  # Unspecified mental disorder due to known physiological condition
        "F1010",  # Alcohol abuse, uncomplicated
        "F1011",  # Alcohol abuse, in remission
        "F10120",  # Alcohol abuse with intoxication, uncomplicated
        "F10121",  # Alcohol abuse with intoxication delirium
        "F10129",  # Alcohol abuse with intoxication, unspecified
        "F10130",  # Alcohol abuse with withdrawal, uncomplicated
        "F10131",  # Alcohol abuse with withdrawal delirium
        "F10132",  # Alcohol abuse with withdrawal with perceptual disturbance
        "F10139",  # Alcohol abuse with withdrawal, unspecified
        "F1014",  # Alcohol abuse with alcohol-induced mood disorder
        "F10150",  # Alcohol abuse with alcohol-induced psychotic disorder with delusions
        "F10151",  # Alcohol abuse with alcohol-induced psychotic disorder with hallucinations
        "F10159",  # Alcohol abuse with alcohol-induced psychotic disorder, unspecified
        "F10180",  # Alcohol abuse with alcohol-induced anxiety disorder
        "F10181",  # Alcohol abuse with alcohol-induced sexual dysfunction
        "F10182",  # Alcohol abuse with alcohol-induced sleep disorder
        "F10188",  # Alcohol abuse with other alcohol-induced disorder
        "F1019",  # Alcohol abuse with unspecified alcohol-induced disorder
        "F1020",  # Alcohol dependence, uncomplicated
        "F1021",  # Alcohol dependence, in remission
        "F10220",  # Alcohol dependence with intoxication, uncomplicated
        "F10221",  # Alcohol dependence with intoxication delirium
        "F10229",  # Alcohol dependence with intoxication, unspecified
        "F10230",  # Alcohol dependence with withdrawal, uncomplicated
        "F10231",  # Alcohol dependence with withdrawal delirium
        "F10232",  # Alcohol dependence with withdrawal with perceptual disturbance
        "F10239",  # Alcohol dependence with withdrawal, unspecified
        "F1024",  # Alcohol dependence with alcohol-induced mood disorder
        "F10250",  # Alcohol dependence with alcohol-induced psychotic disorder with delusions
        "F10251",  # Alcohol dependence with alcohol-induced psychotic disorder with hallucinations
        "F10259",  # Alcohol dependence with alcohol-induced psychotic disorder, unspecified
        "F1026",  # Alcohol dependence with alcohol-induced persisting amnestic disorder
        "F1027",  # Alcohol dependence with alcohol-induced persisting dementia
        "F10280",  # Alcohol dependence with alcohol-induced anxiety disorder
        "F10281",  # Alcohol dependence with alcohol-induced sexual dysfunction
        "F10282",  # Alcohol dependence with alcohol-induced sleep disorder
        "F10288",  # Alcohol dependence with other alcohol-induced disorder
        "F1029",  # Alcohol dependence with unspecified alcohol-induced disorder
        "F1090",  # Alcohol use, unspecified, uncomplicated
        "F1091",  # Alcohol use, unspecified, in remission
        "F10920",  # Alcohol use, unspecified with intoxication, uncomplicated
        "F10921",  # Alcohol use, unspecified with intoxication delirium
        "F10929",  # Alcohol use, unspecified with intoxication, unspecified
        "F10930",  # Alcohol use, unspecified with withdrawal, uncomplicated
        "F10931",  # Alcohol use, unspecified with withdrawal delirium
        "F10932",  # Alcohol use, unspecified with withdrawal with perceptual disturbance
        "F10939",  # Alcohol use, unspecified with withdrawal, unspecified
        "F1094",  # Alcohol use, unspecified with alcohol-induced mood disorder
        "F10950",  # Alcohol use, unspecified with alcohol-induced psychotic disorder with delusions
        "F10951",  # Alcohol use, unspecified with alcohol-induced psychotic disorder with hallucinations
        "F10959",  # Alcohol use, unspecified with alcohol-induced psychotic disorder, unspecified
        "F1096",  # Alcohol use, unspecified with alcohol-induced persisting amnestic disorder
        "F1097",  # Alcohol use, unspecified with alcohol-induced persisting dementia
        "F10980",  # Alcohol use, unspecified with alcohol-induced anxiety disorder
        "F10981",  # Alcohol use, unspecified with alcohol-induced sexual dysfunction
        "F10982",  # Alcohol use, unspecified with alcohol-induced sleep disorder
        "F10988",  # Alcohol use, unspecified with other alcohol-induced disorder
        "F1099",  # Alcohol use, unspecified with unspecified alcohol-induced disorder
        "F1110",  # Opioid abuse, uncomplicated
        "F1111",  # Opioid abuse, in remission
        "F11120",  # Opioid abuse with intoxication, uncomplicated
        "F11121",  # Opioid abuse with intoxication delirium
        "F11122",  # Opioid abuse with intoxication with perceptual disturbance
        "F11129",  # Opioid abuse with intoxication, unspecified
        "F1113",  # Opioid abuse with withdrawal
        "F1114",  # Opioid abuse with opioid-induced mood disorder
        "F11150",  # Opioid abuse with opioid-induced psychotic disorder with delusions
        "F11151",  # Opioid abuse with opioid-induced psychotic disorder with hallucinations
        "F11159",  # Opioid abuse with opioid-induced psychotic disorder, unspecified
        "F11181",  # Opioid abuse with opioid-induced sexual dysfunction
        "F11182",  # Opioid abuse with opioid-induced sleep disorder
        "F11188",  # Opioid abuse with other opioid-induced disorder
        "F1119",  # Opioid abuse with unspecified opioid-induced disorder
        "F1120",  # Opioid dependence, uncomplicated
        "F1121",  # Opioid dependence, in remission
        "F11220",  # Opioid dependence with intoxication, uncomplicated
        "F11221",  # Opioid dependence with intoxication delirium
        "F11222",  # Opioid dependence with intoxication with perceptual disturbance
        "F11229",  # Opioid dependence with intoxication, unspecified
        "F1123",  # Opioid dependence with withdrawal
        "F1124",  # Opioid dependence with opioid-induced mood disorder
        "F11250",  # Opioid dependence with opioid-induced psychotic disorder with delusions
        "F11251",  # Opioid dependence with opioid-induced psychotic disorder with hallucinations
        "F11259",  # Opioid dependence with opioid-induced psychotic disorder, unspecified
        "F11281",  # Opioid dependence with opioid-induced sexual dysfunction
        "F11282",  # Opioid dependence with opioid-induced sleep disorder
        "F11288",  # Opioid dependence with other opioid-induced disorder
        "F1129",  # Opioid dependence with unspecified opioid-induced disorder
        "F1190",  # Opioid use, unspecified, uncomplicated
        "F1191",  # Opioid use, unspecified, in remission
        "F11920",  # Opioid use, unspecified with intoxication, uncomplicated
        "F11921",  # Opioid use, unspecified with intoxication delirium
        "F11922",  # Opioid use, unspecified with intoxication with perceptual disturbance
        "F11929",  # Opioid use, unspecified with intoxication, unspecified
        "F1193",  # Opioid use, unspecified with withdrawal
        "F1194",  # Opioid use, unspecified with opioid-induced mood disorder
        "F11950",  # Opioid use, unspecified with opioid-induced psychotic disorder with delusions
        "F11951",  # Opioid use, unspecified with opioid-induced psychotic disorder with hallucinations
        "F11959",  # Opioid use, unspecified with opioid-induced psychotic disorder, unspecified
        "F11981",  # Opioid use, unspecified with opioid-induced sexual dysfunction
        "F11982",  # Opioid use, unspecified with opioid-induced sleep disorder
        "F11988",  # Opioid use, unspecified with other opioid-induced disorder
        "F1199",  # Opioid use, unspecified with unspecified opioid-induced disorder
        "F1210",  # Cannabis abuse, uncomplicated
        "F1211",  # Cannabis abuse, in remission
        "F12120",  # Cannabis abuse with intoxication, uncomplicated
        "F12121",  # Cannabis abuse with intoxication delirium
        "F12122",  # Cannabis abuse with intoxication with perceptual disturbance
        "F12129",  # Cannabis abuse with intoxication, unspecified
        "F1213",  # Cannabis abuse with withdrawal
        "F12150",  # Cannabis abuse with psychotic disorder with delusions
        "F12151",  # Cannabis abuse with psychotic disorder with hallucinations
        "F12159",  # Cannabis abuse with psychotic disorder, unspecified
        "F12180",  # Cannabis abuse with cannabis-induced anxiety disorder
        "F12188",  # Cannabis abuse with other cannabis-induced disorder
        "F1219",  # Cannabis abuse with unspecified cannabis-induced disorder
        "F1220",  # Cannabis dependence, uncomplicated
        "F1221",  # Cannabis dependence, in remission
        "F12220",  # Cannabis dependence with intoxication, uncomplicated
        "F12221",  # Cannabis dependence with intoxication delirium
        "F12222",  # Cannabis dependence with intoxication with perceptual disturbance
        "F12229",  # Cannabis dependence with intoxication, unspecified
        "F1223",  # Cannabis dependence with withdrawal
        "F12250",  # Cannabis dependence with psychotic disorder with delusions
        "F12251",  # Cannabis dependence with psychotic disorder with hallucinations
        "F12259",  # Cannabis dependence with psychotic disorder, unspecified
        "F12280",  # Cannabis dependence with cannabis-induced anxiety disorder
        "F12288",  # Cannabis dependence with other cannabis-induced disorder
        "F1229",  # Cannabis dependence with unspecified cannabis-induced disorder
        "F1290",  # Cannabis use, unspecified, uncomplicated
        "F1291",  # Cannabis use, unspecified, in remission
        "F12920",  # Cannabis use, unspecified with intoxication, uncomplicated
        "F12921",  # Cannabis use, unspecified with intoxication delirium
        "F12922",  # Cannabis use, unspecified with intoxication with perceptual disturbance
        "F12929",  # Cannabis use, unspecified with intoxication, unspecified
        "F1293",  # Cannabis use, unspecified with withdrawal
        "F12950",  # Cannabis use, unspecified with psychotic disorder with delusions
        "F12951",  # Cannabis use, unspecified with psychotic disorder with hallucinations
        "F12959",  # Cannabis use, unspecified with psychotic disorder, unspecified
        "F12980",  # Cannabis use, unspecified with anxiety disorder
        "F12988",  # Cannabis use, unspecified with other cannabis-induced disorder
        "F1299",  # Cannabis use, unspecified with unspecified cannabis-induced disorder
        "F1310",  # Sedative, hypnotic or anxiolytic abuse, uncomplicated
        "F1311",  # Sedative, hypnotic or anxiolytic abuse, in remission
        "F13120",  # Sedative, hypnotic or anxiolytic abuse with intoxication, uncomplicated
        "F13121",  # Sedative, hypnotic or anxiolytic abuse with intoxication delirium
        "F13129",  # Sedative, hypnotic or anxiolytic abuse with intoxication, unspecified
        "F13130",  # Sedative, hypnotic or anxiolytic abuse with withdrawal, uncomplicated
        "F13131",  # Sedative, hypnotic or anxiolytic abuse with withdrawal delirium
        "F13132",  # Sedative, hypnotic or anxiolytic abuse with withdrawal with perceptual disturbance
        "F13139",  # Sedative, hypnotic or anxiolytic abuse with withdrawal, unspecified
        "F1314",  # Sedative, hypnotic or anxiolytic abuse with sedative, hypnotic or anxiolytic-induced mood disorder
        "F13150",  # Sedative, hypnotic or anxiolytic abuse with sedative, hypnotic or anxiolytic-induced psychotic disorder with delusions
        "F13151",  # Sedative, hypnotic or anxiolytic abuse with sedative, hypnotic or anxiolytic-induced psychotic disorder with hallucinations
        "F13159",  # Sedative, hypnotic or anxiolytic abuse with sedative, hypnotic or anxiolytic-induced psychotic disorder, unspecified
        "F13180",  # Sedative, hypnotic or anxiolytic abuse with sedative, hypnotic or anxiolytic-induced anxiety disorder
        "F13181",  # Sedative, hypnotic or anxiolytic abuse with sedative, hypnotic or anxiolytic-induced sexual dysfunction
        "F13182",  # Sedative, hypnotic or anxiolytic abuse with sedative, hypnotic or anxiolytic-induced sleep disorder
        "F13188",  # Sedative, hypnotic or anxiolytic abuse with other sedative, hypnotic or anxiolytic-induced disorder
        "F1319",  # Sedative, hypnotic or anxiolytic abuse with unspecified sedative, hypnotic or anxiolytic-induced disorder
        "F1320",  # Sedative, hypnotic or anxiolytic dependence, uncomplicated
        "F1321",  # Sedative, hypnotic or anxiolytic dependence, in remission
        "F13220",  # Sedative, hypnotic or anxiolytic dependence with intoxication, uncomplicated
        "F13221",  # Sedative, hypnotic or anxiolytic dependence with intoxication delirium
        "F13229",  # Sedative, hypnotic or anxiolytic dependence with intoxication, unspecified
        "F13230",  # Sedative, hypnotic or anxiolytic dependence with withdrawal, uncomplicated
        "F13231",  # Sedative, hypnotic or anxiolytic dependence with withdrawal delirium
        "F13232",  # Sedative, hypnotic or anxiolytic dependence with withdrawal with perceptual disturbance
        "F13239",  # Sedative, hypnotic or anxiolytic dependence with withdrawal, unspecified
        "F1324",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced mood disorder
        "F13250",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced psychotic disorder with delusions
        "F13251",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced psychotic disorder with hallucinations
        "F13259",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced psychotic disorder, unspecified
        "F1326",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced persisting amnestic disorder
        "F1327",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced persisting dementia
        "F13280",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced anxiety disorder
        "F13281",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced sexual dysfunction
        "F13282",  # Sedative, hypnotic or anxiolytic dependence with sedative, hypnotic or anxiolytic-induced sleep disorder
        "F13288",  # Sedative, hypnotic or anxiolytic dependence with other sedative, hypnotic or anxiolytic-induced disorder
        "F1329",  # Sedative, hypnotic or anxiolytic dependence with unspecified sedative, hypnotic or anxiolytic-induced disorder
        "F1390",  # Sedative, hypnotic, or anxiolytic use, unspecified, uncomplicated
        "F1391",  # Sedative, hypnotic or anxiolytic use, unspecified, in remission
        "F13920",  # Sedative, hypnotic or anxiolytic use, unspecified with intoxication, uncomplicated
        "F13921",  # Sedative, hypnotic or anxiolytic use, unspecified with intoxication delirium
        "F13929",  # Sedative, hypnotic or anxiolytic use, unspecified with intoxication, unspecified
        "F13930",  # Sedative, hypnotic or anxiolytic use, unspecified with withdrawal, uncomplicated
        "F13931",  # Sedative, hypnotic or anxiolytic use, unspecified with withdrawal delirium
        "F13932",  # Sedative, hypnotic or anxiolytic use, unspecified with withdrawal with perceptual disturbances
        "F13939",  # Sedative, hypnotic or anxiolytic use, unspecified with withdrawal, unspecified
        "F1394",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced mood disorder
        "F13950",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced psychotic disorder with delusions
        "F13951",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced psychotic disorder with hallucinations
        "F13959",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced psychotic disorder, unspecified
        "F1396",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced persisting amnestic disorder
        "F1397",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced persisting dementia
        "F13980",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced anxiety disorder
        "F13981",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced sexual dysfunction
        "F13982",  # Sedative, hypnotic or anxiolytic use, unspecified with sedative, hypnotic or anxiolytic-induced sleep disorder
        "F13988",  # Sedative, hypnotic or anxiolytic use, unspecified with other sedative, hypnotic or anxiolytic-induced disorder
        "F1399",  # Sedative, hypnotic or anxiolytic use, unspecified with unspecified sedative, hypnotic or anxiolytic-induced disorder
        "F1410",  # Cocaine abuse, uncomplicated
        "F1411",  # Cocaine abuse, in remission
        "F14120",  # Cocaine abuse with intoxication, uncomplicated
        "F14121",  # Cocaine abuse with intoxication with delirium
        "F14122",  # Cocaine abuse with intoxication with perceptual disturbance
        "F14129",  # Cocaine abuse with intoxication, unspecified
        "F1413",  # Cocaine abuse, unspecified with withdrawal
        "F1414",  # Cocaine abuse with cocaine-induced mood disorder
        "F14150",  # Cocaine abuse with cocaine-induced psychotic disorder with delusions
        "F14151",  # Cocaine abuse with cocaine-induced psychotic disorder with hallucinations
        "F14159",  # Cocaine abuse with cocaine-induced psychotic disorder, unspecified
        "F14180",  # Cocaine abuse with cocaine-induced anxiety disorder
        "F14181",  # Cocaine abuse with cocaine-induced sexual dysfunction
        "F14182",  # Cocaine abuse with cocaine-induced sleep disorder
        "F14188",  # Cocaine abuse with other cocaine-induced disorder
        "F1419",  # Cocaine abuse with unspecified cocaine-induced disorder
        "F1420",  # Cocaine dependence, uncomplicated
        "F1421",  # Cocaine dependence, in remission
        "F14220",  # Cocaine dependence with intoxication, uncomplicated
        "F14221",  # Cocaine dependence with intoxication delirium
        "F14222",  # Cocaine dependence with intoxication with perceptual disturbance
        "F14229",  # Cocaine dependence with intoxication, unspecified
        "F1423",  # Cocaine dependence with withdrawal
        "F1424",  # Cocaine dependence with cocaine-induced mood disorder
        "F14250",  # Cocaine dependence with cocaine-induced psychotic disorder with delusions
        "F14251",  # Cocaine dependence with cocaine-induced psychotic disorder with hallucinations
        "F14259",  # Cocaine dependence with cocaine-induced psychotic disorder, unspecified
        "F14280",  # Cocaine dependence with cocaine-induced anxiety disorder
        "F14281",  # Cocaine dependence with cocaine-induced sexual dysfunction
        "F14282",  # Cocaine dependence with cocaine-induced sleep disorder
        "F14288",  # Cocaine dependence with other cocaine-induced disorder
        "F1429",  # Cocaine dependence with unspecified cocaine-induced disorder
        "F1490",  # Cocaine use, unspecified, uncomplicated
        "F1491",  # Cocaine use, unspecified, in remission
        "F14920",  # Cocaine use, unspecified with intoxication, uncomplicated
        "F14921",  # Cocaine use, unspecified with intoxication delirium
        "F14922",  # Cocaine use, unspecified with intoxication with perceptual disturbance
        "F14929",  # Cocaine use, unspecified with intoxication, unspecified
        "F1493",  # Cocaine use, unspecified with withdrawal
        "F1494",  # Cocaine use, unspecified with cocaine-induced mood disorder
        "F14950",  # Cocaine use, unspecified with cocaine-induced psychotic disorder with delusions
        "F14951",  # Cocaine use, unspecified with cocaine-induced psychotic disorder with hallucinations
        "F14959",  # Cocaine use, unspecified with cocaine-induced psychotic disorder, unspecified
        "F14980",  # Cocaine use, unspecified with cocaine-induced anxiety disorder
        "F14981",  # Cocaine use, unspecified with cocaine-induced sexual dysfunction
        "F14982",  # Cocaine use, unspecified with cocaine-induced sleep disorder
        "F14988",  # Cocaine use, unspecified with other cocaine-induced disorder
        "F1499",  # Cocaine use, unspecified with unspecified cocaine-induced disorder
        "F1510",  # Other stimulant abuse, uncomplicated
        "F1511",  # Other stimulant abuse, in remission
        "F15120",  # Other stimulant abuse with intoxication, uncomplicated
        "F15121",  # Other stimulant abuse with intoxication delirium
        "F15122",  # Other stimulant abuse with intoxication with perceptual disturbance
        "F15129",  # Other stimulant abuse with intoxication, unspecified
        "F1513",  # Other stimulant abuse with withdrawal
        "F1514",  # Other stimulant abuse with stimulant-induced mood disorder
        "F15150",  # Other stimulant abuse with stimulant-induced psychotic disorder with delusions
        "F15151",  # Other stimulant abuse with stimulant-induced psychotic disorder with hallucinations
        "F15159",  # Other stimulant abuse with stimulant-induced psychotic disorder, unspecified
        "F15180",  # Other stimulant abuse with stimulant-induced anxiety disorder
        "F15181",  # Other stimulant abuse with stimulant-induced sexual dysfunction
        "F15182",  # Other stimulant abuse with stimulant-induced sleep disorder
        "F15188",  # Other stimulant abuse with other stimulant-induced disorder
        "F1519",  # Other stimulant abuse with unspecified stimulant-induced disorder
        "F1520",  # Other stimulant dependence, uncomplicated
        "F1521",  # Other stimulant dependence, in remission
        "F15220",  # Other stimulant dependence with intoxication, uncomplicated
        "F15221",  # Other stimulant dependence with intoxication delirium
        "F15222",  # Other stimulant dependence with intoxication with perceptual disturbance
        "F15229",  # Other stimulant dependence with intoxication, unspecified
        "F1523",  # Other stimulant dependence with withdrawal
        "F1524",  # Other stimulant dependence with stimulant-induced mood disorder
        "F15250",  # Other stimulant dependence with stimulant-induced psychotic disorder with delusions
        "F15251",  # Other stimulant dependence with stimulant-induced psychotic disorder with hallucinations
        "F15259",  # Other stimulant dependence with stimulant-induced psychotic disorder, unspecified
        "F15280",  # Other stimulant dependence with stimulant-induced anxiety disorder
        "F15281",  # Other stimulant dependence with stimulant-induced sexual dysfunction
        "F15282",  # Other stimulant dependence with stimulant-induced sleep disorder
        "F15288",  # Other stimulant dependence with other stimulant-induced disorder
        "F1529",  # Other stimulant dependence with unspecified stimulant-induced disorder
        "F1590",  # Other stimulant use, unspecified, uncomplicated
        "F1591",  # Other stimulant use, unspecified, in remission
        "F15920",  # Other stimulant use, unspecified with intoxication, uncomplicated
        "F15921",  # Other stimulant use, unspecified with intoxication delirium
        "F15922",  # Other stimulant use, unspecified with intoxication with perceptual disturbance
        "F15929",  # Other stimulant use, unspecified with intoxication, unspecified
        "F1593",  # Other stimulant use, unspecified with withdrawal
        "F1594",  # Other stimulant use, unspecified with stimulant-induced mood disorder
        "F15950",  # Other stimulant use, unspecified with stimulant-induced psychotic disorder with delusions
        "F15951",  # Other stimulant use, unspecified with stimulant-induced psychotic disorder with hallucinations
        "F15959",  # Other stimulant use, unspecified with stimulant-induced psychotic disorder, unspecified
        "F15980",  # Other stimulant use, unspecified with stimulant-induced anxiety disorder
        "F15981",  # Other stimulant use, unspecified with stimulant-induced sexual dysfunction
        "F15982",  # Other stimulant use, unspecified with stimulant-induced sleep disorder
        "F15988",  # Other stimulant use, unspecified with other stimulant-induced disorder
        "F1599",  # Other stimulant use, unspecified with unspecified stimulant-induced disorder
        "F1610",  # Hallucinogen abuse, uncomplicated
        "F1611",  # Hallucinogen abuse, in remission
        "F16120",  # Hallucinogen abuse with intoxication, uncomplicated
        "F16121",  # Hallucinogen abuse with intoxication with delirium
        "F16122",  # Hallucinogen abuse with intoxication with perceptual disturbance
        "F16129",  # Hallucinogen abuse with intoxication, unspecified
        "F1614",  # Hallucinogen abuse with hallucinogen-induced mood disorder
        "F16150",  # Hallucinogen abuse with hallucinogen-induced psychotic disorder with delusions
        "F16151",  # Hallucinogen abuse with hallucinogen-induced psychotic disorder with hallucinations
        "F16159",  # Hallucinogen abuse with hallucinogen-induced psychotic disorder, unspecified
        "F16180",  # Hallucinogen abuse with hallucinogen-induced anxiety disorder
        "F16183",  # Hallucinogen abuse with hallucinogen persisting perception disorder (flashbacks)
        "F16188",  # Hallucinogen abuse with other hallucinogen-induced disorder
        "F1619",  # Hallucinogen abuse with unspecified hallucinogen-induced disorder
        "F1620",  # Hallucinogen dependence, uncomplicated
        "F1621",  # Hallucinogen dependence, in remission
        "F16220",  # Hallucinogen dependence with intoxication, uncomplicated
        "F16221",  # Hallucinogen dependence with intoxication with delirium
        "F16229",  # Hallucinogen dependence with intoxication, unspecified
        "F1624",  # Hallucinogen dependence with hallucinogen-induced mood disorder
        "F16250",  # Hallucinogen dependence with hallucinogen-induced psychotic disorder with delusions
        "F16251",  # Hallucinogen dependence with hallucinogen-induced psychotic disorder with hallucinations
        "F16259",  # Hallucinogen dependence with hallucinogen-induced psychotic disorder, unspecified
        "F16280",  # Hallucinogen dependence with hallucinogen-induced anxiety disorder
        "F16283",  # Hallucinogen dependence with hallucinogen persisting perception disorder (flashbacks)
        "F16288",  # Hallucinogen dependence with other hallucinogen-induced disorder
        "F1629",  # Hallucinogen dependence with unspecified hallucinogen-induced disorder
        "F1690",  # Hallucinogen use, unspecified, uncomplicated
        "F1691",  # Hallucinogen use, unspecified, in remission
        "F16920",  # Hallucinogen use, unspecified with intoxication, uncomplicated
        "F16921",  # Hallucinogen use, unspecified with intoxication with delirium
        "F16929",  # Hallucinogen use, unspecified with intoxication, unspecified
        "F1694",  # Hallucinogen use, unspecified with hallucinogen-induced mood disorder
        "F16950",  # Hallucinogen use, unspecified with hallucinogen-induced psychotic disorder with delusions
        "F16951",  # Hallucinogen use, unspecified with hallucinogen-induced psychotic disorder with hallucinations
        "F16959",  # Hallucinogen use, unspecified with hallucinogen-induced psychotic disorder, unspecified
        "F16980",  # Hallucinogen use, unspecified with hallucinogen-induced anxiety disorder
        "F16983",  # Hallucinogen use, unspecified with hallucinogen persisting perception disorder (flashbacks)
        "F16988",  # Hallucinogen use, unspecified with other hallucinogen-induced disorder
        "F1699",  # Hallucinogen use, unspecified with unspecified hallucinogen-induced disorder
        "F17200",  # Nicotine dependence, unspecified, uncomplicated
        "F17201",  # Nicotine dependence, unspecified, in remission
        "F17203",  # Nicotine dependence unspecified, with withdrawal
        "F17208",  # Nicotine dependence, unspecified, with other nicotine-induced disorders
        "F17209",  # Nicotine dependence, unspecified, with unspecified nicotine-induced disorders
        "F17210",  # Nicotine dependence, cigarettes, uncomplicated
        "F17211",  # Nicotine dependence, cigarettes, in remission
        "F17213",  # Nicotine dependence, cigarettes, with withdrawal
        "F17218",  # Nicotine dependence, cigarettes, with other nicotine-induced disorders
        "F17219",  # Nicotine dependence, cigarettes, with unspecified nicotine-induced disorders
        "F17220",  # Nicotine dependence, chewing tobacco, uncomplicated
        "F17221",  # Nicotine dependence, chewing tobacco, in remission
        "F17223",  # Nicotine dependence, chewing tobacco, with withdrawal
        "F17228",  # Nicotine dependence, chewing tobacco, with other nicotine-induced disorders
        "F17229",  # Nicotine dependence, chewing tobacco, with unspecified nicotine-induced disorders
        "F17290",  # Nicotine dependence, other tobacco product, uncomplicated
        "F17291",  # Nicotine dependence, other tobacco product, in remission
        "F17293",  # Nicotine dependence, other tobacco product, with withdrawal
        "F17298",  # Nicotine dependence, other tobacco product, with other nicotine-induced disorders
        "F17299",  # Nicotine dependence, other tobacco product, with unspecified nicotine-induced disorders
        "F1810",  # Inhalant abuse, uncomplicated
        "F1811",  # Inhalant abuse, in remission
        "F18120",  # Inhalant abuse with intoxication, uncomplicated
        "F18121",  # Inhalant abuse with intoxication delirium
        "F18129",  # Inhalant abuse with intoxication, unspecified
        "F1814",  # Inhalant abuse with inhalant-induced mood disorder
        "F18150",  # Inhalant abuse with inhalant-induced psychotic disorder with delusions
        "F18151",  # Inhalant abuse with inhalant-induced psychotic disorder with hallucinations
        "F18159",  # Inhalant abuse with inhalant-induced psychotic disorder, unspecified
        "F1817",  # Inhalant abuse with inhalant-induced dementia
        "F18180",  # Inhalant abuse with inhalant-induced anxiety disorder
        "F18188",  # Inhalant abuse with other inhalant-induced disorder
        "F1819",  # Inhalant abuse with unspecified inhalant-induced disorder
        "F1820",  # Inhalant dependence, uncomplicated
        "F1821",  # Inhalant dependence, in remission
        "F18220",  # Inhalant dependence with intoxication, uncomplicated
        "F18221",  # Inhalant dependence with intoxication delirium
        "F18229",  # Inhalant dependence with intoxication, unspecified
        "F1824",  # Inhalant dependence with inhalant-induced mood disorder
        "F18250",  # Inhalant dependence with inhalant-induced psychotic disorder with delusions
        "F18251",  # Inhalant dependence with inhalant-induced psychotic disorder with hallucinations
        "F18259",  # Inhalant dependence with inhalant-induced psychotic disorder, unspecified
        "F1827",  # Inhalant dependence with inhalant-induced dementia
        "F18280",  # Inhalant dependence with inhalant-induced anxiety disorder
        "F18288",  # Inhalant dependence with other inhalant-induced disorder
        "F1829",  # Inhalant dependence with unspecified inhalant-induced disorder
        "F1890",  # Inhalant use, unspecified, uncomplicated
        "F1891",  # Inhalant use, unspecified, in remission
        "F18920",  # Inhalant use, unspecified with intoxication, uncomplicated
        "F18921",  # Inhalant use, unspecified with intoxication with delirium
        "F18929",  # Inhalant use, unspecified with intoxication, unspecified
        "F1894",  # Inhalant use, unspecified with inhalant-induced mood disorder
        "F18950",  # Inhalant use, unspecified with inhalant-induced psychotic disorder with delusions
        "F18951",  # Inhalant use, unspecified with inhalant-induced psychotic disorder with hallucinations
        "F18959",  # Inhalant use, unspecified with inhalant-induced psychotic disorder, unspecified
        "F1897",  # Inhalant use, unspecified with inhalant-induced persisting dementia
        "F18980",  # Inhalant use, unspecified with inhalant-induced anxiety disorder
        "F18988",  # Inhalant use, unspecified with other inhalant-induced disorder
        "F1899",  # Inhalant use, unspecified with unspecified inhalant-induced disorder
        "F1910",  # Other psychoactive substance abuse, uncomplicated
        "F1911",  # Other psychoactive substance abuse, in remission
        "F19120",  # Other psychoactive substance abuse with intoxication, uncomplicated
        "F19121",  # Other psychoactive substance abuse with intoxication delirium
        "F19122",  # Other psychoactive substance abuse with intoxication with perceptual disturbances
        "F19129",  # Other psychoactive substance abuse with intoxication, unspecified
        "F19130",  # Other psychoactive substance abuse with withdrawal, uncomplicated
        "F19131",  # Other psychoactive substance abuse with withdrawal delirium
        "F19132",  # Other psychoactive substance abuse with withdrawal with perceptual disturbance
        "F19139",  # Other psychoactive substance abuse with withdrawal, unspecified
        "F1914",  # Other psychoactive substance abuse with psychoactive substance-induced mood disorder
        "F19150",  # Other psychoactive substance abuse with psychoactive substance-induced psychotic disorder with delusions
        "F19151",  # Other psychoactive substance abuse with psychoactive substance-induced psychotic disorder with hallucinations
        "F19159",  # Other psychoactive substance abuse with psychoactive substance-induced psychotic disorder, unspecified
        "F1916",  # Other psychoactive substance abuse with psychoactive substance-induced persisting amnestic disorder
        "F1917",  # Other psychoactive substance abuse with psychoactive substance-induced persisting dementia
        "F19180",  # Other psychoactive substance abuse with psychoactive substance-induced anxiety disorder
        "F19181",  # Other psychoactive substance abuse with psychoactive substance-induced sexual dysfunction
        "F19182",  # Other psychoactive substance abuse with psychoactive substance-induced sleep disorder
        "F19188",  # Other psychoactive substance abuse with other psychoactive substance-induced disorder
        "F1919",  # Other psychoactive substance abuse with unspecified psychoactive substance-induced disorder
        "F1920",  # Other psychoactive substance dependence, uncomplicated
        "F1921",  # Other psychoactive substance dependence, in remission
        "F19220",  # Other psychoactive substance dependence with intoxication, uncomplicated
        "F19221",  # Other psychoactive substance dependence with intoxication delirium
        "F19222",  # Other psychoactive substance dependence with intoxication with perceptual disturbance
        "F19229",  # Other psychoactive substance dependence with intoxication, unspecified
        "F19230",  # Other psychoactive substance dependence with withdrawal, uncomplicated
        "F19231",  # Other psychoactive substance dependence with withdrawal delirium
        "F19232",  # Other psychoactive substance dependence with withdrawal with perceptual disturbance
        "F19239",  # Other psychoactive substance dependence with withdrawal, unspecified
        "F1924",  # Other psychoactive substance dependence with psychoactive substance-induced mood disorder
        "F19250",  # Other psychoactive substance dependence with psychoactive substance-induced psychotic disorder with delusions
        "F19251",  # Other psychoactive substance dependence with psychoactive substance-induced psychotic disorder with hallucinations
        "F19259",  # Other psychoactive substance dependence with psychoactive substance-induced psychotic disorder, unspecified
        "F1926",  # Other psychoactive substance dependence with psychoactive substance-induced persisting amnestic disorder
        "F1927",  # Other psychoactive substance dependence with psychoactive substance-induced persisting dementia
        "F19280",  # Other psychoactive substance dependence with psychoactive substance-induced anxiety disorder
        "F19281",  # Other psychoactive substance dependence with psychoactive substance-induced sexual dysfunction
        "F19282",  # Other psychoactive substance dependence with psychoactive substance-induced sleep disorder
        "F19288",  # Other psychoactive substance dependence with other psychoactive substance-induced disorder
        "F1929",  # Other psychoactive substance dependence with unspecified psychoactive substance-induced disorder
        "F1990",  # Other psychoactive substance use, unspecified, uncomplicated
        "F1991",  # Other psychoactive substance use, unspecified, in remission
        "F19920",  # Other psychoactive substance use, unspecified with intoxication, uncomplicated
        "F19921",  # Other psychoactive substance use, unspecified with intoxication with delirium
        "F19922",  # Other psychoactive substance use, unspecified with intoxication with perceptual disturbance
        "F19929",  # Other psychoactive substance use, unspecified with intoxication, unspecified
        "F19930",  # Other psychoactive substance use, unspecified with withdrawal, uncomplicated
        "F19931",  # Other psychoactive substance use, unspecified with withdrawal delirium
        "F19932",  # Other psychoactive substance use, unspecified with withdrawal with perceptual disturbance
        "F19939",  # Other psychoactive substance use, unspecified with withdrawal, unspecified
        "F1994",  # Other psychoactive substance use, unspecified with psychoactive substance-induced mood disorder
        "F19950",  # Other psychoactive substance use, unspecified with psychoactive substance-induced psychotic disorder with delusions
        "F19951",  # Other psychoactive substance use, unspecified with psychoactive substance-induced psychotic disorder with hallucinations
        "F19959",  # Other psychoactive substance use, unspecified with psychoactive substance-induced psychotic disorder, unspecified
        "F1996",  # Other psychoactive substance use, unspecified with psychoactive substance-induced persisting amnestic disorder
        "F1997",  # Other psychoactive substance use, unspecified with psychoactive substance-induced persisting dementia
        "F19980",  # Other psychoactive substance use, unspecified with psychoactive substance-induced anxiety disorder
        "F19981",  # Other psychoactive substance use, unspecified with psychoactive substance-induced sexual dysfunction
        "F19982",  # Other psychoactive substance use, unspecified with psychoactive substance-induced sleep disorder
        "F19988",  # Other psychoactive substance use, unspecified with other psychoactive substance-induced disorder
        "F1999",  # Other psychoactive substance use, unspecified with unspecified psychoactive substance-induced disorder
        "F200",  # Paranoid schizophrenia
        "F201",  # Disorganized schizophrenia
        "F202",  # Catatonic schizophrenia
        "F203",  # Undifferentiated schizophrenia
        "F205",  # Residual schizophrenia
        "F2081",  # Schizophreniform disorder
        "F2089",  # Other schizophrenia
        "F209",  # Schizophrenia, unspecified
        "F21",  # Schizotypal disorder
        "F22",  # Delusional disorders
        "F23",  # Brief psychotic disorder
        "F24",  # Shared psychotic disorder
        "F250",  # Schizoaffective disorder, bipolar type
        "F251",  # Schizoaffective disorder, depressive type
        "F258",  # Other schizoaffective disorders
        "F259",  # Schizoaffective disorder, unspecified
        "F28",  # Other psychotic disorder not due to a substance or known physiological condition
        "F29",  # Unspecified psychosis not due to a substance or known physiological condition
        "F3010",  # Manic episode without psychotic symptoms, unspecified
        "F3011",  # Manic episode without psychotic symptoms, mild
        "F3012",  # Manic episode without psychotic symptoms, moderate
        "F3013",  # Manic episode, severe, without psychotic symptoms
        "F302",  # Manic episode, severe with psychotic symptoms
        "F303",  # Manic episode in partial remission
        "F304",  # Manic episode in full remission
        "F308",  # Other manic episodes
        "F309",  # Manic episode, unspecified
        "F310",  # Bipolar disorder, current episode hypomanic
        "F3110",  # Bipolar disorder, current episode manic without psychotic features, unspecified
        "F3111",  # Bipolar disorder, current episode manic without psychotic features, mild
        "F3112",  # Bipolar disorder, current episode manic without psychotic features, moderate
        "F3113",  # Bipolar disorder, current episode manic without psychotic features, severe
        "F312",  # Bipolar disorder, current episode manic severe with psychotic features
        "F3130",  # Bipolar disorder, current episode depressed, mild or moderate severity, unspecified
        "F3131",  # Bipolar disorder, current episode depressed, mild
        "F3132",  # Bipolar disorder, current episode depressed, moderate
        "F314",  # Bipolar disorder, current episode depressed, severe, without psychotic features
        "F315",  # Bipolar disorder, current episode depressed, severe, with psychotic features
        "F3160",  # Bipolar disorder, current episode mixed, unspecified
        "F3161",  # Bipolar disorder, current episode mixed, mild
        "F3162",  # Bipolar disorder, current episode mixed, moderate
        "F3163",  # Bipolar disorder, current episode mixed, severe, without psychotic features
        "F3164",  # Bipolar disorder, current episode mixed, severe, with psychotic features
        "F3170",  # Bipolar disorder, currently in remission, most recent episode unspecified
        "F3171",  # Bipolar disorder, in partial remission, most recent episode hypomanic
        "F3172",  # Bipolar disorder, in full remission, most recent episode hypomanic
        "F3173",  # Bipolar disorder, in partial remission, most recent episode manic
        "F3174",  # Bipolar disorder, in full remission, most recent episode manic
        "F3175",  # Bipolar disorder, in partial remission, most recent episode depressed
        "F3176",  # Bipolar disorder, in full remission, most recent episode depressed
        "F3177",  # Bipolar disorder, in partial remission, most recent episode mixed
        "F3178",  # Bipolar disorder, in full remission, most recent episode mixed
        "F3181",  # Bipolar II disorder
        "F3189",  # Other bipolar disorder
        "F319",  # Bipolar disorder, unspecified
        "F320",  # Major depressive disorder, single episode, mild
        "F321",  # Major depressive disorder, single episode, moderate
        "F322",  # Major depressive disorder, single episode, severe without psychotic features
        "F323",  # Major depressive disorder, single episode, severe with psychotic features
        "F324",  # Major depressive disorder, single episode, in partial remission
        "F325",  # Major depressive disorder, single episode, in full remission
        "F3281",  # Premenstrual dysphoric disorder
        "F3289",  # Other specified depressive episodes
        "F329",  # Major depressive disorder, single episode, unspecified
        "F32A",  # Depression, unspecified
        "F330",  # Major depressive disorder, recurrent, mild
        "F331",  # Major depressive disorder, recurrent, moderate
        "F332",  # Major depressive disorder, recurrent severe without psychotic features
        "F333",  # Major depressive disorder, recurrent, severe with psychotic symptoms
        "F3340",  # Major depressive disorder, recurrent, in remission, unspecified
        "F3341",  # Major depressive disorder, recurrent, in partial remission
        "F3342",  # Major depressive disorder, recurrent, in full remission
        "F338",  # Other recurrent depressive disorders
        "F339",  # Major depressive disorder, recurrent, unspecified
        "F340",  # Cyclothymic disorder
        "F341",  # Dysthymic disorder
        "F3481",  # Disruptive mood dysregulation disorder
        "F3489",  # Other specified persistent mood disorders
        "F349",  # Persistent mood [affective] disorder, unspecified
        "F39",  # Unspecified mood [affective] disorder
        "F4000",  # Agoraphobia, unspecified
        "F4001",  # Agoraphobia with panic disorder
        "F4002",  # Agoraphobia without panic disorder
        "F4010",  # Social phobia, unspecified
        "F4011",  # Social phobia, generalized
        "F40210",  # Arachnophobia
        "F40218",  # Other animal type phobia
        "F40220",  # Fear of thunderstorms
        "F40228",  # Other natural environment type phobia
        "F40230",  # Fear of blood
        "F40231",  # Fear of injections and transfusions
        "F40232",  # Fear of other medical care
        "F40233",  # Fear of injury
        "F40240",  # Claustrophobia
        "F40241",  # Acrophobia
        "F40242",  # Fear of bridges
        "F40243",  # Fear of flying
        "F40248",  # Other situational type phobia
        "F40290",  # Androphobia
        "F40291",  # Gynephobia
        "F40298",  # Other specified phobia
        "F408",  # Other phobic anxiety disorders
        "F409",  # Phobic anxiety disorder, unspecified
        "F410",  # Panic disorder [episodic paroxysmal anxiety]
        "F411",  # Generalized anxiety disorder
        "F413",  # Other mixed anxiety disorders
        "F418",  # Other specified anxiety disorders
        "F419",  # Anxiety disorder, unspecified
        "F422",  # Mixed obsessional thoughts and acts
        "F423",  # Hoarding disorder
        "F424",  # Excoriation (skin-picking) disorder
        "F428",  # Other obsessive-compulsive disorder
        "F429",  # Obsessive-compulsive disorder, unspecified
        "F430",  # Acute stress reaction
        "F4310",  # Post-traumatic stress disorder, unspecified
        "F4311",  # Post-traumatic stress disorder, acute
        "F4312",  # Post-traumatic stress disorder, chronic
        "F4320",  # Adjustment disorder, unspecified
        "F4321",  # Adjustment disorder with depressed mood
        "F4322",  # Adjustment disorder with anxiety
        "F4323",  # Adjustment disorder with mixed anxiety and depressed mood
        "F4324",  # Adjustment disorder with disturbance of conduct
        "F4325",  # Adjustment disorder with mixed disturbance of emotions and conduct
        "F4329",  # Adjustment disorder with other symptoms
        "F4381",  # Prolonged grief disorder
        "F4389",  # Other reactions to severe stress
        "F439",  # Reaction to severe stress, unspecified
        "F440",  # Dissociative amnesia
        "F441",  # Dissociative fugue
        "F442",  # Dissociative stupor
        "F444",  # Conversion disorder with motor symptom or deficit
        "F445",  # Conversion disorder with seizures or convulsions
        "F446",  # Conversion disorder with sensory symptom or deficit
        "F447",  # Conversion disorder with mixed symptom presentation
        "F4481",  # Dissociative identity disorder
        "F4489",  # Other dissociative and conversion disorders
        "F449",  # Dissociative and conversion disorder, unspecified
        "F450",  # Somatization disorder
        "F451",  # Undifferentiated somatoform disorder
        "F4520",  # Hypochondriacal disorder, unspecified
        "F4521",  # Hypochondriasis
        "F4522",  # Body dysmorphic disorder
        "F4529",  # Other hypochondriacal disorders
        "F4541",  # Pain disorder exclusively related to psychological factors
        "F4542",  # Pain disorder with related psychological factors
        "F458",  # Other somatoform disorders
        "F459",  # Somatoform disorder, unspecified
        "F481",  # Depersonalization-derealization syndrome
        "F482",  # Pseudobulbar affect
        "F488",  # Other specified nonpsychotic mental disorders
        "F489",  # Nonpsychotic mental disorder, unspecified
        "F5000",  # Anorexia nervosa, unspecified
        "F5001",  # Anorexia nervosa, restricting type
        "F5002",  # Anorexia nervosa, binge eating/purging type
        "F502",  # Bulimia nervosa
        "F5081",  # Binge eating disorder
        "F5082",  # Avoidant/restrictive food intake disorder
        "F5089",  # Other specified eating disorder
        "F509",  # Eating disorder, unspecified
        "F5101",  # Primary insomnia
        "F5102",  # Adjustment insomnia
        "F5103",  # Paradoxical insomnia
        "F5104",  # Psychophysiologic insomnia
        "F5105",  # Insomnia due to other mental disorder
        "F5109",  # Other insomnia not due to a substance or known physiological condition
        "F5111",  # Primary hypersomnia
        "F5112",  # Insufficient sleep syndrome
        "F5113",  # Hypersomnia due to other mental disorder
        "F5119",  # Other hypersomnia not due to a substance or known physiological condition
        "F513",  # Sleepwalking [somnambulism]
        "F514",  # Sleep terrors [night terrors]
        "F515",  # Nightmare disorder
        "F518",  # Other sleep disorders not due to a substance or known physiological condition
        "F519",  # Sleep disorder not due to a substance or known physiological condition, unspecified
        "F520",  # Hypoactive sexual desire disorder
        "F521",  # Sexual aversion disorder
        "F5221",  # Male erectile disorder
        "F5222",  # Female sexual arousal disorder
        "F5231",  # Female orgasmic disorder
        "F5232",  # Male orgasmic disorder
        "F524",  # Premature ejaculation
        "F525",  # Vaginismus not due to a substance or known physiological condition
        "F526",  # Dyspareunia not due to a substance or known physiological condition
        "F528",  # Other sexual dysfunction not due to a substance or known physiological condition
        "F529",  # Unspecified sexual dysfunction not due to a substance or known physiological condition
        "F530",  # Postpartum depression
        "F531",  # Puerperal psychosis
        "F54",  # Psychological and behavioral factors associated with disorders or diseases classified elsewhere
        "F550",  # Abuse of antacids
        "F551",  # Abuse of herbal or folk remedies
        "F552",  # Abuse of laxatives
        "F553",  # Abuse of steroids or hormones
        "F554",  # Abuse of vitamins
        "F558",  # Abuse of other non-psychoactive substances
        "F59",  # Unspecified behavioral syndromes associated with physiological disturbances and physical factors
        "F600",  # Paranoid personality disorder
        "F601",  # Schizoid personality disorder
        "F602",  # Antisocial personality disorder
        "F603",  # Borderline personality disorder
        "F604",  # Histrionic personality disorder
        "F605",  # Obsessive-compulsive personality disorder
        "F606",  # Avoidant personality disorder
        "F607",  # Dependent personality disorder
        "F6081",  # Narcissistic personality disorder
        "F6089",  # Other specific personality disorders
        "F609",  # Personality disorder, unspecified
        "F630",  # Pathological gambling
        "F631",  # Pyromania
        "F632",  # Kleptomania
        "F633",  # Trichotillomania
        "F6381",  # Intermittent explosive disorder
        "F6389",  # Other impulse disorders
        "F639",  # Impulse disorder, unspecified
        "F640",  # Transsexualism
        "F641",  # Dual role transvestism
        "F642",  # Gender identity disorder of childhood
        "F648",  # Other gender identity disorders
        "F649",  # Gender identity disorder, unspecified
        "F650",  # Fetishism
        "F651",  # Transvestic fetishism
        "F652",  # Exhibitionism
        "F653",  # Voyeurism
        "F654",  # Pedophilia
        "F6550",  # Sadomasochism, unspecified
        "F6551",  # Sexual masochism
        "F6552",  # Sexual sadism
        "F6581",  # Frotteurism
        "F6589",  # Other paraphilias
        "F659",  # Paraphilia, unspecified
        "F66",  # Other sexual disorders
        "F6810",  # Factitious disorder imposed on self, unspecified
        "F6811",  # Factitious disorder imposed on self, with predominantly psychological signs and symptoms
        "F6812",  # Factitious disorder imposed on self, with predominantly physical signs and symptoms
        "F6813",  # Factitious disorder imposed on self, with combined psychological and physical signs and symptoms
        "F688",  # Other specified disorders of adult personality and behavior
        "F68A",  # Factitious disorder imposed on another
        "F69",  # Unspecified disorder of adult personality and behavior
        "F70",  # Mild intellectual disabilities
        "F71",  # Moderate intellectual disabilities
        "F72",  # Severe intellectual disabilities
        "F73",  # Profound intellectual disabilities
        "F78A1",  # SYNGAP1-related intellectual disability
        "F78A9",  # Other genetic related intellectual disability
        "F79",  # Unspecified intellectual disabilities
        "F800",  # Phonological disorder
        "F801",  # Expressive language disorder
        "F802",  # Mixed receptive-expressive language disorder
        "F804",  # Speech and language development delay due to hearing loss
        "F8081",  # Childhood onset fluency disorder
        "F8082",  # Social pragmatic communication disorder
        "F8089",  # Other developmental disorders of speech and language
        "F809",  # Developmental disorder of speech and language, unspecified
        "F810",  # Specific reading disorder
        "F812",  # Mathematics disorder
        "F8181",  # Disorder of written expression
        "F8189",  # Other developmental disorders of scholastic skills
        "F819",  # Developmental disorder of scholastic skills, unspecified
        "F82",  # Specific developmental disorder of motor function
        "F840",  # Autistic disorder
        "F842",  # Rett's syndrome
        "F843",  # Other childhood disintegrative disorder
        "F845",  # Asperger's syndrome
        "F848",  # Other pervasive developmental disorders
        "F849",  # Pervasive developmental disorder, unspecified
        "F88",  # Other disorders of psychological development
        "F89",  # Unspecified disorder of psychological development
        "F900",  # Attention-deficit hyperactivity disorder, predominantly inattentive type
        "F901",  # Attention-deficit hyperactivity disorder, predominantly hyperactive type
        "F902",  # Attention-deficit hyperactivity disorder, combined type
        "F908",  # Attention-deficit hyperactivity disorder, other type
        "F909",  # Attention-deficit hyperactivity disorder, unspecified type
        "F910",  # Conduct disorder confined to family context
        "F911",  # Conduct disorder, childhood-onset type
        "F912",  # Conduct disorder, adolescent-onset type
        "F913",  # Oppositional defiant disorder
        "F918",  # Other conduct disorders
        "F919",  # Conduct disorder, unspecified
        "F930",  # Separation anxiety disorder of childhood
        "F938",  # Other childhood emotional disorders
        "F939",  # Childhood emotional disorder, unspecified
        "F940",  # Selective mutism
        "F941",  # Reactive attachment disorder of childhood
        "F942",  # Disinhibited attachment disorder of childhood
        "F948",  # Other childhood disorders of social functioning
        "F949",  # Childhood disorder of social functioning, unspecified
        "F950",  # Transient tic disorder
        "F951",  # Chronic motor or vocal tic disorder
        "F952",  # Tourette's disorder
        "F958",  # Other tic disorders
        "F959",  # Tic disorder, unspecified
        "F980",  # Enuresis not due to a substance or known physiological condition
        "F981",  # Encopresis not due to a substance or known physiological condition
        "F9821",  # Rumination disorder of infancy and childhood
        "F9829",  # Other feeding disorders of infancy and early childhood
        "F983",  # Pica of infancy and childhood
        "F984",  # Stereotyped movement disorders
        "F985",  # Adult onset fluency disorder
        "F988",  # Other specified behavioral and emotional disorders with onset usually occurring in childhood and adolescence
        "F989",  # Unspecified behavioral and emotional disorders with onset usually occurring in childhood and adolescence
        "F99",  # Mental disorder, not otherwise specified
    }

    SNOMEDCT = {
        "129605006",  # Postgastrectomy neurosis (disorder)
        "191738003",  # Obsessional neurosis (disorder)
        "192014006",  # Psychogenic rumination (disorder)
        "288511000119108",  # Chronic mood disorder (disorder)
        "31297008",  # Somatoform disorder (disorder)
        "722287002",  # Autism and facial port-wine stain syndrome (disorder)
        "18393005",  # Undifferentiated somatoform disorder (disorder)
        "191561004",  # Subchronic latent schizophrenia (disorder)
        "191562006",  # Chronic latent schizophrenia (disorder)
        "191563001",  # Acute exacerbation of subchronic latent schizophrenia (disorder)
        "191564007",  # Acute exacerbation of chronic latent schizophrenia (disorder)
        "191625000",  # Bipolar affective disorder, currently manic, in full remission (disorder)
        "191634005",  # Bipolar affective disorder, currently depressed, in full remission (disorder)
        "191737008",  # Compulsive neurosis (disorder)
        "191766006",  # Psychoinfantile personality (disorder)
        "274952002",  # Borderline schizophrenia (disorder)
        "30871003",  # Flashbacks (disorder)
        "416073003",  # Long duration flashbacks (disorder)
        "416714005",  # Episodic flashbacks (disorder)
        "417143004",  # Short duration flashbacks (disorder)
        "417360004",  # Duplicative flashbacks (disorder)
        "722065002",  # Okamoto syndrome (disorder)
        "724564005",  # Intellectual developmental disorder due to nutritional deficiency (disorder)
        "724725009",  # Psychoactive substance withdrawal syndrome without complication (disorder)
        "733185001",  # Dementia following injury caused by exposure to ionizing radiation (disorder)
        "788912006",  # Dissociative neurological symptom disorder co-occurrent with tremor (disorder)
        "85561006",  # Alcohol withdrawal syndrome without complication (disorder)
        "10007009",  # Coffin-Siris syndrome (disorder)
        "1003385006",  # Neurodevelopmental disorder due to maternal use of alcohol (disorder)
        "1010630006",  # X-linked complicated corpus callosum dysgenesis (disorder)
        "101421000119107",  # Dementia due to Parkinson's disease (disorder)
        "10211000132109",  # Perinatal depression (disorder)
        "10327003",  # Cocaine-induced mood disorder (disorder)
        "10349009",  # Multi-infarct dementia with delirium (disorder)
        "104851000119103",  # Postpartum major depression in remission (disorder)
        "10532003",  # Primary degenerative dementia of the Alzheimer type, presenile onset, with depression (disorder)
        "105421000119105",  # Early onset Alzheimer's disease with behavioral disturbance (disorder)
        "105451000119102",  # Amnestic disorder associated with general medical condition (disorder)
        "10586006",  # Occupation-related stress disorder (disorder)
        "106015009",  # Mental disorder AND/OR culture bound syndrome (disorder)
        "106021000119105",  # Multi-infarct dementia due to atherosclerosis (disorder)
        "10741871000119101",  # Alcohol dependence in pregnancy (disorder)
        "10743001000119103",  # Anxiety disorder in mother complicating childbirth (disorder)
        "10755001000119102",  # Postpartum mood disorder (disorder)
        "10755041000119100",  # Alcohol dependence in childbirth (disorder)
        "10760421000119102",  # Psychotic disorder in mother complicating childbirth (disorder)
        "10760461000119107",  # Psychotic disorder in mother complicating pregnancy (disorder)
        "10783000",  # Symptomatic pedophilia (disorder)
        "10811121000119102",  # Major depressive disorder in mother complicating childbirth (disorder)
        "10811161000119107",  # Major depressive disorder in mother complicating pregnancy (disorder)
        "10811201000119102",  # Mental disorder in mother complicating childbirth (disorder)
        "10835871000119104",  # Depressive disorder in mother complicating childbirth (disorder)
        "10875004",  # Severe mixed bipolar I disorder with psychotic features, mood-incongruent (disorder)
        "109006",  # Anxiety disorder of childhood OR adolescence (disorder)
        "109478007",  # Kohlschutter's syndrome (disorder)
        "109805003",  # Factitious cheilitis (disorder)
        "10981006",  # Severe mixed bipolar I disorder with psychotic features (disorder)
        "109896009",  # Indication for modification of patient status (disorder)
        "109897000",  # Indication for modification of patient behavior status (disorder)
        "109898005",  # Indication for modification of patient cognitive status (disorder)
        "109899002",  # Indication for modification of patient emotional status (disorder)
        "109900007",  # Indication for modification of patient physical status (disorder)
        "109901006",  # Indication for modification of patient psychological status (disorder)
        "110359009",  # Intellectual disability (disorder)
        "111475002",  # Neurosis (disorder)
        "111477005",  # Reactive attachment disorder of infancy OR early childhood, disinhibited type (disorder)
        "111479008",  # Organic mental disorder (disorder)
        "111480006",  # Psychoactive substance-induced organic dementia (disorder)
        "111482003",  # Subchronic schizophrenia with acute exacerbations (disorder)
        "111483008",  # Catatonic schizophrenia in remission (disorder)
        "111484002",  # Undifferentiated schizophrenia (disorder)
        "111485001",  # Mixed bipolar I disorder in full remission (disorder)
        "111486000",  # Symptomatic sexual sadism (disorder)
        "111487009",  # Dream anxiety disorder (disorder)
        "111490003",  # Panic disorder with agoraphobia, agoraphobic avoidance in partial remission AND severe panic attacks (disorder)
        "111491004",  # Panic disorder with agoraphobia, agoraphobic avoidance in full remission AND panic attacks in partial remission (disorder)
        "111492006",  # Conversion disorder, single episode (disorder)
        "11387009",  # Organic mental disorder caused by psychoactive substance (disorder)
        "1142047007",  # Possession trance disorder (disorder)
        "1144942002",  # Neuropsychiatric disorder due to systemic lupus erythematosus (disorder)
        "1145003",  # Developmental speech disorder (disorder)
        "1148924004",  # Dementia due to deficiency of folic acid (disorder)
        "1153570009",  # Treatment resistant depression (disorder)
        "1153575004",  # Persistent depressive disorder (disorder)
        "1156584007",  # X-linked intellectual disability hypotonic face syndrome (disorder)
        "1156789004",  # Autosomal dominant Alzheimer disease due to mutation of amyloid precursor protein (disorder)
        "1156798001",  # Autosomal dominant Alzheimer disease due to mutation of presenilin 2 (disorder)
        "1156800008",  # Autosomal dominant Alzheimer disease due to mutation of presenilin 1 (disorder)
        "1162462009",  # Angelman syndrome due to maternal monosomy 15q11q13 (disorder)
        "1163406003",  # Foreign accent syndrome (disorder)
        "1167371007",  # Polyhydramnios, megalencephaly, symptomatic epilepsy syndrome (disorder)
        "1167375003",  # Microcephaly, corpus callosum and cerebellar vermis hypoplasia, facial dysmorphism, intellectual disability syndrome (disorder)
        "1169355000",  # Brain malformations, musculoskeletal abnormalities, facial dysmorphism, intellectual disability syndrome (disorder)
        "1169359006",  # Tall stature, intellectual disability, renal anomalies syndrome (disorder)
        "1172594000",  # Congenital labioscrotal agenesis, cerebellar malformation, corneal dystrophy, facial dysmorphism syndrome (disorder)
        "1172624000",  # Arginine-glutamic acid dipeptide repeats-related neurodevelopmental syndrome (disorder)
        "1172626003",  # Telomere maintenance 2-related intellectual disability, neurodevelopmental disorder (disorder)
        "1172627007",  # Early-onset epilepsy, intellectual disability, brain anomalies syndrome (disorder)
        "1172629005",  # Severe growth deficiency, strabismus, extensive dermal melanocytosis, intellectual disability syndrome (disorder)
        "1172630000",  # Global developmental delay, neuro-ophthalmological abnormalities, seizures, intellectual disability syndrome (disorder)
        "1172685001",  # Macrothrombocytopenia, lymphedema, developmental delay, facial dysmorphism, camptodactyly syndrome (disorder)
        "1172691004",  # Chloride voltage-gated channel 4-related X-linked intellectual disability syndrome (disorder)
        "1172697000",  # X-linked female restricted facial dysmorphism, short stature, choanal atresia, intellectual disability (disorder)
        "1172698005",  # Recurrent metabolic encephalomyopathic crises, rhabdomyolysis, cardiac arrhythmia, intellectual disability syndrome (disorder)
        "1172844009",  # Combined oxidative phosphorylation defect type 27 (disorder)
        "1172889005",  # Palatal anomalies, widely spaced teeth, facial dysmorphism, developmental delay syndrome (disorder)
        "1172899000",  # Peripheral myelin protein 22-retinoic acid induced 1 contiguous gene duplication syndrome (disorder)
        "1173036000",  # Combined oxidative phosphorylation defect type 23 (disorder)
        "1173998003",  # Postnatal microcephaly, infantile hypotonia, spastic diplegia, dysarthria, intellectual disability syndrome (disorder)
        "1177001000",  # Tic disorder due to rheumatic chorea (disorder)
        "1177002007",  # Tic disorder due to prion disease (disorder)
        "1177006005",  # Tic disorder due to post-encephalitic syndrome (disorder)
        "1177058004",  # Tic disorder due to encephalitis (disorder)
        "1177060002",  # Tic disorder due to neurosyphilis (disorder)
        "1177167002",  # Intellectual disability, seizures, abnormal gait, facial dysmorphism syndrome (disorder)
        "1177169004",  # Congenital cerebellar ataxia due to RNA, U12 small nuclear mutation (disorder)
        "1177175008",  # Skeletal dysplasia, T-cell immunodeficiency, developmental delay syndrome (disorder)
        "1179282009",  # Severe neurodevelopmental disorder with feeding difficulties, stereotypic hand movement, bilateral cataract (disorder)
        "1179283004",  # Metopic ridging, ptosis, facial dysmorphism syndrome (disorder)
        "1179301003",  # Dual specificity tyrosine phosphorylation regulated kinase 1A-related intellectual disability syndrome (disorder)
        "1179408008",  # Chromodomain helicase dna-binding protein 3- related developmental delay, speech delay, intellectual disability, abnormalities of vision, facial dysmorphism syndrome (disorder)
        "11806006",  # Separation anxiety disorder of childhood (disorder)
        "1186711002",  # G protein subunit beta 5-related intellectual disability, cardiac arrhythmia syndrome (disorder)
        "1186713004",  # Growth delay, intellectual disability, hepatopathy syndrome (disorder)
        "1186721005",  # Infantile inflammatory bowel disease with neurological involvement (disorder)
        "1186723008",  # Prepubertal anorexia nervosa (disorder)
        "1186724002",  # HtrA serine peptidase 1-related autosomal dominant cerebral small vessel disease (disorder)
        "1186729007",  # Intellectual disability, cardiac anomalies, short stature, joint laxity syndrome (disorder)
        "1186730002",  # Gabriele-de Vries syndrome (disorder)
        "1186734006",  # Autosomal recessive complex spastic paraplegia due to Kennedy pathway dysfunction (disorder)
        "1186821000",  # Developmental academic disorder due to deficiency of micronutrients (disorder)
        "1186823002",  # Developmental academic disorder due to nutritional stunting (disorder)
        "1186826005",  # Developmental academic disorder due to iron deficiency (disorder)
        "1186832000",  # Developmental academic disorder due to iodine deficiency (disorder)
        "1186877003",  # Dementia due to vitamin E deficiency (disorder)
        "1186879000",  # Dementia due to thiamine deficiency (disorder)
        "1186880002",  # Dementia due to cobalamin deficiency (disorder)
        "1186881003",  # Dementia due to niacin deficiency (disorder)
        "1186883000",  # Dementia due to nutritional deficiency disorder (disorder)
        "1186887004",  # Dementia caused by manganese and/or manganese compound (disorder)
        "1187004001",  # Chronic traumatic encephalopathy (disorder)
        "1187038009",  # Non-specific syndromic intellectual disability (disorder)
        "1187041000",  # Stromal antigen 1-related intellectual disability, facial dysmorphism, gastroesophageal reflux syndrome (disorder)
        "1187042007",  # Early-onset seizures, distal limb anomalies, facial dysmorphism, global developmental delay syndrome (disorder)
        "1187114007",  # Micrognathia, recurrent infections, behavioral abnormalities, mild intellectual disability syndrome (disorder)
        "1187122000",  # Witteveen Kolk syndrome (disorder)
        "1187126002",  # Integral membrane protein 2B related amyloidosis (disorder)
        "1187195007",  # Microcephalic cortical malformations, short stature due to rotatin deficiency (disorder)
        "1187205008",  # Organic mental disorder caused by sedative (disorder)
        "1187210007",  # Intellectual disability, epilepsy, extrapyramidal syndrome (disorder)
        "1187247007",  # WW domain containing adaptor with coiled-coil-related facial dysmorphism, developmental delay, behavioral abnormalities syndrome (disorder)
        "1187249005",  # VPS11 core subunit of CORVET and HOPS complexes-related autosomal recessive hypomyelinating leukodystrophy (disorder)
        "1187250005",  # Seizures, scoliosis, macrocephaly syndrome (disorder)
        "1187277001",  # Short stature, brachydactyly, obesity, global developmental delay syndrome (disorder)
        "1187278006",  # Spastic paraplegia, severe developmental delay, epilepsy syndrome (disorder)
        "1187303004",  # Progressive spondyloepimetaphyseal dysplasia, short stature, short fourth metatarsals, intellectual disability syndrome (disorder)
        "1187304005",  # Macrocephaly, intellectual disability, neurodevelopmental disorder, small thorax syndrome (disorder)
        "1187642008",  # Macrocephaly, intellectual disability, left ventricular non compaction syndrome (disorder)
        "1187644009",  # Basel Vanagaite Smirin Yosef syndrome (disorder)
        "11941006",  # Panic disorder with agoraphobia, agoraphobic avoidance in full remission AND panic attacks in full remission (disorder)
        "1196001",  # Chronic bipolar II disorder, most recent episode major depressive (disorder)
        "1197148005",  # Sanjad Sakati syndrome (disorder)
        "1197149002",  # Psychogenic movement disorder (disorder)
        "1197587003",  # Lethal neonatal spasticity, epileptic encephalopathy syndrome (disorder)
        "1197588008",  # X-linked microcephaly, growth retardation, prognathism, cryptorchidism syndrome (disorder)
        "1197591008",  # Severe intellectual disability, hypotonia, strabismus, coarse face, planovalgus syndrome (disorder)
        "1197593006",  # Intellectual disability, expressive aphasia, facial dysmorphism syndrome (disorder)
        "1197717008",  # Functional vomiting in childhood (disorder)
        "1197718003",  # Adolescent rumination disorder (disorder)
        "1204417003",  # Early onset schizophrenia (disorder)
        "1208341008",  # Severe oculo-renal-cerebellar syndrome (disorder)
        "1208344000",  # Fryns Smeets Thiry syndrome (disorder)
        "1208481000",  # Progressive cerebello-cerebral atrophy (disorder)
        "1208486005",  # Multiple mitochondrial dysfunctions syndrome type 2 (disorder)
        "1208488006",  # Special AT-rich sequence-binding protein 2-associated syndrome (disorder)
        "1208614008",  # Autosomal dominant deafness with onychodystrophy syndrome (disorder)
        "1208720000",  # Agenesis of corpus callosum, macrocephaly, hypertelorism syndrome (disorder)
        "1208727002",  # Severe intellectual disability, agenesis of corpus callosum, facial dysmorphism, cerebellar ataxia syndrome (disorder)
        "1208746001",  # Intellectual disability, muscle weakness, short stature, facial dysmorphism syndrome (disorder)
        "1208936008",  # Congenital ichthyosis, intellectual disability, spastic quadriplegia syndrome (disorder)
        "1208987006",  # Pleckstrin homology domain interacting protein-related behavioral problems, intellectual disability, obesity, dysmorphic features syndrome (disorder)
        "1217228004",  # X-linked intellectual disability, cerebellar hypoplasia, spondyloepiphyseal dysplasia syndrome (disorder)
        "1217229007",  # Craniofacial dysplasia, short stature, ectodermal anomalies, intellectual disability syndrome (disorder)
        "1217367007",  # Phospholipase A2 activating protein-associated neurodevelopmental disorder (disorder)
        "1217371005",  # Infantile hypotonia, oculomotor anomalies, hyperkinetic movements, developmental delay syndrome (disorder)
        "1217379007",  # NK6 homeobox 2-related autosomal recessive hypomyelinating leukodystrophy (disorder)
        "1217381009",  # Neurodevelopmental delay, seizures, ophthalmic anomalies, osteopenia, cerebellar atrophy syndrome (disorder)
        "1217382002",  # Intellectual disability, autism, speech apraxia, craniofacial dysmorphism syndrome (disorder)
        "1220568003",  # Glutamine rich 1-related intellectual disability, chondrodysplasia syndrome (disorder)
        "1220589007",  # Keppen Lubinsky syndrome (disorder)
        "1220594007",  # Pierpont syndrome (disorder)
        "1220597000",  # Retinitis pigmentosa, juvenile cataract, short stature, intellectual disability syndrome (disorder)
        "1220600004",  # Arginyl-tRNA synthetase 1-related autosomal recessive hypomyelinating leukodystrophy (disorder)
        "1220650006",  # Delusion of emitting foul body odor (disorder)
        "1222656005",  # Synaptic Ras GTPase activating protein 1-related developmental and epileptic encephalopathy (disorder)
        "1222657001",  # Prune exopolyphosphatase 1-related neurological syndrome (disorder)
        "1222658006",  # Global developmental delay, alopecia, macrocephaly, facial dysmorphism, structural brain anomalies syndrome (disorder)
        "1222659003",  # Ring finger protein 13-related severe early-onset epileptic encephalopathy (disorder)
        "1222662000",  # Neonatal epileptic encephalopathy due to deficiency of glutaminase (disorder)
        "1222672002",  # 3-methylglutaconic aciduria type 9 (disorder)
        "1222706005",  # Anterior maxillary protrusion, strabismus, intellectual disability syndrome (disorder)
        "1222710008",  # Neurodevelopmental disorder, craniofacial dysmorphism, cardiac defect, skeletal anomalies syndrome (disorder)
        "12277671000119109",  # Gender dysphoria in childhood (disorder)
        "12277711000119108",  # Gender dysphoria in adolescence and adulthood (disorder)
        "1228886008",  # 9q33.3q34.11 microdeletion syndrome (disorder)
        "1228890005",  # 16p13.2 microdeletion syndrome (disorder)
        "1229872004",  # Xq25 microduplication syndrome (disorder)
        "1229873009",  # 17q24.2 microdeletion syndrome (disorder)
        "1229875002",  # 9q21.13 microdeletion syndrome (disorder)
        "1229882003",  # 11q22.2q22.3 microdeletion syndrome (disorder)
        "1229883008",  # 19p13.3 microduplication syndrome (disorder)
        "1229891004",  # 20q11.2 microdeletion syndrome (disorder)
        "1229895008",  # 8q24.3 microdeletion syndrome (disorder)
        "1230262006",  # Abuse of steroid hormone (disorder)
        "1230273004",  # Megaconial congenital muscular dystrophy (disorder)
        "1230376005",  # Contactin associated protein 2-related developmental and epileptic encephalopathy (disorder)
        "1231503005",  # Psychotic disorder with insight present (disorder)
        "1231846001",  # Psychosis caused by ethanol (disorder)
        "1234779007",  # Mood disorder caused by ethanol (disorder)
        "1234780005",  # Mood disorder with mixed manic and depressive symptoms caused by ethanol (disorder)
        "1234781009",  # Mood disorder with manic symptoms caused by ethanol (disorder)
        "1234782002",  # Mood disorder with depressive symptoms caused by ethanol (disorder)
        "1234783007",  # Organic mental disorder caused by ethanol (disorder)
        "12348006",  # Presenile dementia (disorder)
        "1236807002",  # Encephalopathy due to mitochondrial and peroxisomal fission defect (disorder)
        "1236843008",  # Phosphodiesterase 4D haploinsufficiency syndrome (disorder)
        "1237179007",  # FG syndrome type 1 (disorder)
        "1237344003",  # Symptomatic form of fragile X syndrome in female carrier (disorder)
        "1237417007",  # Carbamoyl-phosphate synthetase 2, aspartate transcarbamylase, and dihydroorotase congenital disorder of glycosylation (disorder)
        "1237418002",  # Spastic tetraplegia, thin corpus callosum, progressive postnatal microcephaly syndrome (disorder)
        "1237420004",  # X-linked intellectual disability, global development delay, facial dysmorphism, sacral caudal remnant syndrome (disorder)
        "1237421000",  # Pyrroline-5-carboxylate reductase 2 related microcephaly, progressive leukoencephalopathy (disorder)
        "1237462006",  # nudE neurodevelopment protein 1-related microhydranencephaly (disorder)
        "1237512003",  # Short stature, developmental delay, congenital heart defect syndrome (disorder)
        "1237619001",  # Fatty acyl-coenzyme A reductase 1 deficiency (disorder)
        "1237623009",  # Congenital insensitivity to pain with severe intellectual disability (disorder)
        "1237625002",  # Autosomal recessive cerebellar ataxia due to CWF19 like cell cycle control factor 1 deficiency (disorder)
        "12398201000119102",  # Anxiety disorder caused by methamphetamine (disorder)
        "12398281000119105",  # Methamphetamine withdrawal syndrome (disorder)
        "12398321000119100",  # Mood disorder caused by methamphetamine (disorder)
        "12398361000119105",  # Mental disorder caused by methamphetamine (disorder)
        "1251452003",  # 4q25 proximal deletion syndrome (disorder)
        "1251453008",  # Lamb Shaffer syndrome (disorder)
        "1254650002",  # Microcephaly, corpus callosum hypoplasia, intellectual disability, facial dysmorphism syndrome (disorder)
        "1254651003",  # Microcephaly, intellectual disability, sensorineural hearing loss, epilepsy, abnormal muscle tone syndrome (disorder)
        "1254652005",  # Intellectual disability, macrocephaly, hypotonia, behavioral abnormalities syndrome (disorder)
        "1254654006",  # X-linked intellectual disability, hypotonia, movement disorder syndrome (disorder)
        "1255319004",  # Autosomal dominant intellectual disability, craniofacial anomalies, cardiac defects syndrome (disorder)
        "1255322002",  # Congenital contracture of limbs and face, hypotonia, developmental delay syndrome (disorder)
        "1255335006",  # X-linked intellectual disability, short stature, overweight syndrome (disorder)
        "1256061006",  # Trichoteiromania (disorder)
        "1256062004",  # Trichotemnomania (disorder)
        "1258898000",  # Mental disorder during puerperium (disorder)
        "1258920002",  # Trichodynia (disorder)
        "1258972007",  # Baraitser Winter cerebrofrontofacial syndrome (disorder)
        "1259070005",  # Adult-onset tic disorder (disorder)
        "1259124000",  # Amyotrophic lateral sclerosis with frontotemporal dementia (disorder)
        "1259128002",  # Alzheimer disease with psychosis (disorder)
        "1259465009",  # Dementia due to hepatic failure (disorder)
        "1259467001",  # Dementia due to hypercalcemia (disorder)
        "1259469003",  # Dementia due to Gerstmann Straussler Scheinker syndrome (disorder)
        "1259471003",  # Dementia due to Hashimoto encephalopathy (disorder)
        "1259473000",  # Dementia due to fragile X syndrome (disorder)
        "1259476008",  # Dementia due to genetic disease (disorder)
        "1259478009",  # Dementia due to familial Creutzfeldt-Jakob disease (disorder)
        "1259480003",  # Dementia due to fatal familial insomnia (disorder)
        "1259485008",  # Dementia due to cerebral vasculitis (disorder)
        "1259488005",  # Dementia due to cerebral amyloid angiopathy (disorder)
        "1259492003",  # Dementia due to metastatic malignant neoplasm to brain (disorder)
        "1259494002",  # Dementia due to leukodystrophy (disorder)
        "1259496000",  # Dementia due to Lyme disease (disorder)
        "1259499007",  # Dementia due to hemorrhagic cerebral infarction due to hypertension (disorder)
        "1259501004",  # Dementia due to kuru (disorder)
        "1259503001",  # Dementia due to iatrogenic Creutzfeldt-Jakob disease (disorder)
        "1259511006",  # Dementia due to Wilson disease (disorder)
        "1259513009",  # Dementia due to Whipple disease (disorder)
        "1259517005",  # Dementia due to systemic lupus erythematosus (disorder)
        "1259519008",  # Dementia due to subacute sclerosing panencephalitis (disorder)
        "1259522005",  # Dementia due to variant Creutzfeldt-Jakob disease (disorder)
        "1259524006",  # Dementia due to trypanosomiasis (disorder)
        "1259529001",  # Dementia due to sporadic Creutzfeldt-Jakob disease (disorder)
        "1259531005",  # Dementia due to hypertensive encephalopathy (disorder)
        "1259579003",  # Dementia due to Behcet syndrome (disorder)
        "1259581001",  # Dementia due to celiac disease (disorder)
        "1259584009",  # Dementia due to and following dialysis (disorder)
        "1259586006",  # Dementia due to autoimmune encephalitis (disorder)
        "1259591007",  # Dementia due to acquired hypothyroidism (disorder)
        "1259656006",  # Dementia due to renal failure (disorder)
        "1259661008",  # Dementia due to inflammatory disorder of musculoskeletal system (disorder)
        "1259663006",  # Dementia due to polyarteritis nodosa (disorder)
        "1259665004",  # Dementia due to progressive subcortical gliosis (disorder)
        "1259667007",  # Dementia due to paraneoplastic encephalitis (disorder)
        "1259673008",  # Dementia due to neurofilament inclusion body disease (disorder)
        "1259675001",  # Dementia due to obstructive hydrocephalus (disorder)
        "1259677009",  # Dementia due to multiple system atrophy (disorder)
        "1259679007",  # Dementia due to atypical pantothenate kinase associated neurodegeneration (disorder)
        "1259990004",  # Dementia due to classical pantothenate kinase associated neurodegeneration (disorder)
        "1260095004",  # Menke Hennekam syndrome (disorder)
        "1260097007",  # Pumilio RNA binding family member 1-associated developmental disability, ataxia, seizure syndrome (disorder)
        "1260128008",  # Tryptophanyl tRNA synthetase 2, mitochondrial-related combined oxidative phosphorylation defect (disorder)
        "1260129000",  # Infantile-onset axonal motor and sensory neuropathy, optic atrophy, neurodegenerative syndrome (disorder)
        "1260130005",  # Progressive essential tremor, speech impairment, facial dysmorphism, intellectual disability, abnormal behavior syndrome (disorder)
        "1260134001",  # Spastic paraplegia, intellectual disability, nystagmus, obesity syndrome (disorder)
        "1260143005",  # Megalencephaly, severe kyphoscoliosis, overgrowth syndrome (disorder)
        "1260195002",  # Glutamate ionotropic receptor NMDA type subunit 2B-related developmental delay, intellectual disability, autism spectrum disorder (disorder)
        "1260298008",  # Depression following menopause (disorder)
        "1260351002",  # Functional diplopia (disorder)
        "1260352009",  # Frontotemporal dementia due to TARDBP mutation (disorder)
        "1260353004",  # Frontotemporal dementia due to VCP mutation (disorder)
        "1260354005",  # Frontotemporal dementia due to C9orf72 mutation (disorder)
        "1260355006",  # Frontotemporal dementia due to FUS mutation (disorder)
        "1260449002",  # Polyendocrine polyneuropathy syndrome (disorder)
        "1260450002",  # Infantile multisystem neurologic, endocrine, pancreatic disease (disorder)
        "1263555006",  # Logopenic non-amnestic Alzheimer disease (disorder)
        "1263585001",  # Frontal variant non-amnestic Alzheimer disease (disorder)
        "1269224009",  # Craniosynostosis, microretrognathia, severe intellectual disability syndrome (disorder)
        "1269226006",  # Spondylometaphyseal dysplasia, corneal dystrophy syndrome (disorder)
        "1269233006",  # Posterior-predominant lissencephaly, broad flat pons and medulla-midline crossing defects syndrome (disorder)
        "1269236003",  # Primary hypomagnesemia, refractory seizures, intellectual disability syndrome (disorder)
        "126943008",  # Separation anxiety (disorder)
        "1275631007",  # Developmental and epileptic encephalopathy (disorder)
        "1279845005",  # Combined oxidative phosphorylation defect type 39 (disorder)
        "128293007",  # Chronic mental disorder (disorder)
        "1284851009",  # Short stature, skeletal dysplasia, retinal degeneration, intellectual disability, sensorineural hearing loss syndrome (disorder)
        "129104009",  # Developmental mental disorder (disorder)
        "12939007",  # Chronic disorganized schizophrenia (disorder)
        "1295485009",  # Aldehyde dehydrogenase 18 family member A1-related de Barsy syndrome (disorder)
        "1295488006",  # Pyrroline-5-carboxylate reductase 1 related de Barsy syndrome (disorder)
        "129562004",  # Psychogenic skin disease (disorder)
        "129602009",  # Symbiotic infantile psychosis (disorder)
        "129604005",  # Delusion of heart disease syndrome (disorder)
        "129606007",  # Frontal lobe syndrome (disorder)
        "129607003",  # Mother-daughter symbiotic syndrome (disorder)
        "12969000",  # Severe bipolar II disorder, most recent episode major depressive, in full remission (disorder)
        "130121000119104",  # Dementia due to Rett syndrome (disorder)
        "13127006",  # Factitious psychosis (disorder)
        "133091000119105",  # Rapid cycling bipolar I disorder (disorder)
        "133121000119109",  # Severe seasonal affective disorder (disorder)
        "13313007",  # Mild bipolar disorder (disorder)
        "133991000119109",  # Fluency disorder as sequela of cerebrovascular disease (disorder)
        "13438001",  # Overanxious disorder of childhood (disorder)
        "135311000119100",  # Insomnia caused by alcohol (disorder)
        "13581000",  # Severe bipolar I disorder, single manic episode with psychotic features, mood-congruent (disorder)
        "13601005",  # Paranoid personality disorder (disorder)
        "13670005",  # Gender identity disorder of adulthood, previously heterosexual (disorder)
        "13746004",  # Bipolar disorder (disorder)
        "1376001",  # Obsessive compulsive personality disorder (disorder)
        "1380006",  # Agoraphobia without history of panic disorder with limited symptom attacks (disorder)
        "1383008",  # Hallucinogen mood disorder (disorder)
        "140621000119106",  # Memory disorder co-occurrent and due to organic brain damage (disorder)
        "14070001",  # Multi-infarct dementia with depression (disorder)
        "14077003",  # Pica (disorder)
        "14144000",  # Erotomanic delusion disorder (disorder)
        "14183003",  # Chronic major depressive disorder, single episode (disorder)
        "141991000119109",  # Delusions in Alzheimer's disease (disorder)
        "142001000119106",  # Depressed mood in Alzheimer's disease (disorder)
        "142011000119109",  # Alzheimer's disease co-occurrent with delirium (disorder)
        "14291003",  # Subchronic disorganized schizophrenia with acute exacerbations (disorder)
        "14495005",  # Severe bipolar I disorder, single manic episode without psychotic features (disorder)
        "14784000",  # Organic mental disorder caused by opioid (disorder)
        "1499003",  # Bipolar I disorder, single manic episode with postpartum onset (disorder)
        "15167005",  # Alcohol abuse (disorder)
        "15182000",  # Coffin-Lowry syndrome (disorder)
        "15193003",  # Severe recurrent major depression with psychotic features, mood-incongruent (disorder)
        "15277004",  # Hallucinogen-induced anxiety disorder (disorder)
        "153071000119108",  # Recurrent manic episodes in partial remission (disorder)
        "15639000",  # Moderate major depression, single episode (disorder)
        "15662003",  # Senile dementia (disorder)
        "1581000119101",  # Dementia of the Alzheimer type with behavioral disturbance (disorder)
        "15840001",  # Symptomatic fetishism (disorder)
        "1591000119103",  # Dementia with behavioral disturbance (disorder)
        "15921731000119106",  # Psychotic disorder caused by methamphetamine (disorder)
        "15945005",  # Psychogenic polydipsia (disorder)
        "15977008",  # Adjustment disorder with academic inhibition (disorder)
        "162004",  # Severe manic bipolar I disorder without psychotic features (disorder)
        "16219201000119101",  # Behavioral disturbance co-occurrent and due to late onset Alzheimer dementia (disorder)
        "162218007",  # Stress-related problem (disorder)
        "162313000",  # Morbid jealousy (disorder)
        "16236661000119100",  # Delirium due to methamphetamine intoxication (disorder)
        "16236701000119107",  # Delirium due to substance withdrawal syndrome (disorder)
        "16237261000119100",  # Adult onset fluency disorder (disorder)
        "16238181000119101",  # Depressive disorder caused by amphetamine (disorder)
        "16238221000119109",  # Depressive disorder caused by methamphetamine (disorder)
        "16238741000119105",  # Bipolar disorder caused by drug (disorder)
        "16264621000119109",  # Recurrent mild major depressive disorder co-occurrent with anxiety (disorder)
        "16264821000119108",  # Recurrent severe major depressive disorder co-occurrent with anxiety (disorder)
        "16264901000119109",  # Recurrent moderate major depressive disorder co-occurrent with anxiety (disorder)
        "16265061000119105",  # Recurrent major depressive disorder co-occurrent with anxiety in full remission (disorder)
        "16265301000119106",  # Recurrent major depressive disorder in partial remission co-occurrent with anxiety (disorder)
        "16265701000119107",  # Illness anxiety disorder (disorder)
        "16265951000119109",  # Mild major depressive disorder co-occurrent with anxiety single episode (disorder)
        "16266831000119100",  # Moderate major depressive disorder co-occurrent with anxiety single episode (disorder)
        "16266991000119108",  # Severe major depressive disorder co-occurrent with anxiety single episode (disorder)
        "16270831000119107",  # Bulimia nervosa in partial remission (disorder)
        "16270871000119105",  # Bulimia nervosa in full remission (disorder)
        "16276361000119109",  # Vascular dementia without behavioral disturbance (disorder)
        "16279021000119106",  # Delirium due to opioid withdrawal (disorder)
        "16295005",  # Bipolar II disorder, most recent episode major depressive (disorder)
        "16506000",  # Mixed bipolar I disorder (disorder)
        "16805009",  # Cluster A personality disorder (disorder)
        "1686006",  # Sedative, hypnotic AND/OR anxiolytic-induced anxiety disorder (disorder)
        "16966009",  # Factitious hypoglycemia (disorder)
        "16990005",  # Subchronic schizophrenia (disorder)
        "17155009",  # Trichotillomania (disorder)
        "17226007",  # Adjustment disorder (disorder)
        "17262008",  # Non-alcoholic Korsakoff's psychosis (disorder)
        "1740001000004102",  # Iatrogenic thyrotoxicosis factitia (disorder)
        "17496003",  # Organic anxiety disorder (disorder)
        "17782008",  # Bipolar I disorder, most recent episode manic with catatonic features (disorder)
        "17827007",  # Cross syndrome (disorder)
        "17961008",  # Conduct disorder, childhood-onset type (disorder)
        "18003009",  # Gender identity disorder of adulthood (disorder)
        "18085000",  # Compulsive gambling (disorder)
        "1816003",  # Panic disorder with agoraphobia, severe agoraphobic avoidance AND mild panic attacks (disorder)
        "18186001",  # True compulsive fetishism (disorder)
        "18193002",  # Hypochondriasis (disorder)
        "18260003",  # Postpartum psychosis (disorder)
        "18478005",  # Adjustment disorder with physical complaints (disorder)
        "18491000119109",  # Psychological disorder during pregnancy (disorder)
        "1855002",  # Developmental academic disorder (disorder)
        "18573003",  # Obsessional erotomania (disorder)
        "18653004",  # Alcohol intoxication delirium (disorder)
        "18689007",  # Inhalant intoxication delirium (disorder)
        "187921002",  # Developmental receptive language disorder (disorder)
        "18818009",  # Moderate recurrent major depression (disorder)
        "18941000",  # Oppositional defiant disorder (disorder)
        "191447007",  # Organic psychotic condition (disorder)
        "191449005",  # Uncomplicated senile dementia (disorder)
        "191451009",  # Uncomplicated presenile dementia (disorder)
        "191452002",  # Presenile dementia with delirium (disorder)
        "191454001",  # Presenile dementia with paranoia (disorder)
        "191455000",  # Presenile dementia with depression (disorder)
        "191457008",  # Senile dementia with depressive or paranoid features (disorder)
        "191458003",  # Senile dementia with paranoia (disorder)
        "191459006",  # Senile dementia with depression (disorder)
        "191461002",  # Senile dementia with delirium (disorder)
        "191463004",  # Uncomplicated arteriosclerotic dementia (disorder)
        "191464005",  # Arteriosclerotic dementia with delirium (disorder)
        "191465006",  # Arteriosclerotic dementia with paranoia (disorder)
        "191466007",  # Arteriosclerotic dementia with depression (disorder)
        "191471000",  # Korsakov's alcoholic psychosis with peripheral neuritis (disorder)
        "191475009",  # Chronic alcoholic brain syndrome (disorder)
        "191476005",  # Alcohol withdrawal hallucinosis (disorder)
        "191478006",  # Alcoholic paranoia (disorder)
        "191480000",  # Alcohol withdrawal syndrome (disorder)
        "191483003",  # Psychotic disorder caused by drug (disorder)
        "191485005",  # Paranoid state caused by drug (disorder)
        "191486006",  # Hallucinosis caused by drug (disorder)
        "191492000",  # Delirium caused by drug (disorder)
        "191493005",  # Dementia caused by drug (disorder)
        "191494004",  # Amnestic disorder caused by drug (disorder)
        "191495003",  # Depressive disorder caused by drug (disorder)
        "191496002",  # Personality disorder caused by drug (disorder)
        "191499009",  # Transient organic psychoses (disorder)
        "191501001",  # Acute confusional state, post-traumatic (disorder)
        "191502008",  # Acute confusional state, of infective origin (disorder)
        "191503003",  # Acute confusional state, of endocrine origin (disorder)
        "191504009",  # Acute confusional state, of metabolic origin (disorder)
        "191505005",  # Acute confusional state, of cerebrovascular origin (disorder)
        "191507002",  # Subacute delirium (disorder)
        "191508007",  # Subacute confusional state, post-traumatic (disorder)
        "191509004",  # Subacute confusional state, of infective origin (disorder)
        "191510009",  # Subacute confusional state, of endocrine origin (disorder)
        "191511008",  # Subacute confusional state, of metabolic origin (disorder)
        "191512001",  # Subacute confusional state, of cerebrovascular origin (disorder)
        "191519005",  # Dementia associated with another disease (disorder)
        "191525009",  # Non-organic psychosis (disorder)
        "191526005",  # Schizophrenic disorders (disorder)
        "191527001",  # Simple schizophrenia (disorder)
        "191531007",  # Acute exacerbation of chronic schizophrenia (disorder)
        "191542003",  # Catatonic schizophrenia (disorder)
        "191547009",  # Acute exacerbation of subchronic catatonic schizophrenia (disorder)
        "191548004",  # Acute exacerbation of chronic catatonic schizophrenia (disorder)
        "191554003",  # Acute exacerbation of subchronic paranoid schizophrenia (disorder)
        "191555002",  # Acute exacerbation of chronic paranoid schizophrenia (disorder)
        "191559008",  # Latent schizophrenia (disorder)
        "191565008",  # Latent schizophrenia in remission (disorder)
        "191567000",  # Schizoaffective schizophrenia (disorder)
        "191569002",  # Subchronic schizoaffective schizophrenia (disorder)
        "191570001",  # Chronic schizoaffective schizophrenia (disorder)
        "191571002",  # Acute exacerbation of subchronic schizoaffective schizophrenia (disorder)
        "191572009",  # Acute exacerbation of chronic schizoaffective schizophrenia (disorder)
        "191574005",  # Schizoaffective schizophrenia in remission (disorder)
        "191577003",  # Cenesthopathic schizophrenia (disorder)
        "191583000",  # Single manic episode, mild (disorder)
        "191584006",  # Single manic episode, moderate (disorder)
        "191586008",  # Single manic episode, severe, with psychosis (disorder)
        "191588009",  # Single manic episode in full remission (disorder)
        "191590005",  # Recurrent manic episodes (disorder)
        "191592002",  # Recurrent manic episodes, mild (disorder)
        "191593007",  # Recurrent manic episodes, moderate (disorder)
        "191595000",  # Recurrent manic episodes, severe, with psychosis (disorder)
        "191597008",  # Recurrent manic episodes, in full remission (disorder)
        "191604000",  # Single major depressive episode, severe, with psychosis (disorder)
        "191610000",  # Recurrent major depressive episodes, mild (disorder)
        "191611001",  # Recurrent major depressive episodes, moderate (disorder)
        "191613003",  # Recurrent major depressive episodes, severe, with psychosis (disorder)
        "191616006",  # Recurrent depression (disorder)
        "191618007",  # Bipolar affective disorder, current episode manic (disorder)
        "191620005",  # Bipolar affective disorder, currently manic, mild (disorder)
        "191621009",  # Bipolar affective disorder, currently manic, moderate (disorder)
        "191623007",  # Bipolar affective disorder, currently manic, severe, with psychosis (disorder)
        "191627008",  # Bipolar affective disorder, current episode depression (disorder)
        "191629006",  # Bipolar affective disorder, currently depressed, mild (disorder)
        "191630001",  # Bipolar affective disorder, currently depressed, moderate (disorder)
        "191636007",  # Mixed bipolar affective disorder (disorder)
        "191638008",  # Mixed bipolar affective disorder, mild (disorder)
        "191639000",  # Mixed bipolar affective disorder, moderate (disorder)
        "191641004",  # Mixed bipolar affective disorder, severe, with psychosis (disorder)
        "191643001",  # Mixed bipolar affective disorder, in full remission (disorder)
        "191658009",  # Atypical manic disorder (disorder)
        "191659001",  # Atypical depressive disorder (disorder)
        "191667009",  # Paranoid disorder (disorder)
        "191668004",  # Simple paranoid state (disorder)
        "191672000",  # Paranoia querulans (disorder)
        "191676002",  # Reactive depressive psychosis (disorder)
        "191677006",  # Acute hysterical psychosis (disorder)
        "191678001",  # Reactive confusion (disorder)
        "191680007",  # Psychogenic paranoid psychosis (disorder)
        "191683009",  # Psychogenic stupor (disorder)
        "191687005",  # Psychosis with origin in childhood (disorder)
        "191689008",  # Active infantile autism (disorder)
        "191690004",  # Residual infantile autism (disorder)
        "191692007",  # Active disintegrative psychoses (disorder)
        "191693002",  # Residual disintegrative psychoses (disorder)
        "191696005",  # Atypical childhood psychoses (disorder)
        "191697001",  # Borderline psychosis of childhood (disorder)
        "191713008",  # Dissociative neurological symptom disorder with tremor (disorder)
        "191714002",  # Dissociative convulsions (disorder)
        "191722009",  # Agoraphobia with panic attacks (disorder)
        "191724005",  # Social phobia, fear of eating in public (disorder)
        "191725006",  # Social phobia, fear of public speaking (disorder)
        "191726007",  # Social phobia, fear of public washing (disorder)
        "191736004",  # Obsessive-compulsive disorder (disorder)
        "191744004",  # Writer's cramp neurosis (disorder)
        "191746002",  # Psychasthenic neurosis (disorder)
        "191753006",  # Hypomanic personality disorder (disorder)
        "191765005",  # Emotionally unstable personality disorder (disorder)
        "191772006",  # Eccentric personality disorder (disorder)
        "191773001",  # Immature personality disorder (disorder)
        "191774007",  # Masochistic personality disorder (disorder)
        "191787001",  # Psychosexual identity disorder (disorder)
        "191811004",  # Continuous chronic alcoholism (disorder)
        "191812006",  # Episodic chronic alcoholism (disorder)
        "191813001",  # Chronic alcoholism in remission (disorder)
        "191882002",  # Nondependent alcohol abuse, continuous (disorder)
        "191883007",  # Nondependent alcohol abuse, episodic (disorder)
        "191884001",  # Nondependent alcohol abuse in remission (disorder)
        "191928000",  # Abuse of antidepressant drug (disorder)
        "191930003",  # Nondependent antidepressant type drug abuse, continuous (disorder)
        "191931004",  # Nondependent antidepressant type drug abuse, episodic (disorder)
        "191932006",  # Nondependent antidepressant type drug abuse in remission (disorder)
        "191952007",  # Somatoform autonomic dysfunction - respiratory tract (disorder)
        "191953002",  # Psychogenic air hunger (disorder)
        "191954008",  # Psychogenic cough (disorder)
        "191955009",  # Psychogenic hiccough (disorder)
        "191956005",  # Psychogenic hyperventilation (disorder)
        "191962000",  # Neurocirculatory asthenia (disorder)
        "191965003",  # Psychogenic skin symptoms (disorder)
        "191966002",  # Psychogenic pruritus (disorder)
        "191970005",  # Psychogenic cyclical vomiting (disorder)
        "191972002",  # Psychogenic dyspepsia (disorder)
        "191973007",  # Psychogenic constipation (disorder)
        "191977008",  # Psychogenic dysmenorrhea (disorder)
        "191978003",  # Psychogenic dysuria (disorder)
        "191980009",  # Psychogenic endocrine malfunction (disorder)
        "191981008",  # Psychogenic symptom of special sense organ (disorder)
        "191990001",  # Transient childhood tic (disorder)
        "192016008",  # Non-organic infant feeding disturbance (disorder)
        "192029008",  # Psychogenic backache (disorder)
        "192037000",  # Acute panic state due to acute stress reaction (disorder)
        "192038005",  # Acute fugue state due to acute stress reaction (disorder)
        "192039002",  # Acute stupor state due to acute stress reaction (disorder)
        "192041001",  # Acute situational disturbance (disorder)
        "192042008",  # Acute post-trauma stress state (disorder)
        "192044009",  # Stress reaction causing mixed disturbance of emotion and conduct (disorder)
        "192046006",  # Brief depressive adjustment reaction (disorder)
        "192049004",  # Prolonged depressive adjustment reaction (disorder)
        "192051000",  # Adolescent emancipation disorder (disorder)
        "192052007",  # Early adult emancipation disorder (disorder)
        "192054008",  # Culture shock (disorder)
        "192056005",  # Adjustment reaction with aggression (disorder)
        "192057001",  # Adjustment reaction with antisocial behavior (disorder)
        "192058006",  # Adjustment reaction with destructiveness (disorder)
        "192061007",  # Concentration camp syndrome (disorder)
        "192063005",  # Adjustment reaction with physical symptoms (disorder)
        "192064004",  # Elective mutism due to an adjustment reaction (disorder)
        "192065003",  # Hospitalism (disorder)
        "192069009",  # Specific nonpsychotic mental disorders following organic brain damage (disorder)
        "192072002",  # Organic memory impairment (disorder)
        "192073007",  # Change in personality (disorder)
        "192079006",  # Postviral depression (disorder)
        "192080009",  # Chronic depression (disorder)
        "192082001",  # Aggressive unsocial conduct disorder (disorder)
        "192092009",  # Group delinquency (disorder)
        "192097003",  # Isolated explosive disorder (disorder)
        "192099000",  # Childhood disorder of conduct and emotion (disorder)
        "192100008",  # Neurotic delinquency (disorder)
        "192108001",  # Disturbance of anxiety and fearfulness in childhood and adolescence (disorder)
        "192110004",  # Childhood and adolescent fearfulness disturbance (disorder)
        "192119003",  # Sibling jealousy (disorder)
        "192123006",  # Academic underachievement disorder (disorder)
        "192127007",  # Child attention deficit disorder (disorder)
        "192131001",  # Hyperkinesis with developmental delay (disorder)
        "192132008",  # Hyperkinetic conduct disorder (disorder)
        "192136006",  # Specific reading disorder (disorder)
        "192138007",  # Developmental dyslexia (disorder)
        "192147004",  # Mixed disorder of psychological development (disorder)
        "192362008",  # Bipolar affective disorder, current episode mixed (disorder)
        "192527004",  # Elaboration of physical symptoms for psychological reasons (disorder)
        "192562009",  # Disorder of psychological development (disorder)
        "192575009",  # Mixed disorder of scholastic skills (disorder)
        "192611004",  # Childhood phobic anxiety disorder (disorder)
        "192616009",  # Childhood or adolescent disorder of social functioning (disorder)
        "192630004",  # Psychogenic feeding disorder of infancy and childhood (disorder)
        "192631000",  # Pica of infancy and childhood (disorder)
        "192845009",  # Myoclonic encephalopathy (disorder)
        "19300006",  # Severe bipolar II disorder, most recent episode major depressive with psychotic features, mood-congruent (disorder)
        "193756007",  # Charles Bonnet syndrome (disorder)
        "19445006",  # Opioid-induced psychotic disorder with hallucinations (disorder)
        "19480005",  # Axis V diagnosis (disorder)
        "19527009",  # Single episode of major depression in full remission (disorder)
        "19694002",  # Late onset dysthymia (disorder)
        "1973000",  # Sedative, hypnotic AND/OR anxiolytic-induced psychotic disorder with delusions (disorder)
        "197480006",  # Anxiety disorder (disorder)
        "19766004",  # Panic disorder with agoraphobia, mild agoraphobic avoidance AND severe panic attacks (disorder)
        "19922006",  # Compulsive sexual sadism (disorder)
        "199257008",  # Mental disorders during pregnancy, childbirth and the puerperium (disorder)
        "19972008",  # Postencephalitic parkinsonism (disorder)
        "20010003",  # Borderline personality disorder (disorder)
        "20250007",  # Severe major depression, single episode, with psychotic features, mood-incongruent (disorder)
        "20385005",  # Psychotic disorder with delusions caused by opioid (disorder)
        "20876004",  # Inhalant-induced anxiety disorder (disorder)
        "20960007",  # Severe bipolar II disorder, most recent episode major depressive with psychotic features, mood-incongruent (disorder)
        "21071000119101",  # Mood disorder of manic type (disorder)
        "21586000",  # Munchausen's syndrome (disorder)
        "21634003",  # Borjeson-Forssman-Lehmann syndrome (disorder)
        "21831000119109",  # Psychotic disorder caused by phencyclidine (disorder)
        "21841000119100",  # Organic mental disorder caused by phencyclidine (disorder)
        "21897009",  # Generalized anxiety disorder (disorder)
        "21900002",  # Bipolar I disorder, most recent episode depressed with catatonic features (disorder)
        "21921000119103",  # Dementia co-occurrent and due to Pick's disease (disorder)
        "22121000",  # Depressed bipolar I disorder in full remission (disorder)
        "22230001",  # Panic disorder with agoraphobia, agoraphobic avoidance in partial remission AND panic attacks in full remission (disorder)
        "22381000119105",  # Primary degenerative dementia (disorder)
        "22407005",  # Bipolar II disorder, most recent episode major depressive with catatonic features (disorder)
        "22419002",  # Mood disorder with mixed features due to general medical condition (disorder)
        "225040001",  # Localized dissociative amnesia (disorder)
        "22621000119103",  # Anxiety disorder caused by drug (disorder)
        "22641000119109",  # Psychosis in early childhood (disorder)
        "229621000",  # Disorder of fluency (disorder)
        "229622007",  # Dysfluency (disorder)
        "229623002",  # Developmental dysfluency (disorder)
        "229625009",  # Normal non-fluency (disorder)
        "229630008",  # Psychogenic stammering (disorder)
        "229631007",  # Acquired stammering (disorder)
        "229632000",  # Neurogenic stammering (disorder)
        "229683000",  # Motor speech disorder (disorder)
        "229697008",  # Oral-verbal dyspraxia (disorder)
        "229698003",  # Articulatory dyspraxia (disorder)
        "229699006",  # Immature articulatory praxis (disorder)
        "229700007",  # Developmental motor speech disorder (disorder)
        "229701006",  # Developmental articulatory dyspraxia (disorder)
        "229703009",  # Developmental verbal dyspraxia (disorder)
        "229704003",  # Acquired choreiform dyspraxia (disorder)
        "229705002",  # Mixed acquired dyspraxia (disorder)
        "229706001",  # Ideomotor dyspraxia (disorder)
        "229707005",  # Dyspraxia of velopharynx (disorder)
        "229708000",  # Velar dyspraxia (disorder)
        "229709008",  # Tongue tip dyspraxia (disorder)
        "229712006",  # Disorders of attention and motor control (disorder)
        "229715008",  # Deficits in attention motor control and perception (disorder)
        "229721007",  # Speech delay (disorder)
        "229733002",  # Expressive language disorder (disorder)
        "229734008",  # Expressive language delay (disorder)
        "229736005",  # Receptive language delay (disorder)
        "229740001",  # Delayed pre-verbal development (disorder)
        "229741002",  # Restricted language development (disorder)
        "229742009",  # Restricted expressive language development (disorder)
        "229743004",  # Restricted receptive language development (disorder)
        "229744005",  # Developmental syntactic impairment (disorder)
        "229745006",  # Developmental semantic impairment (disorder)
        "229748008",  # Congenital auditory imperception (disorder)
        "22981000119106",  # Recurrent severe manic episodes (disorder)
        "230191005",  # Rasmussen syndrome (disorder)
        "230265002",  # Familial Alzheimer's disease of early onset (disorder)
        "230266001",  # Non-familial Alzheimer's disease of early onset (disorder)
        "230267005",  # Familial Alzheimer's disease of late onset (disorder)
        "230268000",  # Non-familial Alzheimer's disease of late onset (disorder)
        "230269008",  # Focal Alzheimer's disease (disorder)
        "230270009",  # Frontotemporal dementia (disorder)
        "230271008",  # Pick's disease with Pick bodies (disorder)
        "230272001",  # Pick's disease with Pick cells and no Pick bodies (disorder)
        "230274000",  # Frontal lobe degeneration with motor neurone disease (disorder)
        "230280008",  # Progressive aphasia in Alzheimer's disease (disorder)
        "230282000",  # Post-traumatic dementia (disorder)
        "230285003",  # Vascular dementia of acute onset (disorder)
        "230286002",  # Subcortical vascular dementia (disorder)
        "230287006",  # Mixed cortical and subcortical vascular dementia (disorder)
        "230288001",  # Semantic dementia (disorder)
        "230289009",  # Patchy dementia (disorder)
        "230299004",  # Juvenile onset Huntington's disease (disorder)
        "230300007",  # Late onset Huntington's disease (disorder)
        "230301006",  # Akinetic-rigid form of Huntington's disease (disorder)
        "230334008",  # Tic caused by drug (disorder)
        "230335009",  # Facial tic disorder (disorder)
        "230336005",  # Vocal tic disorder (disorder)
        "230337001",  # Motor tic disorder (disorder)
        "230338006",  # Gestural tic disorder (disorder)
        "230418006",  # Lennox-Gastaut syndrome (disorder)
        "230419003",  # Cryptogenic Lennox-Gastaut syndrome (disorder)
        "230420009",  # Symptomatic Lennox-Gastaut syndrome (disorder)
        "230421008",  # Epilepsy with myoclonic-atonic seizures (disorder)
        "230429005",  # Early infantile epileptic encephalopathy with suppression bursts (disorder)
        "230437002",  # Severe myoclonic epilepsy in infancy (disorder)
        "230438007",  # Acquired epileptic aphasia (disorder)
        "230439004",  # Epilepsy with continuous spike wave during slow-wave sleep (disorder)
        "230443000",  # Narcotic withdrawal epilepsy (disorder)
        "230539002",  # Cluster tic syndrome (disorder)
        "2312009",  # Reactive attachment disorder of infancy OR early childhood, inhibited type (disorder)
        "231437006",  # Reactive psychoses (disorder)
        "231438001",  # Presbyophrenic psychosis (disorder)
        "231439009",  # Toxic confusional state (disorder)
        "231440006",  # Delirium of mixed origin (disorder)
        "231442003",  # Organic catatonic disorder (disorder)
        "231443008",  # Right hemispheric organic affective disorder (disorder)
        "231444002",  # Organic bipolar disorder (disorder)
        "231445001",  # Organic dissociative disorder (disorder)
        "231446000",  # Organic emotionally labile disorder (disorder)
        "231448004",  # Age-associated memory impairment (disorder)
        "231449007",  # Epileptic psychosis (disorder)
        "231452004",  # Limbic epilepsy personality syndrome (disorder)
        "231453009",  # Lobotomy syndrome (disorder)
        "231454003",  # Organic pseudopsychopathic personality (disorder)
        "231455002",  # Organic pseudoretarded personality (disorder)
        "231456001",  # Postleucotomy syndrome (disorder)
        "231459008",  # Abuse of nonpsychotropic analgesic drugs (disorder)
        "231467000",  # Absinthe addiction (disorder)
        "23148009",  # Undifferentiated attention deficit disorder (disorder)
        "231485007",  # Post-schizophrenic depression (disorder)
        "231487004",  # Persistent delusional disorder (disorder)
        "231489001",  # Acute transient psychotic disorder (disorder)
        "231494001",  # Mania (disorder)
        "231495000",  # Manic stupor (disorder)
        "231496004",  # Hypomania (disorder)
        "231499006",  # Endogenous depression first episode (disorder)
        "231500002",  # Masked depression (disorder)
        "231504006",  # Mixed anxiety and depressive disorder (disorder)
        "231509001",  # Dissociative astasia-abasia (disorder)
        "231515001",  # Hypochondriacal pain (disorder)
        "231516000",  # Cutaneous hypochondriasis (disorder)
        "231517009",  # Somatoform autonomic dysfunction (disorder)
        "231519007",  # Depersonalization-derealization syndrome (disorder)
        "231520001",  # Behavioral syndrome associated with physiological disturbance and physical factors (disorder)
        "231521002",  # Weight fixation (disorder)
        "231522009",  # Atypical anorexia nervosa (disorder)
        "231523004",  # Atypical bulimia nervosa (disorder)
        "231524005",  # Interictal behavior disorder (disorder)
        "231525006",  # Manipulative personality disorder (disorder)
        "231526007",  # Fanatic personality (disorder)
        "231527003",  # Explosive personality disorder (disorder)
        "231528008",  # Anxious personality disorder (disorder)
        "231530005",  # Post-concussional personality disorder (disorder)
        "231531009",  # Dermatological pathomimicry (disorder)
        "231536004",  # Atypical autism (disorder)
        "231537008",  # Developmental agnosia (disorder)
        "231538003",  # Behavioral and emotional disorder with onset in childhood (disorder)
        "231539006",  # Adolescent - emotional problem (disorder)
        "231540008",  # Conduct disorder - in family context (disorder)
        "231541007",  # Conduct disorder - unsocialized (disorder)
        "231542000",  # Depressive conduct disorder (disorder)
        "231864002",  # Conjunctivitis artefacta (disorder)
        "232059000",  # Laurence-Moon syndrome (disorder)
        "232534061000119102",  # Delirium due to hepatic encephalopathy (disorder)
        "233690008",  # Factitious asthma (disorder)
        "234146006",  # Hennekam lymphangiectasia-lymphedema syndrome (disorder)
        "235004005",  # Gingivitis artefacta (disorder)
        "23560001",  # Asperger's disorder (disorder)
        "23645006",  # Organic mood disorder (disorder)
        "236529001",  # Prune belly syndrome with pulmonic stenosis, intellectual disability and deafness (disorder)
        "236667007",  # Psychogenic urinary incontinence (disorder)
        "237349002",  # Mild postnatal depression (disorder)
        "237350002",  # Severe postnatal depression (disorder)
        "237351003",  # Mild postnatal psychosis (disorder)
        "237352005",  # Severe postnatal psychosis (disorder)
        "23741000119105",  # Severe manic bipolar I disorder (disorder)
        "23772009",  # Dysphonia of Gilles de la Tourette's syndrome (disorder)
        "23871000119106",  # Somnambulism co-occurrent with sleep terror disorder (disorder)
        "238884009",  # Factitial panniculitis (disorder)
        "238958004",  # Repetitive self-excoriation (disorder)
        "238959007",  # Disorders of cutaneous image and perception (disorder)
        "238960002",  # Dermatological non-disease (disorder)
        "238961003",  # Trichophobia (disorder)
        "238965007",  # Venereophobia (disorder)
        "238966008",  # Syphilophobia (disorder)
        "238967004",  # Psychogenic sensory disturbance of skin (disorder)
        "238972008",  # Cutaneous monosymptomatic delusional psychosis (disorder)
        "238973003",  # Delusions of parasitosis (disorder)
        "238974009",  # Delusions of infestation (disorder)
        "238977002",  # Delusional hyperhidrosis (disorder)
        "238978007",  # Hyperschemazia (disorder)
        "238979004",  # Hyposchemazia (disorder)
        "2403008",  # Psychoactive substance dependence (disorder)
        "24121004",  # Insomnia disorder related to another mental disorder (disorder)
        "24125008",  # Mental disorder in infancy (disorder)
        "2421000119107",  # Hallucinations co-occurrent and due to late onset dementia (disorder)
        "24315006",  # Factitious disorder with combined physical AND psychological symptoms (disorder)
        "247364000",  # Psychosomatic rheumatism (disorder)
        "247803002",  # Seasonal affective disorder (disorder)
        "247804008",  # Schizophrenic prodrome (disorder)
        "24781009",  # Panic disorder with agoraphobia, mild agoraphobic avoidance AND panic attacks in full remission (disorder)
        "248103001",  # Flashing (disorder)
        "248118000",  # Self-induced purging to lose weight (disorder)
        "249520001",  # Self-induced purging (disorder)
        "25029006",  # Deferred diagnosis on Axis III (disorder)
        "2506003",  # Early onset dysthymia (disorder)
        "251000119105",  # Severe major depression, single episode (disorder)
        "25297005",  # Psychogenic adductor spastic dysphonia (disorder)
        "253176002",  # Gillespie syndrome (disorder)
        "25501002",  # Social phobia (disorder)
        "25766007",  # Mixed receptive-expressive language disorder (disorder)
        "25772007",  # Multi-infarct dementia with delusions (disorder)
        "25922000",  # Major depressive disorder, single episode with postpartum onset (disorder)
        "25971005",  # Pedophilia, exclusive type (disorder)
        "26025008",  # Residual schizophrenia (disorder)
        "261000119107",  # Severe depressed bipolar I disorder (disorder)
        "2618002",  # Chronic recurrent major depressive disorder (disorder)
        "26203008",  # Severe depressed bipolar I disorder with psychotic features, mood-incongruent (disorder)
        "26453000",  # Mental disorder in adolescence (disorder)
        "26472000",  # Paraphrenia (disorder)
        "26516009",  # Severe mood disorder with psychotic features (disorder)
        "26530004",  # Severe bipolar disorder with psychotic features, mood-incongruent (disorder)
        "26665006",  # Antisocial personality disorder (disorder)
        "26714005",  # Cannabis-induced psychotic disorder with hallucinations (disorder)
        "267320004",  # Pregnancy with mental disorders (disorder)
        "267414004",  # Jumping disease (disorder)
        "26852004",  # Primary degenerative dementia of the Alzheimer type, senile onset, with depression (disorder)
        "268612007",  # Senile and presenile organic psychotic conditions (disorder)
        "268617001",  # Acute schizophrenic episode (disorder)
        "268619003",  # Manic disorder, single episode (disorder)
        "268621008",  # Recurrent major depressive episodes (disorder)
        "268622001",  # Chronic paranoid psychosis (disorder)
        "268624000",  # Acute paranoid reaction (disorder)
        "268633003",  # Introverted personality disorder (disorder)
        "268634009",  # Psychoneurotic personality disorder (disorder)
        "268645007",  # Nondependent alcohol abuse (disorder)
        "268650001",  # Somatoform autonomic dysfunction - gastrointestinal tract (disorder)
        "268658008",  # Specific academic or work inhibition (disorder)
        "268661009",  # Nonaggressive unsocial conduct disorder (disorder)
        "268662002",  # Unsocial childhood truancy (disorder)
        "268664001",  # Childhood emotional disorder (disorder)
        "268666004",  # Childhood and adolescent disturbance with sensitivity (disorder)
        "268667008",  # Childhood and adolescent disturbance with shyness (disorder)
        "268668003",  # Childhood and adolescent disturbance with introversion (disorder)
        "268669006",  # Childhood and adolescent disturbance with elective mutism (disorder)
        "268672004",  # Disorder of speech and language development (disorder)
        "268673009",  # Developmental aphasia (disorder)
        "268674003",  # Developmental disorder of motor function (disorder)
        "268715000",  # Dissociative motor disorder (disorder)
        "268724009",  # Excessive sexual drive (disorder)
        "268734000",  # Developmental expressive language disorder (disorder)
        "268738002",  # Specific spelling disorder (disorder)
        "268957000",  # Neurotic condition, insight present (disorder)
        "268958005",  # Poor insight into neurotic condition (disorder)
        "26929004",  # Alzheimer's disease (disorder)
        "270291000119109",  # Identity disorder of childhood (disorder)
        "27051000119102",  # Chronic abuse of laxatives (disorder)
        "270901009",  # Schizoaffective disorder, mixed type (disorder)
        "270903007",  # Lack or loss of sexual desire (disorder)
        "270905000",  # Childhood disinhibited attachment disorder (disorder)
        "271000119101",  # Severe mixed bipolar I disorder (disorder)
        "271428004",  # Schizoaffective disorder, manic type (disorder)
        "271952001",  # Stress and adjustment reaction (disorder)
        "27387000",  # Subchronic disorganized schizophrenia (disorder)
        "274948002",  # Endogenous depression - recurrent (disorder)
        "274949005",  # Self-inflicted skin lesions (disorder)
        "274953007",  # Acute polymorphic psychotic disorder (disorder)
        "275271004",  # Apraxia, developmental (disorder)
        "27544004",  # Developmental coordination disorder (disorder)
        "275446004",  # Gardner-Diamond syndrome (disorder)
        "275472008",  # Psychogenic dysphonia (disorder)
        "275473003",  # Specific work inhibition (disorder)
        "275474009",  # Psychogenic overeating (disorder)
        "276296007",  # Dissociative trance (disorder)
        "276297003",  # Dissociative possession disorder (disorder)
        "276300008",  # Dissociative stupor (disorder)
        "2776000",  # Delirium (disorder)
        "27803006",  # Qi-gong psychotic reaction (disorder)
        "278506006",  # Involutional paranoid state (disorder)
        "278508007",  # Delusional dysmorphophobia (disorder)
        "278852008",  # Paranoid-hallucinatory epileptic psychosis (disorder)
        "278853003",  # Acute schizophrenia-like psychotic disorder (disorder)
        "278857002",  # Dementia of frontal lobe type (disorder)
        "278920007",  # Speech and language dyspraxias (disorder)
        "279225001",  # Maternity blues (disorder)
        "27956007",  # Cocaine intoxication (disorder)
        "279611005",  # Shell shock (disorder)
        "280032002",  # Developmental language disorder (disorder)
        "280901000",  # Couvade (disorder)
        "280943007",  # Dissociative confusion (disorder)
        "280945000",  # Derealization syndrome (disorder)
        "280946004",  # Occupational neurosis (disorder)
        "280949006",  # Erotomania (disorder)
        "280982009",  # Abuse of laxatives (disorder)
        "280983004",  # Abuse of vitamins (disorder)
        "280984005",  # Abuse of herbal medicine (disorder)
        "280986007",  # Abuse of antacids (disorder)
        "280994000",  # Chronic confusional state (disorder)
        "281000119103",  # Severe recurrent major depression (disorder)
        "281004",  # Dementia associated with alcoholism (disorder)
        "2815001",  # Sexual pyromania (disorder)
        "28357009",  # Transitory postpartum mood disturbance (disorder)
        "28368009",  # Organic hallucinosis caused by psychoactive substance (disorder)
        "2838003",  # Piblokto (disorder)
        "284591009",  # Persistent alcohol abuse (disorder)
        "28475009",  # Severe recurrent major depression with psychotic features (disorder)
        "28663008",  # Severe manic bipolar I disorder with psychotic features (disorder)
        "28676002",  # Mood disorder with manic features due to general medical condition (disorder)
        "286933003",  # Confusional state (disorder)
        "288031000119105",  # Alcohol induced disorder co-occurrent and due to alcohol dependence (disorder)
        "288271000119103",  # Childhood onset fluency disorder (disorder)
        "288421000119100",  # Hyposomnia co-occurrent and due to psychological disorder (disorder)
        "288461000119105",  # Psychosis caused by inhalant (disorder)
        "288631000119104",  # Vascular dementia with behavioral disturbance (disorder)
        "28864000",  # Sedative, hypnotic AND/OR anxiolytic-induced mood disorder (disorder)
        "288751000119101",  # Reactive depressive psychosis, single episode (disorder)
        "28884001",  # Moderate bipolar I disorder, single manic episode (disorder)
        "288851000119106",  # Opioid-induced mood disorder due to opioid abuse (disorder)
        "288861000119108",  # Opioid-induced mood disorder due to opioid dependence (disorder)
        "290791000119105",  # Fluency disorder due to and following cerebrovascular accident (disorder)
        "291751000119105",  # Fluency disorder due to and following spontaneous intracerebral hemorrhage (disorder)
        "293671000119109",  # Behavioral disturbance due to multi-infarct dementia (disorder)
        "29599000",  # Chronic undifferentiated schizophrenia (disorder)
        "29657007",  # Deferred diagnosis on Axis IV (disorder)
        "29733004",  # Mood disorder caused by opioid (disorder)
        "29929003",  # Bipolar I disorder, most recent episode depressed with atypical features (disorder)
        "2994004",  # Brain fag (disorder)
        "30059008",  # Panic disorder with agoraphobia, severe agoraphobic avoidance AND moderate panic attacks (disorder)
        "300706003",  # Endogenous depression (disorder)
        "30077003",  # Somatoform pain disorder (disorder)
        "300979000",  # Caregiver stress syndrome (disorder)
        "30310000",  # Nicotine-induced organic mental disorder (disorder)
        "30336007",  # Chronic residual schizophrenia with acute exacerbations (disorder)
        "30491001",  # Cocaine delusional disorder (disorder)
        "30509009",  # Gender identity disorder of adolescence, previously homosexual (disorder)
        "30520009",  # Severe bipolar II disorder, most recent episode major depressive with psychotic features (disorder)
        "30605009",  # Major depression in partial remission (disorder)
        "30687003",  # Bipolar II disorder, most recent episode major depressive with postpartum onset (disorder)
        "307199009",  # Psychosomatic abdominal pain (disorder)
        "307417003",  # Cycloid psychosis (disorder)
        "307653008",  # Clumsiness - motor delay (disorder)
        "30935000",  # Manic bipolar I disorder in full remission (disorder)
        "31027006",  # Schizotypal personality disorder (disorder)
        "310495003",  # Mild depression (disorder)
        "310496002",  # Moderate depression (disorder)
        "310497006",  # Severe depression (disorder)
        "31081000119101",  # Presenile dementia with delusions (disorder)
        "310814007",  # Discourse difficulties (disorder)
        "3109008",  # Secondary dysthymia early onset (disorder)
        "311173003",  # Phencyclidine-related disorder (disorder)
        "31177006",  # Attention deficit hyperactivity disorder, combined type (disorder)
        "312098001",  # Sedative, hypnotic AND/OR anxiolytic-related disorder (disorder)
        "31216003",  # Profound intellectual disability (disorder)
        "312214005",  # Floating-Harbor syndrome (disorder)
        "312936002",  # Organic mental disorder caused by anxiolytic agent (disorder)
        "312991009",  # Senile dementia of the Lewy body type (disorder)
        "313182004",  # Chronic post-traumatic stress disorder (disorder)
        "31358003",  # Coprophilia (disorder)
        "31373002",  # Disorganized schizophrenia in remission (disorder)
        "313915006",  # Organic mental disorder caused by hypnotic agent (disorder)
        "31446002",  # Bipolar I disorder, most recent episode hypomanic (disorder)
        "3158007",  # Panic disorder with agoraphobia, agoraphobic avoidance in partial remission AND panic attacks in partial remission (disorder)
        "31611000",  # Multiple personality disorder (disorder)
        "31648009",  # Unaggressive type unsocialized behavior disorder (disorder)
        "31658008",  # Chronic paranoid schizophrenia (disorder)
        "31715000",  # Phencyclidine intoxication delirium (disorder)
        "31781004",  # Panic disorder with agoraphobia, agoraphobic avoidance in partial remission AND mild panic attacks (disorder)
        "317816007",  # Stockholm syndrome (disorder)
        "318784009",  # Posttraumatic stress disorder, delayed onset (disorder)
        "319768000",  # Recurrent major depressive disorder with melancholic features (disorder)
        "32009006",  # Hallucinogen hallucinosis (disorder)
        "320751009",  # Major depression, melancholic type (disorder)
        "321717001",  # Involutional depression (disorder)
        "32174002",  # Voice disorder due to psychosexual conflict (disorder)
        "32358001",  # Amphetamine delusional disorder (disorder)
        "32388005",  # Panic disorder with agoraphobia, agoraphobic avoidance in partial remission AND moderate panic attacks (disorder)
        "32410009",  # Pederasty (disorder)
        "32552001",  # Organic delusional disorder caused by psychoactive substance (disorder)
        "32721004",  # Bulimia nervosa, purging type (disorder)
        "32875003",  # Inhalant-induced persisting dementia (disorder)
        "32880007",  # Adjustment disorder with work inhibition (disorder)
        "3298001",  # Amnestic disorder (disorder)
        "33078009",  # Severe recurrent major depression with psychotic features, mood-congruent (disorder)
        "33135002",  # Recurrent major depression in partial remission (disorder)
        "33323008",  # Somatic delusion disorder (disorder)
        "33380008",  # Severe manic bipolar I disorder with psychotic features, mood-incongruent (disorder)
        "33449004",  # Personality disorder (disorder)
        "33736005",  # Severe major depression with psychotic features, mood-congruent (disorder)
        "33871004",  # Phencyclidine-induced psychotic disorder with hallucinations (disorder)
        "33982008",  # Hyperphosphatasemia with intellectual disability (disorder)
        "34116005",  # Panic disorder with agoraphobia, agoraphobic avoidance in full remission AND severe panic attacks (disorder)
        "34134009",  # Shenjing shuairuo (disorder)
        "34315001",  # Bipolar II disorder, most recent episode major depressive with melancholic features (disorder)
        "34485008",  # Axis IV diagnosis (disorder)
        "34741005",  # Nervios (disorder)
        "34938008",  # Anxiety disorder caused by alcohol (disorder)
        "35218008",  # Chronic disorganized schizophrenia with acute exacerbation (disorder)
        "35252006",  # Disorganized schizophrenia (disorder)
        "35253001",  # Attention deficit hyperactivity disorder, predominantly inattentive type (disorder)
        "3530005",  # Bipolar I disorder, single manic episode, in full remission (disorder)
        "35481005",  # Mixed bipolar I disorder in remission (disorder)
        "35489007",  # Depressive disorder (disorder)
        "35607004",  # Panic disorder with agoraphobia (disorder)
        "35722002",  # Severe bipolar II disorder, most recent episode major depressive, in remission (disorder)
        "357705009",  # Cotard's syndrome (disorder)
        "35827000",  # Recurrent conversion disorder (disorder)
        "35846004",  # Moderate bipolar II disorder, most recent episode major depressive (disorder)
        "3586005",  # Psychogenic fugue (disorder)
        "35919005",  # Pervasive developmental disorder (disorder)
        "359661001",  # Specific number difficulty (disorder)
        "36039004",  # Rumination disorder of infancy (disorder)
        "361151007",  # Delirium due to sedative withdrawal (disorder)
        "361275004",  # Oral dyspraxia (disorder)
        "361277007",  # Verbal dyspraxia (disorder)
        "36158005",  # Schizophreniform disorder with good prognostic features (disorder)
        "36170009",  # Secondary dysthymia late onset (disorder)
        "36217008",  # Organic personality disorder (disorder)
        "36262007",  # Pygmalionism (disorder)
        "363236004",  # Neurodevelopmental disorder of fetus (disorder)
        "36474008",  # Severe recurrent major depression without psychotic features (disorder)
        "36583000",  # Mixed bipolar I disorder in partial remission (disorder)
        "36622002",  # Mild mood disorder (disorder)
        "367515004",  # Receptive language disorder (disorder)
        "368361000119108",  # Thyrotoxicosis factitia without thyrotoxic crisis (disorder)
        "36923009",  # Major depression, single episode (disorder)
        "370143000",  # Major depressive disorder (disorder)
        "371024007",  # Senile dementia with delusion (disorder)
        "371026009",  # Senile dementia with psychosis (disorder)
        "371596008",  # Bipolar I disorder (disorder)
        "371599001",  # Severe bipolar I disorder (disorder)
        "371600003",  # Severe bipolar disorder (disorder)
        "371604007",  # Severe bipolar II disorder (disorder)
        "371631005",  # Panic disorder (disorder)
        "37224001",  # Psychogenic vomiting (disorder)
        "37331004",  # Organic mood disorder caused by psychoactive substance (disorder)
        "373618009",  # Autistic spectrum disorder with isolated skills (disorder)
        "37739004",  # Mood disorder due to a general medical condition (disorder)
        "37746008",  # Avoidant personality disorder (disorder)
        "37868008",  # Anxiety disorder of adolescence (disorder)
        "37872007",  # Avoidant disorder of childhood OR adolescence (disorder)
        "37941009",  # Rumination disorder (disorder)
        "38295006",  # Involutional paraphrenia (disorder)
        "38328002",  # Panic disorder with agoraphobia, severe agoraphobic avoidance AND panic attacks in full remission (disorder)
        "38368003",  # Schizoaffective disorder, bipolar type (disorder)
        "38451003",  # Primary dysthymia early onset (disorder)
        "38547003",  # Mood disorder in full remission (disorder)
        "386537007",  # Psychogenic pylorospasm (disorder)
        "386572005",  # Psychogenic syncope (disorder)
        "386701004",  # Developmental articulation disorder (disorder)
        "386810004",  # Phobic disorder (disorder)
        "386820009",  # Socialized behavior disorder (disorder)
        "386821008",  # Adjustment reaction in infancy (disorder)
        "386822001",  # Adjustment reaction of adolescence (disorder)
        "386823006",  # Adjustment reaction of adult life (disorder)
        "386824000",  # Adjustment reaction of childhood (disorder)
        "386825004",  # Adjustment reaction of late life (disorder)
        "38694004",  # Recurrent major depressive disorder with atypical features (disorder)
        "39003006",  # Psychoactive substance-induced organic delirium (disorder)
        "3914008",  # Mental disorder in childhood (disorder)
        "39465007",  # Emotional deprivation syndrome (disorder)
        "39610001",  # Undifferentiated schizophrenia in remission (disorder)
        "397795007",  # Polysomatizing disorder (disorder)
        "397826007",  # Briquet's syndrome (disorder)
        "397923000",  # Somatization disorder (disorder)
        "39807006",  # Cannabis intoxication delirium (disorder)
        "39809009",  # Recurrent major depressive disorder with catatonic features (disorder)
        "39951000119105",  # Pervasive developmental disorder of residual state (disorder)
        "39951001",  # Cannabis-induced anxiety disorder (disorder)
        "40083003",  # Stereotypic movement disorder with self-injurious behavior (disorder)
        "402732001",  # Habit tic (disorder)
        "402733006",  # Habit tic affecting skin (disorder)
        "402734000",  # Nail dystrophy due to habit tic (disorder)
        "402735004",  # Habit tic affecting hair (disorder)
        "402736003",  # Factitious skin disease (disorder)
        "402737007",  # Artefactual skin disease (disorder)
        "402738002",  # Addictive behavior with potential to damage skin (disorder)
        "403169003",  # Callosity due to habit tic (disorder)
        "403170002",  # Callosity due to biting and/or chewing (disorder)
        "403578003",  # Factitious blistering (disorder)
        "403579006",  # Factitious lymphedema (disorder)
        "403580009",  # Religious stigmata (disorder)
        "403581008",  # Pseudostigmata (disorder)
        "403582001",  # Self-inflicted caustic burn (disorder)
        "403583006",  # Deliberate self-cutting (disorder)
        "403584000",  # Contact urticaria artefacta (disorder)
        "403585004",  # Patch test artifact (disorder)
        "403586003",  # Cutaneous Munchausen syndrome (disorder)
        "403587007",  # Addiction to sun exposure (disorder)
        "403588002",  # Addiction to sunbed use (disorder)
        "403590001",  # Factitious skin disorder imposed on another (disorder)
        "403593004",  # Phobic fear of skin cancer (disorder)
        "403594005",  # Psychogenic formication (disorder)
        "403595006",  # Pinocchio syndrome (disorder)
        "40379007",  # Mild recurrent major depression (disorder)
        "40425004",  # Postconcussion syndrome (disorder)
        "404906000",  # Postoperative confusion (disorder)
        "40568001",  # Recurrent brief depressive disorder (disorder)
        "40571009",  # Hallucinogen intoxication delirium (disorder)
        "405788002",  # Psychogenic loss of appetite (disorder)
        "406506008",  # Attention deficit hyperactivity disorder (disorder)
        "40673001",  # Post-encephalitic syndrome (disorder)
        "40700009",  # Severe intellectual disability (disorder)
        "408857007",  # Infantile autism (disorder)
        "408858002",  # Infantile psychosis (disorder)
        "40926005",  # Moderate mixed bipolar I disorder (disorder)
        "40950007",  # Zar (disorder)
        "40987004",  # Intermittent explosive disorder (disorder)
        "41021005",  # Psychologic dyspareunia (disorder)
        "41196008",  # Dhat (disorder)
        "412787009",  # Intellectual disability, congenital heart disease, blepharophimosis, blepharoptosis and hypoplastic teeth (disorder)
        "413296003",  # Depression requiring intervention (disorder)
        "41524005",  # Flagellantism (disorder)
        "41526007",  # Reactive attachment disorder (disorder)
        "41552001",  # Mild bipolar I disorder, single manic episode (disorder)
        "416340002",  # Late onset schizophrenia (disorder)
        "41673007",  # Ataque de nervios (disorder)
        "416780008",  # Primary degenerative dementia of the Alzheimer type, presenile onset (disorder)
        "416975007",  # Primary degenerative dementia of the Alzheimer type, senile onset (disorder)
        "417294004",  # Factitious keratitis (disorder)
        "41832009",  # Severe bipolar I disorder, single manic episode with psychotic features (disorder)
        "41836007",  # Bipolar disorder in full remission (disorder)
        "41932008",  # Amok (disorder)
        "420614009",  # Organic dementia with acquired immunodeficiency syndrome (disorder)
        "420774007",  # Organic brain syndrome with acquired immunodeficiency syndrome (disorder)
        "421023003",  # Presenile dementia with acquired immunodeficiency syndrome (disorder)
        "421529006",  # Dementia with acquired immunodeficiency syndrome (disorder)
        "422437002",  # X-linked intellectual disability with marfanoid habitus (disorder)
        "425390006",  # Dementia associated with Parkinson's Disease (disorder)
        "425743007",  # Psychogenic vocal cord dysfunction (disorder)
        "425832009",  # Psychophysiologic insomnia (disorder)
        "425914008",  # Adjustment reaction to medical therapy (disorder)
        "425919003",  # Chronic organic mental disorder (disorder)
        "42594001",  # Organic mood disorder of depressed type (disorder)
        "426174008",  # Chronic stress disorder (disorder)
        "426578000",  # Premenstrual dysphoric disorder in remission (disorder)
        "426881004",  # Developmental delay in feeding (disorder)
        "427145007",  # Articulation disorder due to hyperkinesis (disorder)
        "427469003",  # Eating disorder in remission (disorder)
        "427975003",  # Delusional disorder caused by drug (disorder)
        "428051000124108",  # Mild dementia (disorder)
        "42810003",  # Major depression in remission (disorder)
        "428351000124105",  # Severe dementia (disorder)
        "42868002",  # Subchronic catatonic schizophrenia (disorder)
        "428687006",  # Nightmares associated with chronic post-traumatic stress disorder (disorder)
        "428703001",  # Transient organic mental disorder (disorder)
        "429161000124103",  # Primary degenerative dementia of the Alzheimer type, senile onset, with behavioral disturbance (disorder)
        "42925002",  # Major depressive disorder, single episode with atypical features (disorder)
        "429458009",  # Dementia due to Creutzfeldt Jakob disease (disorder)
        "429571005",  # Sleep-related dissociative disorder (disorder)
        "429672007",  # Mood disorder caused by drug (disorder)
        "429998004",  # Vascular dementia (disorder)
        "430061000124109",  # Early myoclonic encephalopathy, refractory (disorder)
        "430071000124102",  # Early myoclonic encephalopathy, non-refractory (disorder)
        "430099007",  # Gross motor development delay (disorder)
        "4306003",  # Cluster B personality disorder (disorder)
        "430744005",  # Factitious disorder with predominantly physical signs and symptoms (disorder)
        "430751001",  # Factitious disorder with predominantly psychological signs and symptoms (disorder)
        "430771000124100",  # Moderate dementia (disorder)
        "430852001",  # Severe major depression, single episode, with psychotic features (disorder)
        "430909002",  # Conduct disorder (disorder)
        "431111000124104",  # Lennox-Gastaut syndrome, refractory (disorder)
        "431121000124107",  # Lennox-Gastaut syndrome, non-refractory (disorder)
        "43150009",  # Panic disorder without agoraphobia with severe panic attacks (disorder)
        "432091002",  # Savant syndrome (disorder)
        "432171000124102",  # Severe myoclonic epilepsy in infancy, refractory (disorder)
        "434451000124105",  # Acute tic disorder (disorder)
        "43497001",  # Amfetamine-induced mood disorder (disorder)
        "435321000124106",  # Acquired epileptic aphasia, non-refractory (disorder)
        "435331000124109",  # Acquired epileptic aphasia, refractory (disorder)
        "435341000124104",  # Rasmussen syndrome, refractory (disorder)
        "43568002",  # Bipolar II disorder, most recent episode major depressive with atypical features (disorder)
        "436001000124105",  # Insomnia due to anxiety and fear (disorder)
        "43614003",  # Autistic disorder of childhood onset (disorder)
        "43769008",  # Mild mixed bipolar I disorder (disorder)
        "438421000124109",  # Myoclonic astatic epilepsy, non-refractory (disorder)
        "439960005",  # Binge eating disorder (disorder)
        "44031002",  # Postseizure confusion (disorder)
        "44124003",  # Reactive attachment disorder of early childhood (disorder)
        "441704009",  # Affective psychosis (disorder)
        "441711008",  # Chronic psychogenic pain (disorder)
        "441716003",  # Residual childhood psychosis (disorder)
        "441719005",  # Speech and language developmental delay due to hearing loss (disorder)
        "441833000",  # Lethal catatonia (disorder)
        "441972000",  # Psychogenic disorder of the genitourinary system (disorder)
        "442057004",  # Chronic depressive personality disorder (disorder)
        "442099003",  # Psychogenic fatigue (disorder)
        "442168001",  # Retardation of physical development (disorder)
        "442183006",  # Psychogenic dyskinesia (disorder)
        "442243005",  # Psychosexual dysfunction associated with inhibited libido (disorder)
        "442245003",  # Chronic hypomanic personality disorder (disorder)
        "442314000",  # Active but odd autism (disorder)
        "442344002",  # Dementia due to Huntington chorea (disorder)
        "442351006",  # Mental disorder caused by drug (disorder)
        "443735008",  # Nonverbal learning disorder (disorder)
        "44376007",  # Dissociative disorder (disorder)
        "443853005",  # Psychogenic tremor (disorder)
        "443919007",  # Complex posttraumatic stress disorder (disorder)
        "4441000",  # Severe bipolar disorder with psychotic features (disorder)
        "44423001",  # Early myoclonic encephalopathy (disorder)
        "44433009",  # Recurrent transient tic disorder (disorder)
        "444613000",  # Adult attention deficit hyperactivity disorder (disorder)
        "446175003",  # Acute posttraumatic stress disorder following military combat (disorder)
        "446180007",  # Delayed posttraumatic stress disorder following military combat (disorder)
        "44966003",  # Passive aggressive personality disorder (disorder)
        "450714000",  # Severe major depression (disorder)
        "45479006",  # Manic bipolar I disorder in remission (disorder)
        "45677003",  # Developmental expressive writing disorder (disorder)
        "45912004",  # Organic hallucinosis (disorder)
        "45924006",  # Necrophilia (disorder)
        "45994004",  # Erotic vomiting (disorder)
        "46023009",  # Pedophilia, same AND opposite sex (disorder)
        "46206005",  # Mood disorder (disorder)
        "46229002",  # Severe mixed bipolar I disorder without psychotic features (disorder)
        "46244001",  # Recurrent major depression in full remission (disorder)
        "46432001",  # Lecherism (disorder)
        "46721000",  # Organic personality disorder caused by psychoactive substance (disorder)
        "46762006",  # Sexual desire disorder (disorder)
        "46975003",  # Organic mental disorder caused by cocaine (disorder)
        "471971000124108",  # Anxiety disorder due to severe acute respiratory syndrome coronavirus 2 (disorder)
        "472981000",  # Fetishistic transvestism (disorder)
        "473452003",  # Atypical psychosis (disorder)
        "473456000",  # Compulsive personality disorder (disorder)
        "473457009",  # Obsessional personality disorder (disorder)
        "47372000",  # Adjustment disorder with anxious mood (disorder)
        "47447001",  # Grandiose delusion disorder (disorder)
        "47505003",  # Posttraumatic stress disorder (disorder)
        "47664006",  # Sedative, hypnotic AND/OR anxiolytic-induced psychotic disorder with hallucinations (disorder)
        "47916000",  # Developmental arithmetic disorder (disorder)
        "48046002",  # Symptomatic sexual masochism (disorder)
        "4817008",  # Primary degenerative dementia of the Alzheimer type, senile onset, with delirium (disorder)
        "48309007",  # Pedophilia, nonexclusive type (disorder)
        "48500005",  # Delusional disorder (disorder)
        "48589009",  # Minor depressive disorder (disorder)
        "4863002",  # Mood disorder caused by phencyclidine (disorder)
        "48826008",  # Conduct disorder, adolescent-onset type (disorder)
        "48937005",  # Bipolar II disorder, most recent episode hypomanic (disorder)
        "4926007",  # Schizophrenia in remission (disorder)
        "49271002",  # Deferred diagnosis on Axis II (disorder)
        "4932002",  # Panic disorder with agoraphobia, moderate agoraphobic avoidance AND mild panic attacks (disorder)
        "49468007",  # Depressed bipolar I disorder (disorder)
        "49481000",  # Postseizure delirium (disorder)
        "4949009",  # Motor skill disorder (disorder)
        "49512000",  # Depressed bipolar I disorder in partial remission (disorder)
        "49564006",  # Panic disorder with agoraphobia, mild agoraphobic avoidance AND moderate panic attacks (disorder)
        "4997005",  # Thyrotoxicosis factitia (disorder)
        "50026000",  # Organic anxiety disorder caused by psychoactive substance (disorder)
        "50299009",  # Paraphilia (disorder)
        "50320000",  # Hallucinogen intoxication (disorder)
        "50643003",  # Latah (disorder)
        "50705009",  # Factitious disorder (disorder)
        "50722006",  # Delusional disorder caused by phencyclidine (disorder)
        "50933003",  # Hallucinogen delusional disorder (disorder)
        "5095008",  # Gender identity disorder of childhood (disorder)
        "50983008",  # Panic disorder with agoraphobia, mild agoraphobic avoidance AND panic attacks in partial remission (disorder)
        "51133006",  # Residual schizophrenia in remission (disorder)
        "51239001",  # Sexual masochism (disorder)
        "51443000",  # Amphetamine-induced psychotic disorder with hallucinations (disorder)
        "51493001",  # Anxiety disorder caused by cocaine (disorder)
        "5158005",  # Gilles de la Tourette's syndrome (disorder)
        "51637008",  # Chronic bipolar I disorder, most recent episode depressed (disorder)
        "51928006",  # General paresis - neurosyphilis (disorder)
        "51946000",  # Susto (disorder)
        "52448006",  # Dementia (disorder)
        "52824009",  # Developmental reading disorder (disorder)
        "52866005",  # Opioid intoxication delirium (disorder)
        "52910006",  # Anxiety disorder due to a general medical condition (disorder)
        "52954000",  # Schizoid personality disorder (disorder)
        "53049002",  # Severe bipolar disorder without psychotic features (disorder)
        "53050002",  # Organic mental disorder caused by hallucinogen (disorder)
        "53467004",  # Anxiety disorder of childhood (disorder)
        "53607008",  # Depressed bipolar I disorder in remission (disorder)
        "53956006",  # Panic disorder without agoraphobia with panic attacks in partial remission (disorder)
        "54319003",  # Disruptive behavior disorder (disorder)
        "54417002",  # Adult gender identity disorder, sexually attracted to females (disorder)
        "5444000",  # Sedative, hypnotic AND/OR anxiolytic intoxication delirium (disorder)
        "54502004",  # Primary degenerative dementia of the Alzheimer type, presenile onset, with delusions (disorder)
        "54560009",  # Windigo (disorder)
        "54587008",  # Simple phobia (disorder)
        "5464005",  # Brief reactive psychosis (disorder)
        "54761006",  # Severe depressed bipolar I disorder with psychotic features, mood-congruent (disorder)
        "55009008",  # Primary degenerative dementia of the Alzheimer type, senile onset, with delusions (disorder)
        "5507002",  # Stereotypy habit disorder (disorder)
        "5509004",  # Panic disorder with agoraphobia AND severe panic attacks (disorder)
        "5510009",  # Organic delusional disorder (disorder)
        "55341008",  # Histrionic personality disorder (disorder)
        "55516002",  # Bipolar I disorder, most recent episode manic with postpartum onset (disorder)
        "55668003",  # Adjustment disorder with mixed emotional features (disorder)
        "55728007",  # Sexual aversion disorder (disorder)
        "55736003",  # Schizophreniform disorder without good prognostic features (disorder)
        "55967005",  # Anxiety disorder caused by phencyclidine (disorder)
        "56034001",  # Compulsive exhibitionism (disorder)
        "56095002",  # Necrosadism (disorder)
        "5619004",  # Bardet-Biedl syndrome (disorder)
        "56267009",  # Multi-infarct dementia (disorder)
        "56573006",  # Transient tic disorder (disorder)
        "56576003",  # Panic disorder without agoraphobia (disorder)
        "56627002",  # Psychosexual disorder (disorder)
        "5664002",  # Situational hypoactive sexual desire disorder (disorder)
        "56641006",  # Axis II diagnosis (disorder)
        "568005",  # Tic disorder (disorder)
        "56882008",  # Anorexia nervosa (disorder)
        "5703000",  # Bipolar disorder in partial remission (disorder)
        "57194009",  # Adjustment disorder with depressed mood (disorder)
        "57588009",  # Sedative, hypnotic AND/OR anxiolytic-induced sleep disorder (disorder)
        "57715001",  # Gender identity disorder of adolescence (disorder)
        "57917004",  # Seckel syndrome (disorder)
        "5793009",  # Mixed behavior and emotional disorder (disorder)
        "58214004",  # Schizophrenia (disorder)
        "58329000",  # Organic mood disorder of manic type (disorder)
        "58349009",  # Exhibitionism (disorder)
        "58535001",  # Physical AND emotional exhaustion state (disorder)
        "58647003",  # Severe mood disorder with psychotic features, mood-congruent (disorder)
        "58703003",  # Postpartum depression (disorder)
        "58756001",  # Huntington's chorea (disorder)
        "58855008",  # Symptomatic exhibitionism (disorder)
        "59174009",  # Fetishism (disorder)
        "59216005",  # Adult gender identity disorder, sexually attracted to males (disorder)
        "59252009",  # de Barsey syndrome (disorder)
        "59394009",  # Sexual sadism (disorder)
        "596004",  # Premenstrual dysphoric disorder (disorder)
        "59617007",  # Severe depressed bipolar I disorder with psychotic features (disorder)
        "59645001",  # Bulimia nervosa, nonpurging type (disorder)
        "59651006",  # Sedative, hypnotic AND/OR anxiolytic-induced persisting dementia (disorder)
        "59923000",  # Panic disorder with agoraphobia AND panic attacks in full remission (disorder)
        "600009",  # Pyromania (disorder)
        "60099002",  # Severe major depression with psychotic features, mood-incongruent (disorder)
        "60103007",  # Inhibited female orgasm (disorder)
        "60123008",  # Delusional disorder, mixed type (disorder)
        "60251000119101",  # Impulse control disorder in remission (disorder)
        "60401000119104",  # Postpartum psychosis in remission (disorder)
        "61104008",  # Inhalant-induced organic mental disorder (disorder)
        "61144001",  # Alcohol-induced psychotic disorder with delusions (disorder)
        "61152003",  # Moderate intellectual disability (disorder)
        "61157009",  # Combat fatigue (disorder)
        "61180001",  # Adult gender identity disorder, sexually attracted to neither sex (disorder)
        "61212007",  # Panic disorder with agoraphobia, severe agoraphobic avoidance AND severe panic attacks (disorder)
        "613003",  # Fragile X syndrome (disorder)
        "61403008",  # Severe depressed bipolar I disorder without psychotic features (disorder)
        "61569007",  # Agoraphobia without history of panic disorder (disorder)
        "61831009",  # Induced psychotic disorder (disorder)
        "61901004",  # Conduct disorder, undifferentiated type (disorder)
        "62211000119103",  # Moderate expressive language delay (disorder)
        "62221000119105",  # Severe expressive language delay (disorder)
        "62231000119108",  # Mild expressive language delay (disorder)
        "62351001",  # Generalized social phobia (disorder)
        "62491004",  # Frotteurism (disorder)
        "62792007",  # Urophilia (disorder)
        "63181006",  # Paranoid schizophrenia in remission (disorder)
        "63204009",  # Bouffee delirante (disorder)
        "63249007",  # Manic bipolar I disorder in partial remission (disorder)
        "63393005",  # Anorexia nervosa, binge-eating purging type (disorder)
        "63395003",  # Folie a trois (disorder)
        "63412003",  # Major depression in full remission (disorder)
        "6348008",  # Cocaine-induced psychotic disorder with hallucinations (disorder)
        "63649001",  # Cannabis delusional disorder (disorder)
        "63701002",  # Panic disorder with agoraphobia, mild agoraphobic avoidance AND mild panic attacks (disorder)
        "63778009",  # Major depressive disorder, single episode with melancholic features (disorder)
        "63835008",  # Voyeurism (disorder)
        "63909006",  # Panic disorder with agoraphobia AND panic attacks in partial remission (disorder)
        "63983005",  # Inhalant-induced psychotic disorder with hallucinations (disorder)
        "63990000",  # Psychogenic urticaria (disorder)
        "64060000",  # Panic disorder with agoraphobia, moderate agoraphobic avoidance AND panic attacks in full remission (disorder)
        "64161004",  # Psychogenic voice disorder (disorder)
        "64165008",  # Avoidant disorder of childhood (disorder)
        "64731001",  # Severe mixed bipolar I disorder with psychotic features, mood-congruent (disorder)
        "6475002",  # Primary degenerative dementia of the Alzheimer type, presenile onset, uncomplicated (disorder)
        "64905009",  # Paranoid schizophrenia (disorder)
        "65042007",  # Bipolar I disorder, most recent episode mixed with postpartum onset (disorder)
        "65064003",  # Panic disorder without agoraphobia with moderate panic attacks (disorder)
        "65096006",  # Primary degenerative dementia of the Alzheimer type, presenile onset, with delirium (disorder)
        "651003",  # Root work (disorder)
        "65179007",  # Koro (disorder)
        "65207000",  # Locuru (disorder)
        "65384007",  # Psychogenic alopecia (disorder)
        "65410009",  # Compulsive sexual masochism (disorder)
        "65438001",  # Psychogenic torticollis (disorder)
        "65971000052100",  # Acute psychosis (disorder)
        "66108005",  # Primary degenerative dementia of the Alzheimer type, senile onset, uncomplicated (disorder)
        "66307007",  # Conduct disorder, group type (disorder)
        "66344007",  # Recurrent major depression (disorder)
        "66347000",  # Impulse control disorder (disorder)
        "66381006",  # Adjustment disorder with mixed disturbance of emotions AND conduct (disorder)
        "66551002",  # Psychogenic headache (disorder)
        "66590003",  # Alcohol dependence (disorder)
        "66631006",  # Moderate depressed bipolar I disorder (disorder)
        "66936004",  # Identity disorder (disorder)
        "67002003",  # Severe bipolar II disorder, most recent episode major depressive, in partial remission (disorder)
        "67123006",  # Adult gender identity disorder, sexually attracted to both sexes (disorder)
        "67195008",  # Acute stress disorder (disorder)
        "67227000",  # Pedophilia, same sex (disorder)
        "672481000119108",  # Fluency disorder due to and following ischemic cerebrovascular accident (disorder)
        "672491000119106",  # Fluency disorder due to and following hemorrhagic cerebrovascular accident (disorder)
        "67711008",  # Primary dysthymia late onset (disorder)
        "68019004",  # Recurrent major depression in remission (disorder)
        "68569003",  # Manic bipolar I disorder (disorder)
        "68618008",  # Rett syndrome (disorder)
        "68890003",  # Schizoaffective disorder (disorder)
        "68963006",  # Gender identity disorder of adolescence, previously heterosexual (disorder)
        "68995007",  # Chronic catatonic schizophrenia (disorder)
        "69322001",  # Psychotic disorder (disorder)
        "69361009",  # Kleptomania (disorder)
        "69392006",  # Major depressive disorder, single episode with catatonic features (disorder)
        "69403006",  # Dissociative neurological symptom disorder with aphonia (disorder)
        "69479009",  # Anxiety hyperventilation (disorder)
        "69482004",  # Korsakoff's psychosis (disorder)
        "698624003",  # Dementia associated with cerebral lipidosis (disorder)
        "698625002",  # Dementia associated with normal pressure hydrocephalus (disorder)
        "698626001",  # Dementia associated with multiple sclerosis (disorder)
        "698687007",  # Post-traumatic dementia with behavioral change (disorder)
        "698689005",  # Attention deficit hyperactivity disorder, predominantly inattentive type in remission (disorder)
        "698690001",  # Avoidant personality disorder in remission (disorder)
        "698692009",  # Attention deficit hyperactivity disorder, predominantly hyperactive impulsive type in remission (disorder)
        "698693004",  # Adjustment disorder with anxious mood in remission (disorder)
        "698695006",  # Anorexia nervosa in remission (disorder)
        "698696007",  # Adjustment disorder with depressed mood in remission (disorder)
        "698697003",  # Adjustment disorder with mixed disturbance of emotions and conduct in remission (disorder)
        "698698008",  # Bulimia nervosa in remission (disorder)
        "698699000",  # Antisocial personality disorder in remission (disorder)
        "698700004",  # Borderline personality disorder in remission (disorder)
        "698701000",  # Adjustment disorder in remission (disorder)
        "698725008",  # Dementia associated with neurosyphilis (disorder)
        "698726009",  # Dementia associated with viral encephalitis (disorder)
        "698781002",  # Dementia associated with cerebral anoxia (disorder)
        "698946008",  # Cyclothymia in remission (disorder)
        "698947004",  # Conduct disorder in remission (disorder)
        "698948009",  # Vascular dementia in remission (disorder)
        "698949001",  # Dementia in remission (disorder)
        "698951002",  # Delusional disorder in remission (disorder)
        "698952009",  # Dissociative disorder in remission (disorder)
        "698954005",  # Primary degenerative dementia of the Alzheimer type, senile onset in remission (disorder)
        "698955006",  # Primary degenerative dementia of the Alzheimer type, presenile onset in remission (disorder)
        "698957003",  # Depressive disorder in remission (disorder)
        "698958008",  # Delirium in remission (disorder)
        "699241002",  # Chronic post-traumatic stress disorder following military combat (disorder)
        "699297004",  # Blepharophimosis-intellectual disability syndrome Maat-Kievit-Brunner type (disorder)
        "699298009",  # Blepharophimosis, intellectual disability syndrome, Say-Barber-Biesecker-Young-Simpson type (disorder)
        "699316006",  # Myhre syndrome (disorder)
        "699669001",  # Renpenning syndrome (disorder)
        "700213005",  # Avoidant restrictive food intake disorder (disorder)
        "700364009",  # Neurodevelopmental disorder (disorder)
        "70043001",  # Severe mood disorder with psychotic features, mood-incongruent (disorder)
        "70066000",  # Dissociative neurological symptom disorder with muteness (disorder)
        "702327009",  # Monocarboxylate transporter 8 deficiency (disorder)
        "702344008",  # Pitt-Hopkins syndrome (disorder)
        "702354007",  # X-linked intellectual developmental disorder Christianson type (disorder)
        "702356009",  # X-linked intellectual disability-psychosis-macroorchidism syndrome (disorder)
        "702393003",  # Frontotemporal dementia with gene located on 3p11 (disorder)
        "702412005",  # X-linked intellectual deficit-dystonia-dysarthria syndrome (disorder)
        "702416008",  # X-linked intellectual disability Snyder type (disorder)
        "702423009",  # Deafness-dystonia-optic neuronopathy syndrome (disorder)
        "702441001",  # Fatal X-linked ataxia with deafness and loss of vision (disorder)
        "702450004",  # FOXG1 syndrome (disorder)
        "7025000",  # Subchronic undifferentiated schizophrenia with acute exacerbations (disorder)
        "702528003",  # Developmental delay in receptive-expressive language (disorder)
        "702711004",  # Mental disorder in mother complicating pregnancy (disorder)
        "702732007",  # High-functioning autism (disorder)
        "702815001",  # Attention deficit hyperactivity disorder, inattentive presentation (restrictive) (disorder)
        "702816000",  # Methyl-cytosine phosphate guanine binding protein-2 duplication syndrome (disorder)
        "703041000",  # Dysexecutive syndrome (disorder)
        "7031000119100",  # Psychogenic fugue co-occurrent and due to stress reaction (disorder)
        "70328006",  # Cocaine intoxication delirium (disorder)
        "703389002",  # Calcium/calmodulin-dependent serine protein kinase related intellectual disability (disorder)
        "703477003",  # Developmental delay in fine motor function (disorder)
        "703526007",  # Progressive epilepsy-intellectual disability syndrome Finnish type (disorder)
        "703535000",  # Mowat-Wilson syndrome (disorder)
        "703850002",  # Delirium due to benzodiazepine withdrawal (disorder)
        "705001007",  # Self-induced vomiting to lose weight (disorder)
        "7052005",  # Alcohol hallucinosis (disorder)
        "70546001",  # Severe bipolar disorder with psychotic features, mood-congruent (disorder)
        "70691001",  # Agoraphobia (disorder)
        "70747007",  # Major depression single episode, in partial remission (disorder)
        "70764005",  # Depersonalization disorder (disorder)
        "708037001",  # Residual Asperger's disorder (disorder)
        "70814008",  # Subchronic residual schizophrenia with acute exacerbations (disorder)
        "70922000",  # Compulsive pedophilia (disorder)
        "70936005",  # Multi-infarct dementia, uncomplicated (disorder)
        "70967007",  # Dissociative deafness (disorder)
        "710072005",  # Female athlete triad (disorder)
        "71103003",  # Chronic residual schizophrenia (disorder)
        "712823008",  # Acute depression (disorder)
        "712824002",  # Acute polymorphic psychotic disorder without symptoms of schizophrenia (disorder)
        "712850003",  # Acute polymorphic psychotic disorder co-occurrent with symptoms of schizophrenia (disorder)
        "712884004",  # Pathological demand avoidance (disorder)
        "71294008",  # Mild bipolar II disorder, most recent episode major depressive (disorder)
        "71336009",  # Recurrent major depressive disorder with postpartum onset (disorder)
        "713488003",  # Presenile dementia co-occurrent with human immunodeficiency virus infection (disorder)
        "713491003",  # Organic brain syndrome co-occurrent with human immunodeficiency virus infection (disorder)
        "713583005",  # Mild alcohol dependence (disorder)
        "713844000",  # Dementia co-occurrent with human immunodeficiency virus infection (disorder)
        "713862009",  # Severe alcohol dependence (disorder)
        "714829008",  # Moderate alcohol dependence (disorder)
        "715409005",  # Trigonocephaly C syndrome (disorder)
        "715428003",  # Skeletal dysplasia with epilepsy and short stature syndrome (disorder)
        "715441004",  # McDonough syndrome (disorder)
        "715628009",  # Intellectual disability, truncal obesity, retinal dystrophy and micropenis syndrome (disorder)
        "715737004",  # Parkinsonism co-occurrent with dementia of Guadeloupe (disorder)
        "715924009",  # Disruptive mood dysregulation disorder (disorder)
        "715989002",  # Congenital cataract with intellectual disability and anal atresia and urinary defect syndrome (disorder)
        "716024001",  # Goniodysgenesis with intellectual disability and short stature syndrome (disorder)
        "716089008",  # Craniofacial digital and genital anomalies syndrome (disorder)
        "716096005",  # Hypospadias and intellectual disability syndrome Goldblatt type (disorder)
        "716107009",  # Early onset parkinsonism and intellectual disability syndrome (disorder)
        "716112005",  # Microcephaly with deafness and intellectual disability syndrome (disorder)
        "716191002",  # Alopecia and intellectual disability syndrome (disorder)
        "716199000",  # Delayed speech and facial asymmetry with strabismus and ear lobe skin crease syndrome (disorder)
        "716334004",  # Intellectual disability and short stature with hand contracture and genital anomaly syndrome (disorder)
        "716578009",  # Developmental language comprehension impairment (disorder)
        "716667005",  # Right temporal atrophy variant frontotemporal dementia (disorder)
        "716706009",  # Female restricted epilepsy with intellectual disability syndrome (disorder)
        "716709002",  # FRAXE intellectual disability syndrome (disorder)
        "716994006",  # Behavioral variant of frontotemporal dementia (disorder)
        "716996008",  # Hypoplasia of corpus callosum, intellectual disability, adducted thumbs, spasticity, hydrocephalus syndrome (disorder)
        "717157006",  # Trisomy 10p (disorder)
        "717222003",  # Microphthalmia with ankyloblepharon and intellectual disability syndrome (disorder)
        "717223008",  # X-linked epilepsy with learning disability and behavior disorder syndrome (disorder)
        "717276003",  # Folinic acid responsive seizure syndrome (disorder)
        "717822006",  # Goldberg Shprintzen megacolon syndrome (disorder)
        "71787009",  # Psychologic vaginismus (disorder)
        "717887003",  # Biemond syndrome type 2 (disorder)
        "717913006",  # Blepharonasofacial malformation syndrome (disorder)
        "717945001",  # Brain anomaly, severe intellectual disability, ectodermal dysplasia, skeletal deformity, ear anomaly, kidney dysplasia syndrome (disorder)
        "71802006",  # Astasia-abasia (disorder)
        "718226002",  # Wolf Hirschhorn syndrome (disorder)
        "718393002",  # Atypical Rett syndrome (disorder)
        "718573009",  # Achalasia microcephaly syndrome (disorder)
        "718577005",  # X-linked intellectual disability Atkin type (disorder)
        "718636001",  # Minimal depression (disorder)
        "718680001",  # Oro-facial digital syndrome type 9 (disorder)
        "718681002",  # Oro-facial digital syndrome type 11 (disorder)
        "718766002",  # Spondyloepiphyseal dysplasia, craniosynostosis, cleft palate, cataract and intellectual disability syndrome (disorder)
        "718845002",  # X-linked intellectual disability with ataxia and apraxia syndrome (disorder)
        "718847005",  # X-linked neurodegenerative syndrome Hamel type (disorder)
        "718848000",  # Fried syndrome (disorder)
        "718896000",  # X-linked recessive intellectual disability and macrocephaly with ciliary dysfunction syndrome (disorder)
        "718897009",  # X-linked intellectual disability Seemanova type (disorder)
        "718900002",  # Syndromic X-linked intellectual disability type 11 (disorder)
        "718905007",  # X-linked intellectual disability Shrimpton type (disorder)
        "718908009",  # X-linked intellectual disability Siderius type (disorder)
        "718909001",  # X-linked intellectual disability Stevenson type (disorder)
        "718910006",  # X-linked intellectual disability Stocco Dos Santos type (disorder)
        "718911005",  # X-linked intellectual disability Stoll type (disorder)
        "718912003",  # X-linked intellectual disability Turner type (disorder)
        "718914002",  # X-linked intellectual disability Van Esch type (disorder)
        "719009006",  # X-linked intellectual disability Wilson type (disorder)
        "719010001",  # X-linked intellectual disability Schimke type (disorder)
        "719011002",  # X-linked intellectual disability Pai type (disorder)
        "719012009",  # X-linked intellectual disability Miles Carpenter type (disorder)
        "719013004",  # X-linked intellectual disability Cilliers type (disorder)
        "719016007",  # X-linked intellectual disability Cantagrel type (disorder)
        "719017003",  # X-linked intellectual disability Armfield type (disorder)
        "719018008",  # X-linked intellectual disability Abidi type (disorder)
        "719020006",  # Pallister W syndrome (disorder)
        "719042007",  # Uveal coloboma with cleft lip and palate and intellectual disability syndrome (disorder)
        "719046005",  # 12q14 microdeletion syndrome (disorder)
        "719069008",  # Shprintzen Goldberg craniosynostosis syndrome (disorder)
        "719097002",  # Branchioskeletogenital syndrome (disorder)
        "719102004",  # Congenital cataract with ataxia and deafness syndrome (disorder)
        "719136005",  # X-linked intellectual disability with cerebellar hypoplasia syndrome (disorder)
        "719138006",  # X-linked intellectual disability with cubitus valgus and dysmorphism syndrome (disorder)
        "719139003",  # X-linked Dandy-Walker malformation with intellectual disability, basal ganglia disease and seizure syndrome (disorder)
        "719140001",  # X-linked intellectual disability with dysmorphism and cerebral atrophy syndrome (disorder)
        "719155005",  # X-linked intellectual disability and epilepsy with progressive joint contracture and facial dysmorphism syndrome (disorder)
        "719156006",  # X-linked intellectual disability with hypogammaglobulinemia and progressive neurological deterioration syndrome (disorder)
        "719157002",  # X-linked intellectual disability and hypotonia with facial dysmorphism and aggressive behavior syndrome (disorder)
        "719160009",  # Syndromic X-linked intellectual disability type 7 (disorder)
        "719161008",  # Syndromic X-linked intellectual disability due to jumonji at-rich interactive domain 1c mutation (disorder)
        "719162001",  # Radioulnar synostosis with microcephaly and scoliosis syndrome (disorder)
        "719202006",  # Spondyloepiphyseal dysplasia tarda Kohn type (disorder)
        "719378009",  # Microcephalus with brachydactyly and kyphoscoliosis syndrome (disorder)
        "719380003",  # Microcephalus cardiomyopathy syndrome (disorder)
        "719450007",  # Disorder of sex development with intellectual disability syndrome (disorder)
        "719466009",  # Cleft palate with short stature and vertebral anomaly syndrome (disorder)
        "719583002",  # 17q11.2 microduplication syndrome (disorder)
        "71959007",  # Elective mutism (disorder)
        "719592004",  # Moderately severe major depression (disorder)
        "719593009",  # Moderately severe depression (disorder)
        "719599008",  # 19q13.11 microdeletion syndrome (disorder)
        "719600006",  # 1p21.3 microdeletion syndrome (disorder)
        "71961003",  # Childhood disintegrative disorder (disorder)
        "719717006",  # Psychosis co-occurrent and due to Parkinson's disease (disorder)
        "719800009",  # Deafness, onychodystrophy, osteodystrophy, intellectual disability syndrome (disorder)
        "719808002",  # Chromosome Xp11.3 microdeletion syndrome (disorder)
        "719810000",  # X-linked intellectual disability with seizure and psoriasis syndrome (disorder)
        "719811001",  # X-linked intellectual disability Cabezas type (disorder)
        "719812008",  # X-linked intellectual disability with plagiocephaly syndrome (disorder)
        "719825000",  # X-linked intellectual disability, macrocephaly, macroorchidism syndrome (disorder)
        "719826004",  # X-linked intellectual disability with acromegaly and hyperactivity syndrome (disorder)
        "719834005",  # Wilson Turner syndrome (disorder)
        "71984005",  # Mild manic bipolar I disorder (disorder)
        "719842006",  # Congenital hypoplasia of ulna and intellectual disability syndrome (disorder)
        "719947004",  # Craniofacial dysmorphism with coloboma of eye and corpus callosum agenesis syndrome (disorder)
        "7200002",  # Alcoholism (disorder)
        "720401009",  # Cystic fibrosis with gastritis and megaloblastic anemia syndrome (disorder)
        "720451004",  # Minimal recurrent major depression (disorder)
        "720452006",  # Moderately severe recurrent major depression (disorder)
        "720453001",  # Moderately severe major depression single episode (disorder)
        "720454007",  # Minimal major depression single episode (disorder)
        "720455008",  # Minimal major depression (disorder)
        "720468000",  # Aniridia and intellectual disability syndrome (disorder)
        "720501007",  # Arachnodactyly with abnormal ossification and intellectual disability syndrome (disorder)
        "720502000",  # Arachnodactyly and intellectual disability with facial dysmorphism syndrome (disorder)
        "720517001",  # Ataxia with deafness and intellectual disability syndrome (disorder)
        "720573009",  # Brachymorphism with onychodysplasia and dysphalangism syndrome (disorder)
        "720635002",  # Cerebro-facio-thoracic dysplasia (disorder)
        "720639008",  # Coloboma, congenital heart disease, ichthyosiform dermatosis, intellectual disability ear anomaly syndrome (disorder)
        "720746006",  # Contracture with ectodermal dysplasia and orofacial cleft syndrome (disorder)
        "720748007",  # Aural atresia with multiple congenital anomalies and intellectual disability syndrome (disorder)
        "720825005",  # Cystic leukoencephalopathy without megalencephaly (disorder)
        "720855003",  # Cerebrooculonasal syndrome (disorder)
        "720954000",  # Filippi syndrome (disorder)
        "720955004",  # Fine Lubinsky syndrome (disorder)
        "720957007",  # Deafness with skeletal dysplasia and lip granuloma syndrome (disorder)
        "720979002",  # Alopecia, contracture, dwarfism, intellectual disability syndrome (disorder)
        "720981000",  # Alopecia and intellectual disability with hypergonadotropic hypogonadism syndrome (disorder)
        "720982007",  # Alport syndrome, intellectual disability, midface hypoplasia, elliptocytosis syndrome (disorder)
        "721007005",  # Hair defect with photosensitivity and intellectual disability syndrome (disorder)
        "721008000",  # Hall Riggs syndrome (disorder)
        "721017000",  # Postaxial polydactyly and intellectual disability syndrome (disorder)
        "721073008",  # Short stature with webbed neck and congenital heart disease syndrome (disorder)
        "721086004",  # Deafness, genital anomaly, metacarpal and metatarsal synostosis syndrome (disorder)
        "721087008",  # Deafness and intellectual disability Martin Probst type syndrome (disorder)
        "721089006",  # Dentinogenesis imperfecta, short stature, hearing loss, intellectual disability syndrome (disorder)
        "721146009",  # Intellectual disability, epilepsy, bulbous nose syndrome (disorder)
        "721207002",  # Seizure, sensorineural deafness, ataxia, intellectual disability, electrolyte imbalance syndrome (disorder)
        "721208007",  # Ectodermal dysplasia with blindness syndrome (disorder)
        "721251000124100",  # Early infantile developmental and epileptic encephalopathy (disorder)
        "721841001",  # Hypogonadism with mitral valve prolapse and intellectual disability syndrome (disorder)
        "721843003",  # Growth retardation, alopecia, pseudoanodontia, optic atrophy syndrome (disorder)
        "721875000",  # Juberg Marsidi syndrome (disorder)
        "721883006",  # Radioulnar synostosis with developmental delay and hypotonia syndrome (disorder)
        "721973006",  # Lipodystrophy, intellectual disability, deafness syndrome (disorder)
        "721974000",  # Lowry MacLean syndrome (disorder)
        "722002002",  # Intellectual disability, balding, patella luxation, acromicria syndrome (disorder)
        "722031003",  # Kapur Toriello syndrome (disorder)
        "722033000",  # Macrocephaly, short stature, paraplegia syndrome (disorder)
        "722035007",  # Intellectual disability, enteropathy, deafness, peripheral neuropathy, ichthyosis, keratoderma syndrome (disorder)
        "722037004",  # Intellectual disability, epileptic seizures, hypogonadism and hypogenitalism, microcephaly, obesity syndrome (disorder)
        "722055008",  # Oculopalatocerebral syndrome (disorder)
        "722056009",  # Oculocerebrofacial syndrome Kaufman type (disorder)
        "722075004",  # Oro-facial digital syndrome type 10 (disorder)
        "722105002",  # Oro-facial digital syndrome type 5 (disorder)
        "722106001",  # Oro-facial digital syndrome type 8 (disorder)
        "722107005",  # Ossification anomaly with psychomotor developmental delay syndrome (disorder)
        "722110003",  # Osteogenesis imperfecta, retinopathy, seizures, intellectual disability syndrome (disorder)
        "722209002",  # Spastic paraplegia, intellectual disability, palmoplantar hyperkeratosis syndrome (disorder)
        "722213009",  # Severe X-linked intellectual disability Gustavson type (disorder)
        "722281001",  # Agammaglobulinemia, microcephaly, craniosynostosis, severe dermatitis syndrome (disorder)
        "722282008",  # Agenesis of corpus callosum, intellectual disability, coloboma, micrognathia syndrome (disorder)
        "722378009",  # Congenital cataract with deafness and hypogonadism syndrome (disorder)
        "722379001",  # Congenital cataract with hypertrichosis and intellectual disability syndrome (disorder)
        "722380003",  # Congenital cataract with intellectual disability and hypogonadotropic hypogonadism syndrome (disorder)
        "722454003",  # Intellectual disability, craniofacial dysmorphism, hypogonadism, diabetes mellitus syndrome (disorder)
        "722455002",  # Intellectual disability, hypoplastic corpus callosum, preauricular tag syndrome (disorder)
        "722456001",  # Intellectual disability, developmental delay, contracture syndrome (disorder)
        "722459008",  # Male hypergonadotropic hypogonadism, intellectual disability, skeletal anomaly syndrome (disorder)
        "722477003",  # Toriello Carey syndrome (disorder)
        "722478008",  # Skeletal dysplasia with intellectual disability syndrome (disorder)
        "722600006",  # Non-amnestic Alzheimer disease (disorder)
        "722877006",  # Adult rumination syndrome of ingested food (disorder)
        "722959000",  # Anorexia nervosa co-occurrent with dangerously low body weight (disorder)
        "722960005",  # Anorexia nervosa co-occurrent with significantly low body weight (disorder)
        "722972004",  # Secondary tic disorder (disorder)
        "722973009",  # Tic due to developmental disorder (disorder)
        "722975002",  # Primary stereotypy (disorder)
        "722976001",  # Secondary stereotypy (disorder)
        "722977005",  # Dementia co-occurrent and due to neurocysticercosis (disorder)
        "722978000",  # Toxic dementia (disorder)
        "722979008",  # Dementia due to metabolic abnormality (disorder)
        "722980006",  # Dementia due to chromosomal anomaly (disorder)
        "723122006",  # Primary tic disorder (disorder)
        "723123001",  # Ischemic vascular dementia (disorder)
        "723125008",  # Epileptic encephalopathy (disorder)
        "723304001",  # Microcephaly, seizure, intellectual disability, heart disease syndrome (disorder)
        "723332005",  # Isodicentric chromosome 15 syndrome (disorder)
        "723333000",  # Faciocardiorenal syndrome (disorder)
        "723336008",  # Fallot complex with intellectual disability and growth delay syndrome (disorder)
        "723365002",  # Hypotrichosis and intellectual disability syndrome Lopes type (disorder)
        "723390000",  # Rapidly progressive dementia (disorder)
        "723403008",  # Microbrachycephaly, ptosis, cleft lip syndrome (disorder)
        "723410002",  # N syndrome (disorder)
        "723441001",  # Non-progressive cerebellar ataxia with intellectual disability (disorder)
        "723454008",  # Phosphoribosylpyrophosphate synthetase superactivity (disorder)
        "723504000",  # Ramos Arroyo syndrome (disorder)
        "723621000",  # Spastic tetraplegia, retinitis pigmentosa, intellectual disability syndrome (disorder)
        "72366004",  # Eating disorder (disorder)
        "723676007",  # Severe intellectual disability, epilepsy, anal anomaly, distal phalangeal hypoplasia syndrome (disorder)
        "723899008",  # Delusional disorder currently symptomatic (disorder)
        "723900003",  # Delusional disorder currently in partial remission (disorder)
        "723901004",  # Delusional disorder currently in full remission (disorder)
        "723903001",  # Bipolar type I disorder currently in full remission (disorder)
        "723905008",  # Bipolar type II disorder currently in full remission (disorder)
        "723912004",  # Secondary mood disorder (disorder)
        "723913009",  # Olfactory reference disorder (disorder)
        "723915002",  # Secondary dissociative disorder (disorder)
        "723916001",  # Bodily distress disorder (disorder)
        "723917005",  # Dangerously low body weight co-occurrent and due to anorexia nervosa of restricting type (disorder)
        "723918000",  # Dangerously low body weight co-occurrent and due to anorexia nervosa of binge-eating purging type (disorder)
        "723919008",  # Significantly low body weight co-occurrent and due to anorexia nervosa of restricting type (disorder)
        "723920002",  # Significantly low body weight co-occurrent and due to anorexia nervosa of binge-eating purging type (disorder)
        "723926008",  # Perceptual disturbances and seizures co-occurrent and due to alcohol withdrawal (disorder)
        "723927004",  # Psychotic disorder caused by alcohol with schizophreniform symptoms (disorder)
        "723936000",  # Psychotic disorder caused by cannabis (disorder)
        "723937009",  # Sleep disorder caused by cannabis (disorder)
        "723994004",  # Seizures and intellectual disability due to hydroxylysinuria syndrome (disorder)
        "724001005",  # Retinitis pigmentosa, intellectual disability, deafness, hypogenitalism syndrome (disorder)
        "724039002",  # Psychomotor retardation due to S-adenosylhomocysteine hydrolase deficiency (disorder)
        "724137002",  # Macrocephaly, obesity, mental disability, ocular abnormality syndrome (disorder)
        "724178000",  # Laryngeal abductor paralysis with intellectual disability syndrome (disorder)
        "724207001",  # Kleefstra syndrome (disorder)
        "724228005",  # Infantile choroidocerebral calcification syndrome (disorder)
        "724544000",  # Infection causing tic (disorder)
        "724545004",  # Tic due to and following infection (disorder)
        "724651001",  # Developmental speech fluency disorder (disorder)
        "724652008",  # Stereotypic movement disorder without self-injurious behavior (disorder)
        "724654009",  # Anxiety disorder caused by opioid (disorder)
        "724655005",  # Psychotic disorder caused by opioid (disorder)
        "724673008",  # Psychotic disorder caused by sedative (disorder)
        "724674002",  # Psychotic disorder caused by hypnotic (disorder)
        "724675001",  # Psychotic disorder caused by anxiolytic (disorder)
        "724676000",  # Mood disorder with depressive symptoms caused by sedative (disorder)
        "724677009",  # Mood disorder with depressive symptoms caused by hypnotic (disorder)
        "724678004",  # Mood disorder with depressive symptoms caused by anxiolytic (disorder)
        "724679007",  # Mood disorder with manic symptoms caused by sedative (disorder)
        "724680005",  # Mood disorder with manic symptoms caused by hypnotic (disorder)
        "724681009",  # Mood disorder with manic symptoms caused by anxiolytic (disorder)
        "724682002",  # Mood disorder with mixed depressive and manic symptoms caused by sedative (disorder)
        "724683007",  # Mood disorder with mixed depressive and manic symptoms caused by hypnotic (disorder)
        "724684001",  # Mood disorder with mixed depressive and manic symptoms caused by anxiolytic (disorder)
        "724685000",  # Amnestic disorder caused by sedative (disorder)
        "724686004",  # Amnestic disorder caused by hypnotic (disorder)
        "724687008",  # Amnestic disorder caused by anxiolytic (disorder)
        "724689006",  # Psychotic disorder caused by cocaine (disorder)
        "724690002",  # Mood disorder with depressive symptoms caused by cocaine (disorder)
        "724691003",  # Mood disorder with manic symptoms caused by cocaine (disorder)
        "724692005",  # Mood disorder with mixed depressive and manic symptoms caused by cocaine (disorder)
        "724693000",  # Obsessive compulsive disorder caused by cocaine (disorder)
        "724696008",  # Psychotic disorder caused by hallucinogen (disorder)
        "724702008",  # Psychotic disorder caused by volatile inhalant (disorder)
        "724705005",  # Delirium caused by methylenedioxymethamphetamine (disorder)
        "724706006",  # Psychotic disorder caused by methylenedioxymethamphetamine (disorder)
        "724707002",  # Mood disorder caused by methylenedioxymethamphetamine (disorder)
        "724708007",  # Anxiety disorder caused by methylenedioxymethamphetamine (disorder)
        "724716003",  # Delirium caused by ketamine (disorder)
        "724717007",  # Delirium caused by dissociative drug (disorder)
        "724718002",  # Psychotic disorder caused by dissociative drug (disorder)
        "724719005",  # Psychotic disorder caused by ketamine (disorder)
        "724720004",  # Mood disorder caused by dissociative drug (disorder)
        "724721000",  # Mood disorder caused by ketamine (disorder)
        "724722007",  # Anxiety disorder caused by dissociative drug (disorder)
        "724723002",  # Anxiety disorder caused by ketamine (disorder)
        "724726005",  # Perceptual disturbances co-occurrent and due to psychoactive substance withdrawal (disorder)
        "724727001",  # Seizure co-occurrent and due to psychoactive substance withdrawal (disorder)
        "724728006",  # Perceptual disturbances and seizures co-occurrent and due to psychoactive substance withdrawal (disorder)
        "724729003",  # Psychotic disorder caused by psychoactive substance (disorder)
        "724730008",  # Obsessive compulsive disorder caused by psychoactive substance (disorder)
        "724733005",  # Oppositional defiant disorder co-occurrent with chronic irritability-anger (disorder)
        "724734004",  # Oppositional defiant disorder co-occurrent with chronic irritability-anger with normal prosocial emotions (disorder)
        "724735003",  # Oppositional defiant disorder without chronic irritability-anger (disorder)
        "724736002",  # Oppositional defiant disorder without chronic irritability-anger with limited prosocial emotions (disorder)
        "724737006",  # Oppositional defiant disorder without chronic irritability-anger with normal prosocial emotions (disorder)
        "724738001",  # Childhood onset conduct-dissocial disorder with limited prosocial emotions (disorder)
        "724739009",  # Childhood onset conduct-dissocial disorder with normal prosocial emotions (disorder)
        "724740006",  # Adolescent onset conduct-dissocial disorder (disorder)
        "724741005",  # Adolescent onset conduct-dissocial disorder with limited prosocial emotions (disorder)
        "724742003",  # Adolescent onset conduct-dissocial disorder with normal prosocial emotions (disorder)
        "724743008",  # Coercive sexual sadism (disorder)
        "724744002",  # Paraphilia involving non-consenting individual (disorder)
        "724745001",  # Paraphilia involving solitary behavior or consenting individuals (disorder)
        "724746000",  # Delirium due to multiple etiological factors (disorder)
        "724747009",  # Amnestic disorder due to multiple etiological factors (disorder)
        "724752004",  # Hypnogogic exploding head syndrome (disorder)
        "724755002",  # Positive symptoms co-occurrent and due to primary psychotic disorder (disorder)
        "724756001",  # Negative symptoms co-occurrent and due to primary psychotic disorder (disorder)
        "724757005",  # Depressive symptoms due to primary psychotic disorder (disorder)
        "724758000",  # Manic symptoms co-occurrent and due to primary psychotic disorder (disorder)
        "724759008",  # Psychomotor symptom co-occurrent and due to psychotic disorder (disorder)
        "724760003",  # Cognitive impairment co-occurrent and due to primary psychotic disorder (disorder)
        "724776007",  # Dementia due to disorder of central nervous system (disorder)
        "724777003",  # Dementia due to infectious disease (disorder)
        "724818008",  # Functional monoparesis (disorder)
        "724819000",  # Functional paraparesis (disorder)
        "724992007",  # Epilepsy co-occurrent and due to dementia (disorder)
        "725140007",  # Temple Baraitser syndrome (disorder)
        "725163002",  # X-linked spasticity, intellectual disability, epilepsy syndrome (disorder)
        "725289009",  # 5-amino-4-imidazole carboxamide ribosiduria (disorder)
        "725413002",  # Febrile infection related epilepsy syndrome (disorder)
        "725589005",  # Bullous dystrophy macular type (disorder)
        "725898002",  # Delirium co-occurrent with dementia (disorder)
        "725906006",  # Intellectual disability Buenos Aires type (disorder)
        "725908007",  # Neurofaciodigitorenal syndrome (disorder)
        "725912001",  # X-linked intellectual disability Brooks type (disorder)
        "726031001",  # Cerebellar ataxia, intellectual disability, optic atrophy, skin abnormalities syndrome (disorder)
        "726621009",  # Caudal appendage deafness syndrome (disorder)
        "726669007",  # Central nervous system calcification, deafness, tubular acidosis, anemia syndrome (disorder)
        "726670008",  # Weaver Williams syndrome (disorder)
        "726672000",  # Short stature, unique facies, enamel hypoplasia, progressive joint stiffness, high-pitched voice syndrome (disorder)
        "726702005",  # Epileptic encephalopathy with global cerebral demyelination (disorder)
        "726709001",  # Intellectual disability, cataract, calcified pinna, myopathy syndrome (disorder)
        "726727003",  # X-linked intellectual disability Hedera type (disorder)
        "726732002",  # X-linked intellectual disability Nascimento type (disorder)
        "726772006",  # Major depression with psychotic features (disorder)
        "72861004",  # Panic disorder without agoraphobia with mild panic attacks (disorder)
        "7291006",  # Reactive attachment disorder of infancy (disorder)
        "73097000",  # Alcohol amnestic disorder (disorder)
        "732246009",  # X-linked intellectual disability, limb spasticity, retinal dystrophy, arginine vasopressin deficiency (disorder)
        "732251003",  # Cortical blindness, intellectual disability, polydactyly syndrome (disorder)
        "732954002",  # Osteopenia, intellectual disability, sparse hair syndrome (disorder)
        "732957009",  # Brachydactyly and preaxial hallux varus syndrome (disorder)
        "732958004",  # Spastic paraplegia with precocious puberty syndrome (disorder)
        "732961003",  # Branchial dysplasia, intellectual disability, inguinal hernia syndrome (disorder)
        "733031004",  # Epilepsy, microcephaly, skeletal dysplasia syndrome (disorder)
        "733032006",  # Epilepsy telangiectasia syndrome (disorder)
        "733049004",  # Encephalopathy, intracerebral calcification, retinal degeneration syndrome (disorder)
        "733050004",  # Dysmorphism, short stature, deafness, disorder of sex development syndrome (disorder)
        "733062000",  # Marfanoid habitus with autosomal recessive intellectual disability syndrome (disorder)
        "733072002",  # Alaninuria, microcephaly, dwarfism, enamel hypoplasia, diabetes mellitus syndrome (disorder)
        "733086003",  # Pseudoprogeria syndrome (disorder)
        "733088002",  # Preaxial polydactyly, colobomata, intellectual disability syndrome (disorder)
        "733097003",  # Ichthyosis, intellectual disability, dwarfism, renal impairment syndrome (disorder)
        "733110004",  # Van den Bosch syndrome (disorder)
        "733116005",  # Aniridia, renal agenesis, psychomotor retardation syndrome (disorder)
        "733117001",  # Thumb stiffness, brachydactyly, intellectual disability syndrome (disorder)
        "733184002",  # Dementia caused by heavy metal exposure (disorder)
        "733190003",  # Dementia due to primary malignant neoplasm of brain (disorder)
        "733191004",  # Dementia due to chronic subdural hematoma (disorder)
        "733192006",  # Dementia due to herpes encephalitis (disorder)
        "733193001",  # Dementia co-occurrent and due to progressive multifocal leukoencephalopathy (disorder)
        "733194007",  # Dementia co-occurrent and due to Down syndrome (disorder)
        "733417008",  # Facial dysmorphism, macrocephaly, myopia, Dandy-Walker malformation syndrome (disorder)
        "733419006",  # Metaphyseal dysostosis, intellectual disability, conductive deafness syndrome (disorder)
        "733455003",  # Spastic paraplegia, glaucoma, intellectual disability syndrome (disorder)
        "733472005",  # Microcephalus, glomerulonephritis, marfanoid habitus syndrome (disorder)
        "733522005",  # Megalocornea with intellectual disability syndrome (disorder)
        "733623005",  # Autism spectrum disorder, epilepsy, arthrogryposis syndrome (disorder)
        "734017008",  # Ectodermal dysplasia, intellectual disability, central nervous system malformation syndrome (disorder)
        "734173003",  # Skeletal abnormality, cutis laxa, craniostenosis, ambiguous genitalia, retardation, facial abnormality syndrome (disorder)
        "734349003",  # Alpha-thalassemia intellectual disability syndrome linked to chromosome 16 (disorder)
        "73462009",  # Chronic vocal tic disorder (disorder)
        "73471000",  # Bipolar I disorder, most recent episode mixed with catatonic features (disorder)
        "735541006",  # Dissociative neurological symptom disorder (disorder)
        "735542004",  # Dissociative neurological disorder with symptom of weakness (disorder)
        "735543009",  # Dissociative neurological disorder with symptom of alteration of sensation (disorder)
        "735544003",  # Dissociative neurological disorder with symptom of movement disorder (disorder)
        "735545002",  # Dissociative neurological symptom disorder with visual symptom (disorder)
        "735546001",  # Dissociative neurological symptom disorder with swallowing symptom (disorder)
        "735547005",  # Dissociative neurological symptom disorder co-occurrent with auditory symptom (disorder)
        "735548000",  # Dissociative neurological symptom disorder co-occurrent with dizziness (disorder)
        "735549008",  # Gambling disorder predominantly offline (disorder)
        "735550008",  # Gambling disorder predominantly online (disorder)
        "735551007",  # Gaming disorder (disorder)
        "735552000",  # Gaming disorder predominantly online (disorder)
        "735553005",  # Gaming disorder predominantly offline (disorder)
        "735625001",  # Acquired generalized anorgasmia (disorder)
        "735626000",  # Acquired situational anorgasmia (disorder)
        "735627009",  # Lifelong generalized anorgasmia (disorder)
        "735628004",  # Lifelong situational anorgasmia (disorder)
        "735750005",  # Psychotic disorder with schizophreniform symptoms caused by cocaine (disorder)
        "736313002",  # Dissociative neurological symptom disorder co-occurrent with symptoms of gait disorder (disorder)
        "736314008",  # Dissociative neurological symptom disorder co-occurrent with cognitive impairment (disorder)
        "736315009",  # Dissociative neurological symptom disorder co-occurrent with alteration of consciousness (disorder)
        "736316005",  # Dissociative neurological symptom disorder co-occurrent with symptom of speech production (disorder)
        "737225007",  # Secondary psychotic syndrome with hallucinations and delusions (disorder)
        "737226008",  # Disorder caused by cannabis (disorder)
        "737334000",  # Disorder caused by synthetic cannabinoid use (disorder)
        "737335004",  # Synthetic cannabinoid intoxication (disorder)
        "737336003",  # Synthetic cannabinoid abuse (disorder)
        "737337007",  # Synthetic cannabinoid dependence (disorder)
        "737338002",  # Synthetic cannabinoid withdrawal syndrome (disorder)
        "737339005",  # Delirium caused by synthetic cannabinoid (disorder)
        "737340007",  # Psychotic disorder caused by synthetic cannabinoid (disorder)
        "737341006",  # Anxiety disorder caused by synthetic cannabinoid (disorder)
        "737342004",  # Sleep disorder caused by synthetic cannabinoid (disorder)
        "737343009",  # Secondary neurodevelopmental disorder (disorder)
        "73867007",  # Severe major depression with psychotic features (disorder)
        "7397008",  # Aggressor identification syndrome (disorder)
        "73972002",  # Postpartum neurosis (disorder)
        "74010007",  # Panic disorder with agoraphobia, severe agoraphobic avoidance AND panic attacks in partial remission (disorder)
        "74142004",  # Feeding disorder of infancy OR early childhood (disorder)
        "74266001",  # Mood disorder in partial remission (disorder)
        "7461003",  # Attention deficit hyperactivity disorder, predominantly hyperactive impulsive type (disorder)
        "74686005",  # Mild depressed bipolar I disorder (disorder)
        "74732009",  # Mental disorder (disorder)
        "74791000",  # Pedophilia, limited to incest (disorder)
        "74803002",  # Taijin kyofusho (disorder)
        "74850006",  # Conduct disorder, solitary aggressive type (disorder)
        "74934004",  # Psychoactive substance withdrawal syndrome (disorder)
        "75084000",  # Severe major depression without psychotic features (disorder)
        "75122001",  # Inhalant-induced psychotic disorder with delusions (disorder)
        "75360000",  # Bipolar I disorder, single manic episode, in remission (disorder)
        "75605002",  # Sangue dormido (disorder)
        "75752004",  # Bipolar I disorder, most recent episode depressed with melancholic features (disorder)
        "75837004",  # Mood disorder with depressive features due to general medical condition (disorder)
        "76105009",  # Cyclothymia (disorder)
        "76129002",  # Ganser syndrome (disorder)
        "762317007",  # Developmental language disorder co-occurrent with impairment of receptive and expressive language (disorder)
        "762318002",  # Developmental language disorder co-occurrent with impairment of expressive language (disorder)
        "762319005",  # Developmental language disorder co-occurrent with impairment of mainly pragmatic language (disorder)
        "762320004",  # Mood disorder with manic symptoms caused by opioid (disorder)
        "762321000",  # Mood disorder with depressive symptoms caused by opioid (disorder)
        "762322007",  # Mood disorder with mixed depressive and manic symptoms caused by opioid (disorder)
        "762324008",  # Delirium caused by stimulant (disorder)
        "762325009",  # Psychotic disorder caused by stimulant (disorder)
        "762326005",  # Psychotic disorder with hallucinations caused by stimulant (disorder)
        "762327001",  # Psychotic disorder with delusions caused by stimulant (disorder)
        "762328006",  # Mood disorder caused by stimulant (disorder)
        "762329003",  # Mood disorder with depressive symptoms caused by stimulant (disorder)
        "762330008",  # Mood disorder with mixed depressive and manic symptoms caused by stimulant (disorder)
        "762331007",  # Anxiety disorder caused by stimulant (disorder)
        "762332000",  # Obsessive compulsive disorder caused by stimulant (disorder)
        "762335003",  # Mood disorder with manic symptoms caused by hallucinogen (disorder)
        "762336002",  # Mood disorder with depressive symptoms caused by hallucinogen (disorder)
        "762337006",  # Mood disorder with mixed depressive and manic symptoms caused by hallucinogen (disorder)
        "762338001",  # Mood disorder with manic symptoms caused by volatile inhalant (disorder)
        "762339009",  # Mood disorder with depressive symptoms caused by volatile inhalant (disorder)
        "762340006",  # Mood disorder with mixed depressive and manic symptoms caused by volatile inhalant (disorder)
        "762344002",  # Mood disorder with manic symptoms caused by dissociative drug (disorder)
        "762345001",  # Mood disorder with depressive symptoms caused by dissociative drug (disorder)
        "762346000",  # Mood disorder with mixed depressive and manic symptoms caused by dissociative drug (disorder)
        "762347009",  # Childhood onset conduct-dissocial disorder (disorder)
        "762350007",  # Dementia due to prion disease (disorder)
        "762351006",  # Dementia due to and following injury of head (disorder)
        "76236006",  # Atypical tic disorder (disorder)
        "762461003",  # Complex dissociative intrusion disorder (disorder)
        "762502009",  # Developmental language disorder co-occurrent with language impairment (disorder)
        "762506007",  # Delirium caused by synthetic cathinone (disorder)
        "762507003",  # Psychotic disorder caused by synthetic cathinone (disorder)
        "762508008",  # Psychotic disorder with hallucinations caused by synthetic cathinone (disorder)
        "762509000",  # Psychotic disorder with delusions caused by synthetic cathinone (disorder)
        "762510005",  # Psychotic disorder with schizophreniform symptoms caused by synthetic cathinone (disorder)
        "762511009",  # Mood disorder caused by synthetic cathinone (disorder)
        "762512002",  # Mood disorder with depressive symptoms caused by synthetic cathinone (disorder)
        "762513007",  # Mood disorder with manic symptoms caused by synthetic cathinone (disorder)
        "762514001",  # Mood disorder with mixed depressive and manic symptoms caused by synthetic cathinone (disorder)
        "762515000",  # Anxiety disorder caused by synthetic cathinone (disorder)
        "762516004",  # Obsessive compulsive disorder caused by synthetic cathinone (disorder)
        "762522008",  # Penoscrotodynia (disorder)
        "762707000",  # Subcortical dementia (disorder)
        "763136000",  # Charcot-Marie-Tooth disease, deafness, intellectual disability syndrome (disorder)
        "763186006",  # Grubben, De Cock, Borghgraef syndrome (disorder)
        "763278004",  # Facial dysmorphism, cleft palate, loose skin syndrome (disorder)
        "763320005",  # Craniofaciofrontodigital syndrome (disorder)
        "763344007",  # Cerebellar ataxia, intellectual disability, oculomotor apraxia, cerebellar cysts syndrome (disorder)
        "763350002",  # Intellectual disability, obesity, brain malformation, facial dysmorphism syndrome (disorder)
        "763353000",  # Cerebrofacioarticular syndrome (disorder)
        "763404001",  # Ichthyosis, alopecia, eclabion, ectropion, intellectual disability syndrome (disorder)
        "763615003",  # Aortic arch anomaly, facial dysmorphism, intellectual disability syndrome (disorder)
        "763618001",  # Wiedemann Steiner syndrome (disorder)
        "763626009",  # Intellectual disability due to nutritional deficiency (disorder)
        "763665007",  # Craniodigital syndrome and intellectual disability syndrome (disorder)
        "763722004",  # Hypotonia, speech impairment, severe cognitive delay syndrome (disorder)
        "763741001",  # Intellectual disability, alacrima, achalasia syndrome (disorder)
        "763742008",  # Intellectual disability, polydactyly, uncombable hair syndrome (disorder)
        "763743003",  # Intellectual disability, spasticity, ectrodactyly syndrome (disorder)
        "763744009",  # Intellectual disability, brachydactyly, Pierre Robin syndrome (disorder)
        "763745005",  # Intellectual disability Wolff type (disorder)
        "763773007",  # Macrocephaly and developmental delay syndrome (disorder)
        "763795006",  # Malan overgrowth syndrome (disorder)
        "763797003",  # Agenesis of corpus callosum and abnormal genitalia syndrome (disorder)
        "763837007",  # Oro-facial digital syndrome type 14 (disorder)
        "763861000",  # Pachygyria, intellectual disability, epilepsy syndrome (disorder)
        "76399004",  # Mal de ojo (disorder)
        "76441001",  # Severe major depression, single episode, without psychotic features (disorder)
        "764455002",  # Cognitive impairment, coarse facies, heart defects, obesity, pulmonary involvement, short stature, skeletal dysplasia syndrome (disorder)
        "764732004",  # Microcephalus, cerebellar hypoplasia, cardiac conduction defect syndrome (disorder)
        "764783004",  # Mild bodily distress disorder (disorder)
        "764784005",  # Moderate bodily distress disorder (disorder)
        "764785006",  # Severe bodily distress disorder (disorder)
        "764861005",  # Intellectual disability Birk-Barel type (disorder)
        "764950001",  # Cryptorchidism, arachnodactyly, intellectual disability syndrome (disorder)
        "764959000",  # Intellectual disability, myopathy, short stature, endocrine defect syndrome (disorder)
        "765089003",  # Focal epilepsy, intellectual disability, cerebro-cerebellar malformation syndrome (disorder)
        "765093009",  # Rolandic epilepsy, speech dyspraxia syndrome (disorder)
        "765108007",  # Pedophilia targeting children of female sex (disorder)
        "765109004",  # Pedophilia targeting children of male sex (disorder)
        "765110009",  # Sexual arousal by exposure of genitals to non-consenting person (disorder)
        "765111008",  # Sexual arousal by exposure of genitals to non-consenting postpubertal person (disorder)
        "765112001",  # Sexual arousal by exposure of genitals to non-consenting prepubertal person (disorder)
        "765151006",  # Asphyxiophilia (disorder)
        "765169002",  # Telephone scatologia (disorder)
        "765170001",  # Sodium voltage-gated channel alpha subunit 8-related epilepsy with encephalopathy (disorder)
        "765176007",  # Psychosis and severe depression co-occurrent and due to bipolar affective disorder (disorder)
        "765325002",  # Peripheral demyelinating neuropathy, central dysmyelinating leukodystrophy, Waardenburg syndrome, Hirschsprung disease (disorder)
        "765399000",  # Sexual arousal by exposure of genitals to non-consenting prepubertal and postpubertal person (disorder)
        "765434008",  # Human immunodeficiency virus type I enhancer binding protein 2 related intellectual disability (disorder)
        "765471005",  # X-linked intellectual disability, hypogonadism, ichthyosis, obesity, short stature syndrome (disorder)
        "76566000",  # Subchronic residual schizophrenia (disorder)
        "765758008",  # Microcephalic primordial dwarfism Montreal type (disorder)
        "765761009",  # Brachydactyly, mesomelia, intellectual disability, heart defect syndrome (disorder)
        "766753005",  # Nijmegen breakage syndrome-like disorder (disorder)
        "766824003",  # Activity dependent neuroprotector homeobox related multiple congenital anomalies, intellectual disability, autism spectrum disorder (disorder)
        "766870005",  # Epiphyseal dysplasia, hearing loss, dysmorphism syndrome (disorder)
        "766871009",  # Diencephalic mesencephalic junction dysplasia (disorder)
        "766932005",  # Hypothalamic hamartoma with gelastic seizure (disorder)
        "767631007",  # Bipolar disorder, most recent episode depression (disorder)
        "767632000",  # Bipolar disorder, most recent episode manic (disorder)
        "767633005",  # Bipolar affective disorder, most recent episode mixed (disorder)
        "767635003",  # Bipolar I disorder, most recent episode manic (disorder)
        "767636002",  # Bipolar I disorder, most recent episode depression (disorder)
        "76812003",  # Panic disorder with agoraphobia, moderate agoraphobic avoidance AND panic attacks in partial remission (disorder)
        "768473009",  # Purine rich element binding protein A syndrome (disorder)
        "768555009",  # 5q31.3 microdeletion syndrome (disorder)
        "768666006",  # Syntaxin binding protein 1 encephalopathy with epilepsy (disorder)
        "768677000",  # Protein phosphatase 2 regulatory subunit b (b56) delta-related intellectual disability (disorder)
        "76868007",  # Panic disorder with agoraphobia, agoraphobic avoidance in full remission AND mild panic attacks (disorder)
        "76880004",  # Angelman syndrome (disorder)
        "768843007",  # Tall stature, intellectual disability, facial dysmorphism syndrome (disorder)
        "770404004",  # Autosomal recessive chorioretinopathy and microcephaly syndrome (disorder)
        "770431001",  # Early-onset epileptic encephalopathy and intellectual disability due to glutamate receptor, ionotropic, N-methyl-D-aspartate, subunit 2A mutation (disorder)
        "770564004",  # Microcephalic primordial dwarfism Alazami type (disorder)
        "770565003",  # Microcephalic primordial dwarfism Dauber type (disorder)
        "770604006",  # X-linked cerebral, cerebellar, coloboma syndrome (disorder)
        "770679002",  # Polyneuropathy, intellectual disability, acromicria, premature menopause syndrome (disorder)
        "770719004",  # 3q27.3 microdeletion syndrome (disorder)
        "770721009",  # Microcephaly, thin corpus callosum, intellectual disability syndrome (disorder)
        "770723007",  # Optic atrophy, intellectual disability syndrome (disorder)
        "770725000",  # Infantile cerebral and cerebellar atrophy with postnatal progressive microcephaly (disorder)
        "770750002",  # Intellectual disability, seizures, macrocephaly, obesity syndrome (disorder)
        "770751003",  # Severe motor and intellectual disabilities, sensorineural deafness, dystonia syndrome (disorder)
        "770755007",  # Intellectual disability, seizures, hypotonia, ophthalmologic, skeletal anomalies syndrome (disorder)
        "770756008",  # 2p13.2 microdeletion syndrome (disorder)
        "770790004",  # Developmental delay with autism spectrum disorder and gait instability (disorder)
        "770793002",  # 5p13 microduplication syndrome (disorder)
        "770794008",  # 11p15.4 microduplication syndrome (disorder)
        "770898002",  # Autosomal recessive cerebellar ataxia, epilepsy, intellectual disability syndrome due to WW domain containing oxidoreductase deficiency (disorder)
        "770901001",  # Autosomal recessive intellectual disability, motor dysfunction, multiple joint contracture syndrome (disorder)
        "770907002",  # Kagami Ogata syndrome (disorder)
        "770941005",  # Alopecia, progressive neurological defect, endocrinopathy syndrome (disorder)
        "771074000",  # Microcephaly, short stature, intellectual disability, facial dysmorphism syndrome (disorder)
        "771077007",  # Intellectual disability, short stature, hypertelorism syndrome (disorder)
        "771148008",  # X-linked colobomatous microphthalmia, microcephaly, intellectual disability, short stature syndrome (disorder)
        "771149000",  # Hepatic fibrosis, renal cyst, intellectual disability syndrome (disorder)
        "771179007",  # Extrasystoles, short stature, hyperpigmentation, microcephaly syndrome (disorder)
        "771223000",  # Infantile epileptic dyskinetic encephalopathy (disorder)
        "771262009",  # Pseudoleprechaunism syndrome Patterson type (disorder)
        "771303004",  # Severe neonatal onset encephalopathy with microcephaly (disorder)
        "771336003",  # Polymicrogyria with optic nerve hypoplasia (disorder)
        "771418002",  # Delirium following surgical procedure (disorder)
        "771419005",  # Hyperactive delirium following surgical procedure (disorder)
        "771420004",  # Hypoactive delirium following surgical procedure (disorder)
        "771421000",  # Mixed hyperactive hypoactive delirium following surgical procedure (disorder)
        "771448004",  # Autism epilepsy syndrome due to branched chain ketoacid dehydrogenase kinase deficiency (disorder)
        "771470001",  # Jawad syndrome (disorder)
        "771472009",  # Developmental and speech delay due to SRY-box 5 deficiency (disorder)
        "771476007",  # Autosomal recessive leukoencephalopathy, ischemic stroke, retinitis pigmentosa syndrome (disorder)
        "771477003",  # 15q overgrowth syndrome (disorder)
        "771512003",  # Autism spectrum disorder due to AUTS2 activator of transcription and developmental regulator deficiency (disorder)
        "771516000",  # Solute carrier family 35 member A2 congenital disorder of glycosylation (disorder)
        "7718000",  # Bilis (disorder)
        "772127009",  # White Sutton syndrome (disorder)
        "772224009",  # Warburg micro syndrome (disorder)
        "772225005",  # RAB18, member RAS oncogene family deficiency (disorder)
        "77287004",  # Borderline intellectual disability (disorder)
        "773230003",  # Cyclin-dependent kinase-like 5 deficiency (disorder)
        "773274001",  # X-linked intellectual disability, craniofacioskeletal syndrome (disorder)
        "773303005",  # Spondyloepimetaphyseal dysplasia Genevieve type (disorder)
        "773307006",  # Zechi Ceide syndrome (disorder)
        "77332003",  # Partialism (disorder)
        "773329005",  # CK syndrome (disorder)
        "773400009",  # Severe feeding difficulties, failure to thrive, microcephaly due to ASXL transcriptional regulator 3 deficiency syndrome (disorder)
        "773404000",  # Roifman syndrome (disorder)
        "773405004",  # Intellectual disability with strabismus syndrome (disorder)
        "773416006",  # Intellectual disability, facial dysmorphism, hand anomalies syndrome (disorder)
        "773418007",  # Xylosyltransferase 1 congenital disorder of glycosylation (disorder)
        "773419004",  # Severe intellectual disability, short stature, behavioral abnormalities, facial dysmorphism syndrome (disorder)
        "773493002",  # 9q31.1q31.3 microdeletion syndrome (disorder)
        "773494008",  # 14q24.1q24.3 microdeletion syndrome (disorder)
        "773498006",  # Autosomal recessive cerebellar ataxia, epilepsy, intellectual disability syndrome due to TUD deficiency (disorder)
        "773547003",  # 13q12.3 microdeletion syndrome (disorder)
        "773548008",  # Early-onset epileptic encephalopathy, cortical blindness, intellectual disability, facial dysmorphism syndrome (disorder)
        "77355000",  # Organic mental disorder caused by cannabis (disorder)
        "773551001",  # Severe intellectual disability, poor language, strabismus, grimacing face, long fingers syndrome (disorder)
        "773552008",  # Intellectual disability, feeding difficulties, developmental delay, microcephaly syndrome (disorder)
        "773553003",  # Hypohidrosis, enamel hypoplasia, palmoplantar keratoderma, intellectual disability syndrome (disorder)
        "773554009",  # THO complex 6-related developmental delay, microcephaly, facial dysmorphism syndrome (disorder)
        "773556006",  # Short ulna, dysmorphism, hypotonia, intellectual disability syndrome (disorder)
        "773581009",  # Intellectual disability, craniofacial dysmorphism, cryptorchidism syndrome (disorder)
        "773583007",  # Aphonia, deafness, retinal dystrophy, bifid halluces, intellectual disability syndrome (disorder)
        "773587008",  # X-linked intellectual disability, cardiomegaly, congestive heart failure syndrome (disorder)
        "773621003",  # Intellectual disability, hypotonia, brachycephaly, pyloric stenosis, cryptorchidism syndrome (disorder)
        "773643006",  # Multiple congenital anomalies, hypotonia, seizures syndrome type 2 (disorder)
        "773670004",  # Distal Xq28 microduplication syndrome (disorder)
        "773692000",  # Late-onset localized junctional epidermolysis bullosa, intellectual disability syndrome (disorder)
        "773735007",  # Deafness with onychodystrophy syndrome (disorder)
        "77375009",  # Adductor spastic dysphonia of conversion reaction (disorder)
        "773769008",  # Ataxia, photosensitivity, short stature syndrome (disorder)
        "773772001",  # Rare non-syndromic intellectual disability (disorder)
        "773984007",  # Piebald trait with neurologic defects syndrome (disorder)
        "774068004",  # AT-hook DNA binding motif containing 1-related intellectual disability, obstructive sleep apnea, mild dysmorphism syndrome (disorder)
        "774069007",  # Protein kinase cAMP-dependent type I regulatory subunit beta-related neurodegenerative dementia with intermediate filaments (disorder)
        "774070008",  # Fibulin 1-related developmental delay, central nervous system anomaly, syndactyly syndrome (disorder)
        "774102003",  # Intellectual disability, obesity, prognathism, eye and skin anomalies syndrome (disorder)
        "774149004",  # Severe intellectual disability, progressive postnatal microcephaly, midline stereotypic hand movements syndrome (disorder)
        "774203000",  # Intellectual disability, severe speech delay, mild dysmorphism syndrome (disorder)
        "77475008",  # Jealous delusion disorder (disorder)
        "77486005",  # Mood disorder with major depressive-like episode due to general medical condition (disorder)
        "7761000119106",  # Psychotic disorder caused by amphetamine (disorder)
        "776204008",  # Colobomatous microphthalmia, obesity, hypogenitalism, intellectual disability syndrome (disorder)
        "77675002",  # Anorexia nervosa, restricting type (disorder)
        "777998000",  # Temtamy preaxial brachydactyly syndrome (disorder)
        "778001003",  # Potassium voltage-gated channel subfamily Q member 2 related epileptic encephalopathy (disorder)
        "778007004",  # 12p12.1 microdeletion syndrome (disorder)
        "778009001",  # Blepharophimosis, intellectual disability syndrome, Verloes type (disorder)
        "778011005",  # Severe intellectual disability and progressive spastic paraplegia (disorder)
        "778025006",  # Atypical hypotonia cystinuria syndrome (disorder)
        "778029000",  # FAST kinase domains 2-related infantile mitochondrial encephalomyopathy (disorder)
        "778047006",  # Myoclonic epilepsy in non-progressive encephalopathy (disorder)
        "77815007",  # Gender identity disorder of adulthood, previously homosexual (disorder)
        "77911002",  # Severe major depression, single episode, with psychotic features, mood-congruent (disorder)
        "7794004",  # Chronic motor tic disorder (disorder)
        "78004001",  # Bulimia nervosa (disorder)
        "780827006",  # Synaptic Ras GTPase activating protein 1- related intellectual disability (disorder)
        "782501005",  # Adjustment disorder with mixed anxiety and depressed mood (disorder)
        "78269000",  # Bipolar I disorder, single manic episode, in partial remission (disorder)
        "782723007",  # Severe intellectual disability, progressive spastic diplegia syndrome (disorder)
        "782736007",  # Intellectual disability, facial dysmorphism syndrome due to SET domain containing 5 haploinsufficiency (disorder)
        "782753000",  # Intellectual disability, coarse face, macrocephaly, cerebellar hypotrophy syndrome (disorder)
        "782755007",  # Primary microcephaly, mild intellectual disability, young-onset diabetes syndrome (disorder)
        "782757004",  # Congenital microcephaly, severe encephalopathy, progressive cerebral atrophy syndrome (disorder)
        "782772000",  # Congenital muscular dystrophy with intellectual disability and severe epilepsy (disorder)
        "782825008",  # Primary microcephaly, epilepsy, permanent neonatal diabetes syndrome (disorder)
        "782886007",  # Infantile spasms, psychomotor retardation, progressive brain atrophy, basal ganglia disease syndrome (disorder)
        "782911008",  # Hereditary cryohydrocytosis with reduced stomatin (disorder)
        "782941005",  # Richieri Costa-da Silva syndrome (disorder)
        "782945001",  # Ophthalmoplegia, intellectual disability, lingua scrotalis syndrome (disorder)
        "783005002",  # Severe microbrachycephaly, intellectual disability, athetoid cerebral palsy syndrome (disorder)
        "783061008",  # Facial dysmorphism, developmental delay, behavioral abnormalities syndrome due to 10p11.21p12.31 microdeletion (disorder)
        "783089006",  # Macrocephaly, intellectual disability, autism syndrome (disorder)
        "783161005",  # Familial dementia British type (disorder)
        "783174004",  # Congenital muscular dystrophy with intellectual disability (disorder)
        "783258000",  # Familial dementia Danish type (disorder)
        "78358001",  # Amphetamine withdrawal syndrome (disorder)
        "783619003",  # Dual specificity tyrosine phosphorylation regulated kinase 1A-related intellectual disability syndrome due to 21q22.13q22.2 microdeletion (disorder)
        "783702009",  # X-linked intellectual disability due to glutamate ionotropic receptor AMPA type subunit 3 mutations (disorder)
        "783703004",  # White matter hypoplasia, corpus callosum agenesis, intellectual disability syndrome (disorder)
        "785298001",  # Muscle eye brain disease with bilateral multicystic leukodystrophy (disorder)
        "785726009",  # Hyperekplexia epilepsy syndrome (disorder)
        "78640000",  # Severe manic bipolar I disorder with psychotic features, mood-congruent (disorder)
        "78667006",  # Dysthymia (disorder)
        "787093004",  # Developmental delay, facial dysmorphism syndrome due to mediator complex subunit 13 like deficiency (disorder)
        "787171006",  # 21q22.11q22.12 microdeletion syndrome (disorder)
        "787174003",  # Intellectual disability, hyperkinetic movement, truncal ataxia syndrome (disorder)
        "787175002",  # Ankyrin 3 related intellectual disability, sleep disturbance syndrome (disorder)
        "788120007",  # Antenatal depression (disorder)
        "788417006",  # Alopecia, epilepsy, intellectual disability syndrome Moynahan type (disorder)
        "788584007",  # Blepharophimosis, intellectual disability syndrome (disorder)
        "788863007",  # Amnestic disorder caused by psychoactive substance (disorder)
        "788864001",  # Amnestic disorder caused by volatile solvent (disorder)
        "788898005",  # Dementia caused by volatile inhalant (disorder)
        "788899002",  # Dementia due to pellagra (disorder)
        "788904003",  # Disorder caused by dissociative drug (disorder)
        "788905002",  # Disorder caused by stimulant (disorder)
        "788907005",  # Dissociative neurological symptom disorder co-occurrent with chorea (disorder)
        "788908000",  # Dissociative neurological symptom disorder co-occurrent with dystonia (disorder)
        "788909008",  # Dissociative neurological symptom disorder co-occurrent with facial spasm (disorder)
        "788910003",  # Dissociative neurological symptom disorder co-occurrent with myoclonus (disorder)
        "788911004",  # Dissociative neurological symptom disorder co-occurrent with parkinsonism (disorder)
        "788955005",  # Impulse control disorder caused by cocaine (disorder)
        "788956006",  # Impulse control disorder caused by psychoactive substance (disorder)
        "788957002",  # Impulse control disorder caused by stimulant (disorder)
        "788958007",  # Impulse control disorder caused by synthetic cathinone (disorder)
        "788983007",  # Mood disorder caused by cannabis (disorder)
        "789053008",  # Transient motor tic (disorder)
        "789061003",  # Rapid cycling bipolar II disorder (disorder)
        "789119007",  # Mood disorder caused by synthetic cannabinoid (disorder)
        "789170003",  # Disinhibited behavior due to dementia (disorder)
        "789399002",  # Persistent adjustment disorder (disorder)
        "79204003",  # Chronic undifferentiated schizophrenia with acute exacerbations (disorder)
        "79298009",  # Mild major depression, single episode (disorder)
        "79341000119107",  # Mixed dementia (disorder)
        "79385002",  # Lowe syndrome (disorder)
        "79459002",  # Cheshire cat syndrome (disorder)
        "79524000",  # Ecouteurism (disorder)
        "7956006",  # Psychogenic vertigo (disorder)
        "79584002",  # Moderate bipolar disorder (disorder)
        "79842004",  # Stuporous depression (disorder)
        "79866005",  # Subchronic paranoid schizophrenia (disorder)
        "80495009",  # Sleep walking disorder (disorder)
        "80711002",  # Narcissistic personality disorder (disorder)
        "80868005",  # Cocaine withdrawal syndrome (disorder)
        "81319007",  # Severe bipolar II disorder, most recent episode major depressive without psychotic features (disorder)
        "81463002",  # Bestiality (disorder)
        "816067005",  # Diabetes, hypogonadism, deafness, intellectual disability syndrome (disorder)
        "81812009",  # Hwa-byung (disorder)
        "8185002",  # Panic disorder with agoraphobia AND moderate panic attacks (disorder)
        "81903006",  # Inhibited male orgasm (disorder)
        "82218004",  # Postoperative depression (disorder)
        "82339009",  # Anxiety disorder caused by amfetamine (disorder)
        "82351000119105",  # Altered behavior due to Pick's disease (disorder)
        "82361000119107",  # Altered behavior in dementia due to Huntington chorea (disorder)
        "82371000119101",  # Dementia due to multiple sclerosis with altered behavior (disorder)
        "82381000119103",  # Epileptic dementia with behavioral disturbance (disorder)
        "82415003",  # Agoraphobia without history of panic disorder without limited symptom attacks (disorder)
        "82494000",  # Panic disorder without agoraphobia with panic attacks in full remission (disorder)
        "82636008",  # Orgasm disorder (disorder)
        "82738004",  # Panic disorder with agoraphobia, moderate agoraphobic avoidance AND moderate panic attacks (disorder)
        "82959004",  # Dementia paralytica juvenilis (disorder)
        "82998009",  # Moderate manic bipolar I disorder (disorder)
        "83176005",  # Primary dysthymia (disorder)
        "832007",  # Moderate major depression (disorder)
        "83225003",  # Bipolar II disorder (disorder)
        "83233002",  # Ghost sickness (disorder)
        "83253003",  # Shyness disorder of childhood (disorder)
        "833326008",  # Cortical vascular dementia (disorder)
        "83367009",  # Organic mental disorder caused by amphetamine and/or amfetamine derivative (disorder)
        "83458005",  # Agitated depression (disorder)
        "83482000",  # Body dysmorphic disorder (disorder)
        "83501007",  # Organic mood disorder of mixed type (disorder)
        "83631006",  # Panic disorder with agoraphobia, moderate agoraphobic avoidance AND severe panic attacks (disorder)
        "83746006",  # Chronic schizophrenia (disorder)
        "838276009",  # Amyotrophic lateral sclerosis, parkinsonism, dementia complex (disorder)
        "838441009",  # Intellectual disability, aphasia, shuffling gait, adducted thumbs syndrome (disorder)
        "838528007",  # Mood disorder with manic symptoms caused by amfetamine and/or amfetamine derivative (disorder)
        "838529004",  # Mood disorder with mixed depressive and manic symptoms caused by amfetamine and/or amfetamine derivative (disorder)
        "838530009",  # Mood disorder with depressive symptoms caused by amfetamine and/or amfetamine derivative (disorder)
        "83890006",  # Cluster C personality disorder (disorder)
        "84002002",  # Pedophilia (disorder)
        "840464007",  # Dementia due to carbon monoxide poisoning (disorder)
        "840465008",  # Dementia due to iron deficiency (disorder)
        "84209002",  # Psychogenic amnesia (disorder)
        "84466009",  # Dependent personality disorder (disorder)
        "84760002",  # Schizoaffective disorder, depressive type (disorder)
        "84788008",  # Menopausal depression (disorder)
        "84984002",  # Adjustment disorder with disturbance of conduct (disorder)
        "85061001",  # Separation anxiety disorder of childhood, early onset (disorder)
        "85080004",  # Secondary dysthymia (disorder)
        "8511007",  # Transient tic disorder, single episode (disorder)
        "8522006",  # Klismaphilia (disorder)
        "85248005",  # Bipolar disorder in remission (disorder)
        "8547008",  # Vocal abuse in children (disorder)
        "85821003",  # Acute non-psychotic brain syndrome (disorder)
        "85861002",  # Subchronic undifferentiated schizophrenia (disorder)
        "86058007",  # Severe bipolar I disorder, single manic episode with psychotic features, mood-incongruent (disorder)
        "8635005",  # Alcohol withdrawal delirium (disorder)
        "86765009",  # Mild intellectual disability (disorder)
        "870260008",  # Pervasive developmental disorder with marked impairment of functional language with loss of previously acquired skills (disorder)
        "870261007",  # Pervasive developmental disorder with marked impairment of functional language without loss of previously acquired skills (disorder)
        "870262000",  # Pervasive developmental disorder with disorder of intellectual development without loss of previously acquired skills (disorder)
        "870263005",  # Pervasive developmental disorder with impairment of functional language (disorder)
        "870264004",  # Pervasive developmental disorder with disorder of intellectual development and pervasive impairment of functional language without loss of previously acquired skills (disorder)
        "870265003",  # Pervasive developmental disorder with disorder of intellectual development with loss of previously acquired skills (disorder)
        "870266002",  # Pervasive developmental disorder with disorder of intellectual development and marked impairment of functional language with loss of previously acquired skills (disorder)
        "870267006",  # Pervasive developmental disorder with disorder of intellectual development and marked impairment of functional language without loss of previously acquired skills (disorder)
        "870268001",  # Pervasive developmental disorder with disorder of intellectual development and complete impairment of functional language without loss of previously acquired skills (disorder)
        "870269009",  # Pervasive developmental disorder with disorder of intellectual development and absence of functional language with loss of previously acquired skills (disorder)
        "870270005",  # Pervasive developmental disorder with disorder of intellectual development and complete impairment of functional language with loss of previously acquired skills (disorder)
        "870280009",  # Pervasive developmental disorder with severe impairment of functional language with loss of previously acquired skills (disorder)
        "870282001",  # Pervasive developmental disorder with severe impairment of functional language without loss of previously acquired skills (disorder)
        "870303005",  # Pervasive developmental disorder with complete impairment of functional language with loss of previously acquired skills (disorder)
        "870304004",  # Pervasive developmental disorder with complete impairment of functional language without loss of previously acquired skills (disorder)
        "870305003",  # Pervasive developmental disorder with cognitive developmental delay and marked impairment of functional language (disorder)
        "870306002",  # Pervasive developmental disorder with complete impairment of functional language (disorder)
        "870307006",  # Pervasive developmental disorder with abscence of functional language (disorder)
        "870308001",  # Pervasive developmental disorder with cognitive developmental delay and complete impairment of functional language (disorder)
        "870568002",  # Orthorexia nervosa (disorder)
        "87132004",  # Opioid withdrawal syndrome (disorder)
        "87203005",  # Bipolar I disorder, most recent episode depressed with postpartum onset (disorder)
        "87414006",  # Reactive depression (situational) (disorder)
        "87512008",  # Mild major depression (disorder)
        "87798009",  # Panic disorder with agoraphobia, agoraphobic avoidance in full remission AND moderate panic attacks (disorder)
        "87810006",  # Megaloblastic anemia due to alcoholism (disorder)
        "87842000",  # Generalized neuromuscular exhaustion syndrome (disorder)
        "87950005",  # Bipolar I disorder, single manic episode with catatonic features (disorder)
        "87991007",  # Gender identity disorder (disorder)
        "879939002",  # 14q32 deletion syndrome (disorder)
        "8837000",  # Delirium caused by amphetamine (disorder)
        "88740003",  # Thyrotoxicosis factitia with thyrotoxic crisis (disorder)
        "88845000",  # Explosive type organic personality disorder (disorder)
        "88902008",  # Dissociative blindness (disorder)
        "88939009",  # Severe mood disorder without psychotic features (disorder)
        "88975006",  # Schizophreniform disorder (disorder)
        "88984006",  # Dissociative paralysis (disorder)
        "890118006",  # Mowat-Wilson syndrome due to monosomy 2q22 (disorder)
        "89016005",  # Axis III diagnosis (disorder)
        "89248000",  # Erotic zoophilia (disorder)
        "89361000119103",  # Mild developmental articulation disorder (disorder)
        "89381000119107",  # Moderate receptive language delay (disorder)
        "89391000119105",  # Severe receptive language delay (disorder)
        "89392001",  # Prader-Willi syndrome (disorder)
        "89415002",  # Hypersomnia disorder related to another mental disorder (disorder)
        "89451009",  # Inhalant-induced mood disorder (disorder)
        "89501000119108",  # Mild receptive language delay (disorder)
        "89601008",  # Tic of organic origin (disorder)
        "89618007",  # Persecutory delusion disorder (disorder)
        "899001",  # Axis I diagnosis (disorder)
        "89948007",  # Panic disorder with agoraphobia AND mild panic attacks (disorder)
        "89989005",  # Deferred diagnosis on Axis V (disorder)
        "90099008",  # Subcortical leukoencephalopathy (disorder)
        "90483007",  # Dissociative neurological symptom disorder with dysphonia (disorder)
        "90755006",  # Nicotine withdrawal syndrome (disorder)
        "90790003",  # Avoidant disorder of adolescence (disorder)
        "9083002",  # Pedophilia, opposite sex (disorder)
        "9116003",  # Shin-byung (disorder)
        "9167000",  # Moderate mood disorder (disorder)
        "92501000119101",  # Stress reaction with psychomotor agitation (disorder)
        "9340000",  # Bipolar I disorder, single manic episode (disorder)
        "9345005",  # Dialysis dementia (disorder)
        "93461009",  # Gender dysphoria (disorder)
        "94631000119100",  # Depressive disorder in mother complicating pregnancy (disorder)
        "94641000119109",  # Anxiety in pregnancy (disorder)
        "94921000119107",  # Episodic mood disorder (disorder)
        "9527009",  # Tetrasomy 12p syndrome (disorder)
        "95439001",  # Psychogenic aphonia (disorder)
        "95636001",  # Sadomasochism (disorder)
        "95637005",  # Factitious disorder imposed on another (disorder)
        "95878009",  # Amnesic shellfish poisoning (disorder)
        "9674006",  # Adjustment disorder with withdrawal (disorder)
        "97571000119109",  # Thrombocytopenia co-occurrent and due to alcoholism (disorder)
        "9760005",  # Deferred diagnosis on Axis I (disorder)
        "97751000119108",  # Altered behavior in Alzheimer's disease (disorder)
    }

class TobaccoNonUser(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for an observation of tobacco non-user status.

    **Data Element Scope:** This value set may use a model element related to Observation.

    **Inclusion Criteria:** Includes concepts that represent an observation of non-use of tobacco products, including smoking and smoke-less tobacco products such as chew, snuff, pipe, cigarette, cigar, etc.

    **Exclusion Criteria:** Excludes concepts that represent a current tobacco user.
    """

    VALUE_SET_NAME = "Tobacco Non User"
    OID = "2.16.840.1.113883.3.526.3.1189"
    DEFINITION_VERSION = "20170504"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "105539002",  # Non-smoker for personal reasons (finding)
        "105540000",  # Non-smoker for religious reasons (finding)
        "105541001",  # Non-smoker for medical reasons (finding)
        "1137688001",  # Ex-electronic cigarette user for less than one year (finding)
        "1137690000",  # Never used electronic cigarette (finding)
        "1137692008",  # Ex-electronic cigarette user for more than one year (finding)
        "160620009",  # Ex-pipe smoker (finding)
        "160621008",  # Ex-cigar smoker (finding)
        "221000119102",  # Never smoked any substance (finding)
        "228491005",  # Does not use snuff (finding)
        "228492003",  # Never used snuff (finding)
        "228493008",  # Ex-snuff user (finding)
        "228501004",  # Does not use moist powdered tobacco (finding)
        "228502006",  # Never used moist powdered tobacco (finding)
        "228503001",  # Ex-user of moist powdered tobacco (finding)
        "228511006",  # Does not chew tobacco (finding)
        "228512004",  # Never chewed tobacco (finding)
        "228513009",  # Ex-tobacco chewer (finding)
        "266919005",  # Never smoked tobacco (finding)
        "266921000",  # Ex-trivial cigarette smoker (<1/day) (finding)
        "266922007",  # Ex-light cigarette smoker (1-9/day) (finding)
        "266923002",  # Ex-moderate cigarette smoker (10-19/day) (finding)
        "266924008",  # Ex-heavy cigarette smoker (20-39/day) (finding)
        "266925009",  # Ex-very heavy cigarette smoker (40+/day) (finding)
        "266928006",  # Ex-cigarette smoker amount unknown (finding)
        "281018007",  # Ex-cigarette smoker (finding)
        "360890004",  # Intolerant ex-smoker (finding)
        "360900008",  # Aggressive ex-smoker (finding)
        "360918006",  # Aggressive non-smoker (finding)
        "360929005",  # Intolerant non-smoker (finding)
        "405746006",  # Current non smoker but past smoking history unknown (finding)
        "428081000124100",  # Former heavy tobacco smoker (finding)
        "428091000124102",  # Former light tobacco smoker (finding)
        "451371000124109",  # Tobacco non-user (finding)
        "451381000124107",  # Smokeless tobacco non-user (finding)
        "456711000124105",  # Former smokeless tobacco user (finding)
        "48031000119106",  # Ex-smoker for more than 1 year (finding)
        "53896009",  # Tolerant ex-smoker (finding)
        "702975009",  # Ex-tobacco user (finding)
        "702979003",  # Never used tobacco (finding)
        "735128000",  # Ex-smoker for less than 1 year (finding)
        "8392000",  # Non-smoker (finding)
        "8517006",  # Ex-smoker (finding)
        "87739003",  # Tolerant non-smoker (finding)
    }

class TobaccoUser(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for an observation of tobacco user status.

    **Data Element Scope:** This value set may use a model element related to Observation.

    **Inclusion Criteria:** Includes concepts that represent an observation of use of tobacco products, including smoking and smoke-less tobacco products such as chew, snuff, pipe, cigarette, cigar, etc.

    **Exclusion Criteria:** Excludes concepts that represent a current tobacco non-user.
    """

    VALUE_SET_NAME = "Tobacco User"
    OID = "2.16.840.1.113883.3.526.3.1170"
    DEFINITION_VERSION = "20170504"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "110483000",  # Tobacco user (finding)
        "1137691001",  # Trying to give up using electronic cigarette (finding)
        "160603005",  # Light cigarette smoker (1-9 cigs/day) (finding)
        "160604004",  # Moderate cigarette smoker (10-19 cigs/day) (finding)
        "160605003",  # Heavy cigarette smoker (20-39 cigs/day) (finding)
        "160606002",  # Very heavy cigarette smoker (40+ cigs/day) (finding)
        "160619003",  # Rolls own cigarettes (finding)
        "228494002",  # Snuff user (finding)
        "228499007",  # Finding relating to moist tobacco use (finding)
        "228504007",  # User of moist powdered tobacco (finding)
        "228514003",  # Chews plug tobacco (finding)
        "228515002",  # Chews twist tobacco (finding)
        "228516001",  # Chews loose leaf tobacco (finding)
        "228517005",  # Chews fine cut tobacco (finding)
        "228518000",  # Chews products containing tobacco (finding)
        "230059006",  # Occasional cigarette smoker (finding)
        "230060001",  # Light cigarette smoker (finding)
        "230062009",  # Moderate cigarette smoker (finding)
        "230063004",  # Heavy cigarette smoker (finding)
        "230064005",  # Very heavy cigarette smoker (finding)
        "230065006",  # Chain smoker (finding)
        "266920004",  # Trivial cigarette smoker (less than one cigarette/day) (finding)
        "35341000087101",  # Uses electronic cigarette daily (finding)
        "35371000087109",  # Uses electronic cigarette occasionally (finding)
        "428041000124106",  # Occasional tobacco smoker (finding)
        "428061000124105",  # Light tobacco smoker (finding)
        "428071000124103",  # Heavy tobacco smoker (finding)
        "449867007",  # Uses moist tobacco occasionally (finding)
        "449868002",  # Smokes tobacco daily (finding)
        "449869005",  # Uses moist tobacco daily (finding)
        "450811000124104",  # Cigarette smoker (5-9 cigarettes/day) (finding)
        "450821000124107",  # Cigarette smoker (1-4 cigarettes/day) (finding)
        "56578002",  # Moderate smoker (20 or less per day) (finding)
        "56771006",  # Heavy smoker (over 20 per day) (finding)
        "59978006",  # Cigar smoker (finding)
        "65568007",  # Cigarette smoker (finding)
        "698289004",  # Hookah pipe smoker (finding)
        "713914004",  # User of smokeless tobacco (finding)
        "722499006",  # Electronic cigarette user (finding)
        "77176002",  # Smoker (finding)
        "785889008",  # Nicotine-filled electronic cigarette user (finding)
        "81703003",  # Chews tobacco (finding)
        "82302008",  # Pipe smoker (finding)
    }

class MajorDepressiveDisorderActive(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for diagnoses of active major depressive disorders.

    **Data Element Scope:** This value set may use a model element related to Diagnosis or an Encounter diagnosis.

    **Inclusion Criteria:** Includes concepts that represent a diagnosis of major depressive disorder including both single and recurrent episodes with any level of severity.

    **Exclusion Criteria:** Excludes concepts that represent major depressive disorders in full remission.
    """

    VALUE_SET_NAME = "Major Depressive Disorder Active"
    OID = "2.16.840.1.113883.3.526.3.1491"
    DEFINITION_VERSION = "20210220"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "F320",  # Major depressive disorder, single episode, mild
        "F321",  # Major depressive disorder, single episode, moderate
        "F322",  # Major depressive disorder, single episode, severe without psychotic features
        "F323",  # Major depressive disorder, single episode, severe with psychotic features
        "F324",  # Major depressive disorder, single episode, in partial remission
        "F3289",  # Other specified depressive episodes
        "F329",  # Major depressive disorder, single episode, unspecified
        "F330",  # Major depressive disorder, recurrent, mild
        "F331",  # Major depressive disorder, recurrent, moderate
        "F332",  # Major depressive disorder, recurrent severe without psychotic features
        "F333",  # Major depressive disorder, recurrent, severe with psychotic symptoms
        "F3341",  # Major depressive disorder, recurrent, in partial remission
        "F339",  # Major depressive disorder, recurrent, unspecified
    }

    SNOMEDCT = {
        "10811121000119102",  # Major depressive disorder in mother complicating childbirth (disorder)
        "10811161000119107",  # Major depressive disorder in mother complicating pregnancy (disorder)
        "14183003",  # Chronic major depressive disorder, single episode (disorder)
        "15193003",  # Severe recurrent major depression with psychotic features, mood-incongruent (disorder)
        "15639000",  # Moderate major depression, single episode (disorder)
        "16264621000119109",  # Recurrent mild major depressive disorder co-occurrent with anxiety (disorder)
        "16264821000119108",  # Recurrent severe major depressive disorder co-occurrent with anxiety (disorder)
        "16264901000119109",  # Recurrent moderate major depressive disorder co-occurrent with anxiety (disorder)
        "16265301000119106",  # Recurrent major depressive disorder in partial remission co-occurrent with anxiety (disorder)
        "16265951000119109",  # Mild major depressive disorder co-occurrent with anxiety single episode (disorder)
        "16266831000119100",  # Moderate major depressive disorder co-occurrent with anxiety single episode (disorder)
        "16266991000119108",  # Severe major depressive disorder co-occurrent with anxiety single episode (disorder)
        "18818009",  # Moderate recurrent major depression (disorder)
        "191604000",  # Single major depressive episode, severe, with psychosis (disorder)
        "191610000",  # Recurrent major depressive episodes, mild (disorder)
        "191611001",  # Recurrent major depressive episodes, moderate (disorder)
        "191613003",  # Recurrent major depressive episodes, severe, with psychosis (disorder)
        "20250007",  # Severe major depression, single episode, with psychotic features, mood-incongruent (disorder)
        "251000119105",  # Severe major depression, single episode (disorder)
        "25922000",  # Major depressive disorder, single episode with postpartum onset (disorder)
        "2618002",  # Chronic recurrent major depressive disorder (disorder)
        "268621008",  # Recurrent major depressive episodes (disorder)
        "281000119103",  # Severe recurrent major depression (disorder)
        "28475009",  # Severe recurrent major depression with psychotic features (disorder)
        "30605009",  # Major depression in partial remission (disorder)
        "319768000",  # Recurrent major depressive disorder with melancholic features (disorder)
        "320751009",  # Major depression, melancholic type (disorder)
        "33078009",  # Severe recurrent major depression with psychotic features, mood-congruent (disorder)
        "33135002",  # Recurrent major depression in partial remission (disorder)
        "33736005",  # Severe major depression with psychotic features, mood-congruent (disorder)
        "36474008",  # Severe recurrent major depression without psychotic features (disorder)
        "36923009",  # Major depression, single episode (disorder)
        "370143000",  # Major depressive disorder (disorder)
        "38694004",  # Recurrent major depressive disorder with atypical features (disorder)
        "39809009",  # Recurrent major depressive disorder with catatonic features (disorder)
        "40379007",  # Mild recurrent major depression (disorder)
        "42925002",  # Major depressive disorder, single episode with atypical features (disorder)
        "430852001",  # Severe major depression, single episode, with psychotic features (disorder)
        "450714000",  # Severe major depression (disorder)
        "60099002",  # Severe major depression with psychotic features, mood-incongruent (disorder)
        "63778009",  # Major depressive disorder, single episode with melancholic features (disorder)
        "66344007",  # Recurrent major depression (disorder)
        "67002003",  # Severe bipolar II disorder, most recent episode major depressive, in partial remission (disorder)
        "69392006",  # Major depressive disorder, single episode with catatonic features (disorder)
        "70747007",  # Major depression single episode, in partial remission (disorder)
        "71336009",  # Recurrent major depressive disorder with postpartum onset (disorder)
        "719592004",  # Moderately severe major depression (disorder)
        "720451004",  # Minimal recurrent major depression (disorder)
        "720452006",  # Moderately severe recurrent major depression (disorder)
        "720453001",  # Moderately severe major depression single episode (disorder)
        "720454007",  # Minimal major depression single episode (disorder)
        "720455008",  # Minimal major depression (disorder)
        "726772006",  # Major depression with psychotic features (disorder)
        "73867007",  # Severe major depression with psychotic features (disorder)
        "75084000",  # Severe major depression without psychotic features (disorder)
        "76441001",  # Severe major depression, single episode, without psychotic features (disorder)
        "77911002",  # Severe major depression, single episode, with psychotic features, mood-congruent (disorder)
        "79298009",  # Mild major depression, single episode (disorder)
        "832007",  # Moderate major depression (disorder)
        "87512008",  # Mild major depression (disorder)
    }

class FindingOfElevatedBloodPressureOrHypertension(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for diagnoses of elevated blood pressure or hypertension.

    **Data Element Scope:** This value set may use a model element related to Diagnosis.

    **Inclusion Criteria:** Includes concepts that represent a diagnosis of elevated blood pressure or hypertension.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Finding of Elevated Blood Pressure or Hypertension"
    OID = "2.16.840.1.113762.1.4.1047.514"
    DEFINITION_VERSION = "20190313"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "R030",  # Elevated blood-pressure reading, without diagnosis of hypertension
    }

    SNOMEDCT = {
        "10725009",  # Benign hypertension (disorder)
        "1078301000112109",  # Multiple drug intolerant hypertension (disorder)
        "1204139007",  # Hypertension due to congenital adrenal hyperplasia (disorder)
        "1208845005",  # Secondary hypertension due to congenital heart disorder (disorder)
        "194785008",  # Secondary benign hypertension (disorder)
        "194788005",  # Hypertension secondary to endocrine disorder (disorder)
        "194791005",  # Hypertension caused by drug (disorder)
        "198941007",  # Hypertension complicating pregnancy, childbirth and the puerperium (disorder)
        "198997005",  # Pre-eclampsia or eclampsia with pre-existing hypertension (disorder)
        "23130000",  # Paroxysmal hypertension (disorder)
        "237281009",  # Moderate proteinuric hypertension of pregnancy (disorder)
        "24042004",  # Chronic hypertension complicating AND/OR reason for care during puerperium (disorder)
        "24184005",  # Increased blood pressure (finding)
        "28119000",  # Renal hypertension (disorder)
        "307632004",  # Non-proteinuric hypertension of pregnancy (disorder)
        "31992008",  # Secondary hypertension (disorder)
        "371622005",  # Elevated blood pressure reading without diagnosis of hypertension (situation)
        "37618003",  # Chronic hypertension complicating AND/OR reason for care during pregnancy (disorder)
        "38341003",  # Hypertensive disorder, systemic arterial (disorder)
        "397748008",  # Hypertension with albuminuria (disorder)
        "398254007",  # Pre-eclampsia (disorder)
        "40521000119100",  # Postpartum pregnancy-induced hypertension (disorder)
        "427889009",  # Hypertension associated with transplantation (disorder)
        "429198000",  # Exertional hypertension (disorder)
        "429457004",  # Systolic essential hypertension (disorder)
        "443482000",  # Hypertensive urgency (disorder)
        "461301000124109",  # Resistant hypertensive disorder (disorder)
        "48146000",  # Diastolic hypertension (disorder)
        "48194001",  # Pregnancy-induced hypertension (disorder)
        "56218007",  # Systolic hypertension (disorder)
        "59720008",  # Sustained diastolic hypertension (disorder)
        "65518004",  # Labile diastolic hypertension (disorder)
        "698638005",  # Pregnancy induced hypertension with pulmonary edema (disorder)
        "74451002",  # Secondary diastolic hypertension (disorder)
        "762463000",  # Diastolic hypertension co-occurrent with systolic hypertension (disorder)
        "766937004",  # Hypertension due to gain-of-function mutation in mineralocorticoid receptor (disorder)
        "871642009",  # Hypertension due to aortic arch obstruction (disorder)
        "89242004",  # Malignant secondary hypertension (disorder)
    }

class PatientDeclined(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts indicating a reason for patient refusal.

    **Data Element Scope:** This value set may use a model element related to Negation Rationale.

    **Inclusion Criteria:** Includes concepts that identify a reason for refusing treatment.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Patient Declined"
    OID = "2.16.840.1.113883.3.526.3.1582"
    DEFINITION_VERSION = "20200307"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "1296859006",  # Procedure declined (situation)
        "183945002",  # Procedure declined for religious reason (situation)
        "413311005",  # Patient non-compliant - declined intervention / support (situation)
        "895451009",  # Referral to service declined by subject (situation)
    }

class ThirtySevenToFortyTwoPlusWeeksGestation(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of 37-42 weeks or greater gestation.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of weeks gestation equal to 37-42 weeks or greater.

    **Exclusion Criteria:** Excludes concepts that identify a diagnosis of weeks gestation less than 37 weeks.
    """

    VALUE_SET_NAME = "37 to 42 Plus Weeks Gestation"
    OID = "2.16.840.1.113762.1.4.1110.68"
    DEFINITION_VERSION = "20230217"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "Z3A37",  # 37 weeks gestation of pregnancy
        "Z3A38",  # 38 weeks gestation of pregnancy
        "Z3A39",  # 39 weeks gestation of pregnancy
        "Z3A40",  # 40 weeks gestation of pregnancy
        "Z3A41",  # 41 weeks gestation of pregnancy
        "Z3A42",  # 42 weeks gestation of pregnancy
        "Z3A49",  # Greater than 42 weeks gestation of pregnancy
    }

    SNOMEDCT = {
        "13798002",  # Gestation period, 38 weeks (finding)
        "36428009",  # Gestation period, 42 weeks (finding)
        "433601000124106",  # Gestation period greater than or equal to 37 weeks (finding)
        "43697006",  # Gestation period, 37 weeks (finding)
        "46230007",  # Gestation period, 40 weeks (finding)
        "63503002",  # Gestation period, 41 weeks (finding)
        "80487005",  # Gestation period, 39 weeks (finding)
    }

class DeliveryOfSingleton(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of a delivery of a single live born newborn.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of a delivery of a single live born newborn.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Delivery of Singleton"
    OID = "2.16.840.1.113762.1.4.1045.99"
    DEFINITION_VERSION = "20210611"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "Z370",  # Single live birth
    }

    SNOMEDCT = {
        "169826009",  # Single live birth (finding)
    }

class GenitalHerpes(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for a diagnosis of genital herpes infections that complicate childbirth.

    **Data Element Scope:** This value set may use a model element related to Diagnosis.

    **Inclusion Criteria:** Includes concepts that represent a diagnosis of genital herpes infections complicating childbirth.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Genital Herpes"
    OID = "2.16.840.1.113883.3.464.1003.110.12.1049"
    DEFINITION_VERSION = "20180310"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "A6000",  # Herpesviral infection of urogenital system, unspecified
        "A6003",  # Herpesviral cervicitis
        "A6004",  # Herpesviral vulvovaginitis
        "A6009",  # Herpesviral infection of other urogenital tract
        "A601",  # Herpesviral infection of perianal skin and rectum
        "A609",  # Anogenital herpesviral infection, unspecified
    }

    SNOMEDCT = {
        "10754701000119100",  # Genital herpes simplex in mother complicating childbirth (disorder)
        "129670002",  # Herpetic cervicitis (disorder)
        "27420004",  # Herpetic vulvovaginitis (disorder)
        "278068003",  # Herpetic vesicle in vagina (disorder)
        "33839006",  # Genital herpes simplex (disorder)
        "402888002",  # Primary herpes simplex infection of genitalia (disorder)
        "402890001",  # Primary herpetic vulvovaginitis (disorder)
        "402894005",  # Recurrent genital herpes simplex (disorder)
        "402896007",  # Recurrent herpetic vulvovaginitis (disorder)
        "423391007",  # Genital herpes simplex type 2 (disorder)
        "427578006",  # Herpes simplex of female genitalia (disorder)
        "439912007",  # Recurrent genital Herpes simplex type 1 infection (disorder)
        "439913002",  # Recurrent genital Herpes simplex type 2 infection (disorder)
        "440714005",  # Genital Herpes simplex type 1 infection (disorder)
        "59819007",  # Herpetic ulceration of vulva (disorder)
    }

class PlacentaAccretaSpectrumPreviaOrVasaPrevia(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to group diagnoses of a placenta previa, accreta, increta, percreta, or vasa previa.

    **Data Element Scope:** This value set may use a model element related to diagnosis.

    **Inclusion Criteria:** Includes concepts that identify a diagnosis of a complete or partial placenta previa, accreta, increta, percreta, or vasa previa during the 3rd trimester or when the trimester is unspecified.

    **Exclusion Criteria:** Excludes concepts that represent placenta previa, accreta, increta, percreta, or vasa previa in the 1st or 2nd trimester.
    """

    VALUE_SET_NAME = "Placenta Accreta Spectrum Previa or Vasa Previa"
    OID = "2.16.840.1.113762.1.4.1110.37"
    DEFINITION_VERSION = "20230217"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "O43213",  # Placenta accreta, third trimester
        "O43219",  # Placenta accreta, unspecified trimester
        "O43223",  # Placenta increta, third trimester
        "O43229",  # Placenta increta, unspecified trimester
        "O43233",  # Placenta percreta, third trimester
        "O43239",  # Placenta percreta, unspecified trimester
        "O4400",  # Complete placenta previa NOS or without hemorrhage, unspecified trimester
        "O4403",  # Complete placenta previa NOS or without hemorrhage, third trimester
        "O4410",  # Complete placenta previa with hemorrhage, unspecified trimester
        "O4413",  # Complete placenta previa with hemorrhage, third trimester
        "O4420",  # Partial placenta previa NOS or without hemorrhage, unspecified trimester
        "O4423",  # Partial placenta previa NOS or without hemorrhage, third trimester
        "O4430",  # Partial placenta previa with hemorrhage, unspecified trimester
        "O4433",  # Partial placenta previa with hemorrhage, third trimester
        "O694XX0",  # Labor and delivery complicated by vasa previa, not applicable or unspecified
        "O694XX1",  # Labor and delivery complicated by vasa previa, fetus 1
        "O694XX2",  # Labor and delivery complicated by vasa previa, fetus 2
        "O694XX3",  # Labor and delivery complicated by vasa previa, fetus 3
        "O694XX4",  # Labor and delivery complicated by vasa previa, fetus 4
        "O694XX5",  # Labor and delivery complicated by vasa previa, fetus 5
        "O694XX9",  # Labor and delivery complicated by vasa previa, other fetus
    }

    SNOMEDCT = {
        "1173098001",  # Placenta previa lateralis (disorder)
        "11763009",  # Placenta increta (disorder)
        "119901000119109",  # Hemorrhage co-occurrent and due to partial placenta previa (disorder)
        "1230040001",  # Cornual placenta accreta (disorder)
        "15663008",  # Placenta previa centralis (disorder)
        "198903000",  # Hemorrhage due to placenta previa (disorder)
        "199896005",  # Vasa previa with antenatal problem (disorder)
        "237296008",  # Morbidly adherent placenta (disorder)
        "24095001",  # Placenta previa partialis (disorder)
        "25585008",  # Placenta percreta (disorder)
        "267197003",  # Antepartum hemorrhage due to abruptio placentae and placenta previa (disorder)
        "27388005",  # Intrapartum hemorrhage due to partial placenta previa (disorder)
        "33058001",  # Placenta accreta without hemorrhage (disorder)
        "36813001",  # Placenta previa (disorder)
        "62531004",  # Placenta previa marginalis (disorder)
        "70129008",  # Placenta accreta (disorder)
        "7266006",  # Intrapartum hemorrhage due to total placenta previa (disorder)
        "7792000",  # Placenta previa without hemorrhage (disorder)
        "79668009",  # Vasa previa (disorder)
        "87814002",  # Intrapartum hemorrhage due to marginal placenta previa (disorder)
    }

class HospiceCareReferralOrAdmission(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for an encounter of hospice care.

    **Data Element Scope:** This value set may use a model element related to Intervention or Encounter.

    **Inclusion Criteria:** Includes concepts that represent an intervention of or encounter for hospice care.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Hospice Care Referral or Admission"
    OID = "2.16.840.1.113762.1.4.1116.365"
    DEFINITION_VERSION = "20191010"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "183919006",  # Urgent admission to hospice (procedure)
        "183920000",  # Routine admission to hospice (procedure)
        "183921001",  # Admission to hospice for respite (procedure)
        "305336008",  # Admission to hospice (procedure)
        "306205009",  # Referral to hospice (procedure)
        "385765002",  # Hospice care management (procedure)
        "428361000124107",  # Discharge to home for hospice care (procedure)
        "428371000124100",  # Discharge to healthcare facility for hospice care (procedure)
        "444933003",  # Home hospice service (qualifier value)
    }

class UnavailabilityOfBacillusCalmetteGuerinForUrologyCare(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to identify concepts for the unavailability of Bacillus Calmette Guerin (BCG).

    **Data Element Scope:** This value set may use a model element related to Medication.

    **Inclusion Criteria:** Includes concepts that identify a reason for the unavailability of Bacillus Calmette Guerin (BCG)

    **Exclusion Criteria:** Excludes concepts that identify a medication of BCG administered.
    """

    VALUE_SET_NAME = "Unavailability of Bacillus Calmette Guerin for Urology Care"
    OID = "2.16.840.1.113762.1.4.1248.369"
    DEFINITION_VERSION = "20250312"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "182856006",  # Drug not available - out of stock (finding)
        "182857002",  # Drug not available-off market (finding)
        "242990004",  # Drug not available for administration (event)
        "452631000124107",  # Medication not available (finding)
        "452641000124102",  # Medication not available from manufacturer (finding)
        "452651000124100",  # Medication not available from pharmacy (finding)
        "452661000124103",  # Medication not available from pharmacy supplier (finding)
        "452671000124105",  # Medication not available from wholesaler (finding)
    }

class RoutesOfAdministrationForOpioidAntagonists(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for routes of administration for opioid antagonist administration to reverse opioid overdose which includes intranasal spray, inhalation, intramuscular, subcutaneous, or intravenous injection

    **Data Element Scope:** This value set may use a model element related to routes of medication administrations for opioid antagonists

    **Inclusion Criteria:** Includes concepts that represent intranasal, intramuscular, intravenous, subcutaneous, inhalation routes of administration for opioid antagonist administration

    **Exclusion Criteria:** Excludes enteral routes and other routes that are not intranasal, inhalation, intramuscular, intravenous or subcutaneous such as intradermal, intracoronary, intradiscal, intrapulmonary, etc.
    """

    VALUE_SET_NAME = "Routes of Administration for Opioid Antagonists"
    OID = "2.16.840.1.113762.1.4.1248.187"
    DEFINITION_VERSION = "20230204"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "34206005",  # Subcutaneous route (qualifier value)
        "418114005",  # Intravenous central route (qualifier value)
        "419993007",  # Intravenous peripheral route (qualifier value)
        "447694001",  # Respiratory tract route (qualifier value)
        "46713006",  # Nasal route (qualifier value)
        "47625008",  # Intravenous route (qualifier value)
        "78421000",  # Intramuscular route (qualifier value)
    }

class PressureInjuryDeepTissue(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for deep tissue pressure injuries.

    **Data Element Scope:** This value set may use a model element related to Physical Exam.

    **Inclusion Criteria:** Includes SNOMEDCT concepts that represent deep tissue pressure injuries.

    **Exclusion Criteria:** Excludes SNOMEDCT concepts that represent Stage 1, 2, 3, 4, or unstageable pressure injuries.
    """

    VALUE_SET_NAME = "Pressure Injury Deep Tissue"
    OID = "2.16.840.1.113762.1.4.1147.112"
    DEFINITION_VERSION = "20240112"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "139566261000119101",  # Deep tissue pressure injury of left heel (disorder)
        "282236291000119109",  # Pressure injury of deep tissue of right buttock (disorder)
        "324946811000119102",  # Pressure injury of deep tissue of right ankle (disorder)
        "392913311000119107",  # Pressure injury of deep tissue of left hip (disorder)
        "450728161000119104",  # Pressure injury of deep tissue of left ankle (disorder)
        "468409941000119108",  # Pressure injury of deep tissue of sacral region of back (disorder)
        "480837841000119108",  # Pressure injury of deep tissue of left elbow (disorder)
        "561885931000119106",  # Deep tissue pressure injury of right heel (disorder)
        "585603201000119101",  # Pressure injury of deep tissue of right elbow (disorder)
        "705220971000119104",  # Pressure injury of deep tissue of right hip (disorder)
        "723071003",  # Pressure injury of deep tissue (disorder)
        "82479641000119102",  # Pressure injury of deep tissue of head (disorder)
        "959201281000119107",  # Pressure injury of deep tissue of left buttock (disorder)
    }

class PressureInjuryDeepTissueDiagnoses(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for deep tissue pressure injuries.

    **Data Element Scope:** This value set may use a model element related to Diagnosis.

    **Inclusion Criteria:** Includes ICD-10-CM concepts that represent deep tissue pressure injuries.

    **Exclusion Criteria:** Excludes ICD-10-CM concepts that represent Stage 1, 2, 3, 4, or unstageable pressure injuries.
    """

    VALUE_SET_NAME = "Pressure Injury Deep Tissue Diagnoses"
    OID = "2.16.840.1.113762.1.4.1147.194"
    DEFINITION_VERSION = "20220415"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "L89006",  # Pressure-induced deep tissue damage of unspecified elbow
        "L89016",  # Pressure-induced deep tissue damage of right elbow
        "L89026",  # Pressure-induced deep tissue damage of left elbow
        "L89106",  # Pressure-induced deep tissue damage of unspecified part of back
        "L89116",  # Pressure-induced deep tissue damage of right upper back
        "L89126",  # Pressure-induced deep tissue damage of left upper back
        "L89136",  # Pressure-induced deep tissue damage of right lower back
        "L89146",  # Pressure-induced deep tissue damage of left lower back
        "L89156",  # Pressure-induced deep tissue damage of sacral region
        "L89206",  # Pressure-induced deep tissue damage of unspecified hip
        "L89216",  # Pressure-induced deep tissue damage of right hip
        "L89226",  # Pressure-induced deep tissue damage of left hip
        "L89306",  # Pressure-induced deep tissue damage of unspecified buttock
        "L89316",  # Pressure-induced deep tissue damage of right buttock
        "L89326",  # Pressure-induced deep tissue damage of left buttock
        "L8946",  # Pressure-induced deep tissue damage of contiguous site of back, buttock and hip
        "L89506",  # Pressure-induced deep tissue damage of unspecified ankle
        "L89516",  # Pressure-induced deep tissue damage of right ankle
        "L89526",  # Pressure-induced deep tissue damage of left ankle
        "L89606",  # Pressure-induced deep tissue damage of unspecified heel
        "L89616",  # Pressure-induced deep tissue damage of right heel
        "L89626",  # Pressure-induced deep tissue damage of left heel
        "L89816",  # Pressure-induced deep tissue damage of head
        "L89896",  # Pressure-induced deep tissue damage of other site
        "L8996",  # Pressure-induced deep tissue damage of unspecified site
    }

class PressureInjuryStage234OrUnstageable(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for stage 2, stage 3, stage 4, and unstageable pressure injuries.

    **Data Element Scope:** This value set may use a model element related to Physical Exam.

    **Inclusion Criteria:** Includes grouping of SNOMEDCT and LOINC concepts that represent stage 2, stage 3, stage 4, and unstageable pressure injuries.

    **Exclusion Criteria:** Excludes concepts that represent stage 1 or deep tissue pressure injuries.
    """

    VALUE_SET_NAME = "Pressure Injury Stage 2, 3, 4 or Unstageable"
    OID = "2.16.840.1.113762.1.4.1147.113"
    DEFINITION_VERSION = "20220415"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    LOINC = {
        "54576-4",  # Pressure injuries - stage 2
        "54577-2",  # Pressure injuries - stage 3
        "54578-0",  # Pressure injuries - stage 4
        "54579-8",  # Pressure injuries - unstageable due to non-removable dressing
        "55088-9",  # Pressure injuries - unstageable with suspected deep tissue injury in evolution
        "55089-7",  # Pressure injuries - unstageable due to coverage of wound bed by slough/eschar
        "57188-5",  # Stage 3 or 4 pressure injury with largest surface dimensions
    }

    SNOMEDCT = {
        "10634631000119105",  # Unstageable pressure injury of left heel (disorder)
        "10634671000119108",  # Unstageable pressure injury of right heel (disorder)
        "10637071000119109",  # Pressure injury of buttock stage II (disorder)
        "10637111000119102",  # Pressure injury of buttock stage III (disorder)
        "10637151000119101",  # Pressure injury of buttock stage IV (disorder)
        "10637591000119100",  # Unstageable pressure injury of buttock (disorder)
        "10637631000119100",  # Unstageable pressure injury of left buttock (disorder)
        "10637671000119102",  # Unstageable pressure injury of right buttock (disorder)
        "10642111000119104",  # Unstageable pressure injury of sacral region of back (disorder)
        "10666711000119108",  # Pressure injury of right lower leg stage IV (disorder)
        "10666791000119104",  # Pressure injury of left lower leg stage IV (disorder)
        "10666951000119107",  # Unstageable pressure injury of head (disorder)
        "10667431000119105",  # Pressure injury of left lower leg stage II (disorder)
        "10667471000119108",  # Pressure injury of right lower leg stage II (disorder)
        "10669431000119102",  # Unstageable pressure injury of back (disorder)
        "10669591000119104",  # Pressure injury of coccygeal region of back stage IV (disorder)
        "10669631000119104",  # Pressure injury of coccygeal region of back stage III (disorder)
        "10669671000119101",  # Pressure injury of coccygeal region of back stage II (disorder)
        "10669751000119101",  # Unstageable pressure injury of coccygeal region of back (disorder)
        "10669831000119100",  # Pressure injury of left lower leg stage III (disorder)
        "10670031000119108",  # Pressure injury of right lower leg stage III (disorder)
        "10670791000119109",  # Unstageable pressure injury of left elbow (disorder)
        "10670831000119103",  # Unstageable pressure injury of right elbow (disorder)
        "10670951000119101",  # Unstageable pressure injury of right lower leg (disorder)
        "10670991000119106",  # Unstageable pressure injury of right hip (disorder)
        "10671071000119102",  # Unstageable pressure injury of left lower leg (disorder)
        "10671111000119109",  # Unstageable pressure injury of left ankle (disorder)
        "10671191000119100",  # Unstageable pressure injury of right ankle (disorder)
        "10671231000119109",  # Unstageable pressure injury of left hip (disorder)
        "1163220007",  # Pressure injury stage II (disorder)
        "1163222004",  # Pressure injury stage III (disorder)
        "1163224003",  # Pressure injury stage IV (disorder)
        "1163226001",  # Unstageable pressure injury (disorder)
        "12366701000119107",  # Pressure injury of left foot stage IV (disorder)
        "29231000175105",  # Pressure injury of right buttock stage II (disorder)
        "29241000175104",  # Pressure injury of right buttock stage III (disorder)
        "29251000175102",  # Pressure injury of right buttock stage IV (disorder)
        "29291000175109",  # Pressure injury of left buttock stage II (disorder)
        "29301000175105",  # Pressure injury of left buttock stage III (disorder)
        "29311000175108",  # Pressure injury of left buttock stage IV (disorder)
        "29341000175107",  # Pressure injury of sacral region of back stage II (disorder)
        "29351000175109",  # Pressure injury of sacral region of back stage III (disorder)
        "29361000175106",  # Pressure injury of sacral region of back stage IV (disorder)
        "29681000175108",  # Pressure injury of hip stage II (disorder)
        "29691000175106",  # Pressure injury of hip stage III (disorder)
        "29701000175106",  # Pressure injury of hip stage IV (disorder)
        "29741000175108",  # Pressure injury of right hip stage II (disorder)
        "29751000175105",  # Pressure injury of right hip stage III (disorder)
        "29761000175107",  # Pressure injury of right hip stage IV (disorder)
        "29801000175102",  # Pressure injury of left hip stage II (disorder)
        "29811000175104",  # Pressure injury of left hip stage III (disorder)
        "29821000175108",  # Pressure injury of left hip stage IV (disorder)
        "29861000175101",  # Pressure injury of right heel stage II (disorder)
        "29871000175109",  # Pressure injury of right heel stage III (disorder)
        "29881000175107",  # Pressure injury of right heel stage IV (disorder)
        "29921000175103",  # Pressure injury of left heel stage II (disorder)
        "29931000175100",  # Pressure injury of left heel stage III (disorder)
        "29941000175106",  # Pressure injury of left heel stage IV (disorder)
        "29981000175104",  # Pressure injury of dorsum of right foot stage II (disorder)
        "29991000175101",  # Pressure injury of dorsum of right foot stage III (disorder)
        "30001000175102",  # Pressure injury of dorsum of right foot stage IV (disorder)
        "30041000175100",  # Pressure injury of dorsum of left foot stage II (disorder)
        "30051000175103",  # Pressure injury of dorsum of left foot stage III (disorder)
        "30061000175101",  # Pressure injury of dorsum of left foot stage IV (disorder)
        "30101000175103",  # Pressure injury of right ankle stage II (disorder)
        "30111000175100",  # Pressure injury of right ankle stage III (disorder)
        "30121000175109",  # Pressure injury of right ankle stage IV (disorder)
        "30161000175102",  # Pressure injury of left ankle stage II (disorder)
        "30171000175105",  # Pressure injury of left ankle stage III (disorder)
        "30181000175108",  # Pressure injury of left ankle stage IV (disorder)
        "301891901000119107",  # Unstageable pressure injury of toe of right foot (disorder)
        "30221000175103",  # Pressure injury of right elbow stage II (disorder)
        "30231000175100",  # Pressure injury of right elbow stage III (disorder)
        "30241000175106",  # Pressure injury of right elbow stage IV (disorder)
        "30281000175104",  # Pressure injury of left elbow stage II (disorder)
        "30291000175101",  # Pressure injury of left elbow stage III (disorder)
        "30301000175100",  # Pressure injury of left elbow stage IV (disorder)
        "30331000175109",  # Pressure injury of head stage II (disorder)
        "30341000175103",  # Pressure injury of head stage III (disorder)
        "30351000175101",  # Pressure injury of head stage IV (disorder)
        "35731000175102",  # Pressure injury of elbow stage II (disorder)
        "35741000175108",  # Pressure injury of elbow stage III (disorder)
        "35751000175105",  # Pressure injury of elbow stage IV (disorder)
        "35791000175103",  # Pressure injury of ankle stage II (disorder)
        "35801000175102",  # Pressure injury of ankle stage III (disorder)
        "35811000175104",  # Pressure injury of ankle stage IV (disorder)
        "35841000175100",  # Pressure injury of heel stage II (disorder)
        "35851000175103",  # Pressure injury of heel stage III (disorder)
        "35861000175101",  # Pressure injury of heel stage IV (disorder)
        "551841000124101",  # Pressure injury of left foot stage II (disorder)
        "551851000124104",  # Pressure injury of left foot stage III (disorder)
        "551871000124109",  # Pressure injury of right foot stage II (disorder)
        "551881000124107",  # Pressure injury of right foot stage III (disorder)
        "551891000124105",  # Pressure injury of right foot stage IV (disorder)
        "551911000124107",  # Pressure injury of toe of left foot stage II (disorder)
        "551921000124104",  # Pressure injury of toe of left foot stage III (disorder)
        "551931000124101",  # Pressure injury of toe of left foot stage IV (disorder)
        "551951000124108",  # Pressure injury of toe of right foot stage II (disorder)
        "551961000124105",  # Pressure injury of toe of right foot stage III (disorder)
        "551971000124103",  # Pressure injury of toe of right foot stage IV (disorder)
        "580951000124106",  # Unstageable pressure injury of left foot (disorder)
        "580961000124108",  # Unstageable pressure injury of right foot (disorder)
        "590911000124109",  # Pressure injury of right lumbar region of back stage II (disorder)
        "590921000124101",  # Pressure injury of left lumbar region of back stage II (disorder)
        "590931000124103",  # Pressure injury of back stage II (disorder)
        "590941000124108",  # Pressure injury of left thoracic region of back stage II (disorder)
        "590951000124105",  # Pressure injury of right lumbar region of back stage III (disorder)
        "590961000124107",  # Pressure injury of right thoracic region of back stage II (disorder)
        "590971000124100",  # Pressure injury of left lumbar region of back stage III (disorder)
        "590981000124102",  # Pressure injury of back stage III (disorder)
        "590991000124104",  # Pressure injury of left thoracic region of back stage III (disorder)
        "591001000124103",  # Pressure injury of left lumbar region of back stage IV (disorder)
        "591011000124100",  # Pressure injury of right lumbar region of back stage IV (disorder)
        "591021000124108",  # Pressure injury of right thoracic region of back stage III (disorder)
        "591031000124106",  # Pressure injury of back stage IV (disorder)
        "591041000124101",  # Pressure injury of left thoracic region of back stage IV (disorder)
        "591051000124104",  # Pressure injury of right thoracic region of back stage IV (disorder)
        "78433671000119100",  # Unstageable pressure injury of toe of left foot (disorder)
    }

class PressureInjuryStage234OrUnstageableDiagnoses(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for stage 2, stage 3, stage 4, and unstageable pressure injuries.

    **Data Element Scope:** This value set may use a model element related to Diagnosis.

    **Inclusion Criteria:** Includes ICD-10-CM concepts that represent stage 2, stage 3, stage 4, and unstageable pressure injuries.

    **Exclusion Criteria:** Excludes concepts that represent stage 1 or deep tissue pressure injuries.
    """

    VALUE_SET_NAME = "Pressure Injury Stage 2, 3, 4, or Unstageable Diagnoses"
    OID = "2.16.840.1.113762.1.4.1147.196"
    DEFINITION_VERSION = "20220416"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "L89000",  # Pressure ulcer of unspecified elbow, unstageable
        "L89002",  # Pressure ulcer of unspecified elbow, stage 2
        "L89003",  # Pressure ulcer of unspecified elbow, stage 3
        "L89004",  # Pressure ulcer of unspecified elbow, stage 4
        "L89010",  # Pressure ulcer of right elbow, unstageable
        "L89012",  # Pressure ulcer of right elbow, stage 2
        "L89013",  # Pressure ulcer of right elbow, stage 3
        "L89014",  # Pressure ulcer of right elbow, stage 4
        "L89020",  # Pressure ulcer of left elbow, unstageable
        "L89022",  # Pressure ulcer of left elbow, stage 2
        "L89023",  # Pressure ulcer of left elbow, stage 3
        "L89024",  # Pressure ulcer of left elbow, stage 4
        "L89100",  # Pressure ulcer of unspecified part of back, unstageable
        "L89102",  # Pressure ulcer of unspecified part of back, stage 2
        "L89103",  # Pressure ulcer of unspecified part of back, stage 3
        "L89104",  # Pressure ulcer of unspecified part of back, stage 4
        "L89110",  # Pressure ulcer of right upper back, unstageable
        "L89112",  # Pressure ulcer of right upper back, stage 2
        "L89113",  # Pressure ulcer of right upper back, stage 3
        "L89114",  # Pressure ulcer of right upper back, stage 4
        "L89120",  # Pressure ulcer of left upper back, unstageable
        "L89122",  # Pressure ulcer of left upper back, stage 2
        "L89123",  # Pressure ulcer of left upper back, stage 3
        "L89124",  # Pressure ulcer of left upper back, stage 4
        "L89130",  # Pressure ulcer of right lower back, unstageable
        "L89132",  # Pressure ulcer of right lower back, stage 2
        "L89133",  # Pressure ulcer of right lower back, stage 3
        "L89134",  # Pressure ulcer of right lower back, stage 4
        "L89140",  # Pressure ulcer of left lower back, unstageable
        "L89142",  # Pressure ulcer of left lower back, stage 2
        "L89143",  # Pressure ulcer of left lower back, stage 3
        "L89144",  # Pressure ulcer of left lower back, stage 4
        "L89150",  # Pressure ulcer of sacral region, unstageable
        "L89152",  # Pressure ulcer of sacral region, stage 2
        "L89153",  # Pressure ulcer of sacral region, stage 3
        "L89154",  # Pressure ulcer of sacral region, stage 4
        "L89200",  # Pressure ulcer of unspecified hip, unstageable
        "L89202",  # Pressure ulcer of unspecified hip, stage 2
        "L89203",  # Pressure ulcer of unspecified hip, stage 3
        "L89204",  # Pressure ulcer of unspecified hip, stage 4
        "L89210",  # Pressure ulcer of right hip, unstageable
        "L89212",  # Pressure ulcer of right hip, stage 2
        "L89213",  # Pressure ulcer of right hip, stage 3
        "L89214",  # Pressure ulcer of right hip, stage 4
        "L89220",  # Pressure ulcer of left hip, unstageable
        "L89222",  # Pressure ulcer of left hip, stage 2
        "L89223",  # Pressure ulcer of left hip, stage 3
        "L89224",  # Pressure ulcer of left hip, stage 4
        "L89300",  # Pressure ulcer of unspecified buttock, unstageable
        "L89302",  # Pressure ulcer of unspecified buttock, stage 2
        "L89303",  # Pressure ulcer of unspecified buttock, stage 3
        "L89304",  # Pressure ulcer of unspecified buttock, stage 4
        "L89310",  # Pressure ulcer of right buttock, unstageable
        "L89312",  # Pressure ulcer of right buttock, stage 2
        "L89313",  # Pressure ulcer of right buttock, stage 3
        "L89314",  # Pressure ulcer of right buttock, stage 4
        "L89320",  # Pressure ulcer of left buttock, unstageable
        "L89322",  # Pressure ulcer of left buttock, stage 2
        "L89323",  # Pressure ulcer of left buttock, stage 3
        "L89324",  # Pressure ulcer of left buttock, stage 4
        "L8942",  # Pressure ulcer of contiguous site of back, buttock and hip, stage 2
        "L8943",  # Pressure ulcer of contiguous site of back, buttock and hip, stage 3
        "L8944",  # Pressure ulcer of contiguous site of back, buttock and hip, stage 4
        "L8945",  # Pressure ulcer of contiguous site of back, buttock and hip, unstageable
        "L89500",  # Pressure ulcer of unspecified ankle, unstageable
        "L89502",  # Pressure ulcer of unspecified ankle, stage 2
        "L89503",  # Pressure ulcer of unspecified ankle, stage 3
        "L89504",  # Pressure ulcer of unspecified ankle, stage 4
        "L89510",  # Pressure ulcer of right ankle, unstageable
        "L89512",  # Pressure ulcer of right ankle, stage 2
        "L89513",  # Pressure ulcer of right ankle, stage 3
        "L89514",  # Pressure ulcer of right ankle, stage 4
        "L89520",  # Pressure ulcer of left ankle, unstageable
        "L89522",  # Pressure ulcer of left ankle, stage 2
        "L89523",  # Pressure ulcer of left ankle, stage 3
        "L89524",  # Pressure ulcer of left ankle, stage 4
        "L89600",  # Pressure ulcer of unspecified heel, unstageable
        "L89602",  # Pressure ulcer of unspecified heel, stage 2
        "L89603",  # Pressure ulcer of unspecified heel, stage 3
        "L89604",  # Pressure ulcer of unspecified heel, stage 4
        "L89610",  # Pressure ulcer of right heel, unstageable
        "L89612",  # Pressure ulcer of right heel, stage 2
        "L89613",  # Pressure ulcer of right heel, stage 3
        "L89614",  # Pressure ulcer of right heel, stage 4
        "L89620",  # Pressure ulcer of left heel, unstageable
        "L89622",  # Pressure ulcer of left heel, stage 2
        "L89623",  # Pressure ulcer of left heel, stage 3
        "L89624",  # Pressure ulcer of left heel, stage 4
        "L89810",  # Pressure ulcer of head, unstageable
        "L89812",  # Pressure ulcer of head, stage 2
        "L89813",  # Pressure ulcer of head, stage 3
        "L89814",  # Pressure ulcer of head, stage 4
        "L89890",  # Pressure ulcer of other site, unstageable
        "L89892",  # Pressure ulcer of other site, stage 2
        "L89893",  # Pressure ulcer of other site, stage 3
        "L89894",  # Pressure ulcer of other site, stage 4
        "L8992",  # Pressure ulcer of unspecified site, stage 2
        "L8993",  # Pressure ulcer of unspecified site, stage 3
        "L8994",  # Pressure ulcer of unspecified site, stage 4
        "L8995",  # Pressure ulcer of unspecified site, unstageable
    }

class HighRiskDiagnosisForAki(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for diagnoses that puts patients at risk for developing acute kidney injury (AKI)

    **Data Element Scope:** This value set may use a model element related to Diagnosis

    **Inclusion Criteria:** Includes concepts related to large body surface area (BSA) burns, thrombotic thrombocytopenic purpura (TTP), hemolytic uremic syndrome (HUS), traumatic avulsion of the kidney, and nephritic syndrome

    **Exclusion Criteria:** N/A
    """

    VALUE_SET_NAME = "High Risk Diagnosis for AKI"
    OID = "2.16.840.1.113762.1.4.1248.12"
    DEFINITION_VERSION = "20240112"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    ICD10CM = {
        "D5930",  # Hemolytic-uremic syndrome, unspecified
        "D5931",  # Infection-associated hemolytic-uremic syndrome
        "D5932",  # Hereditary hemolytic-uremic syndrome
        "D5939",  # Other hemolytic-uremic syndrome
        "I462",  # Cardiac arrest due to underlying cardiac condition
        "I468",  # Cardiac arrest due to other underlying condition
        "I469",  # Cardiac arrest, cause unspecified
        "M3110",  # Thrombotic microangiopathy, unspecified
        "M3111",  # Hematopoietic stem cell transplantation-associated thrombotic microangiopathy [HSCT-TMA]
        "M3119",  # Other thrombotic microangiopathy
        "N010",  # Rapidly progressive nephritic syndrome with minor glomerular abnormality
        "N011",  # Rapidly progressive nephritic syndrome with focal and segmental glomerular lesions
        "N012",  # Rapidly progressive nephritic syndrome with diffuse membranous glomerulonephritis
        "N013",  # Rapidly progressive nephritic syndrome with diffuse mesangial proliferative glomerulonephritis
        "N014",  # Rapidly progressive nephritic syndrome with diffuse endocapillary proliferative glomerulonephritis
        "N015",  # Rapidly progressive nephritic syndrome with diffuse mesangiocapillary glomerulonephritis
        "N016",  # Rapidly progressive nephritic syndrome with dense deposit disease
        "N017",  # Rapidly progressive nephritic syndrome with diffuse crescentic glomerulonephritis
        "N018",  # Rapidly progressive nephritic syndrome with other morphologic changes
        "N019",  # Rapidly progressive nephritic syndrome with unspecified morphologic changes
        "N01A",  # Rapidly progressive nephritic syndrome with C3 glomerulonephritis
        "S37061A",  # Major laceration of right kidney, initial encounter
        "S37062A",  # Major laceration of left kidney, initial encounter
        "S37069A",  # Major laceration of unspecified kidney, initial encounter
        "T3140",  # Burns involving 40-49% of body surface with 0% to 9% third degree burns
        "T3141",  # Burns involving 40-49% of body surface with 10-19% third degree burns
        "T3142",  # Burns involving 40-49% of body surface with 20-29% third degree burns
        "T3143",  # Burns involving 40-49% of body surface with 30-39% third degree burns
        "T3144",  # Burns involving 40-49% of body surface with 40-49% third degree burns
        "T3150",  # Burns involving 50-59% of body surface with 0% to 9% third degree burns
        "T3151",  # Burns involving 50-59% of body surface with 10-19% third degree burns
        "T3152",  # Burns involving 50-59% of body surface with 20-29% third degree burns
        "T3153",  # Burns involving 50-59% of body surface with 30-39% third degree burns
        "T3154",  # Burns involving 50-59% of body surface with 40-49% third degree burns
        "T3155",  # Burns involving 50-59% of body surface with 50-59% third degree burns
        "T3160",  # Burns involving 60-69% of body surface with 0% to 9% third degree burns
        "T3161",  # Burns involving 60-69% of body surface with 10-19% third degree burns
        "T3162",  # Burns involving 60-69% of body surface with 20-29% third degree burns
        "T3163",  # Burns involving 60-69% of body surface with 30-39% third degree burns
        "T3164",  # Burns involving 60-69% of body surface with 40-49% third degree burns
        "T3165",  # Burns involving 60-69% of body surface with 50-59% third degree burns
        "T3166",  # Burns involving 60-69% of body surface with 60-69% third degree burns
        "T3170",  # Burns involving 70-79% of body surface with 0% to 9% third degree burns
        "T3171",  # Burns involving 70-79% of body surface with 10-19% third degree burns
        "T3172",  # Burns involving 70-79% of body surface with 20-29% third degree burns
        "T3173",  # Burns involving 70-79% of body surface with 30-39% third degree burns
        "T3174",  # Burns involving 70-79% of body surface with 40-49% third degree burns
        "T3175",  # Burns involving 70-79% of body surface with 50-59% third degree burns
        "T3176",  # Burns involving 70-79% of body surface with 60-69% third degree burns
        "T3177",  # Burns involving 70-79% of body surface with 70-79% third degree burns
        "T3180",  # Burns involving 80-89% of body surface with 0% to 9% third degree burns
        "T3181",  # Burns involving 80-89% of body surface with 10-19% third degree burns
        "T3182",  # Burns involving 80-89% of body surface with 20-29% third degree burns
        "T3183",  # Burns involving 80-89% of body surface with 30-39% third degree burns
        "T3184",  # Burns involving 80-89% of body surface with 40-49% third degree burns
        "T3185",  # Burns involving 80-89% of body surface with 50-59% third degree burns
        "T3186",  # Burns involving 80-89% of body surface with 60-69% third degree burns
        "T3187",  # Burns involving 80-89% of body surface with 70-79% third degree burns
        "T3188",  # Burns involving 80-89% of body surface with 80-89% third degree burns
        "T3190",  # Burns involving 90% or more of body surface with 0% to 9% third degree burns
        "T3191",  # Burns involving 90% or more of body surface with 10-19% third degree burns
        "T3192",  # Burns involving 90% or more of body surface with 20-29% third degree burns
        "T3193",  # Burns involving 90% or more of body surface with 30-39% third degree burns
        "T3194",  # Burns involving 90% or more of body surface with 40-49% third degree burns
        "T3195",  # Burns involving 90% or more of body surface with 50-59% third degree burns
        "T3196",  # Burns involving 90% or more of body surface with 60-69% third degree burns
        "T3197",  # Burns involving 90% or more of body surface with 70-79% third degree burns
        "T3198",  # Burns involving 90% or more of body surface with 80-89% third degree burns
        "T3199",  # Burns involving 90% or more of body surface with 90% or more third degree burns
    }

class UndetectableLabResultValue(ValueSet):
    """
    **Clinical Focus:** This value set contains concepts that represent undetectable lab result values for urine albumin or urine creatinine.

    **Data Element Scope:** This value set may use the model category related to Laboratory Test. Codes include values that represent undetectable lab result values commonly used for urine albumin or urine creatinine.

    **Inclusion Criteria:** Includes only relevant concepts associated with undetected lab result values.

    **Exclusion Criteria:** Excludes concepts representing negative lab result values.
    """

    VALUE_SET_NAME = "Undetectable Lab Result Value"
    OID = "2.16.840.1.113762.1.4.1248.272"
    DEFINITION_VERSION = "20241024"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "131194007",  # Non-Reactive (qualifier value)
        "260389003",  # No reaction (qualifier value)
        "260415000",  # Not detected (qualifier value)
        "260988000",  # Below threshold level (qualifier value)
        "2667000",  # Absent (qualifier value)
        "272519000",  # Absence findings (qualifier value)
        "281297005",  # Analyte not detected (qualifier value)
        "371928007",  # Not significant (qualifier value)
        "444991000124106",  # Repeatedly non-reactive (qualifier value)
        "47492008",  # Not seen (qualifier value)
    }

class MalnutritionScreeningFindingOfAtRiskResult(ValueSet):
    """
    **Clinical Focus:** Malnutrition screening result of at risk for malnutrition.

    **Data Element Scope:** Result finding that indicates a patient is at risk for malnutrition.

    **Inclusion Criteria:** Positive at risk finding for malnutrition.

    **Exclusion Criteria:** Not at risk finding for malnutrition.
    """

    VALUE_SET_NAME = "Malnutrition Screening Finding of At Risk Result"
    OID = "2.16.840.1.113762.1.4.1095.89"
    DEFINITION_VERSION = "20240117"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    LOINC = {
        "LA27538-0",  # At risk for malnutrition
    }

    SNOMEDCT = {
        "129689002",  # At increased risk for nutritional problem (finding)
        "129845004",  # At increased risk for imbalanced nutrition, less than body requirements (finding)
        "700361001",  # Predicted inadequate nutrient intake (finding)
        "704361005",  # At increased risk of deficient food intake (finding)
    }

class MalnutritionScreeningFindingOfNotAtRiskResult(ValueSet):
    """
    **Clinical Focus:** Malnutrition screening result of not at risk for malnutrition.

    **Data Element Scope:** Result finding that indicates a patient is not at risk for malnutrition.

    **Inclusion Criteria:** Screening result which indicates an individual is not at risk for malnutrition.

    **Exclusion Criteria:** At risk finding for malnutrition.
    """

    VALUE_SET_NAME = "Malnutrition Screening Finding of Not At Risk Result"
    OID = "2.16.840.1.113762.1.4.1095.34"
    DEFINITION_VERSION = "20240117"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    LOINC = {
        "LA33699-2",  # Not at risk for malnutrition
    }

class NutritionAssessmentStatusFindingOfModeratelyMalnourished(ValueSet):
    """
    **Clinical Focus:** Malnutrition assessment of a patient based upon clinically relevant criteria indicates that an individual is moderately malnourished.

    **Data Element Scope:** This set of values indicates that an individual is moderately malnourished.

    **Inclusion Criteria:** Terms related to moderately malnourished are included.

    **Exclusion Criteria:** Nutrition screening data and/or data indicating that an individual is not, mildly, or severely malnourished.
    """

    VALUE_SET_NAME = "Nutrition Assessment Status Finding of Moderately Malnourished"
    OID = "2.16.840.1.113762.1.4.1095.47"
    DEFINITION_VERSION = "20240117"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    LOINC = {
        "LA33704-0",  # Moderately malnourished
    }

    SNOMEDCT = {
        "102636009",  # Chronic nutritional deficiency (finding)
        "190606006",  # Moderate protein energy malnutrition (disorder)
        "238107002",  # Deficiency of macronutrients (disorder)
        "238111008",  # Deficiency of micronutrients (disorder)
        "2492009",  # Nutritional disorder (disorder)
        "285588004",  # Nutrition deficiency due to insufficient food (disorder)
        "441961000124100",  # Acute disease or injury-related malnutrition (disorder)
        "441971000124107",  # Chronic disease-related malnutrition (disorder)
        "448765001",  # Unintentional weight loss (finding)
        "65404009",  # Undernutrition (disorder)
        "70241007",  # Nutritional deficiency disorder (disorder)
    }

class NutritionAssessmentStatusFindingOfSeverelyMalnourished(ValueSet):
    """
    **Clinical Focus:** Malnutrition assessment of a patient based upon clinically relevant criteria indicates that an individual is severely malnourished.

    **Data Element Scope:** This set of values indicates that an individual is severely malnourished.

    **Inclusion Criteria:** Terms related to severely malnourished are included.

    **Exclusion Criteria:** Nutrition screening data and/or data indicating that an individual is not, mildly, or moderately malnourished.
    """

    VALUE_SET_NAME = "Nutrition Assessment Status Finding of Severely Malnourished"
    OID = "2.16.840.1.113762.1.4.1095.43"
    DEFINITION_VERSION = "20240117"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    LOINC = {
        "LA33705-7",  # Severely malnourished
    }

    SNOMEDCT = {
        "102635008",  # Acute nutritional deficiency (finding)
        "129588001",  # Adult failure to thrive syndrome (disorder)
        "238108007",  # Cachexia (finding)
        "272588001",  # Malnutrition (calorie) (disorder)
        "281583001",  # Nutritional wasting (disorder)
        "288517002",  # Wasting disease (disorder)
        "371597004",  # Emaciated (finding)
        "432788009",  # Pediatric failure to thrive (disorder)
        "441951000124102",  # Starvation-related malnutrition (disorder)
        "54840006",  # Failure to thrive (disorder)
        "56882008",  # Anorexia nervosa (disorder)
        "722959000",  # Anorexia nervosa co-occurrent with dangerously low body weight (disorder)
        "722960005",  # Anorexia nervosa co-occurrent with significantly low body weight (disorder)
        "723917005",  # Dangerously low body weight co-occurrent and due to anorexia nervosa of restricting type (disorder)
        "723919008",  # Significantly low body weight co-occurrent and due to anorexia nervosa of restricting type (disorder)
        "772791006",  # Sarcopenia (disorder)
        "77675002",  # Anorexia nervosa, restricting type (disorder)
        "788876001",  # Cachexia due to malignant neoplastic disease (finding)
    }

class NutritionAssessmentStatusFindingOfWellNourishedOrNotMalnourishedOrMildlyMalnourished(ValueSet):
    """
    **Clinical Focus:** This set of values indicates that a nutrition assessment, completed by a health professional, finds the individual to be well nourished or not malnourished or mildly malnourished.

    **Data Element Scope:** This set of values indicates that an individual is well nourished or not malnourished or mildly malnourished.

    **Inclusion Criteria:** Terms related to well nourished, not malnourished, and mildly malnourished are included.

    **Exclusion Criteria:** Nutrition screening data and/or data indicating that an individual is moderately or severely malnourished.
    """

    VALUE_SET_NAME = "Nutrition Assessment Status Finding of Well Nourished or Not Malnourished or Mildly Malnourished"
    OID = "2.16.840.1.113762.1.4.1095.96"
    DEFINITION_VERSION = "20240117"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    LOINC = {
        "LA33701-6",  # Well nourished
        "LA33702-4",  # Not malnourished
        "LA33703-2",  # Mildly malnourished
    }

    SNOMEDCT = {
        "248324001",  # Well nourished (finding)
    }

class DrugInterventionNotIndicatedContraindicated(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts of contraindication for drug intervention

    **Data Element Scope:** This value set may use a model element related to Negation Rationale.

    **Inclusion Criteria:** Includes concepts that represent a negation rationale or reason for not providing drug treatment

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Drug Intervention Not Indicated/Contraindicated"
    OID = "2.16.840.1.113762.1.4.1282.1"
    DEFINITION_VERSION = "20241121"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "183932001",  # Procedure contraindicated (situation)
        "183964008",  # Treatment not indicated (situation)
        "183966005",  # Drug treatment not indicated (situation)
        "407563006",  # Treatment not tolerated (situation)
        "410536001",  # Contraindicated (qualifier value)
        "416098002",  # Allergy to drug (finding)
        "428119001",  # Procedure not indicated (situation)
        "62014003",  # Adverse reaction caused by drug (disorder)
        "79899007",  # Drug interaction (finding)
    }

class ProcedureNotIndicatedContraindicated(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts of procedure not indicated/contraindicated

    **Data Element Scope:** This value set may use a model element related to Negation Rationale.

    **Inclusion Criteria:** Includes concepts that represent a negation rationale or reason for not performing procedure

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Procedure Not Indicated/Contraindicated"
    OID = "2.16.840.1.113762.1.4.1282.2"
    DEFINITION_VERSION = "20241121"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "183932001",  # Procedure contraindicated (situation)
        "183964008",  # Treatment not indicated (situation)
        "407563006",  # Treatment not tolerated (situation)
        "410534003",  # Not indicated (qualifier value)
        "410536001",  # Contraindicated (qualifier value)
        "428119001",  # Procedure not indicated (situation)
    }

class ThrombolyticsAdverseEvent(ValueSet):
    """
    **Clinical Focus:** The purpose of this value set is to represent concepts for adverse reactions to thrombolytic medications used for treatment of ST-segment elevation myocardial infaction (STEMI).

    **Data Element Scope:** This value set may use a model element related to Disorder.

    **Inclusion Criteria:** Includes SNOMED-CT codes that represent adverse reactions to thrombolytic medications for STEMI treatment.

    **Exclusion Criteria:** No exclusions.
    """

    VALUE_SET_NAME = "Thrombolytics Adverse Event"
    OID = "2.16.840.1.113762.1.4.1170.6"
    DEFINITION_VERSION = "20250211"
    EXPANSION_VERSION = "eCQM Update 2025-05-08"

    SNOMEDCT = {
        "1300134005",  # Adverse reaction to reteplase (disorder)
        "1300137003",  # Adverse reaction to tenecteplase (disorder)
        "218568007",  # Adverse reaction caused by fibrinolytic drugs (disorder)
        "293571007",  # Streptokinase adverse reaction (disorder)
        "293572000",  # Urokinase adverse reaction (disorder)
        "293573005",  # Alteplase adverse reaction (disorder)
        "293574004",  # Anistreplase adverse reaction (disorder)
    }

__exports__ = (
    "AbnormalWeightLoss",
    "CoagulationDisorders",
    "DeliriumOrDementiaAndOtherPsychoses",
    "Depression",
    "Epilepsy",
    "LeukemiaOrLymphoma",
    "LiverDiseaseModerateToSevere",
    "MajorInjuries",
    "MalignantBoneDisease",
    "Malnutrition",
    "ModerateInjuries",
    "NeurologicMovementAndRelatedDisorders",
    "NotPresentOnAdmissionOrDocumentationInsufficientToDetermine",
    "Obesity",
    "Osteoporosis",
    "PeripheralNeuropathy",
    "PresentOnAdmissionOrClinicallyUndetermined",
    "Stroke",
    "SuicideAttempt",
    "TwentyToFortyTwoPlusWeeksGestation",
    "AcuteHeartFailure",
    "AcuteMyocardialInfarction",
    "AcuteRenalFailure",
    "AcuteRespiratoryDistressSyndrome",
    "AcuteOrPersistentAsthma",
    "AirAndThromboticEmbolism",
    "AmnioticFluidEmbolism",
    "Anemia",
    "AorticAneurysm",
    "AutoimmuneDisease",
    "BariatricSurgery",
    "BleedingDisorder",
    "CardiacArrestVentricularFibrillation",
    "CardiacDisease",
    "DisseminatedIntravascularCoagulation",
    "Eclampsia",
    "EconomicHousingInstability",
    "GastrointestinalDisease",
    "GestationalDiabetes",
    "HivInPregnancyChildbirthAndPuerperium",
    "HeartFailureCardiacArrestRelatedToProcedureOrSurgery",
    "Hypertension",
    "LongTermAnticoagulantUse",
    "MentalHealthDisorder",
    "MildOrModeratePreeclampsia",
    "MorbidOrSevereObesity",
    "MultiplePregnancy",
    "NeuromuscularDisease",
    "PatientExpired",
    "PlacentaAccreta",
    "PlacentaIncretaOrPercreta",
    "PlacentaPrevia",
    "PlacentalAbruption",
    "PreexistingDiabetes",
    "PresentOnAdmissionIsYesOrExempt",
    "PresentOnAdmissionIsNoOrUnableToDetermine",
    "PretermBirth",
    "PreviousCesarean",
    "PuerperalCerebrovascularDisorder",
    "PulmonaryEdema",
    "PulmonaryHypertension",
    "RenalDisease",
    "Sepsis",
    "SevereAnesthesiaComplications",
    "SevereMaternalMorbidityDiagnoses",
    "SeverePreeclampsia",
    "Shock",
    "SickleCellDiseaseWithCrisis",
    "SubstanceAbuse",
    "Thyrotoxicosis",
    "VenousThromboembolismInPregnancy",
    "DischargeToAcuteCareFacility",
    "DischargedToHealthCareFacilityForHospiceCare",
    "DischargedToHomeForHospiceCare",
    "IschemicStroke",
    "LeftAgainstMedicalAdvice",
    "MedicalReasonForNotProvidingTreatment",
    "PatientRefusal",
    "HemorrhagicStroke",
    "IntensiveCareUnit",
    "IntravenousRoute",
    "LowRisk",
    "MentalHealthDiagnoses",
    "ObstetricalOrPregnancyRelatedConditions",
    "ObstetricsVte",
    "SubcutaneousRoute",
    "ProviderTypes",
    "VteDiagnoses",
    "VteSymptoms",
    "AsaPhysicalStatusClass",
    "AcuteRespiratoryFailure",
    "DegenerativeNeurologicalDisorder",
    "NeuromuscularDisorder",
    "ProceduralHospitalLocations",
    "SmokingStatus",
    "TracheostomyDiagnoses",
    "AdmitInpatient",
    "EmergencyDepartmentLocation",
    "EmergencyDepartmentTreatmentLocation",
    "MentalHealthDiagnosisWithoutSubstanceUseDisorders",
    "AutonomousEyeExamResultOrFinding",
    "DiabeticRetinopathySeverityLevel",
    "VisualAcuity2040OrBetter",
    "MedicalReason",
    "ModerateOrSevere",
    "PatientReason",
    "PatientReasonForAceInhibitorOrArbDecline",
    "Ambulatory",
    "MentalBehavioralAndNeurodevelopmentalDisorders",
    "TobaccoNonUser",
    "TobaccoUser",
    "MajorDepressiveDisorderActive",
    "FindingOfElevatedBloodPressureOrHypertension",
    "PatientDeclined",
    "ThirtySevenToFortyTwoPlusWeeksGestation",
    "DeliveryOfSingleton",
    "GenitalHerpes",
    "PlacentaAccretaSpectrumPreviaOrVasaPrevia",
    "HospiceCareReferralOrAdmission",
    "UnavailabilityOfBacillusCalmetteGuerinForUrologyCare",
    "RoutesOfAdministrationForOpioidAntagonists",
    "PressureInjuryDeepTissue",
    "PressureInjuryDeepTissueDiagnoses",
    "PressureInjuryStage234OrUnstageable",
    "PressureInjuryStage234OrUnstageableDiagnoses",
    "HighRiskDiagnosisForAki",
    "UndetectableLabResultValue",
    "MalnutritionScreeningFindingOfAtRiskResult",
    "MalnutritionScreeningFindingOfNotAtRiskResult",
    "NutritionAssessmentStatusFindingOfModeratelyMalnourished",
    "NutritionAssessmentStatusFindingOfSeverelyMalnourished",
    "NutritionAssessmentStatusFindingOfWellNourishedOrNotMalnourishedOrMildlyMalnourished",
    "DrugInterventionNotIndicatedContraindicated",
    "ProcedureNotIndicatedContraindicated",
    "ThrombolyticsAdverseEvent",
)
